/* display-toolbar.c generated by valac 0.29.2.1-265d, the Vala compiler
 * generated from display-toolbar.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <gdk/gdk.h>
#include <float.h>
#include <math.h>


#define BOXES_TYPE_DISPLAY_TOOLBAR (boxes_display_toolbar_get_type ())
#define BOXES_DISPLAY_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_TOOLBAR, BoxesDisplayToolbar))
#define BOXES_DISPLAY_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_TOOLBAR, BoxesDisplayToolbarClass))
#define BOXES_IS_DISPLAY_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_TOOLBAR))
#define BOXES_IS_DISPLAY_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_TOOLBAR))
#define BOXES_DISPLAY_TOOLBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_TOOLBAR, BoxesDisplayToolbarClass))

typedef struct _BoxesDisplayToolbar BoxesDisplayToolbar;
typedef struct _BoxesDisplayToolbarClass BoxesDisplayToolbarClass;
typedef struct _BoxesDisplayToolbarPrivate BoxesDisplayToolbarPrivate;

#define BOXES_TYPE_APP_WINDOW (boxes_app_window_get_type ())
#define BOXES_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindow))
#define BOXES_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))
#define BOXES_IS_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP_WINDOW))
#define BOXES_IS_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP_WINDOW))
#define BOXES_APP_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))

typedef struct _BoxesAppWindow BoxesAppWindow;
typedef struct _BoxesAppWindowClass BoxesAppWindowClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
typedef struct _Block25Data Block25Data;

#define BOXES_TYPE_ACTIONS_POPOVER (boxes_actions_popover_get_type ())
#define BOXES_ACTIONS_POPOVER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_ACTIONS_POPOVER, BoxesActionsPopover))
#define BOXES_ACTIONS_POPOVER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_ACTIONS_POPOVER, BoxesActionsPopoverClass))
#define BOXES_IS_ACTIONS_POPOVER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_ACTIONS_POPOVER))
#define BOXES_IS_ACTIONS_POPOVER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_ACTIONS_POPOVER))
#define BOXES_ACTIONS_POPOVER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_ACTIONS_POPOVER, BoxesActionsPopoverClass))

typedef struct _BoxesActionsPopover BoxesActionsPopover;
typedef struct _BoxesActionsPopoverClass BoxesActionsPopoverClass;

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_UI_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_UI, BoxesUIIface))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIIface BoxesUIIface;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_KEYS_INPUT_POPOVER (boxes_keys_input_popover_get_type ())
#define BOXES_KEYS_INPUT_POPOVER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_KEYS_INPUT_POPOVER, BoxesKeysInputPopover))
#define BOXES_KEYS_INPUT_POPOVER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_KEYS_INPUT_POPOVER, BoxesKeysInputPopoverClass))
#define BOXES_IS_KEYS_INPUT_POPOVER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_KEYS_INPUT_POPOVER))
#define BOXES_IS_KEYS_INPUT_POPOVER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_KEYS_INPUT_POPOVER))
#define BOXES_KEYS_INPUT_POPOVER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_KEYS_INPUT_POPOVER, BoxesKeysInputPopoverClass))

typedef struct _BoxesKeysInputPopover BoxesKeysInputPopover;
typedef struct _BoxesKeysInputPopoverClass BoxesKeysInputPopoverClass;
#define __vala_GdkEvent_free0(var) ((var == NULL) ? NULL : (var = (_vala_GdkEvent_free (var), NULL)))
#define __vala_GdkEventMotion_free0(var) ((var == NULL) ? NULL : (var = (_vala_GdkEventMotion_free (var), NULL)))
typedef struct _Block26Data Block26Data;
typedef struct _Block27Data Block27Data;

struct _BoxesDisplayToolbar {
	GtkHeaderBar parent_instance;
	BoxesDisplayToolbarPrivate * priv;
};

struct _BoxesDisplayToolbarClass {
	GtkHeaderBarClass parent_class;
};

struct _BoxesDisplayToolbarPrivate {
	gboolean _overlay;
	gboolean _handle_drag;
	GtkImage* fullscreen_image;
	GtkButton* back;
	GtkButton* fullscreen;
	GtkMenuButton* menu_button;
	GtkMenuButton* keys_menu_button;
	BoxesAppWindow* window;
	gboolean button_down;
	gint button_down_x;
	gint button_down_y;
	guint button_down_button;
};

struct _Block25Data {
	int _ref_count_;
	BoxesDisplayToolbar* self;
	BoxesAppWindow* window;
};

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUIIface {
	GTypeInterface parent_iface;
	BoxesUIState (*get_previous_ui_state) (BoxesUI* self);
	void (*set_previous_ui_state) (BoxesUI* self, BoxesUIState value);
	BoxesUIState (*get_ui_state) (BoxesUI* self);
	void (*set_ui_state) (BoxesUI* self, BoxesUIState value);
};

struct _Block26Data {
	int _ref_count_;
	BoxesDisplayToolbar* self;
	GdkEventMotion* event;
};

struct _Block27Data {
	int _ref_count_;
	Block26Data * _data26_;
	GtkWindow* window;
	gint old_width;
	gulong id;
};


static gpointer boxes_display_toolbar_parent_class = NULL;
extern BoxesApp* boxes_app_app;

GType boxes_display_toolbar_get_type (void) G_GNUC_CONST;
GType boxes_app_window_get_type (void) G_GNUC_CONST;
#define BOXES_DISPLAY_TOOLBAR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_DISPLAY_TOOLBAR, BoxesDisplayToolbarPrivate))
enum  {
	BOXES_DISPLAY_TOOLBAR_DUMMY_PROPERTY,
	BOXES_DISPLAY_TOOLBAR_OVERLAY,
	BOXES_DISPLAY_TOOLBAR_HANDLE_DRAG
};
BoxesDisplayToolbar* boxes_display_toolbar_new (gboolean overlay, gboolean handle_drag);
BoxesDisplayToolbar* boxes_display_toolbar_construct (GType object_type, gboolean overlay, gboolean handle_drag);
void boxes_display_toolbar_setup_ui (BoxesDisplayToolbar* self, BoxesAppWindow* window);
static Block25Data* block25_data_ref (Block25Data* _data25_);
static void block25_data_unref (void * _userdata_);
BoxesActionsPopover* boxes_actions_popover_new (BoxesAppWindow* window);
BoxesActionsPopover* boxes_actions_popover_construct (GType object_type, BoxesAppWindow* window);
GType boxes_actions_popover_get_type (void) G_GNUC_CONST;
GType boxes_app_get_type (void) G_GNUC_CONST;
static void __lambda57_ (Block25Data* _data25_);
BoxesAppWindow* boxes_app_get_main_window (BoxesApp* self);
static void ___lambda57__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void __lambda58_ (Block25Data* _data25_);
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
BoxesUIState boxes_ui_get_ui_state (BoxesUI* self);
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
void boxes_actions_popover_update_for_item (BoxesActionsPopover* self, BoxesCollectionItem* item);
BoxesCollectionItem* boxes_app_window_get_current_item (BoxesAppWindow* self);
static void ___lambda58__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
BoxesKeysInputPopover* boxes_keys_input_popover_new (BoxesAppWindow* window);
BoxesKeysInputPopover* boxes_keys_input_popover_construct (GType object_type, BoxesAppWindow* window);
GType boxes_keys_input_popover_get_type (void) G_GNUC_CONST;
static gboolean boxes_display_toolbar_real_button_press_event (GtkWidget* base, GdkEventButton* event);
gboolean boxes_display_toolbar_get_handle_drag (BoxesDisplayToolbar* self);
static GdkEvent* _vala_GdkEvent_copy (GdkEvent* self);
static void _vala_GdkEvent_free (GdkEvent* self);
static gboolean boxes_display_toolbar_real_button_release_event (GtkWidget* base, GdkEventButton* event);
static gboolean boxes_display_toolbar_real_motion_notify_event (GtkWidget* base, GdkEventMotion* event);
static GdkEventMotion* _vala_GdkEventMotion_copy (GdkEventMotion* self);
static void _vala_GdkEventMotion_free (GdkEventMotion* self);
static Block26Data* block26_data_ref (Block26Data* _data26_);
static void block26_data_unref (void * _userdata_);
static Block27Data* block27_data_ref (Block27Data* _data27_);
static void block27_data_unref (void * _userdata_);
void boxes_app_window_set_fullscreened (BoxesAppWindow* self, gboolean value);
static void ____lambda59_ (Block27Data* _data27_);
static void _____lambda59__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void boxes_display_toolbar_on_back_clicked (BoxesDisplayToolbar* self);
void boxes_ui_set_state (BoxesUI* self, BoxesUIState new_state);
static void _boxes_display_toolbar_on_back_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
static void boxes_display_toolbar_on_fullscreen_clicked (BoxesDisplayToolbar* self);
gboolean boxes_app_window_get_fullscreened (BoxesAppWindow* self);
static void _boxes_display_toolbar_on_fullscreen_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
gboolean boxes_display_toolbar_get_overlay (BoxesDisplayToolbar* self);
static void boxes_display_toolbar_set_overlay (BoxesDisplayToolbar* self, gboolean value);
static void boxes_display_toolbar_set_handle_drag (BoxesDisplayToolbar* self, gboolean value);
static GObject * boxes_display_toolbar_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static void _boxes_display_toolbar___lambda60_ (BoxesDisplayToolbar* self);
static void __boxes_display_toolbar___lambda60__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void boxes_display_toolbar_finalize (GObject* obj);
static void _vala_boxes_display_toolbar_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_boxes_display_toolbar_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);


BoxesDisplayToolbar* boxes_display_toolbar_construct (GType object_type, gboolean overlay, gboolean handle_drag) {
	BoxesDisplayToolbar * self = NULL;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp0_ = overlay;
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp1_ = handle_drag;
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	self = (BoxesDisplayToolbar*) g_object_new (object_type, "overlay", _tmp0_, "handle-drag", _tmp1_, NULL);
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	return self;
#line 232 "display-toolbar.c"
}


BoxesDisplayToolbar* boxes_display_toolbar_new (gboolean overlay, gboolean handle_drag) {
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	return boxes_display_toolbar_construct (BOXES_TYPE_DISPLAY_TOOLBAR, overlay, handle_drag);
#line 239 "display-toolbar.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	return self ? g_object_ref (self) : NULL;
#line 246 "display-toolbar.c"
}


static Block25Data* block25_data_ref (Block25Data* _data25_) {
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	g_atomic_int_inc (&_data25_->_ref_count_);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	return _data25_;
#line 255 "display-toolbar.c"
}


static void block25_data_unref (void * _userdata_) {
	Block25Data* _data25_;
	_data25_ = (Block25Data*) _userdata_;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	if (g_atomic_int_dec_and_test (&_data25_->_ref_count_)) {
#line 264 "display-toolbar.c"
		BoxesDisplayToolbar* self;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		self = _data25_->self;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_g_object_unref0 (_data25_->window);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_g_object_unref0 (self);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		g_slice_free (Block25Data, _data25_);
#line 274 "display-toolbar.c"
	}
}


static void __lambda57_ (Block25Data* _data25_) {
	BoxesDisplayToolbar* self;
	GtkButton* _tmp0_ = NULL;
	BoxesAppWindow* _tmp1_ = NULL;
	BoxesApp* _tmp2_ = NULL;
	BoxesAppWindow* _tmp3_ = NULL;
	BoxesAppWindow* _tmp4_ = NULL;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	self = _data25_->self;
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp0_ = self->priv->back;
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp1_ = _data25_->window;
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp2_ = boxes_app_app;
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp3_ = boxes_app_get_main_window (_tmp2_);
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp4_ = _tmp3_;
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	gtk_widget_set_visible ((GtkWidget*) _tmp0_, _tmp1_ == _tmp4_);
#line 300 "display-toolbar.c"
}


static void ___lambda57__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	__lambda57_ (self);
#line 307 "display-toolbar.c"
}


static void __lambda58_ (Block25Data* _data25_) {
	BoxesDisplayToolbar* self;
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesUIState _tmp1_ = 0;
	BoxesUIState _tmp2_ = 0;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	self = _data25_->self;
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp0_ = _data25_->window;
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp1_ = boxes_ui_get_ui_state ((BoxesUI*) _tmp0_);
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp2_ = _tmp1_;
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	if (_tmp2_ == BOXES_UI_STATE_DISPLAY) {
#line 326 "display-toolbar.c"
		GtkMenuButton* _tmp3_ = NULL;
		GtkPopover* _tmp4_ = NULL;
		GtkPopover* _tmp5_ = NULL;
		BoxesAppWindow* _tmp6_ = NULL;
		BoxesCollectionItem* _tmp7_ = NULL;
		BoxesCollectionItem* _tmp8_ = NULL;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp3_ = self->priv->menu_button;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp4_ = gtk_menu_button_get_popover (_tmp3_);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp5_ = _tmp4_;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp6_ = _data25_->window;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp7_ = boxes_app_window_get_current_item (_tmp6_);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp8_ = _tmp7_;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		boxes_actions_popover_update_for_item (G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, BOXES_TYPE_ACTIONS_POPOVER) ? ((BoxesActionsPopover*) _tmp5_) : NULL, _tmp8_);
#line 347 "display-toolbar.c"
	}
}


static void ___lambda58__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	__lambda58_ (self);
#line 355 "display-toolbar.c"
}


void boxes_display_toolbar_setup_ui (BoxesDisplayToolbar* self, BoxesAppWindow* window) {
	Block25Data* _data25_;
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesAppWindow* _tmp1_ = NULL;
	BoxesAppWindow* _tmp2_ = NULL;
	BoxesAppWindow* _tmp3_ = NULL;
	GtkMenuButton* _tmp4_ = NULL;
	BoxesAppWindow* _tmp5_ = NULL;
	BoxesActionsPopover* _tmp6_ = NULL;
	BoxesActionsPopover* _tmp7_ = NULL;
	BoxesApp* _tmp8_ = NULL;
	BoxesAppWindow* _tmp9_ = NULL;
	GtkMenuButton* _tmp10_ = NULL;
	BoxesAppWindow* _tmp11_ = NULL;
	BoxesKeysInputPopover* _tmp12_ = NULL;
	BoxesKeysInputPopover* _tmp13_ = NULL;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	g_return_if_fail (self != NULL);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	g_return_if_fail (window != NULL);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_data25_ = g_slice_new0 (Block25Data);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_data25_->_ref_count_ = 1;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_data25_->self = g_object_ref (self);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp0_ = window;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_g_object_unref0 (_data25_->window);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_data25_->window = _tmp1_;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp2_ = _data25_->window;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_g_object_unref0 (self->priv->window);
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	self->priv->window = _tmp3_;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp4_ = self->priv->menu_button;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp5_ = _data25_->window;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp6_ = boxes_actions_popover_new (_tmp5_);
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	g_object_ref_sink (_tmp6_);
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp7_ = _tmp6_;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	gtk_menu_button_set_popover (_tmp4_, (GtkPopover*) _tmp7_);
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_g_object_unref0 (_tmp7_);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp8_ = boxes_app_app;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	g_signal_connect_data ((GObject*) _tmp8_, "notify::main-window", (GCallback) ___lambda57__g_object_notify, block25_data_ref (_data25_), (GClosureNotify) block25_data_unref, 0);
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp9_ = _data25_->window;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	g_signal_connect_data ((GObject*) _tmp9_, "notify::ui-state", (GCallback) ___lambda58__g_object_notify, block25_data_ref (_data25_), (GClosureNotify) block25_data_unref, 0);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp10_ = self->priv->keys_menu_button;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp11_ = _data25_->window;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp12_ = boxes_keys_input_popover_new (_tmp11_);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	g_object_ref_sink (_tmp12_);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp13_ = _tmp12_;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	gtk_menu_button_set_popover (_tmp10_, (GtkPopover*) _tmp13_);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_g_object_unref0 (_tmp13_);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	block25_data_unref (_data25_);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_data25_ = NULL;
#line 441 "display-toolbar.c"
}


static GdkEvent* _vala_GdkEvent_copy (GdkEvent* self) {
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	return g_boxed_copy (gdk_event_get_type (), self);
#line 448 "display-toolbar.c"
}


static gpointer __vala_GdkEvent_copy0 (gpointer self) {
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	return self ? _vala_GdkEvent_copy (self) : NULL;
#line 455 "display-toolbar.c"
}


static void _vala_GdkEvent_free (GdkEvent* self) {
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	g_boxed_free (gdk_event_get_type (), self);
#line 462 "display-toolbar.c"
}


static gboolean boxes_display_toolbar_real_button_press_event (GtkWidget* base, GdkEventButton* event) {
	BoxesDisplayToolbar * self;
	gboolean result = FALSE;
	gboolean res = FALSE;
	GdkEventButton* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
	GdkEvent* base_event = NULL;
	GdkEventButton* _tmp3_ = NULL;
	GdkEvent* _tmp4_ = NULL;
	gboolean _tmp5_ = FALSE;
	gboolean _tmp6_ = FALSE;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	self = (BoxesDisplayToolbar*) base;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp0_ = event;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp1_ = GTK_WIDGET_CLASS (boxes_display_toolbar_parent_class)->button_press_event ((GtkWidget*) G_TYPE_CHECK_INSTANCE_CAST (self, gtk_header_bar_get_type (), GtkHeaderBar), _tmp0_);
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	res = _tmp1_;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp2_ = self->priv->_handle_drag;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	if (!_tmp2_) {
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		result = res;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		return result;
#line 496 "display-toolbar.c"
	}
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp3_ = event;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp4_ = __vala_GdkEvent_copy0 ((GdkEvent*) _tmp3_);
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	base_event = _tmp4_;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp6_ = res;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	if (!_tmp6_) {
#line 508 "display-toolbar.c"
		GdkEvent* _tmp7_ = NULL;
		gboolean _tmp8_ = FALSE;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp7_ = base_event;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp8_ = gdk_event_triggers_context_menu (_tmp7_);
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp5_ = !_tmp8_;
#line 517 "display-toolbar.c"
	} else {
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp5_ = FALSE;
#line 521 "display-toolbar.c"
	}
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	if (_tmp5_) {
#line 525 "display-toolbar.c"
		GdkEventButton* _tmp9_ = NULL;
		guint _tmp10_ = 0U;
		GdkEventButton* _tmp11_ = NULL;
		gdouble _tmp12_ = 0.0;
		GdkEventButton* _tmp13_ = NULL;
		gdouble _tmp14_ = 0.0;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		self->priv->button_down = TRUE;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp9_ = event;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp10_ = _tmp9_->button;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		self->priv->button_down_button = _tmp10_;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp11_ = event;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp12_ = _tmp11_->x;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		self->priv->button_down_x = (gint) _tmp12_;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp13_ = event;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp14_ = _tmp13_->y;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		self->priv->button_down_y = (gint) _tmp14_;
#line 552 "display-toolbar.c"
	}
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	result = res;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	__vala_GdkEvent_free0 (base_event);
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	return result;
#line 560 "display-toolbar.c"
}


static gboolean boxes_display_toolbar_real_button_release_event (GtkWidget* base, GdkEventButton* event) {
	BoxesDisplayToolbar * self;
	gboolean result = FALSE;
	GdkEventButton* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	self = (BoxesDisplayToolbar*) base;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	self->priv->button_down = FALSE;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp0_ = event;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp1_ = GTK_WIDGET_CLASS (boxes_display_toolbar_parent_class)->button_press_event ((GtkWidget*) G_TYPE_CHECK_INSTANCE_CAST (self, gtk_header_bar_get_type (), GtkHeaderBar), _tmp0_);
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	result = _tmp1_;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	return result;
#line 583 "display-toolbar.c"
}


static GdkEventMotion* _vala_GdkEventMotion_copy (GdkEventMotion* self) {
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	return g_boxed_copy (gdk_event_get_type (), self);
#line 590 "display-toolbar.c"
}


static gpointer __vala_GdkEventMotion_copy0 (gpointer self) {
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	return self ? _vala_GdkEventMotion_copy (self) : NULL;
#line 597 "display-toolbar.c"
}


static void _vala_GdkEventMotion_free (GdkEventMotion* self) {
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	g_boxed_free (gdk_event_get_type (), self);
#line 604 "display-toolbar.c"
}


static Block26Data* block26_data_ref (Block26Data* _data26_) {
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	g_atomic_int_inc (&_data26_->_ref_count_);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	return _data26_;
#line 613 "display-toolbar.c"
}


static void block26_data_unref (void * _userdata_) {
	Block26Data* _data26_;
	_data26_ = (Block26Data*) _userdata_;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	if (g_atomic_int_dec_and_test (&_data26_->_ref_count_)) {
#line 622 "display-toolbar.c"
		BoxesDisplayToolbar* self;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		self = _data26_->self;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		__vala_GdkEventMotion_free0 (_data26_->event);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_g_object_unref0 (self);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		g_slice_free (Block26Data, _data26_);
#line 632 "display-toolbar.c"
	}
}


static Block27Data* block27_data_ref (Block27Data* _data27_) {
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	g_atomic_int_inc (&_data27_->_ref_count_);
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	return _data27_;
#line 642 "display-toolbar.c"
}


static void block27_data_unref (void * _userdata_) {
	Block27Data* _data27_;
	_data27_ = (Block27Data*) _userdata_;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	if (g_atomic_int_dec_and_test (&_data27_->_ref_count_)) {
#line 651 "display-toolbar.c"
		BoxesDisplayToolbar* self;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		self = _data27_->_data26_->self;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_g_object_unref0 (_data27_->window);
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		block26_data_unref (_data27_->_data26_);
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_data27_->_data26_ = NULL;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		g_slice_free (Block27Data, _data27_);
#line 663 "display-toolbar.c"
	}
}


static void ____lambda59_ (Block27Data* _data27_) {
	Block26Data* _data26_;
	BoxesDisplayToolbar* self;
	gint root_x = 0;
	gint root_y = 0;
	gint width = 0;
	GtkWindow* _tmp0_ = NULL;
	gint _tmp1_ = 0;
	gint _tmp2_ = 0;
	GtkWindow* _tmp3_ = NULL;
	GdkWindow* _tmp4_ = NULL;
	gint _tmp5_ = 0;
	GtkWindow* _tmp6_ = NULL;
	guint _tmp7_ = 0U;
	gint _tmp8_ = 0;
	gint _tmp9_ = 0;
	gint _tmp10_ = 0;
	GdkEventMotion* _tmp11_ = NULL;
	guint32 _tmp12_ = 0U;
	BoxesApp* _tmp13_ = NULL;
	gulong _tmp14_ = 0UL;
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_data26_ = _data27_->_data26_;
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	self = _data26_->self;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp0_ = _data27_->window;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	gtk_window_get_position (_tmp0_, &_tmp1_, &_tmp2_);
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	root_x = _tmp1_;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	root_y = _tmp2_;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp3_ = _data27_->window;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp4_ = gtk_widget_get_window ((GtkWidget*) _tmp3_);
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	gdk_window_get_geometry (_tmp4_, NULL, NULL, &_tmp5_, NULL);
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	width = _tmp5_;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp6_ = _data27_->window;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp7_ = self->priv->button_down_button;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp8_ = self->priv->button_down_x;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp9_ = _data27_->old_width;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp10_ = self->priv->button_down_y;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp11_ = _data26_->event;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp12_ = _tmp11_->time;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	gtk_window_begin_move_drag (_tmp6_, (gint) _tmp7_, root_x + ((gint) ((_tmp8_ / ((gdouble) _tmp9_)) * width)), root_y + _tmp10_, _tmp12_);
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp13_ = boxes_app_app;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp14_ = _data27_->id;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	g_signal_handler_disconnect ((GObject*) _tmp13_, _tmp14_);
#line 731 "display-toolbar.c"
}


static void _____lambda59__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	____lambda59_ (self);
#line 738 "display-toolbar.c"
}


static gboolean boxes_display_toolbar_real_motion_notify_event (GtkWidget* base, GdkEventMotion* event) {
	BoxesDisplayToolbar * self;
	gboolean result = FALSE;
	Block26Data* _data26_;
	GdkEventMotion* _tmp0_ = NULL;
	GdkEventMotion* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp5_ = FALSE;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	self = (BoxesDisplayToolbar*) base;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_data26_ = g_slice_new0 (Block26Data);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_data26_->_ref_count_ = 1;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_data26_->self = g_object_ref (self);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp0_ = event;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp1_ = __vala_GdkEventMotion_copy0 (_tmp0_);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	__vala_GdkEventMotion_free0 (_data26_->event);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_data26_->event = _tmp1_;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp2_ = self->priv->_handle_drag;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	if (!_tmp2_) {
#line 772 "display-toolbar.c"
		GdkEventMotion* _tmp3_ = NULL;
		gboolean _tmp4_ = FALSE;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp3_ = _data26_->event;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp4_ = GTK_WIDGET_CLASS (boxes_display_toolbar_parent_class)->motion_notify_event ((GtkWidget*) G_TYPE_CHECK_INSTANCE_CAST (self, gtk_header_bar_get_type (), GtkHeaderBar), _tmp3_);
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		result = _tmp4_;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		block26_data_unref (_data26_);
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_data26_ = NULL;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		return result;
#line 787 "display-toolbar.c"
	}
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp5_ = self->priv->button_down;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	if (_tmp5_) {
#line 793 "display-toolbar.c"
		gdouble dx = 0.0;
		GdkEventMotion* _tmp6_ = NULL;
		gdouble _tmp7_ = 0.0;
		gint _tmp8_ = 0;
		gdouble dy = 0.0;
		GdkEventMotion* _tmp9_ = NULL;
		gdouble _tmp10_ = 0.0;
		gint _tmp11_ = 0;
		gdouble _tmp12_ = 0.0;
		gdouble _tmp13_ = 0.0;
		gdouble _tmp14_ = 0.0;
		gdouble _tmp15_ = 0.0;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp6_ = _data26_->event;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp7_ = _tmp6_->x;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp8_ = self->priv->button_down_x;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		dx = _tmp7_ - _tmp8_;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp9_ = _data26_->event;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp10_ = _tmp9_->y;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp11_ = self->priv->button_down_y;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		dy = _tmp10_ - _tmp11_;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp12_ = dx;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp13_ = dx;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp14_ = dy;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp15_ = dy;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		if (((_tmp12_ * _tmp13_) + (_tmp14_ * _tmp15_)) > ((gdouble) (40 * 40))) {
#line 832 "display-toolbar.c"
			Block27Data* _data27_;
			BoxesAppWindow* _tmp16_ = NULL;
			GtkWidget* _tmp17_ = NULL;
			GtkWindow* _tmp18_ = NULL;
			GtkWindow* _tmp19_ = NULL;
			gint _tmp20_ = 0;
			BoxesApp* _tmp21_ = NULL;
			gulong _tmp22_ = 0UL;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
			_data27_ = g_slice_new0 (Block27Data);
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
			_data27_->_ref_count_ = 1;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
			_data27_->_data26_ = block26_data_ref (_data26_);
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
			self->priv->button_down = FALSE;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
			_tmp16_ = self->priv->window;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
			boxes_app_window_set_fullscreened (_tmp16_, FALSE);
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
			_tmp17_ = gtk_widget_get_toplevel ((GtkWidget*) self);
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
			_tmp18_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp17_, gtk_window_get_type ()) ? ((GtkWindow*) _tmp17_) : NULL);
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
			_data27_->window = _tmp18_;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
			_tmp19_ = _data27_->window;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
			gtk_window_get_size (_tmp19_, &_tmp20_, NULL);
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
			_data27_->old_width = _tmp20_;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
			_data27_->id = (gulong) 0;
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
			_tmp21_ = boxes_app_app;
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
			_tmp22_ = g_signal_connect_data ((GObject*) _tmp21_, "notify::fullscreened", (GCallback) _____lambda59__g_object_notify, block27_data_ref (_data27_), (GClosureNotify) block27_data_unref, 0);
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
			_data27_->id = _tmp22_;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
			block27_data_unref (_data27_);
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
			_data27_ = NULL;
#line 877 "display-toolbar.c"
		}
	}
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	if (GTK_WIDGET_CLASS (boxes_display_toolbar_parent_class)->motion_notify_event != NULL) {
#line 882 "display-toolbar.c"
		GdkEventMotion* _tmp23_ = NULL;
		gboolean _tmp24_ = FALSE;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp23_ = _data26_->event;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp24_ = GTK_WIDGET_CLASS (boxes_display_toolbar_parent_class)->motion_notify_event ((GtkWidget*) G_TYPE_CHECK_INSTANCE_CAST (self, gtk_header_bar_get_type (), GtkHeaderBar), _tmp23_);
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		result = _tmp24_;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		block26_data_unref (_data26_);
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_data26_ = NULL;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		return result;
#line 897 "display-toolbar.c"
	}
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	result = FALSE;
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	block26_data_unref (_data26_);
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_data26_ = NULL;
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	return result;
#line 907 "display-toolbar.c"
}


static void boxes_display_toolbar_on_back_clicked (BoxesDisplayToolbar* self) {
	BoxesAppWindow* _tmp0_ = NULL;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	g_return_if_fail (self != NULL);
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp0_ = self->priv->window;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	boxes_ui_set_state ((BoxesUI*) _tmp0_, BOXES_UI_STATE_COLLECTION);
#line 919 "display-toolbar.c"
}


static void _boxes_display_toolbar_on_back_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	boxes_display_toolbar_on_back_clicked ((BoxesDisplayToolbar*) self);
#line 926 "display-toolbar.c"
}


static void boxes_display_toolbar_on_fullscreen_clicked (BoxesDisplayToolbar* self) {
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesAppWindow* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_ = FALSE;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	g_return_if_fail (self != NULL);
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp0_ = self->priv->window;
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp1_ = self->priv->window;
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp2_ = boxes_app_window_get_fullscreened (_tmp1_);
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp3_ = _tmp2_;
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	boxes_app_window_set_fullscreened (_tmp0_, !_tmp3_);
#line 947 "display-toolbar.c"
}


static void _boxes_display_toolbar_on_fullscreen_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	boxes_display_toolbar_on_fullscreen_clicked ((BoxesDisplayToolbar*) self);
#line 954 "display-toolbar.c"
}


gboolean boxes_display_toolbar_get_overlay (BoxesDisplayToolbar* self) {
	gboolean result;
	gboolean _tmp0_ = FALSE;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp0_ = self->priv->_overlay;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	result = _tmp0_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	return result;
#line 969 "display-toolbar.c"
}


static void boxes_display_toolbar_set_overlay (BoxesDisplayToolbar* self, gboolean value) {
	gboolean _tmp0_ = FALSE;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	g_return_if_fail (self != NULL);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp0_ = value;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	self->priv->_overlay = _tmp0_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	g_object_notify ((GObject *) self, "overlay");
#line 983 "display-toolbar.c"
}


gboolean boxes_display_toolbar_get_handle_drag (BoxesDisplayToolbar* self) {
	gboolean result;
	gboolean _tmp0_ = FALSE;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp0_ = self->priv->_handle_drag;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	result = _tmp0_;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	return result;
#line 998 "display-toolbar.c"
}


static void boxes_display_toolbar_set_handle_drag (BoxesDisplayToolbar* self, gboolean value) {
	gboolean _tmp0_ = FALSE;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	g_return_if_fail (self != NULL);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp0_ = value;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	self->priv->_handle_drag = _tmp0_;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	g_object_notify ((GObject *) self, "handle-drag");
#line 1012 "display-toolbar.c"
}


static void _boxes_display_toolbar___lambda60_ (BoxesDisplayToolbar* self) {
	BoxesAppWindow* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp0_ = self->priv->window;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp1_ = boxes_app_window_get_fullscreened (_tmp0_);
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp2_ = _tmp1_;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	if (_tmp2_) {
#line 1028 "display-toolbar.c"
		GtkImage* _tmp3_ = NULL;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp3_ = self->priv->fullscreen_image;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		g_object_set (_tmp3_, "icon-name", "view-restore-symbolic", NULL);
#line 1034 "display-toolbar.c"
	} else {
		GtkImage* _tmp4_ = NULL;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp4_ = self->priv->fullscreen_image;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		g_object_set (_tmp4_, "icon-name", "view-fullscreen-symbolic", NULL);
#line 1041 "display-toolbar.c"
	}
}


static void __boxes_display_toolbar___lambda60__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_boxes_display_toolbar___lambda60_ ((BoxesDisplayToolbar*) self);
#line 1049 "display-toolbar.c"
}


static GObject * boxes_display_toolbar_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	BoxesDisplayToolbar * self;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp3_ = FALSE;
	BoxesApp* _tmp12_ = NULL;
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	parent_class = G_OBJECT_CLASS (boxes_display_toolbar_parent_class);
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_DISPLAY_TOOLBAR, BoxesDisplayToolbar);
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	gtk_widget_add_events ((GtkWidget*) self, (gint) ((GDK_POINTER_MOTION_MASK | GDK_BUTTON_PRESS_MASK) | GDK_BUTTON_RELEASE_MASK));
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp0_ = self->priv->_overlay;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	if (_tmp0_) {
#line 1072 "display-toolbar.c"
		GtkStyleContext* _tmp1_ = NULL;
		GtkStyleContext* _tmp2_ = NULL;
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp1_ = gtk_widget_get_style_context ((GtkWidget*) self);
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		gtk_style_context_add_class (_tmp1_, GTK_STYLE_CLASS_TOOLBAR);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp2_ = gtk_widget_get_style_context ((GtkWidget*) self);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		gtk_style_context_add_class (_tmp2_, GTK_STYLE_CLASS_OSD);
#line 1083 "display-toolbar.c"
	} else {
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		gtk_header_bar_set_show_close_button ((GtkHeaderBar*) self, TRUE);
#line 1087 "display-toolbar.c"
	}
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp3_ = self->priv->_overlay;
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	if (!_tmp3_) {
#line 1093 "display-toolbar.c"
		GtkButton* _tmp4_ = NULL;
		GtkStyleContext* _tmp5_ = NULL;
		GtkButton* _tmp6_ = NULL;
		GtkStyleContext* _tmp7_ = NULL;
		GtkMenuButton* _tmp8_ = NULL;
		GtkStyleContext* _tmp9_ = NULL;
		GtkMenuButton* _tmp10_ = NULL;
		GtkStyleContext* _tmp11_ = NULL;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp4_ = self->priv->back;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp5_ = gtk_widget_get_style_context ((GtkWidget*) _tmp4_);
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		gtk_style_context_add_class (_tmp5_, GTK_STYLE_CLASS_RAISED);
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp6_ = self->priv->fullscreen;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp7_ = gtk_widget_get_style_context ((GtkWidget*) _tmp6_);
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		gtk_style_context_add_class (_tmp7_, GTK_STYLE_CLASS_RAISED);
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp8_ = self->priv->menu_button;
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp9_ = gtk_widget_get_style_context ((GtkWidget*) _tmp8_);
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		gtk_style_context_add_class (_tmp9_, GTK_STYLE_CLASS_RAISED);
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp10_ = self->priv->keys_menu_button;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		_tmp11_ = gtk_widget_get_style_context ((GtkWidget*) _tmp10_);
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		gtk_style_context_add_class (_tmp11_, GTK_STYLE_CLASS_RAISED);
#line 1126 "display-toolbar.c"
	}
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_tmp12_ = boxes_app_app;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	g_signal_connect_object ((GObject*) _tmp12_, "notify::fullscreened", (GCallback) __boxes_display_toolbar___lambda60__g_object_notify, self, G_CONNECT_AFTER);
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	return obj;
#line 1134 "display-toolbar.c"
}


static void boxes_display_toolbar_class_init (BoxesDisplayToolbarClass * klass) {
	gint BoxesDisplayToolbar_private_offset;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	boxes_display_toolbar_parent_class = g_type_class_peek_parent (klass);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	g_type_class_add_private (klass, sizeof (BoxesDisplayToolbarPrivate));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	((GtkWidgetClass *) klass)->button_press_event = boxes_display_toolbar_real_button_press_event;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	((GtkWidgetClass *) klass)->button_release_event = boxes_display_toolbar_real_button_release_event;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	((GtkWidgetClass *) klass)->motion_notify_event = boxes_display_toolbar_real_motion_notify_event;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_display_toolbar_get_property;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_display_toolbar_set_property;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	G_OBJECT_CLASS (klass)->constructor = boxes_display_toolbar_constructor;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_display_toolbar_finalize;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_DISPLAY_TOOLBAR_OVERLAY, g_param_spec_boolean ("overlay", "overlay", "overlay", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_DISPLAY_TOOLBAR_HANDLE_DRAG, g_param_spec_boolean ("handle-drag", "handle-drag", "handle-drag", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	BoxesDisplayToolbar_private_offset = g_type_class_get_instance_private_offset (klass);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/Boxes/ui/display-toolbar.ui");
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "fullscreen_image", FALSE, BoxesDisplayToolbar_private_offset + G_STRUCT_OFFSET (BoxesDisplayToolbarPrivate, fullscreen_image));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "back", FALSE, BoxesDisplayToolbar_private_offset + G_STRUCT_OFFSET (BoxesDisplayToolbarPrivate, back));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "fullscreen", FALSE, BoxesDisplayToolbar_private_offset + G_STRUCT_OFFSET (BoxesDisplayToolbarPrivate, fullscreen));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "menu_button", FALSE, BoxesDisplayToolbar_private_offset + G_STRUCT_OFFSET (BoxesDisplayToolbarPrivate, menu_button));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "keys_menu_button", FALSE, BoxesDisplayToolbar_private_offset + G_STRUCT_OFFSET (BoxesDisplayToolbarPrivate, keys_menu_button));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_back_clicked", G_CALLBACK(_boxes_display_toolbar_on_back_clicked_gtk_button_clicked));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_fullscreen_clicked", G_CALLBACK(_boxes_display_toolbar_on_fullscreen_clicked_gtk_button_clicked));
#line 1180 "display-toolbar.c"
}


static void boxes_display_toolbar_instance_init (BoxesDisplayToolbar * self) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	self->priv = BOXES_DISPLAY_TOOLBAR_GET_PRIVATE (self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	gtk_widget_init_template (GTK_WIDGET (self));
#line 1189 "display-toolbar.c"
}


static void boxes_display_toolbar_finalize (GObject* obj) {
	BoxesDisplayToolbar * self;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_DISPLAY_TOOLBAR, BoxesDisplayToolbar);
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_g_object_unref0 (self->priv->fullscreen_image);
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_g_object_unref0 (self->priv->back);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_g_object_unref0 (self->priv->fullscreen);
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_g_object_unref0 (self->priv->menu_button);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_g_object_unref0 (self->priv->keys_menu_button);
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	_g_object_unref0 (self->priv->window);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	G_OBJECT_CLASS (boxes_display_toolbar_parent_class)->finalize (obj);
#line 1211 "display-toolbar.c"
}


GType boxes_display_toolbar_get_type (void) {
	static volatile gsize boxes_display_toolbar_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_display_toolbar_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesDisplayToolbarClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_display_toolbar_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesDisplayToolbar), 0, (GInstanceInitFunc) boxes_display_toolbar_instance_init, NULL };
		GType boxes_display_toolbar_type_id;
		boxes_display_toolbar_type_id = g_type_register_static (gtk_header_bar_get_type (), "BoxesDisplayToolbar", &g_define_type_info, 0);
		g_once_init_leave (&boxes_display_toolbar_type_id__volatile, boxes_display_toolbar_type_id);
	}
	return boxes_display_toolbar_type_id__volatile;
}


static void _vala_boxes_display_toolbar_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesDisplayToolbar * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_DISPLAY_TOOLBAR, BoxesDisplayToolbar);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	switch (property_id) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		case BOXES_DISPLAY_TOOLBAR_OVERLAY:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		g_value_set_boolean (value, boxes_display_toolbar_get_overlay (self));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		break;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		case BOXES_DISPLAY_TOOLBAR_HANDLE_DRAG:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		g_value_set_boolean (value, boxes_display_toolbar_get_handle_drag (self));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		break;
#line 1244 "display-toolbar.c"
		default:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		break;
#line 1250 "display-toolbar.c"
	}
}


static void _vala_boxes_display_toolbar_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesDisplayToolbar * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_DISPLAY_TOOLBAR, BoxesDisplayToolbar);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
	switch (property_id) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		case BOXES_DISPLAY_TOOLBAR_OVERLAY:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		boxes_display_toolbar_set_overlay (self, g_value_get_boolean (value));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		break;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		case BOXES_DISPLAY_TOOLBAR_HANDLE_DRAG:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		boxes_display_toolbar_set_handle_drag (self, g_value_get_boolean (value));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		break;
#line 1272 "display-toolbar.c"
		default:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-toolbar.vala"
		break;
#line 1278 "display-toolbar.c"
	}
}



