/* machine.c generated by valac 0.29.2.1-265d, the Vala compiler
 * generated from machine.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gio/gio.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <libcommon.h>
#include <stdlib.h>
#include <string.h>
#include <gtk/gtk.h>
#include <libgd/gd.h>
#include <cairo.h>
#include <glib/gi18n-lib.h>
#include <float.h>
#include <math.h>
#include <gdk/gdk.h>
#include <glib/gstdio.h>


#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_UI_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_UI, BoxesUIIface))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIIface BoxesUIIface;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;
typedef struct _BoxesCollectionItemPrivate BoxesCollectionItemPrivate;

#define BOXES_TYPE_IPROPERTIES_PROVIDER (boxes_iproperties_provider_get_type ())
#define BOXES_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProvider))
#define BOXES_IS_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER))
#define BOXES_IPROPERTIES_PROVIDER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProviderIface))

typedef struct _BoxesIPropertiesProvider BoxesIPropertiesProvider;
typedef struct _BoxesIPropertiesProviderIface BoxesIPropertiesProviderIface;

#define BOXES_TYPE_PROPERTIES_PAGE (boxes_properties_page_get_type ())

#define TYPE_PROPERTY_CREATION_FLAG (property_creation_flag_get_type ())

#define BOXES_TYPE_PROPERTY (boxes_property_get_type ())
#define BOXES_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTY, BoxesProperty))
#define BOXES_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTY, BoxesPropertyClass))
#define BOXES_IS_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTY))
#define BOXES_IS_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTY))
#define BOXES_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTY, BoxesPropertyClass))

typedef struct _BoxesProperty BoxesProperty;
typedef struct _BoxesPropertyClass BoxesPropertyClass;

#define BOXES_TYPE_MACHINE (boxes_machine_get_type ())
#define BOXES_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE, BoxesMachine))
#define BOXES_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE, BoxesMachineClass))
#define BOXES_IS_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE))
#define BOXES_IS_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE))
#define BOXES_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE, BoxesMachineClass))

typedef struct _BoxesMachine BoxesMachine;
typedef struct _BoxesMachineClass BoxesMachineClass;
typedef struct _BoxesMachinePrivate BoxesMachinePrivate;

#define BOXES_MACHINE_TYPE_CONNECT_FLAGS (boxes_machine_connect_flags_get_type ())

#define BOXES_MACHINE_TYPE_MACHINE_STATE (boxes_machine_machine_state_get_type ())

#define BOXES_TYPE_APP_WINDOW (boxes_app_window_get_type ())
#define BOXES_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindow))
#define BOXES_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))
#define BOXES_IS_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP_WINDOW))
#define BOXES_IS_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP_WINDOW))
#define BOXES_APP_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))

typedef struct _BoxesAppWindow BoxesAppWindow;
typedef struct _BoxesAppWindowClass BoxesAppWindowClass;

#define BOXES_TYPE_DISPLAY (boxes_display_get_type ())
#define BOXES_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY, BoxesDisplay))
#define BOXES_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY, BoxesDisplayClass))
#define BOXES_IS_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY))
#define BOXES_IS_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY))
#define BOXES_DISPLAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY, BoxesDisplayClass))

typedef struct _BoxesDisplay BoxesDisplay;
typedef struct _BoxesDisplayClass BoxesDisplayClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
typedef struct _BoxesAppWindowPrivate BoxesAppWindowPrivate;

#define BOXES_TYPE_WIZARD_WINDOW (boxes_wizard_window_get_type ())
#define BOXES_WIZARD_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD_WINDOW, BoxesWizardWindow))
#define BOXES_WIZARD_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD_WINDOW, BoxesWizardWindowClass))
#define BOXES_IS_WIZARD_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD_WINDOW))
#define BOXES_IS_WIZARD_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD_WINDOW))
#define BOXES_WIZARD_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD_WINDOW, BoxesWizardWindowClass))

typedef struct _BoxesWizardWindow BoxesWizardWindow;
typedef struct _BoxesWizardWindowClass BoxesWizardWindowClass;

#define BOXES_TYPE_PROPERTIES_WINDOW (boxes_properties_window_get_type ())
#define BOXES_PROPERTIES_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES_WINDOW, BoxesPropertiesWindow))
#define BOXES_PROPERTIES_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES_WINDOW, BoxesPropertiesWindowClass))
#define BOXES_IS_PROPERTIES_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES_WINDOW))
#define BOXES_IS_PROPERTIES_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES_WINDOW))
#define BOXES_PROPERTIES_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES_WINDOW, BoxesPropertiesWindowClass))

typedef struct _BoxesPropertiesWindow BoxesPropertiesWindow;
typedef struct _BoxesPropertiesWindowClass BoxesPropertiesWindowClass;

#define BOXES_TYPE_SEARCHBAR (boxes_searchbar_get_type ())
#define BOXES_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbar))
#define BOXES_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))
#define BOXES_IS_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SEARCHBAR))
#define BOXES_IS_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SEARCHBAR))
#define BOXES_SEARCHBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))

typedef struct _BoxesSearchbar BoxesSearchbar;
typedef struct _BoxesSearchbarClass BoxesSearchbarClass;

#define BOXES_TYPE_TOPBAR (boxes_topbar_get_type ())
#define BOXES_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TOPBAR, BoxesTopbar))
#define BOXES_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TOPBAR, BoxesTopbarClass))
#define BOXES_IS_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TOPBAR))
#define BOXES_IS_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TOPBAR))
#define BOXES_TOPBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TOPBAR, BoxesTopbarClass))

typedef struct _BoxesTopbar BoxesTopbar;
typedef struct _BoxesTopbarClass BoxesTopbarClass;

#define BOXES_TYPE_SELECTIONBAR (boxes_selectionbar_get_type ())
#define BOXES_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbar))
#define BOXES_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))
#define BOXES_IS_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SELECTIONBAR))
#define BOXES_IS_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SELECTIONBAR))
#define BOXES_SELECTIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))

typedef struct _BoxesSelectionbar BoxesSelectionbar;
typedef struct _BoxesSelectionbarClass BoxesSelectionbarClass;

#define BOXES_TYPE_DISPLAY_PAGE (boxes_display_page_get_type ())
#define BOXES_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage))
#define BOXES_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))
#define BOXES_IS_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_IS_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_DISPLAY_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))

typedef struct _BoxesDisplayPage BoxesDisplayPage;
typedef struct _BoxesDisplayPageClass BoxesDisplayPageClass;

#define BOXES_TYPE_EMPTY_BOXES (boxes_empty_boxes_get_type ())
#define BOXES_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxes))
#define BOXES_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))
#define BOXES_IS_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_IS_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_EMPTY_BOXES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))

typedef struct _BoxesEmptyBoxes BoxesEmptyBoxes;
typedef struct _BoxesEmptyBoxesClass BoxesEmptyBoxesClass;

#define BOXES_TYPE_COLLECTION_VIEW (boxes_collection_view_get_type ())
#define BOXES_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionView))
#define BOXES_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))
#define BOXES_IS_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_IS_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_COLLECTION_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))

typedef struct _BoxesCollectionView BoxesCollectionView;
typedef struct _BoxesCollectionViewClass BoxesCollectionViewClass;

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _BoxesMachineSaveData BoxesMachineSaveData;
typedef struct _BoxesMachineSaveRealData BoxesMachineSaveRealData;
typedef struct _BoxesMachineTakeScreenshotData BoxesMachineTakeScreenshotData;
typedef struct _BoxesDisplayPrivate BoxesDisplayPrivate;
typedef struct _BoxesMachineUpdateScreenshotData BoxesMachineUpdateScreenshotData;
#define _cairo_pattern_destroy0(var) ((var == NULL) ? NULL : (var = (cairo_pattern_destroy (var), NULL)))
#define _cairo_destroy0(var) ((var == NULL) ? NULL : (var = (cairo_destroy (var), NULL)))
#define _cairo_surface_destroy0(var) ((var == NULL) ? NULL : (var = (cairo_surface_destroy (var), NULL)))
#define _gtk_icon_info_free0(var) ((var == NULL) ? NULL : (var = (gtk_icon_info_free (var), NULL)))
typedef struct _Block50Data Block50Data;

#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;
typedef struct _BoxesMachineTryConnectDisplayData BoxesMachineTryConnectDisplayData;
typedef struct _BoxesMachineTrySaveData BoxesMachineTrySaveData;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUIIface {
	GTypeInterface parent_iface;
	BoxesUIState (*get_previous_ui_state) (BoxesUI* self);
	void (*set_previous_ui_state) (BoxesUI* self, BoxesUIState value);
	BoxesUIState (*get_ui_state) (BoxesUI* self);
	void (*set_ui_state) (BoxesUI* self, BoxesUIState value);
};

struct _BoxesCollectionItem {
	GObject parent_instance;
	BoxesCollectionItemPrivate * priv;
};

struct _BoxesCollectionItemClass {
	GObjectClass parent_class;
	gint (*compare) (BoxesCollectionItem* self, BoxesCollectionItem* other);
};

typedef enum  {
	BOXES_PROPERTIES_PAGE_GENERAL,
	BOXES_PROPERTIES_PAGE_SYSTEM,
	BOXES_PROPERTIES_PAGE_DEVICES,
	BOXES_PROPERTIES_PAGE_SNAPSHOTS,
	BOXES_PROPERTIES_PAGE_LAST
} BoxesPropertiesPage;

typedef enum  {
	PROPERTY_CREATION_FLAG_NONE = 1 << 0,
	PROPERTY_CREATION_FLAG_NO_USB = 1 << 1
} PropertyCreationFlag;

struct _BoxesIPropertiesProviderIface {
	GTypeInterface parent_iface;
	GList* (*get_properties) (BoxesIPropertiesProvider* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
};

typedef enum  {
	BOXES_MACHINE_CONNECT_FLAGS_NONE = 0,
	BOXES_MACHINE_CONNECT_FLAGS_IGNORE_SAVED_STATE = 1 << 0
} BoxesMachineConnectFlags;

struct _BoxesMachine {
	BoxesCollectionItem parent_instance;
	BoxesMachinePrivate * priv;
	BoxesCollectionSource* source;
	BoxesBoxConfig* config;
	gboolean stay_on_display;
	gboolean suspend_at_exit;
};

struct _BoxesMachineClass {
	BoxesCollectionItemClass parent_class;
	void (*save_real) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*save_real_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*take_screenshot) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GdkPixbuf* (*take_screenshot_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	GList* (*get_properties) (BoxesMachine* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
	void (*connect_display) (BoxesMachine* self, BoxesMachineConnectFlags flags, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*connect_display_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*restart) (BoxesMachine* self);
	void (*disconnect_display) (BoxesMachine* self);
	void (*delete) (BoxesMachine* self, gboolean by_user);
	gboolean (*get_can_save) (BoxesMachine* self);
	gboolean (*get_should_autosave) (BoxesMachine* self);
};

typedef enum  {
	BOXES_MACHINE_MACHINE_STATE_UNKNOWN,
	BOXES_MACHINE_MACHINE_STATE_STOPPED,
	BOXES_MACHINE_MACHINE_STATE_FORCE_STOPPED,
	BOXES_MACHINE_MACHINE_STATE_RUNNING,
	BOXES_MACHINE_MACHINE_STATE_PAUSED,
	BOXES_MACHINE_MACHINE_STATE_SAVED,
	BOXES_MACHINE_MACHINE_STATE_SLEEPING
} BoxesMachineMachineState;

struct _BoxesMachinePrivate {
	GdkPixbuf* _pixbuf;
	gchar* _info;
	gchar* _status;
	gboolean _can_delete;
	gboolean _under_construction;
	gulong show_id;
	gulong hide_id;
	gulong disconnected_id;
	gulong need_password_id;
	gulong need_username_id;
	gulong ui_state_id;
	gulong got_error_id;
	guint screenshot_id;
	gboolean updating_screenshot;
	gchar* username;
	gchar* password;
	guint autosave_timeout_id;
	GCancellable* _connecting_cancellable;
	GdkPixbuf* orig_pixbuf;
	BoxesMachineMachineState _state;
	BoxesAppWindow* _window;
	gboolean _deleted;
	BoxesDisplay* _display;
	gint screenshot_counter;
	GdNotification* auth_notification;
};

struct _BoxesAppWindow {
	GtkApplicationWindow parent_instance;
	BoxesAppWindowPrivate * priv;
	BoxesWizardWindow* wizard_window;
	BoxesPropertiesWindow* props_window;
	BoxesSearchbar* searchbar;
	BoxesTopbar* topbar;
	BoxesSelectionbar* selectionbar;
	BoxesDisplayPage* display_page;
	BoxesEmptyBoxes* empty_boxes;
	GtkStack* below_bin;
	BoxesCollectionView* view;
	GSettings* settings;
};

struct _BoxesAppWindowClass {
	GtkApplicationWindowClass parent_class;
};

struct _BoxesMachineSaveData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesMachine* self;
	BoxesMachineMachineState _tmp0_;
	BoxesMachineMachineState _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	gchar* info;
	const gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	const gchar* _tmp7_;
	const gchar* _tmp8_;
	gchar* _tmp9_;
	gchar* _tmp10_;
	const gchar* _tmp11_;
	const gchar* _tmp12_;
	gchar* _tmp13_;
	gchar* _tmp14_;
	const gchar* _tmp15_;
	GError * _inner_error_;
};

struct _BoxesMachineSaveRealData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesMachine* self;
};

struct _BoxesMachineTakeScreenshotData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesMachine* self;
	GdkPixbuf* result;
	BoxesDisplay* _tmp0_;
	BoxesDisplay* _tmp1_;
	GdkPixbuf* _tmp2_;
	BoxesDisplay* _tmp3_;
	BoxesDisplay* _tmp4_;
	GdkPixbuf* _tmp5_;
	GdkPixbuf* _tmp6_;
	GError * _inner_error_;
};

typedef gint (*BoxesDisplayOpenFDFunc) (void* user_data);
struct _BoxesDisplay {
	GObject parent_instance;
	BoxesDisplayPrivate * priv;
	gboolean connected;
	GHashTable* displays;
};

struct _BoxesDisplayClass {
	GObjectClass parent_class;
	GtkWidget* (*get_display) (BoxesDisplay* self, gint n);
	GdkPixbuf* (*get_pixbuf) (BoxesDisplay* self, gint n, GError** error);
	void (*set_enable_inputs) (BoxesDisplay* self, GtkWidget* widget, gboolean enable);
	void (*set_enable_audio) (BoxesDisplay* self, gboolean enable);
	gboolean (*should_keep_alive) (BoxesDisplay* self);
	void (*connect_it) (BoxesDisplay* self, BoxesDisplayOpenFDFunc open_fd, void* open_fd_target, GError** error);
	void (*disconnect_it) (BoxesDisplay* self);
	void (*collect_logs) (BoxesDisplay* self, GString* builder);
	void (*send_keys) (BoxesDisplay* self, guint* keyvals, int keyvals_length1);
	GList* (*get_properties) (BoxesDisplay* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
	const gchar* (*get_protocol) (BoxesDisplay* self);
	gchar* (*get_uri) (BoxesDisplay* self);
};

struct _BoxesMachineUpdateScreenshotData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesMachine* self;
	gboolean force_save;
	gboolean first_check;
	gboolean _tmp0_;
	GdkPixbuf* large_screenshot;
	GdkPixbuf* _tmp1_;
	GdkPixbuf* _tmp2_;
	GdkPixbuf* _tmp3_;
	gboolean _tmp4_;
	GdkPixbuf* _tmp5_;
	GdkPixbuf* _tmp6_;
	GdkPixbuf* _tmp7_;
	GError* _error_;
	GdkPixbuf* _tmp8_;
	gboolean _tmp9_;
	gboolean _tmp10_;
	gint _tmp11_;
	GdkPixbuf* _tmp12_;
	GError * _inner_error_;
};

struct _Block50Data {
	int _ref_count_;
	BoxesMachine* self;
	BoxesMachineConnectFlags flags;
	gpointer _async_data_;
};

typedef void (*BoxesNotificationOKFunc) (void* user_data);
typedef void (*BoxesNotificationCancelFunc) (void* user_data);
struct _BoxesMachineTryConnectDisplayData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesMachine* self;
	BoxesMachineConnectFlags flags;
	Block50Data* _data50_;
	BoxesMachineConnectFlags _tmp0_;
	BoxesMachineConnectFlags _tmp1_;
	GError* e;
	gchar* message;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	const gchar* _tmp4_;
	gchar* _tmp5_;
	GdNotification* notification;
	BoxesAppWindow* _tmp6_;
	BoxesAppWindow* _tmp7_;
	BoxesNotificationbar* _tmp8_;
	BoxesNotificationbar* _tmp9_;
	const gchar* _tmp10_;
	const gchar* _tmp11_;
	GdNotification* _tmp12_;
	GdNotification* _tmp13_;
	GError* _vala1_e;
	const gchar* _tmp14_;
	const gchar* _tmp15_;
	GError* _tmp16_;
	const gchar* _tmp17_;
	BoxesAppWindow* _tmp18_;
	BoxesAppWindow* _tmp19_;
	BoxesAppWindow* _tmp20_;
	BoxesAppWindow* _tmp21_;
	BoxesNotificationbar* _tmp22_;
	BoxesNotificationbar* _tmp23_;
	const gchar* _tmp24_;
	const gchar* _tmp25_;
	const gchar* _tmp26_;
	gchar* _tmp27_;
	gchar* _tmp28_;
	GdNotification* _tmp29_;
	GdNotification* _tmp30_;
	GError* _vala2_e;
	const gchar* _tmp31_;
	const gchar* _tmp32_;
	GError* _tmp33_;
	const gchar* _tmp34_;
	BoxesAppWindow* _tmp35_;
	BoxesAppWindow* _tmp36_;
	BoxesAppWindow* _tmp37_;
	BoxesAppWindow* _tmp38_;
	BoxesNotificationbar* _tmp39_;
	BoxesNotificationbar* _tmp40_;
	const gchar* _tmp41_;
	const gchar* _tmp42_;
	const gchar* _tmp43_;
	gchar* _tmp44_;
	gchar* _tmp45_;
	GdNotification* _tmp46_;
	GdNotification* _tmp47_;
	GError * _inner_error_;
};

typedef void (*BoxesAuthNotificationAuthFunc) (const gchar* username, const gchar* password, void* user_data);
struct _BoxesMachineTrySaveData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesMachine* self;
	GError* _error_;
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	GError* _tmp2_;
	const gchar* _tmp3_;
	GError * _inner_error_;
};


static gpointer boxes_machine_parent_class = NULL;
static cairo_surface_t* boxes_machine_grid_surface;
static cairo_surface_t* boxes_machine_grid_surface = NULL;
static GdkPixbuf* boxes_machine_default_fallback;
static GdkPixbuf* boxes_machine_default_fallback = NULL;
extern BoxesApp* boxes_app_app;
static BoxesIPropertiesProviderIface* boxes_machine_boxes_iproperties_provider_parent_iface = NULL;

GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_properties_page_get_type (void) G_GNUC_CONST;
GType property_creation_flag_get_type (void) G_GNUC_CONST;
GType boxes_property_get_type (void) G_GNUC_CONST;
GType boxes_iproperties_provider_get_type (void) G_GNUC_CONST;
GType boxes_machine_get_type (void) G_GNUC_CONST;
GType boxes_machine_connect_flags_get_type (void) G_GNUC_CONST;
GType boxes_machine_machine_state_get_type (void) G_GNUC_CONST;
GType boxes_app_window_get_type (void) G_GNUC_CONST;
GType boxes_display_get_type (void) G_GNUC_CONST;
#define BOXES_MACHINE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_MACHINE, BoxesMachinePrivate))
enum  {
	BOXES_MACHINE_DUMMY_PROPERTY,
	BOXES_MACHINE_PIXBUF,
	BOXES_MACHINE_INFO,
	BOXES_MACHINE_STATUS,
	BOXES_MACHINE_CAN_SAVE,
	BOXES_MACHINE_CAN_DELETE,
	BOXES_MACHINE_UNDER_CONSTRUCTION,
	BOXES_MACHINE_SHOULD_AUTOSAVE,
	BOXES_MACHINE_CONNECTING_CANCELLABLE,
	BOXES_MACHINE_STATE,
	BOXES_MACHINE_WINDOW,
	BOXES_MACHINE_DELETED,
	BOXES_MACHINE_DISPLAY
};
#define BOXES_MACHINE_AUTOSAVE_TIMEOUT ((guint) 60)
#define BOXES_MACHINE_SCREENSHOT_WIDTH 180
#define BOXES_MACHINE_SCREENSHOT_HEIGHT 134
void boxes_machine_show_display (BoxesMachine* self);
BoxesAppWindow* boxes_machine_get_window (BoxesMachine* self);
BoxesUIState boxes_ui_get_ui_state (BoxesUI* self);
void boxes_ui_set_state (BoxesUI* self, BoxesUIState new_state);
BoxesDisplay* boxes_machine_get_display (BoxesMachine* self);
GtkWidget* boxes_display_get_display (BoxesDisplay* self, gint n);
void boxes_widget_remove (GtkWidget* widget);
void boxes_display_set_enable_inputs (BoxesDisplay* self, GtkWidget* widget, gboolean enable);
GType boxes_wizard_window_get_type (void) G_GNUC_CONST;
GType boxes_properties_window_get_type (void) G_GNUC_CONST;
GType boxes_searchbar_get_type (void) G_GNUC_CONST;
GType boxes_topbar_get_type (void) G_GNUC_CONST;
GType boxes_selectionbar_get_type (void) G_GNUC_CONST;
GType boxes_display_page_get_type (void) G_GNUC_CONST;
GType boxes_empty_boxes_get_type (void) G_GNUC_CONST;
GType boxes_collection_view_get_type (void) G_GNUC_CONST;
void boxes_display_page_show_display (BoxesDisplayPage* self, BoxesDisplay* display, GtkWidget* widget);
void boxes_display_page_replace_display (BoxesDisplayPage* self, BoxesDisplay* display, GtkWidget* widget);
BoxesMachine* boxes_machine_construct (GType object_type, BoxesCollectionSource* source, const gchar* name);
BoxesCollectionItem* boxes_collection_item_construct (GType object_type);
void boxes_collection_item_set_name (BoxesCollectionItem* self, const gchar* value);
void boxes_machine_set_connecting_cancellable (BoxesMachine* self, GCancellable* value);
static GdkPixbuf* boxes_machine_draw_fallback_vm (gint width, gint height, gboolean force);
void boxes_machine_set_pixbuf (BoxesMachine* self, GdkPixbuf* value);
static void boxes_machine_ui_state_changed (BoxesMachine* self);
static void _boxes_machine_ui_state_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
GType boxes_app_get_type (void) G_GNUC_CONST;
BoxesAppWindow* boxes_app_get_main_window (BoxesApp* self);
static void __lambda207_ (BoxesMachine* self);
void boxes_machine_set_screenshot_enable (BoxesMachine* self, gboolean enable);
static void ___lambda207__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
const gchar* boxes_collection_item_get_name (BoxesCollectionItem* self);
void boxes_machine_set_status (BoxesMachine* self, const gchar* value);
static void __lambda208_ (BoxesMachine* self);
static void ___lambda208__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
void boxes_machine_load_screenshot (BoxesMachine* self);
BoxesMachineMachineState boxes_machine_get_state (BoxesMachine* self);
static gchar* boxes_machine_get_screenshot_filename (BoxesMachine* self, GError** error);
static void boxes_machine_set_screenshot (BoxesMachine* self, GdkPixbuf* large_screenshot, gboolean save);
static void boxes_machine_update_screenshot (BoxesMachine* self, gboolean force_save, gboolean first_check, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_machine_update_screenshot_finish (BoxesMachine* self, GAsyncResult* _res_);
static gboolean ___lambda79_ (BoxesMachine* self);
static gboolean ____lambda79__gsource_func (gpointer self);
static void boxes_machine_save_data_free (gpointer _data);
void boxes_machine_save (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_machine_save_finish (BoxesMachine* self, GAsyncResult* _res_, GError** error);
static gboolean boxes_machine_save_co (BoxesMachineSaveData* _data_);
const gchar* boxes_machine_get_info (BoxesMachine* self);
void boxes_machine_set_info (BoxesMachine* self, const gchar* value);
void boxes_machine_save_real (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_machine_save_real_finish (BoxesMachine* self, GAsyncResult* _res_, GError** error);
static void boxes_machine_save_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
void boxes_machine_schedule_autosave (BoxesMachine* self);
gboolean boxes_machine_get_should_autosave (BoxesMachine* self);
static gboolean __lambda15_ (BoxesMachine* self);
static void boxes_machine_try_save (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_machine_try_save_finish (BoxesMachine* self, GAsyncResult* _res_);
static gboolean ___lambda15__gsource_func (gpointer self);
void boxes_machine_unschedule_autosave (BoxesMachine* self);
static void boxes_machine_real_save_real_data_free (gpointer _data);
static void boxes_machine_real_save_real (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static gboolean boxes_machine_real_save_real_co (BoxesMachineSaveRealData* _data_);
static void boxes_machine_real_take_screenshot_data_free (gpointer _data);
static void boxes_machine_real_take_screenshot (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_machine_take_screenshot (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
GdkPixbuf* boxes_machine_take_screenshot_finish (BoxesMachine* self, GAsyncResult* _res_, GError** error);
static gboolean boxes_machine_real_take_screenshot_co (BoxesMachineTakeScreenshotData* _data_);
GdkPixbuf* boxes_display_get_pixbuf (BoxesDisplay* self, gint n, GError** error);
GList* boxes_machine_get_properties (BoxesMachine* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
static GList* boxes_machine_real_get_properties (BoxesMachine* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
gboolean boxes_machine_is_connected (BoxesMachine* self);
void boxes_machine_connect_display (BoxesMachine* self, BoxesMachineConnectFlags flags, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_machine_connect_display_finish (BoxesMachine* self, GAsyncResult* _res_, GError** error);
void boxes_machine_restart (BoxesMachine* self);
static void boxes_machine_real_restart (BoxesMachine* self);
void boxes_machine_disconnect_display (BoxesMachine* self);
static void boxes_machine_real_disconnect_display (BoxesMachine* self);
GtkWidget* boxes_display_page_remove_display (BoxesDisplayPage* self);
gboolean boxes_display_should_keep_alive (BoxesDisplay* self);
void boxes_display_disconnect_it (BoxesDisplay* self);
void boxes_machine_set_display (BoxesMachine* self, BoxesDisplay* value);
void boxes_display_set_enable_audio (BoxesDisplay* self, gboolean enable);
void boxes_machine_set_window (BoxesMachine* self, BoxesAppWindow* value);
void boxes_machine_create_display_config (BoxesMachine* self, const gchar* uuid);
gchar* boxes_uuid_generate (void);
gboolean boxes_machine_is_running (BoxesMachine* self);
gboolean boxes_machine_is_on (BoxesMachine* self);
static void boxes_machine_save_pixbuf_as_screenshot (BoxesMachine* self, GdkPixbuf* pixbuf);
static gint boxes_machine_pixbuf_energy (BoxesMachine* self, GdkPixbuf* pixbuf);
static GdkPixbuf* boxes_machine_draw_vm (BoxesMachine* self, GdkPixbuf* pixbuf, gint width, gint height);
static GdkPixbuf* boxes_machine_draw_stopped_vm (gint width, gint height);
static void boxes_machine_update_screenshot_data_free (gpointer _data);
static gboolean boxes_machine_update_screenshot_co (BoxesMachineUpdateScreenshotData* _data_);
static void boxes_machine_update_screenshot_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
void boxes_machine_delete (BoxesMachine* self, gboolean by_user);
static void boxes_machine_real_delete (BoxesMachine* self, gboolean by_user);
static void boxes_machine_set_deleted (BoxesMachine* self, gboolean value);
static void boxes_machine_try_connect_display (BoxesMachine* self, BoxesMachineConnectFlags flags, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_machine_try_connect_display_finish (BoxesMachine* self, GAsyncResult* _res_);
BoxesUIState boxes_ui_get_previous_ui_state (BoxesUI* self);
static void boxes_machine_try_connect_display_data_free (gpointer _data);
static gboolean boxes_machine_try_connect_display_co (BoxesMachineTryConnectDisplayData* _data_);
static Block50Data* block50_data_ref (Block50Data* _data50_);
static void block50_data_unref (void * _userdata_);
static void boxes_machine_try_connect_display_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
BoxesNotificationbar* boxes_app_window_get_notificationbar (BoxesAppWindow* self);
GdNotification* boxes_notificationbar_display_for_action (BoxesNotificationbar* self, const gchar* message, const gchar* action_label, BoxesNotificationOKFunc action_func, void* action_func_target, GDestroyNotify action_func_target_destroy_notify, BoxesNotificationCancelFunc ignore_func, void* ignore_func_target, GDestroyNotify ignore_func_target_destroy_notify, gint timeout);
static void ___lambda76_ (Block50Data* _data50_);
static void ____lambda76__boxes_notification_ok_func (gpointer self);
#define BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT 6
static void ___lambda77_ (BoxesMachine* self);
static void ____lambda77__gd_notification_dismissed (GdNotification* _sender, gpointer self);
GdNotification* boxes_notificationbar_display_error (BoxesNotificationbar* self, const gchar* message, gint timeout);
static void boxes_machine_handle_auth (BoxesMachine* self);
gboolean boxes_display_get_need_username (BoxesDisplay* self);
gboolean boxes_display_get_need_password (BoxesDisplay* self);
static void __lambda75_ (BoxesMachine* self, const gchar* username, const gchar* password);
static void ___lambda75__boxes_auth_notification_auth_func (const gchar* username, const gchar* password, gpointer self);
static void __lambda78_ (BoxesMachine* self);
static void ___lambda78__boxes_notification_cancel_func (gpointer self);
GdNotification* boxes_notificationbar_display_for_auth (BoxesNotificationbar* self, const gchar* auth_string, BoxesAuthNotificationAuthFunc auth_func, void* auth_func_target, GDestroyNotify auth_func_target_destroy_notify, BoxesNotificationCancelFunc cancel_func, void* cancel_func_target, GDestroyNotify cancel_func_target_destroy_notify, gboolean need_username);
static gint boxes_machine_real_compare (BoxesCollectionItem* base, BoxesCollectionItem* other);
static void boxes_machine_try_save_data_free (gpointer _data);
static gboolean boxes_machine_try_save_co (BoxesMachineTrySaveData* _data_);
static void boxes_machine_try_save_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
GdkPixbuf* boxes_machine_get_pixbuf (BoxesMachine* self);
const gchar* boxes_machine_get_status (BoxesMachine* self);
gboolean boxes_machine_get_can_save (BoxesMachine* self);
gboolean boxes_machine_get_can_delete (BoxesMachine* self);
void boxes_machine_set_can_delete (BoxesMachine* self, gboolean value);
gboolean boxes_machine_get_under_construction (BoxesMachine* self);
void boxes_machine_set_under_construction (BoxesMachine* self, gboolean value);
GCancellable* boxes_machine_get_connecting_cancellable (BoxesMachine* self);
void boxes_machine_set_state (BoxesMachine* self, BoxesMachineMachineState value);
const gchar* boxes_machine_machine_state_to_string (BoxesMachineMachineState self);
BoxesCollectionItem* boxes_app_window_get_current_item (BoxesAppWindow* self);
gboolean boxes_machine_get_deleted (BoxesMachine* self);
static void _boxes_machine_display___lambda13_ (BoxesMachine* self, gint id);
static void __boxes_machine_display___lambda13__boxes_display_show (BoxesDisplay* _sender, gint display_id, gpointer self);
static void _boxes_machine_display___lambda72_ (BoxesMachine* self, gint id);
static void __boxes_machine_display___lambda72__boxes_display_hide (BoxesDisplay* _sender, gint display_id, gpointer self);
static void _boxes_machine_display___lambda73_ (BoxesMachine* self, const gchar* message);
static void __boxes_machine_display___lambda73__boxes_display_got_error (BoxesDisplay* _sender, const gchar* message, gpointer self);
static void _boxes_machine_display___lambda74_ (BoxesMachine* self, gboolean failed);
static void __boxes_machine_display___lambda74__boxes_display_disconnected (BoxesDisplay* _sender, gboolean connection_failed, gpointer self);
static void _boxes_machine_handle_auth_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
void boxes_display_set_username (BoxesDisplay* self, const gchar* value);
void boxes_display_set_password (BoxesDisplay* self, const gchar* value);
static void boxes_machine_finalize (GObject* obj);
static void _vala_boxes_machine_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_boxes_machine_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);


GType boxes_machine_machine_state_get_type (void) {
	static volatile gsize boxes_machine_machine_state_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_machine_machine_state_type_id__volatile)) {
		static const GEnumValue values[] = {{BOXES_MACHINE_MACHINE_STATE_UNKNOWN, "BOXES_MACHINE_MACHINE_STATE_UNKNOWN", "unknown"}, {BOXES_MACHINE_MACHINE_STATE_STOPPED, "BOXES_MACHINE_MACHINE_STATE_STOPPED", "stopped"}, {BOXES_MACHINE_MACHINE_STATE_FORCE_STOPPED, "BOXES_MACHINE_MACHINE_STATE_FORCE_STOPPED", "force-stopped"}, {BOXES_MACHINE_MACHINE_STATE_RUNNING, "BOXES_MACHINE_MACHINE_STATE_RUNNING", "running"}, {BOXES_MACHINE_MACHINE_STATE_PAUSED, "BOXES_MACHINE_MACHINE_STATE_PAUSED", "paused"}, {BOXES_MACHINE_MACHINE_STATE_SAVED, "BOXES_MACHINE_MACHINE_STATE_SAVED", "saved"}, {BOXES_MACHINE_MACHINE_STATE_SLEEPING, "BOXES_MACHINE_MACHINE_STATE_SLEEPING", "sleeping"}, {0, NULL, NULL}};
		GType boxes_machine_machine_state_type_id;
		boxes_machine_machine_state_type_id = g_enum_register_static ("BoxesMachineMachineState", values);
		g_once_init_leave (&boxes_machine_machine_state_type_id__volatile, boxes_machine_machine_state_type_id);
	}
	return boxes_machine_machine_state_type_id__volatile;
}


GType boxes_machine_connect_flags_get_type (void) {
	static volatile gsize boxes_machine_connect_flags_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_machine_connect_flags_type_id__volatile)) {
		static const GFlagsValue values[] = {{BOXES_MACHINE_CONNECT_FLAGS_NONE, "BOXES_MACHINE_CONNECT_FLAGS_NONE", "none"}, {BOXES_MACHINE_CONNECT_FLAGS_IGNORE_SAVED_STATE, "BOXES_MACHINE_CONNECT_FLAGS_IGNORE_SAVED_STATE", "ignore-saved-state"}, {0, NULL, NULL}};
		GType boxes_machine_connect_flags_type_id;
		boxes_machine_connect_flags_type_id = g_flags_register_static ("BoxesMachineConnectFlags", values);
		g_once_init_leave (&boxes_machine_connect_flags_type_id__volatile, boxes_machine_connect_flags_type_id);
	}
	return boxes_machine_connect_flags_type_id__volatile;
}


void boxes_machine_show_display (BoxesMachine* self) {
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesAppWindow* _tmp1_ = NULL;
	BoxesUIState _tmp2_ = 0;
	BoxesUIState _tmp3_ = 0;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_if_fail (self != NULL);
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = boxes_machine_get_window (self);
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp1_ = _tmp0_;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp2_ = boxes_ui_get_ui_state ((BoxesUI*) _tmp1_);
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp3_ = _tmp2_;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	switch (_tmp3_) {
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		case BOXES_UI_STATE_CREDS:
#line 780 "machine.c"
		{
			BoxesAppWindow* _tmp4_ = NULL;
			BoxesAppWindow* _tmp5_ = NULL;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp4_ = boxes_machine_get_window (self);
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp5_ = _tmp4_;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			boxes_ui_set_state ((BoxesUI*) _tmp5_, BOXES_UI_STATE_DISPLAY);
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			boxes_machine_show_display (self);
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			break;
#line 794 "machine.c"
		}
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		case BOXES_UI_STATE_DISPLAY:
#line 798 "machine.c"
		{
			GtkWidget* widget = NULL;
			BoxesDisplay* _tmp6_ = NULL;
			BoxesDisplay* _tmp7_ = NULL;
			GtkWidget* _tmp8_ = NULL;
			GtkWidget* _tmp9_ = NULL;
			BoxesDisplay* _tmp10_ = NULL;
			BoxesDisplay* _tmp11_ = NULL;
			GtkWidget* _tmp12_ = NULL;
			BoxesAppWindow* _tmp13_ = NULL;
			BoxesAppWindow* _tmp14_ = NULL;
			BoxesDisplayPage* _tmp15_ = NULL;
			BoxesDisplay* _tmp16_ = NULL;
			BoxesDisplay* _tmp17_ = NULL;
			GtkWidget* _tmp18_ = NULL;
			GtkWidget* _tmp19_ = NULL;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp6_ = boxes_machine_get_display (self);
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp7_ = _tmp6_;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp8_ = boxes_display_get_display (_tmp7_, 0);
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			widget = _tmp8_;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp9_ = widget;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			boxes_widget_remove (_tmp9_);
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp10_ = boxes_machine_get_display (self);
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp11_ = _tmp10_;
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp12_ = widget;
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			boxes_display_set_enable_inputs (_tmp11_, _tmp12_, TRUE);
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp13_ = boxes_machine_get_window (self);
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp14_ = _tmp13_;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp15_ = _tmp14_->display_page;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp16_ = boxes_machine_get_display (self);
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp17_ = _tmp16_;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp18_ = widget;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			boxes_display_page_show_display (_tmp15_, _tmp17_, _tmp18_);
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp19_ = widget;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			gtk_widget_grab_focus (_tmp19_);
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_g_object_unref0 (widget);
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			break;
#line 857 "machine.c"
		}
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		case BOXES_UI_STATE_PROPERTIES:
#line 861 "machine.c"
		{
			GtkWidget* widget = NULL;
			BoxesDisplay* _tmp20_ = NULL;
			BoxesDisplay* _tmp21_ = NULL;
			GtkWidget* _tmp22_ = NULL;
			GtkWidget* _tmp23_ = NULL;
			BoxesDisplay* _tmp24_ = NULL;
			BoxesDisplay* _tmp25_ = NULL;
			GtkWidget* _tmp26_ = NULL;
			BoxesAppWindow* _tmp27_ = NULL;
			BoxesAppWindow* _tmp28_ = NULL;
			BoxesDisplayPage* _tmp29_ = NULL;
			BoxesDisplay* _tmp30_ = NULL;
			BoxesDisplay* _tmp31_ = NULL;
			GtkWidget* _tmp32_ = NULL;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp20_ = boxes_machine_get_display (self);
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp21_ = _tmp20_;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp22_ = boxes_display_get_display (_tmp21_, 0);
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			widget = _tmp22_;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp23_ = widget;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			boxes_widget_remove (_tmp23_);
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp24_ = boxes_machine_get_display (self);
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp25_ = _tmp24_;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp26_ = widget;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			boxes_display_set_enable_inputs (_tmp25_, _tmp26_, TRUE);
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp27_ = boxes_machine_get_window (self);
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp28_ = _tmp27_;
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp29_ = _tmp28_->display_page;
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp30_ = boxes_machine_get_display (self);
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp31_ = _tmp30_;
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp32_ = widget;
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			boxes_display_page_replace_display (_tmp29_, _tmp31_, _tmp32_);
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_g_object_unref0 (widget);
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			break;
#line 915 "machine.c"
		}
		default:
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		break;
#line 920 "machine.c"
	}
}


static gpointer _g_object_ref0 (gpointer self) {
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	return self ? g_object_ref (self) : NULL;
#line 928 "machine.c"
}


static void _boxes_machine_ui_state_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_machine_ui_state_changed ((BoxesMachine*) self);
#line 935 "machine.c"
}


static void __lambda207_ (BoxesMachine* self) {
	BoxesApp* _tmp0_ = NULL;
	BoxesAppWindow* _tmp1_ = NULL;
	BoxesAppWindow* _tmp2_ = NULL;
	BoxesUIState _tmp3_ = 0;
	BoxesUIState _tmp4_ = 0;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = boxes_app_app;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp1_ = boxes_app_get_main_window (_tmp0_);
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp2_ = _tmp1_;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp3_ = boxes_ui_get_ui_state ((BoxesUI*) _tmp2_);
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp4_ = _tmp3_;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp4_ == BOXES_UI_STATE_DISPLAY) {
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_machine_set_screenshot_enable (self, FALSE);
#line 959 "machine.c"
	} else {
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_machine_set_screenshot_enable (self, TRUE);
#line 963 "machine.c"
	}
}


static void ___lambda207__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	__lambda207_ ((BoxesMachine*) self);
#line 971 "machine.c"
}


static void __lambda208_ (BoxesMachine* self) {
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = boxes_collection_item_get_name ((BoxesCollectionItem*) self);
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp1_ = _tmp0_;
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_machine_set_status (self, _tmp1_);
#line 984 "machine.c"
}


static void ___lambda208__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	__lambda208_ ((BoxesMachine*) self);
#line 991 "machine.c"
}


BoxesMachine* boxes_machine_construct (GType object_type, BoxesCollectionSource* source, const gchar* name) {
	BoxesMachine * self = NULL;
	const gchar* _tmp0_ = NULL;
	BoxesCollectionSource* _tmp1_ = NULL;
	BoxesCollectionSource* _tmp2_ = NULL;
	GCancellable* _tmp3_ = NULL;
	GCancellable* _tmp4_ = NULL;
	GdkPixbuf* _tmp5_ = NULL;
	GdkPixbuf* _tmp6_ = NULL;
	BoxesApp* _tmp7_ = NULL;
	BoxesAppWindow* _tmp8_ = NULL;
	BoxesAppWindow* _tmp9_ = NULL;
	gulong _tmp10_ = 0UL;
	const gchar* _tmp11_ = NULL;
	const gchar* _tmp12_ = NULL;
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_val_if_fail (source != NULL, NULL);
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	self = (BoxesMachine*) boxes_collection_item_construct (object_type);
#line 202 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = name;
#line 202 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_collection_item_set_name ((BoxesCollectionItem*) self, _tmp0_);
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp1_ = source;
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->source);
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	self->source = _tmp2_;
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp3_ = g_cancellable_new ();
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp4_ = _tmp3_;
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_machine_set_connecting_cancellable (self, _tmp4_);
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (_tmp4_);
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp5_ = boxes_machine_draw_fallback_vm (BOXES_MACHINE_SCREENSHOT_WIDTH, BOXES_MACHINE_SCREENSHOT_HEIGHT, FALSE);
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp6_ = _tmp5_;
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_machine_set_pixbuf (self, _tmp6_);
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (_tmp6_);
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_signal_connect_object ((GObject*) self, "notify::ui-state", (GCallback) _boxes_machine_ui_state_changed_g_object_notify, self, 0);
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp7_ = boxes_app_app;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp8_ = boxes_app_get_main_window (_tmp7_);
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp9_ = _tmp8_;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp10_ = g_signal_connect_object ((GObject*) _tmp9_, "notify::ui-state", (GCallback) ___lambda207__g_object_notify, self, 0);
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	self->priv->ui_state_id = _tmp10_;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp11_ = boxes_collection_item_get_name ((BoxesCollectionItem*) self);
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp12_ = _tmp11_;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_machine_set_status (self, _tmp12_);
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_signal_connect_object ((GObject*) self, "notify::name", (GCallback) ___lambda208__g_object_notify, self, 0);
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	return self;
#line 1066 "machine.c"
}


void boxes_machine_load_screenshot (BoxesMachine* self) {
	GError * _inner_error_ = NULL;
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_if_fail (self != NULL);
#line 1074 "machine.c"
	{
		GdkPixbuf* _tmp0_ = NULL;
		gboolean _tmp1_ = FALSE;
		BoxesMachineMachineState _tmp2_ = 0;
		BoxesMachineMachineState _tmp3_ = 0;
		GdkPixbuf* screenshot = NULL;
		GdkPixbuf* _tmp9_ = NULL;
		GdkPixbuf* _tmp10_ = NULL;
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp2_ = boxes_machine_get_state (self);
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp3_ = _tmp2_;
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		if (_tmp3_ != BOXES_MACHINE_MACHINE_STATE_STOPPED) {
#line 1089 "machine.c"
			BoxesMachineMachineState _tmp4_ = 0;
			BoxesMachineMachineState _tmp5_ = 0;
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp4_ = boxes_machine_get_state (self);
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp5_ = _tmp4_;
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp1_ = _tmp5_ != BOXES_MACHINE_MACHINE_STATE_FORCE_STOPPED;
#line 1098 "machine.c"
		} else {
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp1_ = FALSE;
#line 1102 "machine.c"
		}
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		if (_tmp1_) {
#line 1106 "machine.c"
			gchar* _tmp6_ = NULL;
			gchar* _tmp7_ = NULL;
			GdkPixbuf* _tmp8_ = NULL;
#line 225 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp7_ = boxes_machine_get_screenshot_filename (self, &_inner_error_);
#line 225 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp6_ = _tmp7_;
#line 225 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 225 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
				_g_object_unref0 (_tmp0_);
#line 1118 "machine.c"
				goto __catch49_g_error;
			}
#line 225 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp8_ = gdk_pixbuf_new_from_file (_tmp6_, &_inner_error_);
#line 225 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_g_object_unref0 (_tmp0_);
#line 225 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp0_ = _tmp8_;
#line 225 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 225 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
				_g_free0 (_tmp6_);
#line 225 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
				_g_object_unref0 (_tmp0_);
#line 1133 "machine.c"
				goto __catch49_g_error;
			}
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_g_free0 (_tmp6_);
#line 1138 "machine.c"
		} else {
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_g_object_unref0 (_tmp0_);
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp0_ = NULL;
#line 1144 "machine.c"
		}
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp9_ = _g_object_ref0 (_tmp0_);
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		screenshot = _tmp9_;
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp10_ = screenshot;
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_machine_set_screenshot (self, _tmp10_, FALSE);
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_object_unref0 (screenshot);
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_object_unref0 (_tmp0_);
#line 1158 "machine.c"
	}
	goto __finally49;
	__catch49_g_error:
	{
		GError* _error_ = NULL;
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_error_ = _inner_error_;
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_inner_error_ = NULL;
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_error_free0 (_error_);
#line 1170 "machine.c"
	}
	__finally49:
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_clear_error (&_inner_error_);
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		return;
#line 1181 "machine.c"
	}
}


static gboolean ___lambda79_ (BoxesMachine* self) {
	gboolean result = FALSE;
#line 239 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_machine_update_screenshot (self, FALSE, FALSE, NULL, NULL);
#line 241 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	result = TRUE;
#line 241 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	return result;
#line 1194 "machine.c"
}


static gboolean ____lambda79__gsource_func (gpointer self) {
	gboolean result;
	result = ___lambda79_ ((BoxesMachine*) self);
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	return result;
#line 1203 "machine.c"
}


void boxes_machine_set_screenshot_enable (BoxesMachine* self, gboolean enable) {
	gboolean _tmp0_ = FALSE;
#line 232 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_if_fail (self != NULL);
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = enable;
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp0_) {
#line 1215 "machine.c"
		guint _tmp1_ = 0U;
		gint interval = 0;
		BoxesApp* _tmp2_ = NULL;
		BoxesAppWindow* _tmp3_ = NULL;
		BoxesAppWindow* _tmp4_ = NULL;
		GSettings* _tmp5_ = NULL;
		gint _tmp6_ = 0;
		gint _tmp7_ = 0;
		guint _tmp8_ = 0U;
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp1_ = self->priv->screenshot_id;
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		if (_tmp1_ != ((guint) 0)) {
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			return;
#line 1231 "machine.c"
		}
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_machine_update_screenshot (self, FALSE, TRUE, NULL, NULL);
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp2_ = boxes_app_app;
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp3_ = boxes_app_get_main_window (_tmp2_);
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp4_ = _tmp3_;
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp5_ = _tmp4_->settings;
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp6_ = g_settings_get_int (_tmp5_, "screenshot-interval");
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		interval = _tmp6_;
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp7_ = interval;
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp8_ = g_timeout_add_seconds_full (G_PRIORITY_DEFAULT, (guint) _tmp7_, ____lambda79__gsource_func, g_object_ref (self), g_object_unref);
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		self->priv->screenshot_id = _tmp8_;
#line 1253 "machine.c"
	} else {
		guint _tmp9_ = 0U;
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp9_ = self->priv->screenshot_id;
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		if (_tmp9_ != ((guint) 0)) {
#line 1260 "machine.c"
			guint _tmp10_ = 0U;
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp10_ = self->priv->screenshot_id;
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			g_source_remove (_tmp10_);
#line 1266 "machine.c"
		}
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		self->priv->screenshot_id = (guint) 0;
#line 1270 "machine.c"
	}
}


static gchar* boxes_machine_get_screenshot_filename (BoxesMachine* self, GError** error) {
	gchar* result = NULL;
	BoxesBoxConfig* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gboolean _tmp4_ = FALSE;
	BoxesBoxConfig* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
	gchar* _tmp9_ = NULL;
	gchar* _tmp10_ = NULL;
	gchar* _tmp11_ = NULL;
	GError * _inner_error_ = NULL;
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = self->config;
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp1_ = boxes_box_config_get_uuid (_tmp0_);
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp2_ = _tmp1_;
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp3_ = _tmp2_;
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp4_ = _tmp3_ == NULL;
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_free0 (_tmp3_);
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp4_) {
#line 1305 "machine.c"
		GError* _tmp5_ = NULL;
#line 252 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp5_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_INVALID, "no uuid, cannot build screenshot filename");
#line 252 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_inner_error_ = _tmp5_;
#line 252 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		if (_inner_error_->domain == BOXES_ERROR) {
#line 252 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			g_propagate_error (error, _inner_error_);
#line 252 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			return NULL;
#line 1317 "machine.c"
		} else {
#line 252 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 252 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			g_clear_error (&_inner_error_);
#line 252 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			return NULL;
#line 1325 "machine.c"
		}
	}
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp6_ = self->config;
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp7_ = boxes_box_config_get_uuid (_tmp6_);
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp8_ = _tmp7_;
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp9_ = _tmp8_;
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp10_ = boxes_get_screenshot_filename (_tmp9_);
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp11_ = _tmp10_;
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_free0 (_tmp9_);
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	result = _tmp11_;
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	return result;
#line 1346 "machine.c"
}


static void boxes_machine_save_data_free (gpointer _data) {
	BoxesMachineSaveData* _data_;
	_data_ = _data;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (_data_->self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_slice_free (BoxesMachineSaveData, _data_);
#line 1357 "machine.c"
}


void boxes_machine_save (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesMachineSaveData* _data_;
	BoxesMachine* _tmp0_ = NULL;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_ = g_slice_new0 (BoxesMachineSaveData);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_machine_save);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_machine_save_data_free);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->self = _tmp0_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_machine_save_co (_data_);
#line 1376 "machine.c"
}


void boxes_machine_save_finish (BoxesMachine* self, GAsyncResult* _res_, GError** error) {
	BoxesMachineSaveData* _data_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		return;
#line 1386 "machine.c"
	}
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 1390 "machine.c"
}


static void boxes_machine_save_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesMachineSaveData* _data_;
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_ = _user_data_;
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_source_object_ = source_object;
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_res_ = _res_;
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_machine_save_co (_data_);
#line 1404 "machine.c"
}


static gboolean boxes_machine_save_co (BoxesMachineSaveData* _data_) {
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	switch (_data_->_state_) {
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		case 0:
#line 1413 "machine.c"
		goto _state_0;
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		case 1:
#line 1417 "machine.c"
		goto _state_1;
		default:
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_assert_not_reached ();
#line 1422 "machine.c"
	}
	_state_0:
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_tmp0_ = 0;
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_tmp0_ = boxes_machine_get_state (_data_->self);
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_tmp1_ = 0;
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_tmp1_ = _data_->_tmp0_;
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_data_->_tmp1_ == BOXES_MACHINE_MACHINE_STATE_SAVED) {
#line 259 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp2_ = NULL;
#line 259 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp2_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _data_->self);
#line 259 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp3_ = NULL;
#line 259 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp3_ = _data_->_tmp2_;
#line 259 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_debug ("machine.vala:259: Not saving '%s' since it's already in saved state.", _data_->_tmp3_);
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		if (_data_->_state_ == 0) {
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1449 "machine.c"
		} else {
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1453 "machine.c"
		}
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_object_unref (_data_->_async_result);
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		return FALSE;
#line 1459 "machine.c"
	}
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_tmp4_ = NULL;
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_tmp4_ = _data_->self->priv->_info;
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_tmp5_ = NULL;
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_tmp5_ = g_strdup (_data_->_tmp4_);
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->info = _data_->_tmp5_;
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_tmp7_ = NULL;
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_tmp7_ = _data_->info;
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_data_->_tmp7_ != NULL) {
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp8_ = NULL;
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp8_ = _data_->info;
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp9_ = NULL;
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp9_ = g_strconcat (_data_->_tmp8_, "\n", NULL);
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_free0 (_data_->_tmp6_);
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp6_ = _data_->_tmp9_;
#line 1489 "machine.c"
	} else {
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp10_ = NULL;
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp10_ = g_strdup ("");
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_free0 (_data_->_tmp6_);
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp6_ = _data_->_tmp10_;
#line 1499 "machine.c"
	}
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_machine_set_info (_data_->self, _data_->_tmp6_);
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_tmp11_ = NULL;
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_tmp11_ = _data_->self->priv->_info;
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_tmp12_ = NULL;
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_tmp12_ = _ ("Saving…");
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_tmp13_ = NULL;
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_tmp13_ = g_strconcat (_data_->_tmp11_, _data_->_tmp12_, NULL);
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_tmp14_ = NULL;
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_tmp14_ = _data_->_tmp13_;
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_machine_set_info (_data_->self, _data_->_tmp14_);
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_free0 (_data_->_tmp14_);
#line 1523 "machine.c"
	{
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_state_ = 1;
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_machine_save_real (_data_->self, boxes_machine_save_ready, _data_);
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		return FALSE;
#line 1531 "machine.c"
		_state_1:
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_machine_save_real_finish (_data_->self, _data_->_res_, &_data_->_inner_error_);
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 1537 "machine.c"
			goto __finally50;
		}
	}
	__finally50:
	{
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp15_ = NULL;
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp15_ = _data_->info;
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_machine_set_info (_data_->self, _data_->_tmp15_);
#line 1549 "machine.c"
	}
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_error_free (_data_->_inner_error_);
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_free0 (_data_->_tmp6_);
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_free0 (_data_->info);
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		if (_data_->_state_ == 0) {
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1565 "machine.c"
		} else {
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1569 "machine.c"
		}
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_object_unref (_data_->_async_result);
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		return FALSE;
#line 1575 "machine.c"
	}
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_free0 (_data_->_tmp6_);
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_free0 (_data_->info);
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_data_->_state_ == 0) {
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1585 "machine.c"
	} else {
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1589 "machine.c"
	}
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_unref (_data_->_async_result);
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	return FALSE;
#line 1595 "machine.c"
}


static gboolean __lambda15_ (BoxesMachine* self) {
	gboolean result = FALSE;
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_machine_try_save (self, NULL, NULL);
#line 281 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	self->priv->autosave_timeout_id = (guint) 0;
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	result = FALSE;
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	return result;
#line 1609 "machine.c"
}


static gboolean ___lambda15__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda15_ ((BoxesMachine*) self);
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	return result;
#line 1618 "machine.c"
}


void boxes_machine_schedule_autosave (BoxesMachine* self) {
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	const gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	guint _tmp4_ = 0U;
#line 274 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_if_fail (self != NULL);
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = boxes_machine_get_should_autosave (self);
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp1_ = _tmp0_;
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (!_tmp1_) {
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		return;
#line 1638 "machine.c"
	}
#line 278 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp2_ = boxes_collection_item_get_name ((BoxesCollectionItem*) self);
#line 278 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp3_ = _tmp2_;
#line 278 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_debug ("machine.vala:278: Scheduling autosave for '%s'", _tmp3_);
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp4_ = g_timeout_add_seconds_full (G_PRIORITY_DEFAULT, BOXES_MACHINE_AUTOSAVE_TIMEOUT, ___lambda15__gsource_func, g_object_ref (self), g_object_unref);
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	self->priv->autosave_timeout_id = _tmp4_;
#line 1650 "machine.c"
}


void boxes_machine_unschedule_autosave (BoxesMachine* self) {
	guint _tmp0_ = 0U;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_if_fail (self != NULL);
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = self->priv->autosave_timeout_id;
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp0_ == ((guint) 0)) {
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		return;
#line 1667 "machine.c"
	}
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp1_ = boxes_collection_item_get_name ((BoxesCollectionItem*) self);
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp2_ = _tmp1_;
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_debug ("machine.vala:291: Unscheduling autosave for '%s'", _tmp2_);
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp3_ = self->priv->autosave_timeout_id;
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_source_remove (_tmp3_);
#line 293 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	self->priv->autosave_timeout_id = (guint) 0;
#line 1681 "machine.c"
}


static void boxes_machine_real_save_real_data_free (gpointer _data) {
	BoxesMachineSaveRealData* _data_;
	_data_ = _data;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (_data_->self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_slice_free (BoxesMachineSaveRealData, _data_);
#line 1692 "machine.c"
}


static void boxes_machine_real_save_real (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesMachineSaveRealData* _data_;
	BoxesMachine* _tmp0_ = NULL;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_ = g_slice_new0 (BoxesMachineSaveRealData);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_machine_real_save_real);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_machine_real_save_real_data_free);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->self = _tmp0_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_machine_real_save_real_co (_data_);
#line 1711 "machine.c"
}


static void boxes_machine_real_save_real_finish (BoxesMachine* self, GAsyncResult* _res_, GError** error) {
	BoxesMachineSaveRealData* _data_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		return;
#line 1721 "machine.c"
	}
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 1725 "machine.c"
}


static gboolean boxes_machine_real_save_real_co (BoxesMachineSaveRealData* _data_) {
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	switch (_data_->_state_) {
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		case 0:
#line 1734 "machine.c"
		goto _state_0;
		default:
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_assert_not_reached ();
#line 1739 "machine.c"
	}
	_state_0:
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_data_->_state_ == 0) {
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1746 "machine.c"
	} else {
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1750 "machine.c"
	}
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_unref (_data_->_async_result);
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	return FALSE;
#line 1756 "machine.c"
}


void boxes_machine_save_real (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	BOXES_MACHINE_GET_CLASS (self)->save_real (self, _callback_, _user_data_);
#line 1763 "machine.c"
}


void boxes_machine_save_real_finish (BoxesMachine* self, GAsyncResult* _res_, GError** error) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	BOXES_MACHINE_GET_CLASS (self)->save_real_finish (self, _res_, error);
#line 1770 "machine.c"
}


static void boxes_machine_real_take_screenshot_data_free (gpointer _data) {
	BoxesMachineTakeScreenshotData* _data_;
	_data_ = _data;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (_data_->result);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (_data_->self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_slice_free (BoxesMachineTakeScreenshotData, _data_);
#line 1783 "machine.c"
}


static void boxes_machine_real_take_screenshot (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesMachineTakeScreenshotData* _data_;
	BoxesMachine* _tmp0_ = NULL;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_ = g_slice_new0 (BoxesMachineTakeScreenshotData);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_machine_real_take_screenshot);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_machine_real_take_screenshot_data_free);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->self = _tmp0_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_machine_real_take_screenshot_co (_data_);
#line 1802 "machine.c"
}


static GdkPixbuf* boxes_machine_real_take_screenshot_finish (BoxesMachine* self, GAsyncResult* _res_, GError** error) {
	GdkPixbuf* result;
	BoxesMachineTakeScreenshotData* _data_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		return NULL;
#line 1813 "machine.c"
	}
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	result = _data_->result;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->result = NULL;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	return result;
#line 1823 "machine.c"
}


static gboolean boxes_machine_real_take_screenshot_co (BoxesMachineTakeScreenshotData* _data_) {
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	switch (_data_->_state_) {
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		case 0:
#line 1832 "machine.c"
		goto _state_0;
		default:
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_assert_not_reached ();
#line 1837 "machine.c"
	}
	_state_0:
#line 306 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_tmp0_ = NULL;
#line 306 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_tmp0_ = boxes_machine_get_display (_data_->self);
#line 306 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_tmp1_ = NULL;
#line 306 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_tmp1_ = _data_->_tmp0_;
#line 306 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_data_->_tmp1_ == NULL) {
#line 307 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->result = NULL;
#line 307 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		if (_data_->_state_ == 0) {
#line 307 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1856 "machine.c"
		} else {
#line 307 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1860 "machine.c"
		}
#line 307 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_object_unref (_data_->_async_result);
#line 307 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		return FALSE;
#line 1866 "machine.c"
	}
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_tmp3_ = NULL;
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_tmp3_ = boxes_machine_get_display (_data_->self);
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_tmp4_ = NULL;
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_tmp4_ = _data_->_tmp3_;
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_tmp5_ = NULL;
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_tmp5_ = boxes_display_get_pixbuf (_data_->_tmp4_, 0, &_data_->_inner_error_);
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_tmp2_ = _data_->_tmp5_;
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_error_free (_data_->_inner_error_);
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		if (_data_->_state_ == 0) {
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1892 "machine.c"
		} else {
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1896 "machine.c"
		}
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_object_unref (_data_->_async_result);
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		return FALSE;
#line 1902 "machine.c"
	}
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_tmp6_ = NULL;
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_tmp6_ = _data_->_tmp2_;
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_tmp2_ = NULL;
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->result = _data_->_tmp6_;
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (_data_->_tmp2_);
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_data_->_state_ == 0) {
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1918 "machine.c"
	} else {
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1922 "machine.c"
	}
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_unref (_data_->_async_result);
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	return FALSE;
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (_data_->_tmp2_);
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_data_->_state_ == 0) {
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1934 "machine.c"
	} else {
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1938 "machine.c"
	}
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_unref (_data_->_async_result);
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	return FALSE;
#line 1944 "machine.c"
}


void boxes_machine_take_screenshot (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	BOXES_MACHINE_GET_CLASS (self)->take_screenshot (self, _callback_, _user_data_);
#line 1951 "machine.c"
}


GdkPixbuf* boxes_machine_take_screenshot_finish (BoxesMachine* self, GAsyncResult* _res_, GError** error) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	return BOXES_MACHINE_GET_CLASS (self)->take_screenshot_finish (self, _res_, error);
#line 1958 "machine.c"
}


static GList* boxes_machine_real_get_properties (BoxesMachine* self, BoxesPropertiesPage page, PropertyCreationFlag* flags) {
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_critical ("Type `%s' does not implement abstract method `boxes_machine_get_properties'", g_type_name (G_TYPE_FROM_INSTANCE (self)));
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	return NULL;
#line 1967 "machine.c"
}


GList* boxes_machine_get_properties (BoxesMachine* self, BoxesPropertiesPage page, PropertyCreationFlag* flags) {
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	return BOXES_MACHINE_GET_CLASS (self)->get_properties (self, page, flags);
#line 1976 "machine.c"
}


gboolean boxes_machine_is_connected (BoxesMachine* self) {
	gboolean result = FALSE;
	BoxesDisplay* _tmp0_ = NULL;
	BoxesDisplay* _tmp1_ = NULL;
	BoxesDisplay* _tmp2_ = NULL;
	BoxesDisplay* _tmp3_ = NULL;
	gboolean _tmp4_ = FALSE;
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 315 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = boxes_machine_get_display (self);
#line 315 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp1_ = _tmp0_;
#line 315 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp1_ == NULL) {
#line 316 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		result = FALSE;
#line 316 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		return result;
#line 1999 "machine.c"
	}
#line 318 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp2_ = boxes_machine_get_display (self);
#line 318 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp3_ = _tmp2_;
#line 318 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp4_ = _tmp3_->connected;
#line 318 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	result = _tmp4_;
#line 318 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	return result;
#line 2011 "machine.c"
}


void boxes_machine_connect_display (BoxesMachine* self, BoxesMachineConnectFlags flags, GAsyncReadyCallback _callback_, gpointer _user_data_) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	BOXES_MACHINE_GET_CLASS (self)->connect_display (self, flags, _callback_, _user_data_);
#line 2018 "machine.c"
}


void boxes_machine_connect_display_finish (BoxesMachine* self, GAsyncResult* _res_, GError** error) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	BOXES_MACHINE_GET_CLASS (self)->connect_display_finish (self, _res_, error);
#line 2025 "machine.c"
}


static void boxes_machine_real_restart (BoxesMachine* self) {
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_critical ("Type `%s' does not implement abstract method `boxes_machine_restart'", g_type_name (G_TYPE_FROM_INSTANCE (self)));
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	return;
#line 2034 "machine.c"
}


void boxes_machine_restart (BoxesMachine* self) {
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_if_fail (self != NULL);
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	BOXES_MACHINE_GET_CLASS (self)->restart (self);
#line 2043 "machine.c"
}


static void boxes_machine_real_disconnect_display (BoxesMachine* self) {
	BoxesDisplay* _tmp0_ = NULL;
	BoxesDisplay* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	BoxesMachineMachineState _tmp3_ = 0;
	BoxesMachineMachineState _tmp4_ = 0;
	BoxesAppWindow* _tmp14_ = NULL;
	BoxesAppWindow* _tmp15_ = NULL;
	BoxesDisplayPage* _tmp16_ = NULL;
	GtkWidget* _tmp17_ = NULL;
	GtkWidget* _tmp18_ = NULL;
	BoxesDisplay* _tmp19_ = NULL;
	BoxesDisplay* _tmp20_ = NULL;
	gboolean _tmp21_ = FALSE;
	GError * _inner_error_ = NULL;
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = boxes_machine_get_display (self);
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp1_ = _tmp0_;
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp1_ == NULL) {
#line 326 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		return;
#line 2070 "machine.c"
	}
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp3_ = boxes_machine_get_state (self);
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp4_ = _tmp3_;
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp4_ != BOXES_MACHINE_MACHINE_STATE_STOPPED) {
#line 2078 "machine.c"
		BoxesMachineMachineState _tmp5_ = 0;
		BoxesMachineMachineState _tmp6_ = 0;
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp5_ = boxes_machine_get_state (self);
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp6_ = _tmp5_;
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp2_ = _tmp6_ != BOXES_MACHINE_MACHINE_STATE_FORCE_STOPPED;
#line 2087 "machine.c"
	} else {
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp2_ = FALSE;
#line 2091 "machine.c"
	}
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp2_) {
#line 2095 "machine.c"
		{
			GdkPixbuf* pixbuf = NULL;
			BoxesDisplay* _tmp7_ = NULL;
			BoxesDisplay* _tmp8_ = NULL;
			GdkPixbuf* _tmp9_ = NULL;
			GdkPixbuf* _tmp10_ = NULL;
#line 330 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp7_ = boxes_machine_get_display (self);
#line 330 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp8_ = _tmp7_;
#line 330 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp9_ = boxes_display_get_pixbuf (_tmp8_, 0, &_inner_error_);
#line 330 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			pixbuf = _tmp9_;
#line 330 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2112 "machine.c"
				goto __catch51_g_error;
			}
#line 331 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp10_ = pixbuf;
#line 331 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			if (_tmp10_ != NULL) {
#line 2119 "machine.c"
				GdkPixbuf* _tmp11_ = NULL;
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
				_tmp11_ = pixbuf;
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
				boxes_machine_set_screenshot (self, _tmp11_, TRUE);
#line 2125 "machine.c"
			}
#line 329 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_g_object_unref0 (pixbuf);
#line 2129 "machine.c"
		}
		goto __finally51;
		__catch51_g_error:
		{
			GError* _error_ = NULL;
			GError* _tmp12_ = NULL;
			const gchar* _tmp13_ = NULL;
#line 329 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_error_ = _inner_error_;
#line 329 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_inner_error_ = NULL;
#line 334 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp12_ = _error_;
#line 334 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp13_ = _tmp12_->message;
#line 334 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			g_warning ("machine.vala:334: %s", _tmp13_);
#line 329 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_g_error_free0 (_error_);
#line 2149 "machine.c"
		}
		__finally51:
#line 329 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 329 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 329 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			g_clear_error (&_inner_error_);
#line 329 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			return;
#line 2160 "machine.c"
		}
	}
#line 338 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp14_ = boxes_machine_get_window (self);
#line 338 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp15_ = _tmp14_;
#line 338 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp16_ = _tmp15_->display_page;
#line 338 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp17_ = boxes_display_page_remove_display (_tmp16_);
#line 338 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp18_ = _tmp17_;
#line 338 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (_tmp18_);
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp19_ = boxes_machine_get_display (self);
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp20_ = _tmp19_;
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp21_ = boxes_display_should_keep_alive (_tmp20_);
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (!_tmp21_) {
#line 2183 "machine.c"
		BoxesDisplay* _tmp22_ = NULL;
		BoxesDisplay* _tmp23_ = NULL;
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp22_ = boxes_machine_get_display (self);
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp23_ = _tmp22_;
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_display_disconnect_it (_tmp23_);
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_machine_set_display (self, NULL);
#line 2194 "machine.c"
	} else {
		BoxesDisplay* _tmp24_ = NULL;
		BoxesDisplay* _tmp25_ = NULL;
#line 343 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp24_ = boxes_machine_get_display (self);
#line 343 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp25_ = _tmp24_;
#line 343 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_display_set_enable_audio (_tmp25_, FALSE);
#line 2204 "machine.c"
	}
#line 346 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_machine_set_window (self, NULL);
#line 2208 "machine.c"
}


void boxes_machine_disconnect_display (BoxesMachine* self) {
#line 324 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_if_fail (self != NULL);
#line 324 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	BOXES_MACHINE_GET_CLASS (self)->disconnect_display (self);
#line 2217 "machine.c"
}


void boxes_machine_create_display_config (BoxesMachine* self, const gchar* uuid) {
	BoxesBoxConfig* _tmp0_ = NULL;
	gchar* group = NULL;
	gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	BoxesCollectionSource* _tmp8_ = NULL;
	const gchar* _tmp9_ = NULL;
	BoxesBoxConfig* _tmp10_ = NULL;
	BoxesBoxConfig* _tmp11_ = NULL;
	gchar* _tmp12_ = NULL;
	gchar* _tmp13_ = NULL;
	gchar* _tmp14_ = NULL;
	const gchar* _tmp15_ = NULL;
	const gchar* _tmp16_ = NULL;
	gboolean _tmp17_ = FALSE;
	gboolean _tmp21_ = FALSE;
	const gchar* _tmp22_ = NULL;
	BoxesBoxConfig* _tmp30_ = NULL;
	gchar* _tmp31_ = NULL;
	gchar* _tmp32_ = NULL;
	gchar* _tmp33_ = NULL;
	gboolean _tmp34_ = FALSE;
	BoxesBoxConfig* _tmp38_ = NULL;
	BoxesBoxConfig* _tmp39_ = NULL;
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_if_fail (self != NULL);
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = self->config;
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_vala_return_if_fail (_tmp0_ == NULL, "this.config == null");
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp1_ = g_strdup ("display");
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	group = _tmp1_;
#line 354 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp2_ = uuid;
#line 354 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp2_ != NULL) {
#line 2259 "machine.c"
		const gchar* _tmp3_ = NULL;
		const gchar* _tmp4_ = NULL;
		gchar* _tmp5_ = NULL;
		gchar* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp3_ = group;
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp4_ = uuid;
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp5_ = g_strconcat (" ", _tmp4_, NULL);
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp6_ = _tmp5_;
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp7_ = g_strconcat (_tmp3_, _tmp6_, NULL);
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_free0 (group);
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		group = _tmp7_;
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_free0 (_tmp6_);
#line 2281 "machine.c"
	}
#line 357 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp8_ = self->source;
#line 357 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp9_ = group;
#line 357 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp10_ = boxes_box_config_new_with_group (_tmp8_, _tmp9_);
#line 357 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->config);
#line 357 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	self->config = _tmp10_;
#line 358 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp11_ = self->config;
#line 358 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp12_ = boxes_box_config_get_last_seen_name (_tmp11_);
#line 358 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp13_ = _tmp12_;
#line 358 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp14_ = _tmp13_;
#line 358 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp15_ = boxes_collection_item_get_name ((BoxesCollectionItem*) self);
#line 358 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp16_ = _tmp15_;
#line 358 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp17_ = g_strcmp0 (_tmp14_, _tmp16_) != 0;
#line 358 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_free0 (_tmp14_);
#line 358 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp17_) {
#line 2311 "machine.c"
		BoxesBoxConfig* _tmp18_ = NULL;
		const gchar* _tmp19_ = NULL;
		const gchar* _tmp20_ = NULL;
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp18_ = self->config;
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp19_ = boxes_collection_item_get_name ((BoxesCollectionItem*) self);
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp20_ = _tmp19_;
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_box_config_set_last_seen_name (_tmp18_, _tmp20_);
#line 2323 "machine.c"
	}
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp22_ = uuid;
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp22_ != NULL) {
#line 2329 "machine.c"
		BoxesBoxConfig* _tmp23_ = NULL;
		gchar* _tmp24_ = NULL;
		gchar* _tmp25_ = NULL;
		gchar* _tmp26_ = NULL;
		const gchar* _tmp27_ = NULL;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp23_ = self->config;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp24_ = boxes_box_config_get_uuid (_tmp23_);
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp25_ = _tmp24_;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp26_ = _tmp25_;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp27_ = uuid;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp21_ = g_strcmp0 (_tmp26_, _tmp27_) != 0;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_free0 (_tmp26_);
#line 2349 "machine.c"
	} else {
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp21_ = FALSE;
#line 2353 "machine.c"
	}
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp21_) {
#line 2357 "machine.c"
		BoxesBoxConfig* _tmp28_ = NULL;
		const gchar* _tmp29_ = NULL;
#line 363 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp28_ = self->config;
#line 363 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp29_ = uuid;
#line 363 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_box_config_set_uuid (_tmp28_, _tmp29_);
#line 2366 "machine.c"
	}
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp30_ = self->config;
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp31_ = boxes_box_config_get_uuid (_tmp30_);
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp32_ = _tmp31_;
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp33_ = _tmp32_;
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp34_ = _tmp33_ == NULL;
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_free0 (_tmp33_);
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp34_) {
#line 2382 "machine.c"
		BoxesBoxConfig* _tmp35_ = NULL;
		gchar* _tmp36_ = NULL;
		gchar* _tmp37_ = NULL;
#line 366 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp35_ = self->config;
#line 366 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp36_ = boxes_uuid_generate ();
#line 366 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp37_ = _tmp36_;
#line 366 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_box_config_set_uuid (_tmp35_, _tmp37_);
#line 366 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_free0 (_tmp37_);
#line 2396 "machine.c"
	}
#line 368 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp38_ = self->config;
#line 368 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_iconfig_save ((BoxesIConfig*) _tmp38_);
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_free0 (group);
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp39_ = self->config;
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_vala_warn_if_fail (_tmp39_ != NULL, "this.config != null");
#line 2408 "machine.c"
}


gboolean boxes_machine_is_running (BoxesMachine* self) {
	gboolean result = FALSE;
	BoxesMachineMachineState _tmp0_ = 0;
	BoxesMachineMachineState _tmp1_ = 0;
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = boxes_machine_get_state (self);
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp1_ = _tmp0_;
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	result = _tmp1_ == BOXES_MACHINE_MACHINE_STATE_RUNNING;
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	return result;
#line 2426 "machine.c"
}


gboolean boxes_machine_is_on (BoxesMachine* self) {
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	BoxesMachineMachineState _tmp2_ = 0;
	BoxesMachineMachineState _tmp3_ = 0;
#line 375 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp2_ = boxes_machine_get_state (self);
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp3_ = _tmp2_;
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp3_ == BOXES_MACHINE_MACHINE_STATE_RUNNING) {
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp1_ = TRUE;
#line 2446 "machine.c"
	} else {
		BoxesMachineMachineState _tmp4_ = 0;
		BoxesMachineMachineState _tmp5_ = 0;
#line 377 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp4_ = boxes_machine_get_state (self);
#line 377 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp5_ = _tmp4_;
#line 377 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp1_ = _tmp5_ == BOXES_MACHINE_MACHINE_STATE_PAUSED;
#line 2456 "machine.c"
	}
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp1_) {
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp0_ = TRUE;
#line 2462 "machine.c"
	} else {
		BoxesMachineMachineState _tmp6_ = 0;
		BoxesMachineMachineState _tmp7_ = 0;
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp6_ = boxes_machine_get_state (self);
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp7_ = _tmp6_;
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp0_ = _tmp7_ == BOXES_MACHINE_MACHINE_STATE_SLEEPING;
#line 2472 "machine.c"
	}
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	result = _tmp0_;
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	return result;
#line 2478 "machine.c"
}


static void boxes_machine_save_pixbuf_as_screenshot (BoxesMachine* self, GdkPixbuf* pixbuf) {
	GError * _inner_error_ = NULL;
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_if_fail (self != NULL);
#line 2486 "machine.c"
	{
		gchar* _tmp0_ = NULL;
		gchar* _tmp1_ = NULL;
		GdkPixbuf* _tmp2_ = NULL;
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp1_ = boxes_machine_get_screenshot_filename (self, &_inner_error_);
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp0_ = _tmp1_;
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2497 "machine.c"
			goto __catch52_g_error;
		}
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp2_ = pixbuf;
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		gdk_pixbuf_save (_tmp2_, _tmp0_, "png", &_inner_error_, NULL);
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_g_free0 (_tmp0_);
#line 2508 "machine.c"
			goto __catch52_g_error;
		}
#line 382 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_free0 (_tmp0_);
#line 2513 "machine.c"
	}
	goto __finally52;
	__catch52_g_error:
	{
		GError* _error_ = NULL;
		GError* _tmp3_ = NULL;
		const gchar* _tmp4_ = NULL;
#line 382 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_error_ = _inner_error_;
#line 382 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_inner_error_ = NULL;
#line 385 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp3_ = _error_;
#line 385 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp4_ = _tmp3_->message;
#line 385 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_warning ("machine.vala:385: %s", _tmp4_);
#line 382 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_error_free0 (_error_);
#line 2533 "machine.c"
	}
	__finally52:
#line 382 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 382 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 382 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_clear_error (&_inner_error_);
#line 382 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		return;
#line 2544 "machine.c"
	}
}


static gint boxes_machine_pixbuf_energy (BoxesMachine* self, GdkPixbuf* pixbuf) {
	gint result = 0;
	guint8* pixels = NULL;
	GdkPixbuf* _tmp0_ = NULL;
	guint8* _tmp1_ = NULL;
	gint pixels_length1 = 0;
	gint _pixels_size_ = 0;
	gint w = 0;
	GdkPixbuf* _tmp2_ = NULL;
	gint _tmp3_ = 0;
	gint h = 0;
	GdkPixbuf* _tmp4_ = NULL;
	gint _tmp5_ = 0;
	gint rowstride = 0;
	GdkPixbuf* _tmp6_ = NULL;
	gint _tmp7_ = 0;
	gint n_channels = 0;
	GdkPixbuf* _tmp8_ = NULL;
	gint _tmp9_ = 0;
	gint energy = 0;
	gint row_start = 0;
	gint _tmp40_ = 0;
	gint _tmp41_ = 0;
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_val_if_fail (pixbuf != NULL, 0);
#line 392 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = pixbuf;
#line 392 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp1_ = gdk_pixbuf_get_pixels (_tmp0_);
#line 392 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	pixels = _tmp1_;
#line 392 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	pixels_length1 = -1;
#line 392 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_pixels_size_ = pixels_length1;
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp2_ = pixbuf;
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp3_ = gdk_pixbuf_get_width (_tmp2_);
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	w = _tmp3_;
#line 394 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp4_ = pixbuf;
#line 394 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp5_ = gdk_pixbuf_get_height (_tmp4_);
#line 394 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	h = _tmp5_;
#line 395 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp6_ = pixbuf;
#line 395 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp7_ = gdk_pixbuf_get_rowstride (_tmp6_);
#line 395 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	rowstride = _tmp7_;
#line 396 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp8_ = pixbuf;
#line 396 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp9_ = gdk_pixbuf_get_n_channels (_tmp8_);
#line 396 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	n_channels = _tmp9_;
#line 398 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	energy = 0;
#line 399 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	row_start = 0;
#line 2614 "machine.c"
	{
		gint y = 0;
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		y = 0;
#line 2619 "machine.c"
		{
			gboolean _tmp10_ = FALSE;
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp10_ = TRUE;
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			while (TRUE) {
#line 2626 "machine.c"
				gint _tmp12_ = 0;
				gint _tmp13_ = 0;
				gint row_energy = 0;
				gint i = 0;
				gint _tmp14_ = 0;
				gint _tmp35_ = 0;
				gint _tmp36_ = 0;
				gint _tmp37_ = 0;
				gint _tmp38_ = 0;
				gint _tmp39_ = 0;
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
				if (!_tmp10_) {
#line 2639 "machine.c"
					gint _tmp11_ = 0;
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
					_tmp11_ = y;
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
					y = _tmp11_ + 1;
#line 2645 "machine.c"
				}
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
				_tmp10_ = FALSE;
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
				_tmp12_ = y;
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
				_tmp13_ = h;
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
				if (!(_tmp12_ < _tmp13_)) {
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
					break;
#line 2657 "machine.c"
				}
#line 401 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
				row_energy = 0;
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
				_tmp14_ = row_start;
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
				i = _tmp14_;
#line 2665 "machine.c"
				{
					gint x = 0;
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
					x = 0;
#line 2670 "machine.c"
					{
						gboolean _tmp15_ = FALSE;
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
						_tmp15_ = TRUE;
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
						while (TRUE) {
#line 2677 "machine.c"
							gint _tmp17_ = 0;
							gint _tmp18_ = 0;
							gint max = 0;
							guint8* _tmp19_ = NULL;
							gint _tmp19__length1 = 0;
							gint _tmp20_ = 0;
							guint8 _tmp21_ = 0U;
							guint8* _tmp22_ = NULL;
							gint _tmp22__length1 = 0;
							gint _tmp23_ = 0;
							guint8 _tmp24_ = 0U;
							gint _tmp25_ = 0;
							guint8* _tmp26_ = NULL;
							gint _tmp26__length1 = 0;
							gint _tmp27_ = 0;
							guint8 _tmp28_ = 0U;
							gint _tmp29_ = 0;
							gint _tmp30_ = 0;
							gint _tmp31_ = 0;
							gint _tmp32_ = 0;
							gint _tmp33_ = 0;
							gint _tmp34_ = 0;
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
							if (!_tmp15_) {
#line 2702 "machine.c"
								gint _tmp16_ = 0;
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
								_tmp16_ = x;
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
								x = _tmp16_ + 1;
#line 2708 "machine.c"
							}
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
							_tmp15_ = FALSE;
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
							_tmp17_ = x;
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
							_tmp18_ = w;
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
							if (!(_tmp17_ < _tmp18_)) {
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
								break;
#line 2720 "machine.c"
							}
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
							_tmp19_ = pixels;
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
							_tmp19__length1 = pixels_length1;
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
							_tmp20_ = i;
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
							_tmp21_ = _tmp19_[_tmp20_ + 0];
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
							_tmp22_ = pixels;
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
							_tmp22__length1 = pixels_length1;
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
							_tmp23_ = i;
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
							_tmp24_ = _tmp22_[_tmp23_ + 1];
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
							_tmp25_ = MAX ((gint) _tmp21_, (gint) _tmp24_);
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
							_tmp26_ = pixels;
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
							_tmp26__length1 = pixels_length1;
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
							_tmp27_ = i;
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
							_tmp28_ = _tmp26_[_tmp27_ + 2];
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
							_tmp29_ = MAX (_tmp25_, (gint) _tmp28_);
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
							max = _tmp29_;
#line 405 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
							_tmp30_ = row_energy;
#line 405 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
							_tmp31_ = max;
#line 405 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
							_tmp32_ = max;
#line 405 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
							row_energy = _tmp30_ + (_tmp31_ * _tmp32_);
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
							_tmp33_ = i;
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
							_tmp34_ = n_channels;
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
							i = _tmp33_ + _tmp34_;
#line 2766 "machine.c"
						}
					}
				}
#line 408 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
				_tmp35_ = energy;
#line 408 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
				_tmp36_ = row_energy;
#line 408 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
				_tmp37_ = w;
#line 408 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
				energy = _tmp35_ + (_tmp36_ / _tmp37_);
#line 409 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
				_tmp38_ = row_start;
#line 409 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
				_tmp39_ = rowstride;
#line 409 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
				row_start = _tmp38_ + _tmp39_;
#line 2784 "machine.c"
			}
		}
	}
#line 411 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp40_ = energy;
#line 411 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp41_ = h;
#line 411 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	result = _tmp40_ / _tmp41_;
#line 411 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	return result;
#line 2796 "machine.c"
}


static void boxes_machine_set_screenshot (BoxesMachine* self, GdkPixbuf* large_screenshot, gboolean save) {
	GdkPixbuf* _tmp0_ = NULL;
#line 414 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_if_fail (self != NULL);
#line 415 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = large_screenshot;
#line 415 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp0_ != NULL) {
#line 2808 "machine.c"
		gint pw = 0;
		GdkPixbuf* _tmp1_ = NULL;
		gint _tmp2_ = 0;
		gint ph = 0;
		GdkPixbuf* _tmp3_ = NULL;
		gint _tmp4_ = 0;
		gdouble s = 0.0;
		gint _tmp5_ = 0;
		gint _tmp6_ = 0;
		gdouble _tmp7_ = 0.0;
		gint w = 0;
		gint _tmp8_ = 0;
		gdouble _tmp9_ = 0.0;
		gint h = 0;
		gint _tmp10_ = 0;
		gdouble _tmp11_ = 0.0;
		GdkPixbuf* small_screenshot = NULL;
		GdkPixbuf* _tmp12_ = NULL;
		gboolean _tmp13_ = FALSE;
		gboolean _tmp14_ = FALSE;
		gint _tmp15_ = 0;
		gint _tmp16_ = 0;
		GdkPixbuf* _tmp17_ = NULL;
		GdkPixbuf* _tmp18_ = NULL;
		GdkPixbuf* _tmp19_ = NULL;
		gint _tmp20_ = 0;
		gint _tmp21_ = 0;
		gdouble _tmp22_ = 0.0;
		gdouble _tmp23_ = 0.0;
		GdkPixbuf* _tmp24_ = NULL;
		gint _tmp25_ = 0;
		GdkPixbuf* _tmp26_ = NULL;
		GdkPixbuf* _tmp27_ = NULL;
		GdkPixbuf* _tmp28_ = NULL;
		GdkPixbuf* _tmp29_ = NULL;
		GdkPixbuf* _tmp30_ = NULL;
		gboolean _tmp31_ = FALSE;
#line 416 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp1_ = large_screenshot;
#line 416 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp2_ = gdk_pixbuf_get_width (_tmp1_);
#line 416 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		pw = _tmp2_;
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp3_ = large_screenshot;
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp4_ = gdk_pixbuf_get_height (_tmp3_);
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		ph = _tmp4_;
#line 418 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp5_ = pw;
#line 418 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp6_ = ph;
#line 418 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp7_ = MIN (((gdouble) BOXES_MACHINE_SCREENSHOT_WIDTH) / _tmp5_, ((gdouble) BOXES_MACHINE_SCREENSHOT_HEIGHT) / _tmp6_);
#line 418 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		s = _tmp7_;
#line 419 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp8_ = pw;
#line 419 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp9_ = s;
#line 419 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		w = (gint) (_tmp8_ * _tmp9_);
#line 420 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp10_ = ph;
#line 420 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp11_ = s;
#line 420 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		h = (gint) (_tmp10_ * _tmp11_);
#line 422 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp12_ = large_screenshot;
#line 422 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp13_ = gdk_pixbuf_get_has_alpha (_tmp12_);
#line 422 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp14_ = _tmp13_;
#line 422 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp15_ = w;
#line 422 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp16_ = h;
#line 422 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp17_ = gdk_pixbuf_new (GDK_COLORSPACE_RGB, _tmp14_, 8, _tmp15_, _tmp16_);
#line 422 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		small_screenshot = _tmp17_;
#line 423 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp18_ = large_screenshot;
#line 423 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp19_ = small_screenshot;
#line 423 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp20_ = w;
#line 423 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp21_ = h;
#line 423 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp22_ = s;
#line 423 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp23_ = s;
#line 423 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		gdk_pixbuf_scale (_tmp18_, _tmp19_, 0, 0, _tmp20_, _tmp21_, (gdouble) 0, (gdouble) 0, _tmp22_, _tmp23_, GDK_INTERP_HYPER);
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp24_ = small_screenshot;
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp25_ = boxes_machine_pixbuf_energy (self, _tmp24_);
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		if (_tmp25_ < 50) {
#line 434 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_g_object_unref0 (small_screenshot);
#line 434 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			return;
#line 2916 "machine.c"
		}
#line 436 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp26_ = small_screenshot;
#line 436 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp27_ = _g_object_ref0 (_tmp26_);
#line 436 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_object_unref0 (self->priv->orig_pixbuf);
#line 436 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		self->priv->orig_pixbuf = _tmp27_;
#line 437 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp28_ = small_screenshot;
#line 437 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp29_ = boxes_machine_draw_vm (self, _tmp28_, BOXES_MACHINE_SCREENSHOT_WIDTH, BOXES_MACHINE_SCREENSHOT_HEIGHT);
#line 437 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp30_ = _tmp29_;
#line 437 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_machine_set_pixbuf (self, _tmp30_);
#line 437 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_object_unref0 (_tmp30_);
#line 438 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp31_ = save;
#line 438 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		if (_tmp31_) {
#line 2940 "machine.c"
			GdkPixbuf* _tmp32_ = NULL;
#line 439 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp32_ = small_screenshot;
#line 439 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			boxes_machine_save_pixbuf_as_screenshot (self, _tmp32_);
#line 2946 "machine.c"
		}
#line 415 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_object_unref0 (small_screenshot);
#line 2950 "machine.c"
	} else {
		GdkPixbuf* _tmp33_ = NULL;
		GdkPixbuf* _tmp34_ = NULL;
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_object_unref0 (self->priv->orig_pixbuf);
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		self->priv->orig_pixbuf = NULL;
#line 443 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp33_ = boxes_machine_draw_stopped_vm (BOXES_MACHINE_SCREENSHOT_WIDTH, BOXES_MACHINE_SCREENSHOT_HEIGHT);
#line 443 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp34_ = _tmp33_;
#line 443 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_machine_set_pixbuf (self, _tmp34_);
#line 443 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_object_unref0 (_tmp34_);
#line 2966 "machine.c"
	}
}


static void boxes_machine_update_screenshot_data_free (gpointer _data) {
	BoxesMachineUpdateScreenshotData* _data_;
	_data_ = _data;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (_data_->self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_slice_free (BoxesMachineUpdateScreenshotData, _data_);
#line 2978 "machine.c"
}


static void boxes_machine_update_screenshot (BoxesMachine* self, gboolean force_save, gboolean first_check, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesMachineUpdateScreenshotData* _data_;
	BoxesMachine* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_ = g_slice_new0 (BoxesMachineUpdateScreenshotData);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_machine_update_screenshot);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_machine_update_screenshot_data_free);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->self = _tmp0_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp1_ = force_save;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->force_save = _tmp1_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp2_ = first_check;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->first_check = _tmp2_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_machine_update_screenshot_co (_data_);
#line 3007 "machine.c"
}


static void boxes_machine_update_screenshot_finish (BoxesMachine* self, GAsyncResult* _res_) {
	BoxesMachineUpdateScreenshotData* _data_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 3015 "machine.c"
}


static void boxes_machine_update_screenshot_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesMachineUpdateScreenshotData* _data_;
#line 456 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_ = _user_data_;
#line 456 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_source_object_ = source_object;
#line 456 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_res_ = _res_;
#line 456 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_machine_update_screenshot_co (_data_);
#line 3029 "machine.c"
}


static gboolean boxes_machine_update_screenshot_co (BoxesMachineUpdateScreenshotData* _data_) {
#line 448 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	switch (_data_->_state_) {
#line 448 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		case 0:
#line 3038 "machine.c"
		goto _state_0;
#line 448 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		case 1:
#line 3042 "machine.c"
		goto _state_1;
#line 448 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		case 2:
#line 3046 "machine.c"
		goto _state_2;
		default:
#line 448 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_assert_not_reached ();
#line 3051 "machine.c"
	}
	_state_0:
#line 449 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_tmp0_ = FALSE;
#line 449 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_tmp0_ = _data_->self->priv->updating_screenshot;
#line 449 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_data_->_tmp0_) {
#line 450 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		if (_data_->_state_ == 0) {
#line 450 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3064 "machine.c"
		} else {
#line 450 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 3068 "machine.c"
		}
#line 450 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_object_unref (_data_->_async_result);
#line 450 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		return FALSE;
#line 3074 "machine.c"
	}
#line 452 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->self->priv->updating_screenshot = TRUE;
#line 454 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->large_screenshot = NULL;
#line 3080 "machine.c"
	{
#line 456 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_state_ = 1;
#line 456 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_machine_take_screenshot (_data_->self, boxes_machine_update_screenshot_ready, _data_);
#line 456 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		return FALSE;
#line 3088 "machine.c"
		_state_1:
#line 456 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp2_ = NULL;
#line 456 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp2_ = boxes_machine_take_screenshot_finish (_data_->self, _data_->_res_, &_data_->_inner_error_);
#line 456 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp1_ = _data_->_tmp2_;
#line 456 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 3098 "machine.c"
			goto __catch53_g_error;
		}
#line 456 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp3_ = NULL;
#line 456 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp3_ = _data_->_tmp1_;
#line 456 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp1_ = NULL;
#line 456 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_object_unref0 (_data_->large_screenshot);
#line 456 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->large_screenshot = _data_->_tmp3_;
#line 460 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp4_ = FALSE;
#line 460 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp4_ = _data_->first_check;
#line 460 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		if (_data_->_tmp4_) {
#line 461 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_data_->_state_ = 2;
#line 461 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			boxes_machine_take_screenshot (_data_->self, boxes_machine_update_screenshot_ready, _data_);
#line 461 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			return FALSE;
#line 3123 "machine.c"
			_state_2:
#line 461 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_data_->_tmp6_ = NULL;
#line 461 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_data_->_tmp6_ = boxes_machine_take_screenshot_finish (_data_->self, _data_->_res_, &_data_->_inner_error_);
#line 461 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_data_->_tmp5_ = _data_->_tmp6_;
#line 461 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 461 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
				_g_object_unref0 (_data_->_tmp1_);
#line 3135 "machine.c"
				goto __catch53_g_error;
			}
#line 461 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_data_->_tmp7_ = NULL;
#line 461 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_data_->_tmp7_ = _data_->_tmp5_;
#line 461 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_data_->_tmp5_ = NULL;
#line 461 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_g_object_unref0 (_data_->large_screenshot);
#line 461 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_data_->large_screenshot = _data_->_tmp7_;
#line 460 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_g_object_unref0 (_data_->_tmp5_);
#line 3150 "machine.c"
		}
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_object_unref0 (_data_->_tmp1_);
#line 3154 "machine.c"
	}
	goto __finally53;
	__catch53_g_error:
	{
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_inner_error_ = NULL;
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_error_free0 (_data_->_error_);
#line 3165 "machine.c"
	}
	__finally53:
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_object_unref0 (_data_->large_screenshot);
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_clear_error (&_data_->_inner_error_);
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		return FALSE;
#line 3178 "machine.c"
	}
#line 465 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_tmp8_ = NULL;
#line 465 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_tmp8_ = _data_->large_screenshot;
#line 465 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_data_->_tmp8_ != NULL) {
#line 466 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp10_ = FALSE;
#line 466 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp10_ = _data_->force_save;
#line 466 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		if (_data_->_tmp10_) {
#line 466 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_data_->_tmp9_ = TRUE;
#line 3194 "machine.c"
		} else {
#line 466 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_data_->_tmp11_ = 0;
#line 466 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_data_->_tmp11_ = _data_->self->priv->screenshot_counter;
#line 466 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_data_->self->priv->screenshot_counter = _data_->_tmp11_ + 1;
#line 466 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_data_->_tmp9_ = (_data_->_tmp11_ % 12) == 0;
#line 3204 "machine.c"
		}
#line 466 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp12_ = NULL;
#line 466 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp12_ = _data_->large_screenshot;
#line 466 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_machine_set_screenshot (_data_->self, _data_->_tmp12_, _data_->_tmp9_);
#line 3212 "machine.c"
	}
#line 468 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->self->priv->updating_screenshot = FALSE;
#line 448 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (_data_->large_screenshot);
#line 448 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_data_->_state_ == 0) {
#line 448 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3222 "machine.c"
	} else {
#line 448 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3226 "machine.c"
	}
#line 448 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_unref (_data_->_async_result);
#line 448 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	return FALSE;
#line 3232 "machine.c"
}


static GdkPixbuf* boxes_machine_draw_vm (BoxesMachine* self, GdkPixbuf* pixbuf, gint width, gint height) {
	GdkPixbuf* result = NULL;
	cairo_surface_t* surface = NULL;
	gint _tmp0_ = 0;
	gint _tmp1_ = 0;
	cairo_surface_t* _tmp2_ = NULL;
	cairo_t* context = NULL;
	cairo_surface_t* _tmp3_ = NULL;
	cairo_t* _tmp4_ = NULL;
	gint pw = 0;
	GdkPixbuf* _tmp5_ = NULL;
	gint _tmp6_ = 0;
	gint ph = 0;
	GdkPixbuf* _tmp7_ = NULL;
	gint _tmp8_ = 0;
	gint x = 0;
	gint _tmp9_ = 0;
	gint _tmp10_ = 0;
	gint y = 0;
	gint _tmp11_ = 0;
	gint _tmp12_ = 0;
	cairo_t* _tmp13_ = NULL;
	gint _tmp14_ = 0;
	gint _tmp15_ = 0;
	gint _tmp16_ = 0;
	gint _tmp17_ = 0;
	cairo_t* _tmp18_ = NULL;
	cairo_t* _tmp19_ = NULL;
	GdkPixbuf* _tmp20_ = NULL;
	gint _tmp21_ = 0;
	gint _tmp22_ = 0;
	cairo_t* _tmp23_ = NULL;
	cairo_t* _tmp24_ = NULL;
	gboolean _tmp25_ = FALSE;
	cairo_surface_t* _tmp37_ = NULL;
	gint _tmp38_ = 0;
	gint _tmp39_ = 0;
	GdkPixbuf* _tmp40_ = NULL;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_val_if_fail (pixbuf != NULL, NULL);
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = width;
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp1_ = height;
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp2_ = cairo_image_surface_create (CAIRO_FORMAT_ARGB32, _tmp0_, _tmp1_);
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	surface = _tmp2_;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp3_ = surface;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp4_ = cairo_create (_tmp3_);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	context = _tmp4_;
#line 475 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp5_ = pixbuf;
#line 475 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp6_ = gdk_pixbuf_get_width (_tmp5_);
#line 475 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	pw = _tmp6_;
#line 476 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp7_ = pixbuf;
#line 476 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp8_ = gdk_pixbuf_get_height (_tmp7_);
#line 476 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	ph = _tmp8_;
#line 477 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp9_ = width;
#line 477 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp10_ = pw;
#line 477 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	x = (_tmp9_ - _tmp10_) / 2;
#line 478 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp11_ = height;
#line 478 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp12_ = ph;
#line 478 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	y = (_tmp11_ - _tmp12_) / 2;
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp13_ = context;
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp14_ = x;
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp15_ = y;
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp16_ = pw;
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp17_ = ph;
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	cairo_rectangle (_tmp13_, (gdouble) _tmp14_, (gdouble) _tmp15_, (gdouble) _tmp16_, (gdouble) _tmp17_);
#line 481 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp18_ = context;
#line 481 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	cairo_clip (_tmp18_);
#line 483 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp19_ = context;
#line 483 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp20_ = pixbuf;
#line 483 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp21_ = x;
#line 483 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp22_ = y;
#line 483 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	gdk_cairo_set_source_pixbuf (_tmp19_, _tmp20_, (gdouble) _tmp21_, (gdouble) _tmp22_);
#line 484 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp23_ = context;
#line 484 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	cairo_set_operator (_tmp23_, CAIRO_OPERATOR_SOURCE);
#line 485 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp24_ = context;
#line 485 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	cairo_paint (_tmp24_);
#line 487 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp25_ = boxes_machine_is_running (self);
#line 487 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (!_tmp25_) {
#line 3354 "machine.c"
		cairo_t* _tmp26_ = NULL;
		cairo_t* _tmp27_ = NULL;
		cairo_t* _tmp28_ = NULL;
		cairo_t* _tmp29_ = NULL;
		cairo_pattern_t* grid = NULL;
		cairo_surface_t* _tmp30_ = NULL;
		cairo_pattern_t* _tmp31_ = NULL;
		cairo_pattern_t* _tmp32_ = NULL;
		cairo_t* _tmp33_ = NULL;
		cairo_t* _tmp34_ = NULL;
		cairo_t* _tmp35_ = NULL;
		cairo_pattern_t* _tmp36_ = NULL;
#line 488 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp26_ = context;
#line 488 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		cairo_set_source_rgba (_tmp26_, (gdouble) 1, (gdouble) 1, (gdouble) 1, (gdouble) 1);
#line 489 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp27_ = context;
#line 489 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		cairo_set_operator (_tmp27_, CAIRO_OPERATOR_HSL_SATURATION);
#line 490 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp28_ = context;
#line 490 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		cairo_paint (_tmp28_);
#line 492 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp29_ = context;
#line 492 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		cairo_scale (_tmp29_, 2.0, 2.0);
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp30_ = boxes_machine_grid_surface;
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp31_ = cairo_pattern_create_for_surface (_tmp30_);
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		grid = _tmp31_;
#line 494 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp32_ = grid;
#line 494 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		cairo_pattern_set_extend (_tmp32_, CAIRO_EXTEND_REPEAT);
#line 495 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp33_ = context;
#line 495 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		cairo_set_source_rgba (_tmp33_, 0.2, 0.2, 0.2, (gdouble) 1);
#line 496 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp34_ = context;
#line 496 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		cairo_set_operator (_tmp34_, CAIRO_OPERATOR_ADD);
#line 497 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp35_ = context;
#line 497 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp36_ = grid;
#line 497 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		cairo_mask (_tmp35_, _tmp36_);
#line 487 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_cairo_pattern_destroy0 (grid);
#line 3409 "machine.c"
	}
#line 500 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp37_ = surface;
#line 500 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp38_ = width;
#line 500 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp39_ = height;
#line 500 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp40_ = gdk_pixbuf_get_from_surface (_tmp37_, 0, 0, _tmp38_, _tmp39_);
#line 500 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	result = _tmp40_;
#line 500 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_cairo_destroy0 (context);
#line 500 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_cairo_surface_destroy0 (surface);
#line 500 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	return result;
#line 3427 "machine.c"
}


static GdkPixbuf* boxes_machine_draw_stopped_vm (gint width, gint height) {
	GdkPixbuf* result = NULL;
	cairo_surface_t* surface = NULL;
	gint _tmp0_ = 0;
	gint _tmp1_ = 0;
	cairo_surface_t* _tmp2_ = NULL;
	gint _tmp3_ = 0;
	gint _tmp4_ = 0;
	GdkPixbuf* _tmp5_ = NULL;
#line 505 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = width;
#line 505 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp1_ = height;
#line 505 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp2_ = cairo_image_surface_create (CAIRO_FORMAT_RGB24, _tmp0_, _tmp1_);
#line 505 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	surface = _tmp2_;
#line 506 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp3_ = width;
#line 506 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp4_ = height;
#line 506 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp5_ = gdk_pixbuf_get_from_surface (surface, 0, 0, _tmp3_, _tmp4_);
#line 506 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	result = _tmp5_;
#line 506 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_cairo_surface_destroy0 (surface);
#line 506 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	return result;
#line 3460 "machine.c"
}


static GdkPixbuf* boxes_machine_draw_fallback_vm (gint width, gint height, gboolean force) {
	GdkPixbuf* result = NULL;
	GdkPixbuf* pixbuf = NULL;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	gint _tmp2_ = 0;
	GdkPixbuf* _tmp40_ = NULL;
	cairo_surface_t* surface = NULL;
	gint _tmp41_ = 0;
	gint _tmp42_ = 0;
	cairo_surface_t* _tmp43_ = NULL;
	cairo_surface_t* _tmp44_ = NULL;
	gint _tmp45_ = 0;
	gint _tmp46_ = 0;
	GdkPixbuf* _tmp47_ = NULL;
	GError * _inner_error_ = NULL;
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	pixbuf = NULL;
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp2_ = width;
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp2_ == BOXES_MACHINE_SCREENSHOT_WIDTH) {
#line 3486 "machine.c"
		gint _tmp3_ = 0;
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp3_ = height;
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp1_ = _tmp3_ == BOXES_MACHINE_SCREENSHOT_HEIGHT;
#line 3492 "machine.c"
	} else {
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp1_ = FALSE;
#line 3496 "machine.c"
	}
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp1_) {
#line 3500 "machine.c"
		gboolean _tmp4_ = FALSE;
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp4_ = force;
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp0_ = !_tmp4_;
#line 3506 "machine.c"
	} else {
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp0_ = FALSE;
#line 3510 "machine.c"
	}
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp0_) {
#line 3514 "machine.c"
		GdkPixbuf* _tmp5_ = NULL;
#line 516 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp5_ = boxes_machine_default_fallback;
#line 516 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		if (_tmp5_ != NULL) {
#line 3520 "machine.c"
			GdkPixbuf* _tmp6_ = NULL;
			GdkPixbuf* _tmp7_ = NULL;
#line 517 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp6_ = boxes_machine_default_fallback;
#line 517 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp7_ = _g_object_ref0 (_tmp6_);
#line 517 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			result = _tmp7_;
#line 517 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_g_object_unref0 (pixbuf);
#line 517 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			return result;
#line 3533 "machine.c"
		} else {
			gint _tmp8_ = 0;
			gint _tmp9_ = 0;
			GdkPixbuf* _tmp10_ = NULL;
#line 519 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp8_ = width;
#line 519 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp9_ = height;
#line 519 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp10_ = boxes_machine_draw_fallback_vm (_tmp8_, _tmp9_, TRUE);
#line 519 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_g_object_unref0 (boxes_machine_default_fallback);
#line 519 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			boxes_machine_default_fallback = _tmp10_;
#line 3548 "machine.c"
		}
	}
	{
		cairo_surface_t* surface = NULL;
		gint _tmp11_ = 0;
		gint _tmp12_ = 0;
		cairo_surface_t* _tmp13_ = NULL;
		cairo_t* context = NULL;
		cairo_surface_t* _tmp14_ = NULL;
		cairo_t* _tmp15_ = NULL;
		gint size = 0;
		gint _tmp16_ = 0;
		GtkIconInfo* icon_info = NULL;
		GtkIconTheme* _tmp17_ = NULL;
		gint _tmp18_ = 0;
		GtkIconInfo* _tmp19_ = NULL;
		GdkPixbuf* _tmp20_ = NULL;
		GtkIconInfo* _tmp21_ = NULL;
		GdkPixbuf* _tmp22_ = NULL;
		cairo_t* _tmp23_ = NULL;
		gint _tmp24_ = 0;
		gint _tmp25_ = 0;
		gint _tmp26_ = 0;
		gint _tmp27_ = 0;
		cairo_t* _tmp28_ = NULL;
		gint _tmp29_ = 0;
		gint _tmp30_ = 0;
		gint _tmp31_ = 0;
		gint _tmp32_ = 0;
		gint _tmp33_ = 0;
		gint _tmp34_ = 0;
		cairo_t* _tmp35_ = NULL;
		cairo_surface_t* _tmp36_ = NULL;
		gint _tmp37_ = 0;
		gint _tmp38_ = 0;
		GdkPixbuf* _tmp39_ = NULL;
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp11_ = width;
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp12_ = height;
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp13_ = cairo_image_surface_create (CAIRO_FORMAT_ARGB32, _tmp11_, _tmp12_);
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		surface = _tmp13_;
#line 523 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp14_ = surface;
#line 523 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp15_ = cairo_create (_tmp14_);
#line 523 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		context = _tmp15_;
#line 525 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp16_ = height;
#line 525 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		size = (gint) (_tmp16_ * 0.6);
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp17_ = gtk_icon_theme_get_default ();
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp18_ = size;
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp19_ = gtk_icon_theme_lookup_icon (_tmp17_, "computer-symbolic", _tmp18_, GTK_ICON_LOOKUP_GENERIC_FALLBACK);
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		icon_info = _tmp19_;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp21_ = icon_info;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp22_ = gtk_icon_info_load_icon (_tmp21_, &_inner_error_);
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp20_ = _tmp22_;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_gtk_icon_info_free0 (icon_info);
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_cairo_destroy0 (context);
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_cairo_surface_destroy0 (surface);
#line 3625 "machine.c"
			goto __catch54_g_error;
		}
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp23_ = context;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp24_ = width;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp25_ = size;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp26_ = height;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp27_ = size;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		gdk_cairo_set_source_pixbuf (_tmp23_, _tmp20_, (gdouble) ((_tmp24_ - _tmp25_) / 2), (gdouble) ((_tmp26_ - _tmp27_) / 2));
#line 530 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp28_ = context;
#line 530 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp29_ = width;
#line 530 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp30_ = size;
#line 530 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp31_ = height;
#line 530 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp32_ = size;
#line 530 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp33_ = size;
#line 530 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp34_ = size;
#line 530 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		cairo_rectangle (_tmp28_, (gdouble) ((_tmp29_ - _tmp30_) / 2), (gdouble) ((_tmp31_ - _tmp32_) / 2), (gdouble) _tmp33_, (gdouble) _tmp34_);
#line 531 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp35_ = context;
#line 531 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		cairo_fill (_tmp35_);
#line 532 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp36_ = surface;
#line 532 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp37_ = width;
#line 532 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp38_ = height;
#line 532 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp39_ = gdk_pixbuf_get_from_surface (_tmp36_, 0, 0, _tmp37_, _tmp38_);
#line 532 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_object_unref0 (pixbuf);
#line 532 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		pixbuf = _tmp39_;
#line 521 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_object_unref0 (_tmp20_);
#line 521 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_gtk_icon_info_free0 (icon_info);
#line 521 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_cairo_destroy0 (context);
#line 521 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_cairo_surface_destroy0 (surface);
#line 3680 "machine.c"
	}
	goto __finally54;
	__catch54_g_error:
	{
#line 521 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_clear_error (&_inner_error_);
#line 521 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_inner_error_ = NULL;
#line 3689 "machine.c"
	}
	__finally54:
#line 521 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 521 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_object_unref0 (pixbuf);
#line 521 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 521 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_clear_error (&_inner_error_);
#line 521 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		return NULL;
#line 3702 "machine.c"
	}
#line 536 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp40_ = pixbuf;
#line 536 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp40_ != NULL) {
#line 537 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		result = pixbuf;
#line 537 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		return result;
#line 3712 "machine.c"
	}
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp41_ = width;
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp42_ = height;
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp43_ = cairo_image_surface_create (CAIRO_FORMAT_ARGB32, _tmp41_, _tmp42_);
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	surface = _tmp43_;
#line 540 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp44_ = surface;
#line 540 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp45_ = width;
#line 540 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp46_ = height;
#line 540 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp47_ = gdk_pixbuf_get_from_surface (_tmp44_, 0, 0, _tmp45_, _tmp46_);
#line 540 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	result = _tmp47_;
#line 540 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_cairo_surface_destroy0 (surface);
#line 540 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (pixbuf);
#line 540 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	return result;
#line 3738 "machine.c"
}


static void boxes_machine_real_delete (BoxesMachine* self, gboolean by_user) {
	gulong _tmp0_ = 0UL;
	BoxesBoxConfig* _tmp5_ = NULL;
	GError * _inner_error_ = NULL;
#line 544 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_machine_set_deleted (self, TRUE);
#line 546 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_machine_set_screenshot_enable (self, FALSE);
#line 547 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = self->priv->ui_state_id;
#line 547 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp0_ != ((gulong) 0)) {
#line 3754 "machine.c"
		BoxesApp* _tmp1_ = NULL;
		BoxesAppWindow* _tmp2_ = NULL;
		BoxesAppWindow* _tmp3_ = NULL;
		gulong _tmp4_ = 0UL;
#line 548 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp1_ = boxes_app_app;
#line 548 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp2_ = boxes_app_get_main_window (_tmp1_);
#line 548 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp3_ = _tmp2_;
#line 548 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp4_ = self->priv->ui_state_id;
#line 548 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_signal_handler_disconnect ((GObject*) _tmp3_, _tmp4_);
#line 549 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		self->priv->ui_state_id = (gulong) 0;
#line 3771 "machine.c"
	}
#line 552 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp5_ = self->config;
#line 552 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_box_config_delete (_tmp5_);
#line 3777 "machine.c"
	{
		gchar* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
#line 554 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp7_ = boxes_machine_get_screenshot_filename (self, &_inner_error_);
#line 554 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp6_ = _tmp7_;
#line 554 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 554 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			if (_inner_error_->domain == BOXES_ERROR) {
#line 3789 "machine.c"
				goto __catch55_boxes_error;
			}
#line 554 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 554 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			g_clear_error (&_inner_error_);
#line 554 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			return;
#line 3798 "machine.c"
		}
#line 554 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_unlink (_tmp6_);
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_free0 (_tmp6_);
#line 3804 "machine.c"
	}
	goto __finally55;
	__catch55_boxes_error:
	{
		GError* e = NULL;
		GError* _tmp8_ = NULL;
		const gchar* _tmp9_ = NULL;
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		e = _inner_error_;
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_inner_error_ = NULL;
#line 556 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp8_ = e;
#line 556 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp9_ = _tmp8_->message;
#line 556 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_debug ("machine.vala:556: Could not delete screenshot: %s", _tmp9_);
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_error_free0 (e);
#line 3824 "machine.c"
	}
	__finally55:
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_clear_error (&_inner_error_);
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		return;
#line 3835 "machine.c"
	}
}


void boxes_machine_delete (BoxesMachine* self, gboolean by_user) {
#line 543 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_if_fail (self != NULL);
#line 543 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	BOXES_MACHINE_GET_CLASS (self)->delete (self, by_user);
#line 3845 "machine.c"
}


static void boxes_machine_ui_state_changed (BoxesMachine* self) {
	BoxesUIState _tmp0_ = 0;
	BoxesUIState _tmp1_ = 0;
#line 560 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_if_fail (self != NULL);
#line 561 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 561 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp1_ = _tmp0_;
#line 561 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	switch (_tmp1_) {
#line 561 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		case BOXES_UI_STATE_CREDS:
#line 3862 "machine.c"
		{
			BoxesAppWindow* _tmp2_ = NULL;
			BoxesAppWindow* _tmp3_ = NULL;
			GtkStack* _tmp4_ = NULL;
#line 563 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp2_ = boxes_machine_get_window (self);
#line 563 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp3_ = _tmp2_;
#line 563 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp4_ = _tmp3_->below_bin;
#line 563 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			gtk_stack_set_visible_child_name (_tmp4_, "connecting-page");
#line 564 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			boxes_machine_try_connect_display (self, BOXES_MACHINE_CONNECT_FLAGS_NONE, NULL, NULL);
#line 566 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			break;
#line 3879 "machine.c"
		}
#line 561 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		case BOXES_UI_STATE_DISPLAY:
#line 3883 "machine.c"
		{
			BoxesUIState _tmp5_ = 0;
			BoxesUIState _tmp6_ = 0;
#line 568 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp5_ = boxes_ui_get_previous_ui_state ((BoxesUI*) self);
#line 568 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp6_ = _tmp5_;
#line 568 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			if (_tmp6_ == BOXES_UI_STATE_PROPERTIES) {
#line 3893 "machine.c"
				BoxesAppWindow* _tmp7_ = NULL;
				BoxesAppWindow* _tmp8_ = NULL;
				GtkStack* _tmp9_ = NULL;
#line 569 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
				_tmp7_ = boxes_machine_get_window (self);
#line 569 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
				_tmp8_ = _tmp7_;
#line 569 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
				_tmp9_ = _tmp8_->below_bin;
#line 569 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
				gtk_stack_set_visible_child_name (_tmp9_, "display-page");
#line 3905 "machine.c"
			}
#line 571 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			break;
#line 3909 "machine.c"
		}
#line 561 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		case BOXES_UI_STATE_COLLECTION:
#line 3913 "machine.c"
		{
			GdNotification* _tmp10_ = NULL;
#line 574 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp10_ = self->priv->auth_notification;
#line 574 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			if (_tmp10_ != NULL) {
#line 3920 "machine.c"
				GdNotification* _tmp11_ = NULL;
#line 575 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
				_tmp11_ = self->priv->auth_notification;
#line 575 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
				gd_notification_dismiss (_tmp11_);
#line 3926 "machine.c"
			}
#line 576 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			boxes_machine_disconnect_display (self);
#line 578 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			break;
#line 3932 "machine.c"
		}
		default:
#line 561 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		break;
#line 3937 "machine.c"
	}
}


static void boxes_machine_try_connect_display_data_free (gpointer _data) {
	BoxesMachineTryConnectDisplayData* _data_;
	_data_ = _data;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (_data_->self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_slice_free (BoxesMachineTryConnectDisplayData, _data_);
#line 3949 "machine.c"
}


static void boxes_machine_try_connect_display (BoxesMachine* self, BoxesMachineConnectFlags flags, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesMachineTryConnectDisplayData* _data_;
	BoxesMachine* _tmp0_ = NULL;
	BoxesMachineConnectFlags _tmp1_ = 0;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_ = g_slice_new0 (BoxesMachineTryConnectDisplayData);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_machine_try_connect_display);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_machine_try_connect_display_data_free);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->self = _tmp0_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp1_ = flags;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->flags = _tmp1_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_machine_try_connect_display_co (_data_);
#line 3973 "machine.c"
}


static void boxes_machine_try_connect_display_finish (BoxesMachine* self, GAsyncResult* _res_) {
	BoxesMachineTryConnectDisplayData* _data_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 3981 "machine.c"
}


static Block50Data* block50_data_ref (Block50Data* _data50_) {
#line 582 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_atomic_int_inc (&_data50_->_ref_count_);
#line 582 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	return _data50_;
#line 3990 "machine.c"
}


static void block50_data_unref (void * _userdata_) {
	Block50Data* _data50_;
	_data50_ = (Block50Data*) _userdata_;
#line 582 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (g_atomic_int_dec_and_test (&_data50_->_ref_count_)) {
#line 3999 "machine.c"
		BoxesMachine* self;
#line 582 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		self = _data50_->self;
#line 582 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_object_unref0 (self);
#line 582 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_slice_free (Block50Data, _data50_);
#line 4007 "machine.c"
	}
}


static void boxes_machine_try_connect_display_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesMachineTryConnectDisplayData* _data_;
#line 584 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_ = _user_data_;
#line 584 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_source_object_ = source_object;
#line 584 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_res_ = _res_;
#line 584 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_machine_try_connect_display_co (_data_);
#line 4022 "machine.c"
}


static void ___lambda76_ (Block50Data* _data50_) {
	BoxesMachine* self;
	BoxesMachineConnectFlags _tmp0_ = 0;
#line 587 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	self = _data50_->self;
#line 588 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = _data50_->flags;
#line 588 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_machine_try_connect_display (self, _tmp0_ | BOXES_MACHINE_CONNECT_FLAGS_IGNORE_SAVED_STATE, NULL, NULL);
#line 4035 "machine.c"
}


static void ____lambda76__boxes_notification_ok_func (gpointer self) {
#line 587 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	___lambda76_ (self);
#line 4042 "machine.c"
}


static void ___lambda77_ (BoxesMachine* self) {
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesAppWindow* _tmp1_ = NULL;
#line 591 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = boxes_machine_get_window (self);
#line 591 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp1_ = _tmp0_;
#line 591 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_ui_set_state ((BoxesUI*) _tmp1_, BOXES_UI_STATE_COLLECTION);
#line 4055 "machine.c"
}


static void ____lambda77__gd_notification_dismissed (GdNotification* _sender, gpointer self) {
#line 590 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	___lambda77_ ((BoxesMachine*) self);
#line 4062 "machine.c"
}


static gboolean boxes_machine_try_connect_display_co (BoxesMachineTryConnectDisplayData* _data_) {
#line 582 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	switch (_data_->_state_) {
#line 582 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		case 0:
#line 4071 "machine.c"
		goto _state_0;
#line 582 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		case 1:
#line 4075 "machine.c"
		goto _state_1;
		default:
#line 582 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_assert_not_reached ();
#line 4080 "machine.c"
	}
	_state_0:
#line 582 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_data50_ = g_slice_new0 (Block50Data);
#line 582 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_data50_->_ref_count_ = 1;
#line 582 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_data50_->self = g_object_ref (_data_->self);
#line 582 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_tmp0_ = 0;
#line 582 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_tmp0_ = _data_->flags;
#line 582 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_data50_->flags = _data_->_tmp0_;
#line 582 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_data50_->_async_data_ = _data_;
#line 4097 "machine.c"
	{
#line 584 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp1_ = 0;
#line 584 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp1_ = _data_->_data50_->flags;
#line 584 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_state_ = 1;
#line 584 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_machine_connect_display (_data_->self, _data_->_tmp1_, boxes_machine_try_connect_display_ready, _data_);
#line 584 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		return FALSE;
#line 4109 "machine.c"
		_state_1:
#line 584 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_machine_connect_display_finish (_data_->self, _data_->_res_, &_data_->_inner_error_);
#line 584 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 584 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			if (g_error_matches (_data_->_inner_error_, BOXES_ERROR, BOXES_ERROR_RESTORE_FAILED)) {
#line 4117 "machine.c"
				goto __catch56_boxes_error_restore_failed;
			}
#line 584 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			if (g_error_matches (_data_->_inner_error_, BOXES_ERROR, BOXES_ERROR_START_FAILED)) {
#line 4122 "machine.c"
				goto __catch56_boxes_error_start_failed;
			}
			goto __catch56_g_error;
		}
	}
	goto __finally56;
	__catch56_boxes_error_restore_failed:
	{
#line 583 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->e = _data_->_inner_error_;
#line 583 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_inner_error_ = NULL;
#line 586 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp2_ = NULL;
#line 586 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp2_ = _ ("'%s' could not be restored from disk\nTry without saved state?");
#line 586 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp3_ = NULL;
#line 586 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp3_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _data_->self);
#line 586 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp4_ = NULL;
#line 586 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp4_ = _data_->_tmp3_;
#line 586 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp5_ = NULL;
#line 586 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp5_ = g_strdup_printf (_data_->_tmp2_, _data_->_tmp4_);
#line 586 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->message = _data_->_tmp5_;
#line 587 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp6_ = NULL;
#line 587 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp6_ = boxes_machine_get_window (_data_->self);
#line 587 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp7_ = NULL;
#line 587 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp7_ = _data_->_tmp6_;
#line 587 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp8_ = NULL;
#line 587 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp8_ = boxes_app_window_get_notificationbar (_data_->_tmp7_);
#line 587 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp9_ = NULL;
#line 587 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp9_ = _data_->_tmp8_;
#line 587 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp10_ = NULL;
#line 587 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp10_ = _data_->message;
#line 587 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp11_ = NULL;
#line 587 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp11_ = _ ("Restart");
#line 587 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp12_ = NULL;
#line 587 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp12_ = boxes_notificationbar_display_for_action (_data_->_tmp9_, _data_->_tmp10_, _data_->_tmp11_, ____lambda76__boxes_notification_ok_func, block50_data_ref (_data_->_data50_), block50_data_unref, NULL, NULL, NULL, BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT);
#line 587 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->notification = _data_->_tmp12_;
#line 590 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp13_ = NULL;
#line 590 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp13_ = _data_->notification;
#line 590 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_signal_connect_object (_data_->_tmp13_, "dismissed", (GCallback) ____lambda77__gd_notification_dismissed, _data_->self, 0);
#line 583 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_object_unref0 (_data_->notification);
#line 583 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_free0 (_data_->message);
#line 583 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_error_free0 (_data_->e);
#line 4195 "machine.c"
	}
	goto __finally56;
	__catch56_boxes_error_start_failed:
	{
#line 583 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_vala1_e = _data_->_inner_error_;
#line 583 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_inner_error_ = NULL;
#line 594 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp14_ = NULL;
#line 594 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp14_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _data_->self);
#line 594 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp15_ = NULL;
#line 594 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp15_ = _data_->_tmp14_;
#line 594 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp16_ = NULL;
#line 594 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp16_ = _data_->_vala1_e;
#line 594 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp17_ = NULL;
#line 594 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp17_ = _data_->_tmp16_->message;
#line 594 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_warning ("machine.vala:594: Failed to start %s: %s", _data_->_tmp15_, _data_->_tmp17_);
#line 595 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp18_ = NULL;
#line 595 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp18_ = boxes_machine_get_window (_data_->self);
#line 595 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp19_ = NULL;
#line 595 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp19_ = _data_->_tmp18_;
#line 595 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_ui_set_state ((BoxesUI*) _data_->_tmp19_, BOXES_UI_STATE_COLLECTION);
#line 596 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp20_ = NULL;
#line 596 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp20_ = boxes_machine_get_window (_data_->self);
#line 596 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp21_ = NULL;
#line 596 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp21_ = _data_->_tmp20_;
#line 596 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp22_ = NULL;
#line 596 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp22_ = boxes_app_window_get_notificationbar (_data_->_tmp21_);
#line 596 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp23_ = NULL;
#line 596 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp23_ = _data_->_tmp22_;
#line 596 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp24_ = NULL;
#line 596 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp24_ = _ ("Failed to start '%s'");
#line 596 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp25_ = NULL;
#line 596 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp25_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _data_->self);
#line 596 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp26_ = NULL;
#line 596 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp26_ = _data_->_tmp25_;
#line 596 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp27_ = NULL;
#line 596 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp27_ = g_strdup_printf (_data_->_tmp24_, _data_->_tmp26_);
#line 596 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp28_ = NULL;
#line 596 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp28_ = _data_->_tmp27_;
#line 596 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp29_ = NULL;
#line 596 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp29_ = boxes_notificationbar_display_error (_data_->_tmp23_, _data_->_tmp28_, BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT);
#line 596 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp30_ = NULL;
#line 596 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp30_ = _data_->_tmp29_;
#line 596 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_object_unref0 (_data_->_tmp30_);
#line 596 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_free0 (_data_->_tmp28_);
#line 583 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_error_free0 (_data_->_vala1_e);
#line 4282 "machine.c"
	}
	goto __finally56;
	__catch56_g_error:
	{
#line 583 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_vala2_e = _data_->_inner_error_;
#line 583 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_inner_error_ = NULL;
#line 598 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp31_ = NULL;
#line 598 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp31_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _data_->self);
#line 598 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp32_ = NULL;
#line 598 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp32_ = _data_->_tmp31_;
#line 598 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp33_ = NULL;
#line 598 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp33_ = _data_->_vala2_e;
#line 598 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp34_ = NULL;
#line 598 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp34_ = _data_->_tmp33_->message;
#line 598 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_warning ("machine.vala:598: Failed to connect to %s: %s", _data_->_tmp32_, _data_->_tmp34_);
#line 599 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp35_ = NULL;
#line 599 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp35_ = boxes_machine_get_window (_data_->self);
#line 599 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp36_ = NULL;
#line 599 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp36_ = _data_->_tmp35_;
#line 599 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_ui_set_state ((BoxesUI*) _data_->_tmp36_, BOXES_UI_STATE_COLLECTION);
#line 600 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp37_ = NULL;
#line 600 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp37_ = boxes_machine_get_window (_data_->self);
#line 600 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp38_ = NULL;
#line 600 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp38_ = _data_->_tmp37_;
#line 600 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp39_ = NULL;
#line 600 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp39_ = boxes_app_window_get_notificationbar (_data_->_tmp38_);
#line 600 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp40_ = NULL;
#line 600 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp40_ = _data_->_tmp39_;
#line 600 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp41_ = NULL;
#line 600 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp41_ = _ ("Connection to '%s' failed");
#line 600 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp42_ = NULL;
#line 600 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp42_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _data_->self);
#line 600 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp43_ = NULL;
#line 600 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp43_ = _data_->_tmp42_;
#line 600 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp44_ = NULL;
#line 600 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp44_ = g_strdup_printf (_data_->_tmp41_, _data_->_tmp43_);
#line 600 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp45_ = NULL;
#line 600 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp45_ = _data_->_tmp44_;
#line 600 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp46_ = NULL;
#line 600 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp46_ = boxes_notificationbar_display_error (_data_->_tmp40_, _data_->_tmp45_, BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT);
#line 600 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp47_ = NULL;
#line 600 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp47_ = _data_->_tmp46_;
#line 600 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_object_unref0 (_data_->_tmp47_);
#line 600 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_free0 (_data_->_tmp45_);
#line 583 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_error_free0 (_data_->_vala2_e);
#line 4369 "machine.c"
	}
	__finally56:
#line 583 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 583 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		block50_data_unref (_data_->_data50_);
#line 583 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_data50_ = NULL;
#line 583 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 583 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_clear_error (&_data_->_inner_error_);
#line 583 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		return FALSE;
#line 4384 "machine.c"
	}
#line 582 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	block50_data_unref (_data_->_data50_);
#line 582 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_data50_ = NULL;
#line 582 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_data_->_state_ == 0) {
#line 582 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4394 "machine.c"
	} else {
#line 582 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 4398 "machine.c"
	}
#line 582 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_unref (_data_->_async_result);
#line 582 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	return FALSE;
#line 4404 "machine.c"
}


static void __lambda75_ (BoxesMachine* self, const gchar* username, const gchar* password) {
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp3_ = NULL;
#line 614 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_if_fail (username != NULL);
#line 614 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_if_fail (password != NULL);
#line 615 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = username;
#line 615 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (g_strcmp0 (_tmp0_, "") != 0) {
#line 4419 "machine.c"
		const gchar* _tmp1_ = NULL;
		gchar* _tmp2_ = NULL;
#line 616 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp1_ = username;
#line 616 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp2_ = g_strdup (_tmp1_);
#line 616 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_free0 (self->priv->username);
#line 616 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		self->priv->username = _tmp2_;
#line 4430 "machine.c"
	}
#line 617 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp3_ = password;
#line 617 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (g_strcmp0 (_tmp3_, "") != 0) {
#line 4436 "machine.c"
		const gchar* _tmp4_ = NULL;
		gchar* _tmp5_ = NULL;
#line 618 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp4_ = password;
#line 618 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp5_ = g_strdup (_tmp4_);
#line 618 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_free0 (self->priv->password);
#line 618 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		self->priv->password = _tmp5_;
#line 4447 "machine.c"
	}
#line 620 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->priv->auth_notification);
#line 620 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	self->priv->auth_notification = NULL;
#line 621 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_machine_try_connect_display (self, BOXES_MACHINE_CONNECT_FLAGS_NONE, NULL, NULL);
#line 4455 "machine.c"
}


static void ___lambda75__boxes_auth_notification_auth_func (const gchar* username, const gchar* password, gpointer self) {
#line 614 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	__lambda75_ ((BoxesMachine*) self, username, password);
#line 4462 "machine.c"
}


static void __lambda78_ (BoxesMachine* self) {
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesAppWindow* _tmp1_ = NULL;
#line 624 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->priv->auth_notification);
#line 624 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	self->priv->auth_notification = NULL;
#line 625 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = boxes_machine_get_window (self);
#line 625 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp1_ = _tmp0_;
#line 625 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_ui_set_state ((BoxesUI*) _tmp1_, BOXES_UI_STATE_COLLECTION);
#line 4479 "machine.c"
}


static void ___lambda78__boxes_notification_cancel_func (gpointer self) {
#line 623 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	__lambda78_ ((BoxesMachine*) self);
#line 4486 "machine.c"
}


static void boxes_machine_handle_auth (BoxesMachine* self) {
	GdNotification* _tmp0_ = NULL;
	gboolean need_username = FALSE;
	BoxesDisplay* _tmp1_ = NULL;
	BoxesDisplay* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
	gboolean _tmp4_ = FALSE;
	gboolean _tmp5_ = FALSE;
	BoxesDisplay* _tmp6_ = NULL;
	BoxesDisplay* _tmp7_ = NULL;
	gboolean _tmp8_ = FALSE;
	gboolean _tmp9_ = FALSE;
	BoxesAuthNotificationAuthFunc auth_func = NULL;
	void* auth_func_target = NULL;
	GDestroyNotify auth_func_target_destroy_notify = NULL;
	BoxesNotificationCancelFunc cancel_func = NULL;
	void* cancel_func_target = NULL;
	GDestroyNotify cancel_func_target_destroy_notify = NULL;
	gchar* auth_string = NULL;
	const gchar* _tmp14_ = NULL;
	const gchar* _tmp15_ = NULL;
	const gchar* _tmp16_ = NULL;
	gchar* _tmp17_ = NULL;
	BoxesAppWindow* _tmp18_ = NULL;
	BoxesAppWindow* _tmp19_ = NULL;
	BoxesNotificationbar* _tmp20_ = NULL;
	BoxesNotificationbar* _tmp21_ = NULL;
	const gchar* _tmp22_ = NULL;
	BoxesAuthNotificationAuthFunc _tmp23_ = NULL;
	void* _tmp23__target = NULL;
	GDestroyNotify _tmp23__target_destroy_notify = NULL;
	BoxesNotificationCancelFunc _tmp24_ = NULL;
	void* _tmp24__target = NULL;
	GDestroyNotify _tmp24__target_destroy_notify = NULL;
	gboolean _tmp25_ = FALSE;
	GdNotification* _tmp26_ = NULL;
#line 606 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_if_fail (self != NULL);
#line 607 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = self->priv->auth_notification;
#line 607 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp0_ != NULL) {
#line 608 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		return;
#line 4534 "machine.c"
	}
#line 609 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp1_ = boxes_machine_get_display (self);
#line 609 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp2_ = _tmp1_;
#line 609 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp3_ = boxes_display_get_need_username (_tmp2_);
#line 609 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp4_ = _tmp3_;
#line 609 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	need_username = _tmp4_;
#line 610 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp6_ = boxes_machine_get_display (self);
#line 610 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp7_ = _tmp6_;
#line 610 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp8_ = boxes_display_get_need_username (_tmp7_);
#line 610 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp9_ = _tmp8_;
#line 610 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (!_tmp9_) {
#line 4556 "machine.c"
		BoxesDisplay* _tmp10_ = NULL;
		BoxesDisplay* _tmp11_ = NULL;
		gboolean _tmp12_ = FALSE;
		gboolean _tmp13_ = FALSE;
#line 610 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp10_ = boxes_machine_get_display (self);
#line 610 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp11_ = _tmp10_;
#line 610 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp12_ = boxes_display_get_need_password (_tmp11_);
#line 610 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp13_ = _tmp12_;
#line 610 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp5_ = !_tmp13_;
#line 4571 "machine.c"
	} else {
#line 610 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp5_ = FALSE;
#line 4575 "machine.c"
	}
#line 610 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp5_) {
#line 611 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		return;
#line 4581 "machine.c"
	}
#line 612 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_machine_set_display (self, NULL);
#line 614 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	auth_func = ___lambda75__boxes_auth_notification_auth_func;
#line 614 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	auth_func_target = g_object_ref (self);
#line 614 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	auth_func_target_destroy_notify = g_object_unref;
#line 623 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	cancel_func = ___lambda78__boxes_notification_cancel_func;
#line 623 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	cancel_func_target = g_object_ref (self);
#line 623 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	cancel_func_target_destroy_notify = g_object_unref;
#line 629 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp14_ = _ ("'%s' requires authentication");
#line 629 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp15_ = boxes_collection_item_get_name ((BoxesCollectionItem*) self);
#line 629 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp16_ = _tmp15_;
#line 629 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp17_ = g_strdup_printf (_tmp14_, _tmp16_);
#line 629 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	auth_string = _tmp17_;
#line 630 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp18_ = boxes_machine_get_window (self);
#line 630 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp19_ = _tmp18_;
#line 630 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp20_ = boxes_app_window_get_notificationbar (_tmp19_);
#line 630 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp21_ = _tmp20_;
#line 630 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp22_ = auth_string;
#line 630 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp23_ = auth_func;
#line 630 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp23__target = auth_func_target;
#line 630 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp23__target_destroy_notify = auth_func_target_destroy_notify;
#line 630 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	auth_func_target_destroy_notify = NULL;
#line 630 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp24_ = cancel_func;
#line 630 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp24__target = cancel_func_target;
#line 630 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp24__target_destroy_notify = cancel_func_target_destroy_notify;
#line 630 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	cancel_func_target_destroy_notify = NULL;
#line 630 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp25_ = need_username;
#line 630 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp26_ = boxes_notificationbar_display_for_auth (_tmp21_, _tmp22_, _tmp23_, _tmp23__target, _tmp23__target_destroy_notify, _tmp24_, _tmp24__target, _tmp24__target_destroy_notify, _tmp25_);
#line 630 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->priv->auth_notification);
#line 630 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	self->priv->auth_notification = _tmp26_;
#line 606 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_free0 (auth_string);
#line 606 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	(cancel_func_target_destroy_notify == NULL) ? NULL : (cancel_func_target_destroy_notify (cancel_func_target), NULL);
#line 606 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	cancel_func = NULL;
#line 606 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	cancel_func_target = NULL;
#line 606 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	cancel_func_target_destroy_notify = NULL;
#line 606 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	(auth_func_target_destroy_notify == NULL) ? NULL : (auth_func_target_destroy_notify (auth_func_target), NULL);
#line 606 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	auth_func = NULL;
#line 606 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	auth_func_target = NULL;
#line 606 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	auth_func_target_destroy_notify = NULL;
#line 4659 "machine.c"
}


static gint boxes_machine_real_compare (BoxesCollectionItem* base, BoxesCollectionItem* other) {
	BoxesMachine * self;
	gint result = 0;
	BoxesCollectionItem* _tmp0_ = NULL;
#line 636 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	self = (BoxesMachine*) base;
#line 636 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_val_if_fail (other != NULL, 0);
#line 637 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = other;
#line 637 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, BOXES_TYPE_MACHINE)) {
#line 4675 "machine.c"
		BoxesBoxConfig* _tmp1_ = NULL;
		BoxesCollectionItem* _tmp2_ = NULL;
		BoxesBoxConfig* _tmp3_ = NULL;
		gint _tmp4_ = 0;
#line 638 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp1_ = self->config;
#line 638 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp2_ = other;
#line 638 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp3_ = (G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp2_) : NULL)->config;
#line 638 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp4_ = boxes_box_config_compare (_tmp1_, _tmp3_);
#line 638 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		result = _tmp4_;
#line 638 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		return result;
#line 4692 "machine.c"
	} else {
#line 640 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		result = -1;
#line 640 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		return result;
#line 4698 "machine.c"
	}
}


static void boxes_machine_try_save_data_free (gpointer _data) {
	BoxesMachineTrySaveData* _data_;
	_data_ = _data;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (_data_->self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_slice_free (BoxesMachineTrySaveData, _data_);
#line 4710 "machine.c"
}


static void boxes_machine_try_save (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesMachineTrySaveData* _data_;
	BoxesMachine* _tmp0_ = NULL;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_ = g_slice_new0 (BoxesMachineTrySaveData);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_machine_try_save);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_machine_try_save_data_free);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->self = _tmp0_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_machine_try_save_co (_data_);
#line 4729 "machine.c"
}


static void boxes_machine_try_save_finish (BoxesMachine* self, GAsyncResult* _res_) {
	BoxesMachineTrySaveData* _data_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 4737 "machine.c"
}


static void boxes_machine_try_save_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesMachineTrySaveData* _data_;
#line 645 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_ = _user_data_;
#line 645 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_source_object_ = source_object;
#line 645 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_data_->_res_ = _res_;
#line 645 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_machine_try_save_co (_data_);
#line 4751 "machine.c"
}


static gboolean boxes_machine_try_save_co (BoxesMachineTrySaveData* _data_) {
#line 643 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	switch (_data_->_state_) {
#line 643 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		case 0:
#line 4760 "machine.c"
		goto _state_0;
#line 643 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		case 1:
#line 4764 "machine.c"
		goto _state_1;
		default:
#line 643 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_assert_not_reached ();
#line 4769 "machine.c"
	}
	_state_0:
	{
#line 645 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_state_ = 1;
#line 645 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_machine_save (_data_->self, boxes_machine_try_save_ready, _data_);
#line 645 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		return FALSE;
#line 4779 "machine.c"
		_state_1:
#line 645 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_machine_save_finish (_data_->self, _data_->_res_, &_data_->_inner_error_);
#line 645 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 4785 "machine.c"
			goto __catch57_g_error;
		}
	}
	goto __finally57;
	__catch57_g_error:
	{
#line 644 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 644 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_inner_error_ = NULL;
#line 647 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp0_ = NULL;
#line 647 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp0_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _data_->self);
#line 647 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp1_ = NULL;
#line 647 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp1_ = _data_->_tmp0_;
#line 647 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp2_ = NULL;
#line 647 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp2_ = _data_->_error_;
#line 647 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp3_ = NULL;
#line 647 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_data_->_tmp3_ = _data_->_tmp2_->message;
#line 647 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_warning ("machine.vala:647: Failed to save '%s': %s", _data_->_tmp1_, _data_->_tmp3_);
#line 644 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_g_error_free0 (_data_->_error_);
#line 4816 "machine.c"
	}
	__finally57:
#line 644 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 644 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 644 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_clear_error (&_data_->_inner_error_);
#line 644 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		return FALSE;
#line 4827 "machine.c"
	}
#line 643 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_data_->_state_ == 0) {
#line 643 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4833 "machine.c"
	} else {
#line 643 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 4837 "machine.c"
	}
#line 643 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_unref (_data_->_async_result);
#line 643 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	return FALSE;
#line 4843 "machine.c"
}


GdkPixbuf* boxes_machine_get_pixbuf (BoxesMachine* self) {
	GdkPixbuf* result;
	GdkPixbuf* _tmp0_ = NULL;
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = self->priv->_pixbuf;
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	result = _tmp0_;
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	return result;
#line 4858 "machine.c"
}


void boxes_machine_set_pixbuf (BoxesMachine* self, GdkPixbuf* value) {
	GdkPixbuf* _tmp0_ = NULL;
	GdkPixbuf* _tmp1_ = NULL;
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_if_fail (self != NULL);
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = value;
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->priv->_pixbuf);
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	self->priv->_pixbuf = _tmp1_;
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_notify ((GObject *) self, "pixbuf");
#line 4877 "machine.c"
}


const gchar* boxes_machine_get_info (BoxesMachine* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = self->priv->_info;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	result = _tmp0_;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	return result;
#line 4892 "machine.c"
}


void boxes_machine_set_info (BoxesMachine* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_if_fail (self != NULL);
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = value;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_free0 (self->priv->_info);
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	self->priv->_info = _tmp1_;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_notify ((GObject *) self, "info");
#line 4911 "machine.c"
}


const gchar* boxes_machine_get_status (BoxesMachine* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = self->priv->_status;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	result = _tmp0_;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	return result;
#line 4926 "machine.c"
}


void boxes_machine_set_status (BoxesMachine* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_if_fail (self != NULL);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = value;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_free0 (self->priv->_status);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	self->priv->_status = _tmp1_;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_notify ((GObject *) self, "status");
#line 4945 "machine.c"
}


gboolean boxes_machine_get_can_save (BoxesMachine* self) {
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	return BOXES_MACHINE_GET_CLASS (self)->get_can_save (self);
#line 4954 "machine.c"
}


static gboolean boxes_machine_real_get_can_save (BoxesMachine* base) {
	gboolean result;
	BoxesMachine* self;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	self = base;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	result = FALSE;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	return result;
#line 4967 "machine.c"
}


gboolean boxes_machine_get_can_delete (BoxesMachine* self) {
	gboolean result;
	gboolean _tmp0_ = FALSE;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = self->priv->_can_delete;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	result = _tmp0_;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	return result;
#line 4982 "machine.c"
}


void boxes_machine_set_can_delete (BoxesMachine* self, gboolean value) {
	gboolean _tmp0_ = FALSE;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_if_fail (self != NULL);
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = value;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	self->priv->_can_delete = _tmp0_;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_notify ((GObject *) self, "can-delete");
#line 4996 "machine.c"
}


gboolean boxes_machine_get_under_construction (BoxesMachine* self) {
	gboolean result;
	gboolean _tmp0_ = FALSE;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = self->priv->_under_construction;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	result = _tmp0_;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	return result;
#line 5011 "machine.c"
}


void boxes_machine_set_under_construction (BoxesMachine* self, gboolean value) {
	gboolean _tmp0_ = FALSE;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_if_fail (self != NULL);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = value;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	self->priv->_under_construction = _tmp0_;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_notify ((GObject *) self, "under-construction");
#line 5025 "machine.c"
}


gboolean boxes_machine_get_should_autosave (BoxesMachine* self) {
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	return BOXES_MACHINE_GET_CLASS (self)->get_should_autosave (self);
#line 5034 "machine.c"
}


static gboolean boxes_machine_real_get_should_autosave (BoxesMachine* base) {
	gboolean result;
	BoxesMachine* self;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_ = FALSE;
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	self = base;
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp2_ = boxes_machine_get_can_save (self);
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp3_ = _tmp2_;
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp3_) {
#line 5053 "machine.c"
		gboolean _tmp4_ = FALSE;
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp4_ = boxes_machine_is_running (self);
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp1_ = _tmp4_;
#line 5059 "machine.c"
	} else {
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp1_ = FALSE;
#line 5063 "machine.c"
	}
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp1_) {
#line 5067 "machine.c"
		guint _tmp5_ = 0U;
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp5_ = self->priv->autosave_timeout_id;
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp0_ = _tmp5_ == ((guint) 0);
#line 5073 "machine.c"
	} else {
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp0_ = FALSE;
#line 5077 "machine.c"
	}
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	result = _tmp0_;
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	return result;
#line 5083 "machine.c"
}


GCancellable* boxes_machine_get_connecting_cancellable (BoxesMachine* self) {
	GCancellable* result;
	GCancellable* _tmp0_ = NULL;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = self->priv->_connecting_cancellable;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	result = _tmp0_;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	return result;
#line 5098 "machine.c"
}


void boxes_machine_set_connecting_cancellable (BoxesMachine* self, GCancellable* value) {
	GCancellable* _tmp0_ = NULL;
	GCancellable* _tmp1_ = NULL;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_if_fail (self != NULL);
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = value;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->priv->_connecting_cancellable);
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	self->priv->_connecting_cancellable = _tmp1_;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_notify ((GObject *) self, "connecting-cancellable");
#line 5117 "machine.c"
}


BoxesMachineMachineState boxes_machine_get_state (BoxesMachine* self) {
	BoxesMachineMachineState result;
	BoxesMachineMachineState _tmp0_ = 0;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = self->priv->_state;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	result = _tmp0_;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	return result;
#line 5132 "machine.c"
}


void boxes_machine_set_state (BoxesMachine* self, BoxesMachineMachineState value) {
	BoxesMachineMachineState _tmp0_ = 0;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	BoxesMachineMachineState _tmp3_ = 0;
	BoxesMachineMachineState _tmp4_ = 0;
	GEnumValue* _tmp5_;
	gboolean _tmp6_ = FALSE;
	BoxesMachineMachineState _tmp7_ = 0;
	gboolean _tmp13_ = FALSE;
	gboolean _tmp14_ = FALSE;
	gboolean _tmp15_ = FALSE;
	gboolean _tmp16_ = FALSE;
	gboolean _tmp17_ = FALSE;
	gboolean _tmp18_ = FALSE;
	BoxesDisplay* _tmp19_ = NULL;
	BoxesDisplay* _tmp20_ = NULL;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_if_fail (self != NULL);
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = value;
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	self->priv->_state = _tmp0_;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp1_ = boxes_collection_item_get_name ((BoxesCollectionItem*) self);
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp2_ = _tmp1_;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp3_ = boxes_machine_get_state (self);
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp4_ = _tmp3_;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp5_ = g_enum_get_value (g_type_class_ref (BOXES_MACHINE_TYPE_MACHINE_STATE), _tmp4_);
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_debug ("machine.vala:70: State of '%s' changed to %s", _tmp2_, (_tmp5_ != NULL) ? _tmp5_->value_name : NULL);
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp7_ = value;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp7_ == BOXES_MACHINE_MACHINE_STATE_STOPPED) {
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp6_ = TRUE;
#line 5177 "machine.c"
	} else {
		BoxesMachineMachineState _tmp8_ = 0;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp8_ = value;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp6_ = _tmp8_ == BOXES_MACHINE_MACHINE_STATE_FORCE_STOPPED;
#line 5184 "machine.c"
	}
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp6_) {
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_machine_set_screenshot (self, NULL, FALSE);
#line 5190 "machine.c"
	} else {
		GdkPixbuf* _tmp9_ = NULL;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp9_ = self->priv->orig_pixbuf;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		if (_tmp9_ != NULL) {
#line 5197 "machine.c"
			GdkPixbuf* _tmp10_ = NULL;
			GdkPixbuf* _tmp11_ = NULL;
			GdkPixbuf* _tmp12_ = NULL;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp10_ = self->priv->orig_pixbuf;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp11_ = boxes_machine_draw_vm (self, _tmp10_, BOXES_MACHINE_SCREENSHOT_WIDTH, BOXES_MACHINE_SCREENSHOT_HEIGHT);
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp12_ = _tmp11_;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			boxes_machine_set_pixbuf (self, _tmp12_);
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_g_object_unref0 (_tmp12_);
#line 5211 "machine.c"
		}
	}
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp19_ = boxes_machine_get_display (self);
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp20_ = _tmp19_;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp20_ != NULL) {
#line 5220 "machine.c"
		gboolean _tmp21_ = FALSE;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp21_ = self->stay_on_display;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp18_ = !_tmp21_;
#line 5226 "machine.c"
	} else {
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp18_ = FALSE;
#line 5230 "machine.c"
	}
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp18_) {
#line 5234 "machine.c"
		BoxesAppWindow* _tmp22_ = NULL;
		BoxesAppWindow* _tmp23_ = NULL;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp22_ = boxes_machine_get_window (self);
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp23_ = _tmp22_;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp17_ = _tmp23_ != NULL;
#line 5243 "machine.c"
	} else {
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp17_ = FALSE;
#line 5247 "machine.c"
	}
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp17_) {
#line 5251 "machine.c"
		BoxesAppWindow* _tmp24_ = NULL;
		BoxesAppWindow* _tmp25_ = NULL;
		BoxesCollectionItem* _tmp26_ = NULL;
		BoxesCollectionItem* _tmp27_ = NULL;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp24_ = boxes_machine_get_window (self);
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp25_ = _tmp24_;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp26_ = boxes_app_window_get_current_item (_tmp25_);
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp27_ = _tmp26_;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp16_ = _tmp27_ == G_TYPE_CHECK_INSTANCE_CAST (self, BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem);
#line 5266 "machine.c"
	} else {
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp16_ = FALSE;
#line 5270 "machine.c"
	}
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp16_) {
#line 5274 "machine.c"
		BoxesMachineMachineState _tmp28_ = 0;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp28_ = value;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp15_ = _tmp28_ != BOXES_MACHINE_MACHINE_STATE_RUNNING;
#line 5280 "machine.c"
	} else {
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp15_ = FALSE;
#line 5284 "machine.c"
	}
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp15_) {
#line 5288 "machine.c"
		BoxesAppWindow* _tmp29_ = NULL;
		BoxesAppWindow* _tmp30_ = NULL;
		BoxesUIState _tmp31_ = 0;
		BoxesUIState _tmp32_ = 0;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp29_ = boxes_machine_get_window (self);
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp30_ = _tmp29_;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp31_ = boxes_ui_get_ui_state ((BoxesUI*) _tmp30_);
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp32_ = _tmp31_;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp14_ = _tmp32_ != BOXES_UI_STATE_PROPERTIES;
#line 5303 "machine.c"
	} else {
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp14_ = FALSE;
#line 5307 "machine.c"
	}
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp14_) {
#line 5311 "machine.c"
		BoxesMachineMachineState _tmp33_ = 0;
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp33_ = value;
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp13_ = _tmp33_ != BOXES_MACHINE_MACHINE_STATE_UNKNOWN;
#line 5317 "machine.c"
	} else {
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp13_ = FALSE;
#line 5321 "machine.c"
	}
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp13_) {
#line 5325 "machine.c"
		BoxesAppWindow* _tmp34_ = NULL;
		BoxesAppWindow* _tmp35_ = NULL;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp34_ = boxes_machine_get_window (self);
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp35_ = _tmp34_;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_ui_set_state ((BoxesUI*) _tmp35_, BOXES_UI_STATE_COLLECTION);
#line 5334 "machine.c"
	}
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_notify ((GObject *) self, "state");
#line 5338 "machine.c"
}


BoxesAppWindow* boxes_machine_get_window (BoxesMachine* self) {
	BoxesAppWindow* result;
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesAppWindow* _tmp1_ = NULL;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp1_ = self->priv->_window;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = _tmp1_;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp0_ == NULL) {
#line 5354 "machine.c"
		BoxesApp* _tmp2_ = NULL;
		BoxesAppWindow* _tmp3_ = NULL;
		BoxesAppWindow* _tmp4_ = NULL;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp2_ = boxes_app_app;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp3_ = boxes_app_get_main_window (_tmp2_);
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp4_ = _tmp3_;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp0_ = _tmp4_;
#line 5366 "machine.c"
	}
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	result = _tmp0_;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	return result;
#line 5372 "machine.c"
}


void boxes_machine_set_window (BoxesMachine* self, BoxesAppWindow* value) {
	BoxesAppWindow* _tmp0_ = NULL;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_if_fail (self != NULL);
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = value;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	self->priv->_window = _tmp0_;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_notify ((GObject *) self, "window");
#line 5386 "machine.c"
}


gboolean boxes_machine_get_deleted (BoxesMachine* self) {
	gboolean result;
	gboolean _tmp0_ = FALSE;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = self->priv->_deleted;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	result = _tmp0_;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	return result;
#line 5401 "machine.c"
}


static void boxes_machine_set_deleted (BoxesMachine* self, gboolean value) {
	gboolean _tmp0_ = FALSE;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_if_fail (self != NULL);
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = value;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	self->priv->_deleted = _tmp0_;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_notify ((GObject *) self, "deleted");
#line 5415 "machine.c"
}


BoxesDisplay* boxes_machine_get_display (BoxesMachine* self) {
	BoxesDisplay* result;
	BoxesDisplay* _tmp0_ = NULL;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = self->priv->_display;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	result = _tmp0_;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	return result;
#line 5430 "machine.c"
}


static void _boxes_machine_display___lambda13_ (BoxesMachine* self, gint id) {
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_machine_show_display (self);
#line 5437 "machine.c"
}


static void __boxes_machine_display___lambda13__boxes_display_show (BoxesDisplay* _sender, gint display_id, gpointer self) {
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_boxes_machine_display___lambda13_ ((BoxesMachine*) self, display_id);
#line 5444 "machine.c"
}


static void _boxes_machine_display___lambda72_ (BoxesMachine* self, gint id) {
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesAppWindow* _tmp1_ = NULL;
	BoxesDisplayPage* _tmp2_ = NULL;
	GtkWidget* _tmp3_ = NULL;
	GtkWidget* _tmp4_ = NULL;
#line 156 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = boxes_machine_get_window (self);
#line 156 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp1_ = _tmp0_;
#line 156 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp2_ = _tmp1_->display_page;
#line 156 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp3_ = boxes_display_page_remove_display (_tmp2_);
#line 156 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp4_ = _tmp3_;
#line 156 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (_tmp4_);
#line 5466 "machine.c"
}


static void __boxes_machine_display___lambda72__boxes_display_hide (BoxesDisplay* _sender, gint display_id, gpointer self) {
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_boxes_machine_display___lambda72_ ((BoxesMachine*) self, display_id);
#line 5473 "machine.c"
}


static void _boxes_machine_display___lambda73_ (BoxesMachine* self, const gchar* message) {
	const gchar* _tmp0_ = NULL;
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_if_fail (message != NULL);
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = message;
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_signal_emit_by_name (self, "got-error", _tmp0_);
#line 5485 "machine.c"
}


static void __boxes_machine_display___lambda73__boxes_display_got_error (BoxesDisplay* _sender, const gchar* message, gpointer self) {
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_boxes_machine_display___lambda73_ ((BoxesMachine*) self, message);
#line 5492 "machine.c"
}


static const gchar* string_to_string (const gchar* self) {
	const gchar* result = NULL;
#line 1314 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1315 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
	result = self;
#line 1315 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
	return result;
#line 5504 "machine.c"
}


static void _boxes_machine_display___lambda74_ (BoxesMachine* self, gboolean failed) {
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	BoxesAppWindow* _tmp5_ = NULL;
	BoxesAppWindow* _tmp6_ = NULL;
	gboolean _tmp7_ = FALSE;
	BoxesAppWindow* _tmp8_ = NULL;
	BoxesAppWindow* _tmp9_ = NULL;
	BoxesUIState _tmp10_ = 0;
	BoxesUIState _tmp11_ = 0;
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = boxes_collection_item_get_name ((BoxesCollectionItem*) self);
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp1_ = _tmp0_;
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp2_ = string_to_string (_tmp1_);
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp3_ = g_strconcat ("display ", _tmp2_, " disconnected", NULL);
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp4_ = _tmp3_;
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_message ("machine.vala:164: %s", _tmp4_);
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_free0 (_tmp4_);
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp5_ = boxes_machine_get_window (self);
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp6_ = _tmp5_;
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp6_ == NULL) {
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		return;
#line 5543 "machine.c"
	}
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp8_ = boxes_machine_get_window (self);
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp9_ = _tmp8_;
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp10_ = boxes_ui_get_ui_state ((BoxesUI*) _tmp9_);
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp11_ = _tmp10_;
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp11_ == BOXES_UI_STATE_CREDS) {
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp7_ = TRUE;
#line 5557 "machine.c"
	} else {
		BoxesAppWindow* _tmp12_ = NULL;
		BoxesAppWindow* _tmp13_ = NULL;
		BoxesUIState _tmp14_ = 0;
		BoxesUIState _tmp15_ = 0;
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp12_ = boxes_machine_get_window (self);
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp13_ = _tmp12_;
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp14_ = boxes_ui_get_ui_state ((BoxesUI*) _tmp13_);
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp15_ = _tmp14_;
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp7_ = _tmp15_ == BOXES_UI_STATE_DISPLAY;
#line 5573 "machine.c"
	}
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp7_) {
#line 5577 "machine.c"
		gboolean _tmp16_ = FALSE;
		gboolean _tmp17_ = FALSE;
		gboolean _tmp24_ = FALSE;
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp17_ = self->stay_on_display;
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		if (!_tmp17_) {
#line 5585 "machine.c"
			BoxesAppWindow* _tmp18_ = NULL;
			BoxesAppWindow* _tmp19_ = NULL;
			BoxesCollectionItem* _tmp20_ = NULL;
			BoxesCollectionItem* _tmp21_ = NULL;
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp18_ = boxes_machine_get_window (self);
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp19_ = _tmp18_;
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp20_ = boxes_app_window_get_current_item (_tmp19_);
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp21_ = _tmp20_;
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp16_ = _tmp21_ == G_TYPE_CHECK_INSTANCE_CAST (self, BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem);
#line 5600 "machine.c"
		} else {
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp16_ = FALSE;
#line 5604 "machine.c"
		}
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		if (_tmp16_) {
#line 5608 "machine.c"
			BoxesAppWindow* _tmp22_ = NULL;
			BoxesAppWindow* _tmp23_ = NULL;
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp22_ = boxes_machine_get_window (self);
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp23_ = _tmp22_;
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			boxes_ui_set_state ((BoxesUI*) _tmp23_, BOXES_UI_STATE_COLLECTION);
#line 5617 "machine.c"
		}
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp24_ = failed;
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		if (_tmp24_) {
#line 5623 "machine.c"
			BoxesAppWindow* _tmp25_ = NULL;
			BoxesAppWindow* _tmp26_ = NULL;
			BoxesNotificationbar* _tmp27_ = NULL;
			BoxesNotificationbar* _tmp28_ = NULL;
			const gchar* _tmp29_ = NULL;
			const gchar* _tmp30_ = NULL;
			const gchar* _tmp31_ = NULL;
			gchar* _tmp32_ = NULL;
			gchar* _tmp33_ = NULL;
			GdNotification* _tmp34_ = NULL;
			GdNotification* _tmp35_ = NULL;
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp25_ = boxes_machine_get_window (self);
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp26_ = _tmp25_;
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp27_ = boxes_app_window_get_notificationbar (_tmp26_);
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp28_ = _tmp27_;
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp29_ = _ ("Connection to '%s' failed");
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp30_ = boxes_collection_item_get_name ((BoxesCollectionItem*) self);
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp31_ = _tmp30_;
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp32_ = g_strdup_printf (_tmp29_, _tmp31_);
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp33_ = _tmp32_;
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp34_ = boxes_notificationbar_display_error (_tmp28_, _tmp33_, BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT);
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_tmp35_ = _tmp34_;
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_g_object_unref0 (_tmp35_);
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
			_g_free0 (_tmp33_);
#line 5661 "machine.c"
		}
	}
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_machine_load_screenshot (self);
#line 5666 "machine.c"
}


static void __boxes_machine_display___lambda74__boxes_display_disconnected (BoxesDisplay* _sender, gboolean connection_failed, gpointer self) {
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_boxes_machine_display___lambda74_ ((BoxesMachine*) self, connection_failed);
#line 5673 "machine.c"
}


static void _boxes_machine_handle_auth_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_machine_handle_auth ((BoxesMachine*) self);
#line 5680 "machine.c"
}


void boxes_machine_set_display (BoxesMachine* self, BoxesDisplay* value) {
	BoxesDisplay* _tmp0_ = NULL;
	BoxesDisplay* _tmp13_ = NULL;
	BoxesDisplay* _tmp14_ = NULL;
	BoxesDisplay* _tmp15_ = NULL;
	const gchar* _tmp16_ = NULL;
	const gchar* _tmp17_ = NULL;
	const gchar* _tmp18_ = NULL;
	gchar* _tmp19_ = NULL;
	gchar* _tmp20_ = NULL;
	BoxesDisplay* _tmp21_ = NULL;
	gulong _tmp22_ = 0UL;
	BoxesDisplay* _tmp23_ = NULL;
	gulong _tmp24_ = 0UL;
	BoxesDisplay* _tmp25_ = NULL;
	gulong _tmp26_ = 0UL;
	BoxesDisplay* _tmp27_ = NULL;
	gulong _tmp28_ = 0UL;
	BoxesDisplay* _tmp29_ = NULL;
	gulong _tmp30_ = 0UL;
	BoxesDisplay* _tmp31_ = NULL;
	gulong _tmp32_ = 0UL;
	BoxesDisplay* _tmp33_ = NULL;
	const gchar* _tmp34_ = NULL;
	BoxesDisplay* _tmp35_ = NULL;
	const gchar* _tmp36_ = NULL;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_return_if_fail (self != NULL);
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = self->priv->_display;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp0_ != NULL) {
#line 5716 "machine.c"
		BoxesDisplay* _tmp1_ = NULL;
		gulong _tmp2_ = 0UL;
		BoxesDisplay* _tmp3_ = NULL;
		gulong _tmp4_ = 0UL;
		BoxesDisplay* _tmp5_ = NULL;
		gulong _tmp6_ = 0UL;
		BoxesDisplay* _tmp7_ = NULL;
		gulong _tmp8_ = 0UL;
		BoxesDisplay* _tmp9_ = NULL;
		gulong _tmp10_ = 0UL;
		BoxesDisplay* _tmp11_ = NULL;
		gulong _tmp12_ = 0UL;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp1_ = self->priv->_display;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp2_ = self->priv->show_id;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_signal_handler_disconnect ((GObject*) _tmp1_, _tmp2_);
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		self->priv->show_id = (gulong) 0;
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp3_ = self->priv->_display;
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp4_ = self->priv->hide_id;
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_signal_handler_disconnect ((GObject*) _tmp3_, _tmp4_);
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		self->priv->hide_id = (gulong) 0;
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp5_ = self->priv->_display;
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp6_ = self->priv->disconnected_id;
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_signal_handler_disconnect ((GObject*) _tmp5_, _tmp6_);
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		self->priv->disconnected_id = (gulong) 0;
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp7_ = self->priv->_display;
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp8_ = self->priv->need_password_id;
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_signal_handler_disconnect ((GObject*) _tmp7_, _tmp8_);
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		self->priv->need_password_id = (gulong) 0;
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp9_ = self->priv->_display;
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp10_ = self->priv->need_username_id;
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_signal_handler_disconnect ((GObject*) _tmp9_, _tmp10_);
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		self->priv->need_username_id = (gulong) 0;
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp11_ = self->priv->_display;
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		_tmp12_ = self->priv->got_error_id;
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_signal_handler_disconnect ((GObject*) _tmp11_, _tmp12_);
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		self->priv->got_error_id = (gulong) 0;
#line 5777 "machine.c"
	}
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp13_ = value;
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp14_ = _g_object_ref0 (_tmp13_);
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->priv->_display);
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	self->priv->_display = _tmp14_;
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp15_ = self->priv->_display;
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	if (_tmp15_ == NULL) {
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		return;
#line 5793 "machine.c"
	}
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp16_ = _ ("Connecting to %s");
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp17_ = boxes_collection_item_get_name ((BoxesCollectionItem*) self);
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp18_ = _tmp17_;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp19_ = g_strdup_printf (_tmp16_, _tmp18_);
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp20_ = _tmp19_;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_machine_set_status (self, _tmp20_);
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_free0 (_tmp20_);
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp21_ = self->priv->_display;
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp22_ = g_signal_connect_object (_tmp21_, "show", (GCallback) __boxes_machine_display___lambda13__boxes_display_show, self, 0);
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	self->priv->show_id = _tmp22_;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp23_ = self->priv->_display;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp24_ = g_signal_connect_object (_tmp23_, "hide", (GCallback) __boxes_machine_display___lambda72__boxes_display_hide, self, 0);
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	self->priv->hide_id = _tmp24_;
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp25_ = self->priv->_display;
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp26_ = g_signal_connect_object (_tmp25_, "got-error", (GCallback) __boxes_machine_display___lambda73__boxes_display_got_error, self, 0);
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	self->priv->got_error_id = _tmp26_;
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp27_ = self->priv->_display;
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp28_ = g_signal_connect_object (_tmp27_, "disconnected", (GCallback) __boxes_machine_display___lambda74__boxes_display_disconnected, self, 0);
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	self->priv->disconnected_id = _tmp28_;
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp29_ = self->priv->_display;
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp30_ = g_signal_connect_object ((GObject*) _tmp29_, "notify::need-password", (GCallback) _boxes_machine_handle_auth_g_object_notify, self, 0);
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	self->priv->need_password_id = _tmp30_;
#line 180 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp31_ = self->priv->_display;
#line 180 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp32_ = g_signal_connect_object ((GObject*) _tmp31_, "notify::need-username", (GCallback) _boxes_machine_handle_auth_g_object_notify, self, 0);
#line 180 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	self->priv->need_username_id = _tmp32_;
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp33_ = self->priv->_display;
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp34_ = self->priv->username;
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_display_set_username (_tmp33_, _tmp34_);
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp35_ = self->priv->_display;
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp36_ = self->priv->password;
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_display_set_password (_tmp35_, _tmp36_);
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_notify ((GObject *) self, "display");
#line 5859 "machine.c"
}


static void boxes_machine_class_init (BoxesMachineClass * klass) {
	cairo_surface_t* _tmp0_ = NULL;
	cairo_t* cr = NULL;
	cairo_surface_t* _tmp1_ = NULL;
	cairo_t* _tmp2_ = NULL;
	cairo_t* _tmp3_ = NULL;
	cairo_t* _tmp4_ = NULL;
	cairo_t* _tmp5_ = NULL;
	cairo_t* _tmp6_ = NULL;
	cairo_t* _tmp7_ = NULL;
	cairo_t* _tmp8_ = NULL;
	cairo_t* _tmp9_ = NULL;
	cairo_t* _tmp10_ = NULL;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_machine_parent_class = g_type_class_peek_parent (klass);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_type_class_add_private (klass, sizeof (BoxesMachinePrivate));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	((BoxesMachineClass *) klass)->save_real = boxes_machine_real_save_real;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	((BoxesMachineClass *) klass)->save_real_finish = boxes_machine_real_save_real_finish;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	((BoxesMachineClass *) klass)->take_screenshot = boxes_machine_real_take_screenshot;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	((BoxesMachineClass *) klass)->take_screenshot_finish = boxes_machine_real_take_screenshot_finish;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	((BoxesMachineClass *) klass)->get_properties = boxes_machine_real_get_properties;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	((BoxesMachineClass *) klass)->restart = boxes_machine_real_restart;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	((BoxesMachineClass *) klass)->disconnect_display = boxes_machine_real_disconnect_display;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	((BoxesMachineClass *) klass)->delete = boxes_machine_real_delete;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	((BoxesCollectionItemClass *) klass)->compare = boxes_machine_real_compare;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	BOXES_MACHINE_CLASS (klass)->get_can_save = boxes_machine_real_get_can_save;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	BOXES_MACHINE_CLASS (klass)->get_should_autosave = boxes_machine_real_get_should_autosave;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_machine_get_property;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_machine_set_property;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_machine_finalize;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_MACHINE_PIXBUF, g_param_spec_object ("pixbuf", "pixbuf", "pixbuf", GDK_TYPE_PIXBUF, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_MACHINE_INFO, g_param_spec_string ("info", "info", "info", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_MACHINE_STATUS, g_param_spec_string ("status", "status", "status", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_MACHINE_CAN_SAVE, g_param_spec_boolean ("can-save", "can-save", "can-save", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_MACHINE_CAN_DELETE, g_param_spec_boolean ("can-delete", "can-delete", "can-delete", TRUE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_MACHINE_UNDER_CONSTRUCTION, g_param_spec_boolean ("under-construction", "under-construction", "under-construction", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_MACHINE_SHOULD_AUTOSAVE, g_param_spec_boolean ("should-autosave", "should-autosave", "should-autosave", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_MACHINE_CONNECTING_CANCELLABLE, g_param_spec_object ("connecting-cancellable", "connecting-cancellable", "connecting-cancellable", g_cancellable_get_type (), G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_MACHINE_STATE, g_param_spec_enum ("state", "state", "state", BOXES_MACHINE_TYPE_MACHINE_STATE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_MACHINE_WINDOW, g_param_spec_object ("window", "window", "window", BOXES_TYPE_APP_WINDOW, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_MACHINE_DELETED, g_param_spec_boolean ("deleted", "deleted", "deleted", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_MACHINE_DISPLAY, g_param_spec_object ("display", "display", "display", BOXES_TYPE_DISPLAY, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	g_signal_new ("got_error", BOXES_TYPE_MACHINE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__STRING, G_TYPE_NONE, 1, G_TYPE_STRING);
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp0_ = cairo_image_surface_create (CAIRO_FORMAT_A8, 2, 2);
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_cairo_surface_destroy0 (boxes_machine_grid_surface);
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_machine_grid_surface = _tmp0_;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp1_ = boxes_machine_grid_surface;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp2_ = cairo_create (_tmp1_);
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	cr = _tmp2_;
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp3_ = cr;
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	cairo_set_source_rgba (_tmp3_, (gdouble) 0, (gdouble) 0, (gdouble) 0, (gdouble) 0);
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp4_ = cr;
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	cairo_paint (_tmp4_);
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp5_ = cr;
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	cairo_set_source_rgba (_tmp5_, (gdouble) 1, (gdouble) 1, (gdouble) 1, (gdouble) 1);
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp6_ = cr;
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	cairo_set_operator (_tmp6_, CAIRO_OPERATOR_SOURCE);
#line 195 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp7_ = cr;
#line 195 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	cairo_rectangle (_tmp7_, (gdouble) 0, (gdouble) 0, (gdouble) 1, (gdouble) 1);
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp8_ = cr;
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	cairo_fill (_tmp8_);
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp9_ = cr;
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	cairo_rectangle (_tmp9_, (gdouble) 1, (gdouble) 1, (gdouble) 1, (gdouble) 1);
#line 198 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_tmp10_ = cr;
#line 198 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	cairo_fill (_tmp10_);
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_cairo_destroy0 (cr);
#line 5980 "machine.c"
}


static void boxes_machine_boxes_iproperties_provider_interface_init (BoxesIPropertiesProviderIface * iface) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	boxes_machine_boxes_iproperties_provider_parent_iface = g_type_interface_peek_parent (iface);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	iface->get_properties = (GList* (*)(BoxesIPropertiesProvider*, BoxesPropertiesPage, PropertyCreationFlag*)) boxes_machine_get_properties;
#line 5989 "machine.c"
}


static void boxes_machine_instance_init (BoxesMachine * self) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	self->priv = BOXES_MACHINE_GET_PRIVATE (self);
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	self->priv->_can_delete = TRUE;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	self->priv->_under_construction = FALSE;
#line 6000 "machine.c"
}


static void boxes_machine_finalize (GObject* obj) {
	BoxesMachine * self;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_MACHINE, BoxesMachine);
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->source);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->config);
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->priv->_pixbuf);
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_free0 (self->priv->_info);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_free0 (self->priv->_status);
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_free0 (self->priv->username);
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_free0 (self->priv->password);
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->priv->_connecting_cancellable);
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->priv->orig_pixbuf);
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->priv->_display);
#line 604 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->priv->auth_notification);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	G_OBJECT_CLASS (boxes_machine_parent_class)->finalize (obj);
#line 6032 "machine.c"
}


GType boxes_machine_get_type (void) {
	static volatile gsize boxes_machine_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_machine_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesMachineClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_machine_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesMachine), 0, (GInstanceInitFunc) boxes_machine_instance_init, NULL };
		static const GInterfaceInfo boxes_iproperties_provider_info = { (GInterfaceInitFunc) boxes_machine_boxes_iproperties_provider_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType boxes_machine_type_id;
		boxes_machine_type_id = g_type_register_static (BOXES_TYPE_COLLECTION_ITEM, "BoxesMachine", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
		g_type_add_interface_static (boxes_machine_type_id, BOXES_TYPE_IPROPERTIES_PROVIDER, &boxes_iproperties_provider_info);
		g_once_init_leave (&boxes_machine_type_id__volatile, boxes_machine_type_id);
	}
	return boxes_machine_type_id__volatile;
}


static void _vala_boxes_machine_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesMachine * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_MACHINE, BoxesMachine);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	switch (property_id) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		case BOXES_MACHINE_PIXBUF:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_value_set_object (value, boxes_machine_get_pixbuf (self));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		break;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		case BOXES_MACHINE_INFO:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_value_set_string (value, boxes_machine_get_info (self));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		break;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		case BOXES_MACHINE_STATUS:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_value_set_string (value, boxes_machine_get_status (self));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		break;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		case BOXES_MACHINE_CAN_SAVE:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_value_set_boolean (value, boxes_machine_get_can_save (self));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		break;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		case BOXES_MACHINE_CAN_DELETE:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_value_set_boolean (value, boxes_machine_get_can_delete (self));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		break;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		case BOXES_MACHINE_UNDER_CONSTRUCTION:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_value_set_boolean (value, boxes_machine_get_under_construction (self));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		break;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		case BOXES_MACHINE_SHOULD_AUTOSAVE:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_value_set_boolean (value, boxes_machine_get_should_autosave (self));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		break;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		case BOXES_MACHINE_CONNECTING_CANCELLABLE:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_value_set_object (value, boxes_machine_get_connecting_cancellable (self));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		break;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		case BOXES_MACHINE_STATE:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_value_set_enum (value, boxes_machine_get_state (self));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		break;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		case BOXES_MACHINE_WINDOW:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_value_set_object (value, boxes_machine_get_window (self));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		break;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		case BOXES_MACHINE_DELETED:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_value_set_boolean (value, boxes_machine_get_deleted (self));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		break;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		case BOXES_MACHINE_DISPLAY:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		g_value_set_object (value, boxes_machine_get_display (self));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		break;
#line 6127 "machine.c"
		default:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		break;
#line 6133 "machine.c"
	}
}


static void _vala_boxes_machine_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesMachine * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_MACHINE, BoxesMachine);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
	switch (property_id) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		case BOXES_MACHINE_PIXBUF:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_machine_set_pixbuf (self, g_value_get_object (value));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		break;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		case BOXES_MACHINE_INFO:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_machine_set_info (self, g_value_get_string (value));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		break;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		case BOXES_MACHINE_STATUS:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_machine_set_status (self, g_value_get_string (value));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		break;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		case BOXES_MACHINE_CAN_DELETE:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_machine_set_can_delete (self, g_value_get_boolean (value));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		break;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		case BOXES_MACHINE_UNDER_CONSTRUCTION:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_machine_set_under_construction (self, g_value_get_boolean (value));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		break;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		case BOXES_MACHINE_CONNECTING_CANCELLABLE:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_machine_set_connecting_cancellable (self, g_value_get_object (value));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		break;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		case BOXES_MACHINE_STATE:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_machine_set_state (self, g_value_get_enum (value));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		break;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		case BOXES_MACHINE_WINDOW:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_machine_set_window (self, g_value_get_object (value));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		break;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		case BOXES_MACHINE_DELETED:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_machine_set_deleted (self, g_value_get_boolean (value));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		break;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		case BOXES_MACHINE_DISPLAY:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		boxes_machine_set_display (self, g_value_get_object (value));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		break;
#line 6203 "machine.c"
		default:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/machine.vala"
		break;
#line 6209 "machine.c"
	}
}



