/* libvirt-machine.c generated by valac 0.29.2.1-265d, the Vala compiler
 * generated from libvirt-machine.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gio/gio.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <libcommon.h>
#include <float.h>
#include <math.h>
#include <libvirt-gobject/libvirt-gobject.h>
#include <libvirt-gconfig/libvirt-gconfig.h>
#include <stdlib.h>
#include <string.h>
#include <gtk/gtk.h>
#include <glib/gi18n-lib.h>
#include <libgd/gd.h>


#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_UI_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_UI, BoxesUIIface))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIIface BoxesUIIface;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;
typedef struct _BoxesCollectionItemPrivate BoxesCollectionItemPrivate;

#define BOXES_TYPE_IPROPERTIES_PROVIDER (boxes_iproperties_provider_get_type ())
#define BOXES_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProvider))
#define BOXES_IS_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER))
#define BOXES_IPROPERTIES_PROVIDER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProviderIface))

typedef struct _BoxesIPropertiesProvider BoxesIPropertiesProvider;
typedef struct _BoxesIPropertiesProviderIface BoxesIPropertiesProviderIface;

#define BOXES_TYPE_PROPERTIES_PAGE (boxes_properties_page_get_type ())

#define TYPE_PROPERTY_CREATION_FLAG (property_creation_flag_get_type ())

#define BOXES_TYPE_PROPERTY (boxes_property_get_type ())
#define BOXES_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTY, BoxesProperty))
#define BOXES_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTY, BoxesPropertyClass))
#define BOXES_IS_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTY))
#define BOXES_IS_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTY))
#define BOXES_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTY, BoxesPropertyClass))

typedef struct _BoxesProperty BoxesProperty;
typedef struct _BoxesPropertyClass BoxesPropertyClass;

#define BOXES_TYPE_MACHINE (boxes_machine_get_type ())
#define BOXES_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE, BoxesMachine))
#define BOXES_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE, BoxesMachineClass))
#define BOXES_IS_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE))
#define BOXES_IS_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE))
#define BOXES_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE, BoxesMachineClass))

typedef struct _BoxesMachine BoxesMachine;
typedef struct _BoxesMachineClass BoxesMachineClass;
typedef struct _BoxesMachinePrivate BoxesMachinePrivate;

#define BOXES_MACHINE_TYPE_CONNECT_FLAGS (boxes_machine_connect_flags_get_type ())

#define BOXES_TYPE_LIBVIRT_MACHINE (boxes_libvirt_machine_get_type ())
#define BOXES_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachine))
#define BOXES_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))
#define BOXES_IS_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_IS_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_LIBVIRT_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))

typedef struct _BoxesLibvirtMachine BoxesLibvirtMachine;
typedef struct _BoxesLibvirtMachineClass BoxesLibvirtMachineClass;
typedef struct _BoxesLibvirtMachinePrivate BoxesLibvirtMachinePrivate;

#define BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES (boxes_libvirt_machine_properties_get_type ())
#define BOXES_LIBVIRT_MACHINE_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES, BoxesLibvirtMachineProperties))
#define BOXES_LIBVIRT_MACHINE_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES, BoxesLibvirtMachinePropertiesClass))
#define BOXES_IS_LIBVIRT_MACHINE_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES))
#define BOXES_IS_LIBVIRT_MACHINE_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES))
#define BOXES_LIBVIRT_MACHINE_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES, BoxesLibvirtMachinePropertiesClass))

typedef struct _BoxesLibvirtMachineProperties BoxesLibvirtMachineProperties;
typedef struct _BoxesLibvirtMachinePropertiesClass BoxesLibvirtMachinePropertiesClass;

#define BOXES_TYPE_VM_CREATOR (boxes_vm_creator_get_type ())
#define BOXES_VM_CREATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_VM_CREATOR, BoxesVMCreator))
#define BOXES_VM_CREATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_VM_CREATOR, BoxesVMCreatorClass))
#define BOXES_IS_VM_CREATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_VM_CREATOR))
#define BOXES_IS_VM_CREATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_VM_CREATOR))
#define BOXES_VM_CREATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_VM_CREATOR, BoxesVMCreatorClass))

typedef struct _BoxesVMCreator BoxesVMCreator;
typedef struct _BoxesVMCreatorClass BoxesVMCreatorClass;

#define BOXES_LIBVIRT_MACHINE_TYPE_MACHINE_STAT (boxes_libvirt_machine_machine_stat_get_type ())
typedef struct _BoxesLibvirtMachineMachineStat BoxesLibvirtMachineMachineStat;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _boxes_vm_creator_unref0(var) ((var == NULL) ? NULL : (var = (boxes_vm_creator_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

#define BOXES_TYPE_DISPLAY (boxes_display_get_type ())
#define BOXES_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY, BoxesDisplay))
#define BOXES_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY, BoxesDisplayClass))
#define BOXES_IS_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY))
#define BOXES_IS_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY))
#define BOXES_DISPLAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY, BoxesDisplayClass))

typedef struct _BoxesDisplay BoxesDisplay;
typedef struct _BoxesDisplayClass BoxesDisplayClass;
typedef struct _BoxesLibvirtMachineConnectDisplayData BoxesLibvirtMachineConnectDisplayData;

#define BOXES_TYPE_APP_WINDOW (boxes_app_window_get_type ())
#define BOXES_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindow))
#define BOXES_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))
#define BOXES_IS_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP_WINDOW))
#define BOXES_IS_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP_WINDOW))
#define BOXES_APP_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))

typedef struct _BoxesAppWindow BoxesAppWindow;
typedef struct _BoxesAppWindowClass BoxesAppWindowClass;
#define __vala_GVirDomainInfo_free0(var) ((var == NULL) ? NULL : (var = (_vala_GVirDomainInfo_free (var), NULL)))

#define BOXES_MACHINE_TYPE_MACHINE_STATE (boxes_machine_machine_state_get_type ())
typedef struct _Block31Data Block31Data;
typedef struct _Block32Data Block32Data;
#define __vala_GVirDomainDiskStats_free0(var) ((var == NULL) ? NULL : (var = (_vala_GVirDomainDiskStats_free (var), NULL)))
typedef struct _BoxesLibvirtMachineUpdateIoStatData BoxesLibvirtMachineUpdateIoStatData;
typedef struct _Block33Data Block33Data;
typedef struct _Block34Data Block34Data;
#define __vala_GVirDomainInterfaceStats_free0(var) ((var == NULL) ? NULL : (var = (_vala_GVirDomainInterfaceStats_free (var), NULL)))
typedef struct _BoxesLibvirtMachineUpdateNetStatData BoxesLibvirtMachineUpdateNetStatData;
typedef struct _BoxesLibvirtMachineUpdateStatsData BoxesLibvirtMachineUpdateStatsData;
typedef struct _Block35Data Block35Data;
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))

#define BOXES_TYPE_SPICE_DISPLAY (boxes_spice_display_get_type ())
#define BOXES_SPICE_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SPICE_DISPLAY, BoxesSpiceDisplay))
#define BOXES_SPICE_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SPICE_DISPLAY, BoxesSpiceDisplayClass))
#define BOXES_IS_SPICE_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SPICE_DISPLAY))
#define BOXES_IS_SPICE_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SPICE_DISPLAY))
#define BOXES_SPICE_DISPLAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SPICE_DISPLAY, BoxesSpiceDisplayClass))

typedef struct _BoxesSpiceDisplay BoxesSpiceDisplay;
typedef struct _BoxesSpiceDisplayClass BoxesSpiceDisplayClass;

#define BOXES_TYPE_VNC_DISPLAY (boxes_vnc_display_get_type ())
#define BOXES_VNC_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_VNC_DISPLAY, BoxesVncDisplay))
#define BOXES_VNC_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_VNC_DISPLAY, BoxesVncDisplayClass))
#define BOXES_IS_VNC_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_VNC_DISPLAY))
#define BOXES_IS_VNC_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_VNC_DISPLAY))
#define BOXES_VNC_DISPLAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_VNC_DISPLAY, BoxesVncDisplayClass))

typedef struct _BoxesVncDisplay BoxesVncDisplay;
typedef struct _BoxesVncDisplayClass BoxesVncDisplayClass;
typedef struct _Block36Data Block36Data;
typedef struct _BoxesLibvirtMachineTakeScreenshotData BoxesLibvirtMachineTakeScreenshotData;
typedef struct _Block37Data Block37Data;
typedef struct _BoxesLibvirtMachineSaveRealData BoxesLibvirtMachineSaveRealData;
typedef struct _BoxesLibvirtMachineSuspendData BoxesLibvirtMachineSuspendData;
typedef struct _BoxesLibvirtMachineStartData BoxesLibvirtMachineStartData;
typedef struct _Block38Data Block38Data;

#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;
typedef struct _Block39Data Block39Data;
typedef struct _BoxesLibvirtMachineWaitForSaveData BoxesLibvirtMachineWaitForSaveData;

#define BOXES_TYPE_VM_IMPORTER (boxes_vm_importer_get_type ())
#define BOXES_VM_IMPORTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_VM_IMPORTER, BoxesVMImporter))
#define BOXES_VM_IMPORTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_VM_IMPORTER, BoxesVMImporterClass))
#define BOXES_IS_VM_IMPORTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_VM_IMPORTER))
#define BOXES_IS_VM_IMPORTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_VM_IMPORTER))
#define BOXES_VM_IMPORTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_VM_IMPORTER, BoxesVMImporterClass))

typedef struct _BoxesVMImporter BoxesVMImporter;
typedef struct _BoxesVMImporterClass BoxesVMImporterClass;

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUIIface {
	GTypeInterface parent_iface;
	BoxesUIState (*get_previous_ui_state) (BoxesUI* self);
	void (*set_previous_ui_state) (BoxesUI* self, BoxesUIState value);
	BoxesUIState (*get_ui_state) (BoxesUI* self);
	void (*set_ui_state) (BoxesUI* self, BoxesUIState value);
};

struct _BoxesCollectionItem {
	GObject parent_instance;
	BoxesCollectionItemPrivate * priv;
};

struct _BoxesCollectionItemClass {
	GObjectClass parent_class;
	gint (*compare) (BoxesCollectionItem* self, BoxesCollectionItem* other);
};

typedef enum  {
	BOXES_PROPERTIES_PAGE_GENERAL,
	BOXES_PROPERTIES_PAGE_SYSTEM,
	BOXES_PROPERTIES_PAGE_DEVICES,
	BOXES_PROPERTIES_PAGE_SNAPSHOTS,
	BOXES_PROPERTIES_PAGE_LAST
} BoxesPropertiesPage;

typedef enum  {
	PROPERTY_CREATION_FLAG_NONE = 1 << 0,
	PROPERTY_CREATION_FLAG_NO_USB = 1 << 1
} PropertyCreationFlag;

struct _BoxesIPropertiesProviderIface {
	GTypeInterface parent_iface;
	GList* (*get_properties) (BoxesIPropertiesProvider* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
};

typedef enum  {
	BOXES_MACHINE_CONNECT_FLAGS_NONE = 0,
	BOXES_MACHINE_CONNECT_FLAGS_IGNORE_SAVED_STATE = 1 << 0
} BoxesMachineConnectFlags;

struct _BoxesMachine {
	BoxesCollectionItem parent_instance;
	BoxesMachinePrivate * priv;
	BoxesCollectionSource* source;
	BoxesBoxConfig* config;
	gboolean stay_on_display;
	gboolean suspend_at_exit;
};

struct _BoxesMachineClass {
	BoxesCollectionItemClass parent_class;
	void (*save_real) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*save_real_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*take_screenshot) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GdkPixbuf* (*take_screenshot_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	GList* (*get_properties) (BoxesMachine* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
	void (*connect_display) (BoxesMachine* self, BoxesMachineConnectFlags flags, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*connect_display_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*restart) (BoxesMachine* self);
	void (*disconnect_display) (BoxesMachine* self);
	void (*delete) (BoxesMachine* self, gboolean by_user);
	gboolean (*get_can_save) (BoxesMachine* self);
	gboolean (*get_should_autosave) (BoxesMachine* self);
};

struct _BoxesLibvirtMachine {
	BoxesMachine parent_instance;
	BoxesLibvirtMachinePrivate * priv;
	BoxesLibvirtMachineProperties* properties;
	gdouble* cpu_stats;
	gint cpu_stats_length1;
	gint _cpu_stats_size_;
	gdouble* io_stats;
	gint io_stats_length1;
	gint _io_stats_size_;
	gdouble* net_stats;
	gint net_stats_length1;
	gint _net_stats_size_;
};

struct _BoxesLibvirtMachineClass {
	BoxesMachineClass parent_class;
};

struct _BoxesLibvirtMachineMachineStat {
	gint64 timestamp;
	gdouble cpu_time;
	gdouble cpu_time_abs;
	gdouble cpu_guest_percent;
	gdouble memory_percent;
	GVirDomainDiskStats* disk;
	gdouble disk_read;
	gdouble disk_write;
	GVirDomainInterfaceStats* net;
	gdouble net_read;
	gdouble net_write;
};

struct _BoxesLibvirtMachinePrivate {
	GVirDomain* _domain;
	GVirConfigDomain* _domain_config;
	GVirConnection* _connection;
	GVirStorageVol* _storage_volume;
	BoxesVMCreator* _vm_creator;
	guint shutdown_timeout;
	guint stats_update_timeout;
	GCancellable* stats_cancellable;
	BoxesLibvirtMachineMachineStat* stats;
	gint stats_length1;
	gint _stats_size_;
	gboolean force_stopped;
	gboolean saving;
};

typedef gint (*BoxesDisplayOpenFDFunc) (void* user_data);
struct _BoxesLibvirtMachineConnectDisplayData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesLibvirtMachine* self;
	BoxesMachineConnectFlags flags;
	GCancellable* _tmp0_;
	GCancellable* _tmp1_;
	GCancellable* _tmp2_;
	GCancellable* _tmp3_;
	gboolean _tmp4_;
	GCancellable* _tmp5_;
	GCancellable* _tmp6_;
	BoxesMachineConnectFlags _tmp7_;
	GCancellable* _tmp8_;
	GCancellable* _tmp9_;
	GCancellable* _tmp10_;
	GCancellable* _tmp11_;
	gboolean _tmp12_;
	GCancellable* _tmp13_;
	GCancellable* _tmp14_;
	gboolean _tmp15_;
	gboolean _tmp16_;
	BoxesDisplayOpenFDFunc open_fd;
	void* open_fd_target;
	GDestroyNotify open_fd_target_destroy_notify;
	BoxesCollectionSource* _tmp17_;
	gchar* _tmp18_;
	gchar* _tmp19_;
	gchar* _tmp20_;
	gboolean _tmp21_;
	gboolean _tmp22_;
	BoxesDisplay* _tmp23_;
	BoxesDisplay* _tmp24_;
	BoxesDisplayOpenFDFunc _tmp25_;
	void* _tmp25__target;
	BoxesDisplay* _tmp26_;
	BoxesDisplay* _tmp27_;
	const gchar* _tmp28_;
	const gchar* _tmp29_;
	GError * _inner_error_;
};

typedef enum  {
	BOXES_MACHINE_MACHINE_STATE_UNKNOWN,
	BOXES_MACHINE_MACHINE_STATE_STOPPED,
	BOXES_MACHINE_MACHINE_STATE_FORCE_STOPPED,
	BOXES_MACHINE_MACHINE_STATE_RUNNING,
	BOXES_MACHINE_MACHINE_STATE_PAUSED,
	BOXES_MACHINE_MACHINE_STATE_SAVED,
	BOXES_MACHINE_MACHINE_STATE_SLEEPING
} BoxesMachineMachineState;

struct _Block31Data {
	int _ref_count_;
	BoxesLibvirtMachine* self;
	BoxesLibvirtMachineMachineStat* stat;
	gpointer _async_data_;
};

struct _Block32Data {
	int _ref_count_;
	Block31Data * _data31_;
	GVirDomainDisk* disk;
};

struct _BoxesLibvirtMachineUpdateIoStatData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesLibvirtMachine* self;
	GVirDomainInfo* info;
	BoxesLibvirtMachineMachineStat* stat;
	Block31Data* _data31_;
	BoxesLibvirtMachineMachineStat* _tmp0_;
	GVirDomainInfo* _tmp1_;
	GVirDomainState _tmp2_;
	Block32Data* _data32_;
	GVirDomainDisk* _tmp3_;
	GVirDomainDisk* _tmp4_;
	BoxesLibvirtMachineMachineStat prev;
	BoxesLibvirtMachineMachineStat* _tmp5_;
	gint _tmp5__length1;
	BoxesLibvirtMachineMachineStat _tmp6_;
	BoxesLibvirtMachineMachineStat _tmp7_;
	BoxesLibvirtMachineMachineStat _tmp8_;
	GVirDomainDiskStats* _tmp9_;
	BoxesLibvirtMachineMachineStat* _tmp10_;
	GVirDomainDiskStats* _tmp11_;
	gint64 _tmp12_;
	BoxesLibvirtMachineMachineStat _tmp13_;
	GVirDomainDiskStats* _tmp14_;
	gint64 _tmp15_;
	BoxesLibvirtMachineMachineStat* _tmp16_;
	GVirDomainDiskStats* _tmp17_;
	gint64 _tmp18_;
	BoxesLibvirtMachineMachineStat _tmp19_;
	GVirDomainDiskStats* _tmp20_;
	gint64 _tmp21_;
	GError* err;
	const gchar* _tmp22_;
	const gchar* _tmp23_;
	GError* _tmp24_;
	const gchar* _tmp25_;
	GError * _inner_error_;
};

struct _Block33Data {
	int _ref_count_;
	BoxesLibvirtMachine* self;
	BoxesLibvirtMachineMachineStat* stat;
	gpointer _async_data_;
};

struct _Block34Data {
	int _ref_count_;
	Block33Data * _data33_;
	GVirDomainInterface* net;
};

struct _BoxesLibvirtMachineUpdateNetStatData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesLibvirtMachine* self;
	GVirDomainInfo* info;
	BoxesLibvirtMachineMachineStat* stat;
	Block33Data* _data33_;
	BoxesLibvirtMachineMachineStat* _tmp0_;
	GVirDomainInfo* _tmp1_;
	GVirDomainState _tmp2_;
	Block34Data* _data34_;
	GVirDomainInterface* _tmp3_;
	GVirDomainInterface* _tmp4_;
	BoxesLibvirtMachineMachineStat prev;
	BoxesLibvirtMachineMachineStat* _tmp5_;
	gint _tmp5__length1;
	BoxesLibvirtMachineMachineStat _tmp6_;
	BoxesLibvirtMachineMachineStat _tmp7_;
	BoxesLibvirtMachineMachineStat _tmp8_;
	GVirDomainInterfaceStats* _tmp9_;
	BoxesLibvirtMachineMachineStat* _tmp10_;
	GVirDomainInterfaceStats* _tmp11_;
	gint64 _tmp12_;
	BoxesLibvirtMachineMachineStat _tmp13_;
	GVirDomainInterfaceStats* _tmp14_;
	gint64 _tmp15_;
	BoxesLibvirtMachineMachineStat* _tmp16_;
	GVirDomainInterfaceStats* _tmp17_;
	gint64 _tmp18_;
	BoxesLibvirtMachineMachineStat _tmp19_;
	GVirDomainInterfaceStats* _tmp20_;
	gint64 _tmp21_;
	GError* err;
	const gchar* _tmp22_;
	const gchar* _tmp23_;
	GError* _tmp24_;
	const gchar* _tmp25_;
	GError * _inner_error_;
};

struct _BoxesLibvirtMachineUpdateStatsData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesLibvirtMachine* self;
	gint64 now;
	gint64 _tmp0_;
	BoxesLibvirtMachineMachineStat stat;
	gint64 _tmp1_;
	BoxesLibvirtMachineMachineStat _tmp2_;
	GVirDomainInfo* info;
	GVirDomain* _tmp3_;
	GCancellable* _tmp4_;
	GVirDomainInfo* _tmp5_;
	GVirDomainInfo* _tmp6_;
	GVirDomainInfo* _tmp7_;
	GVirDomainInfo* _tmp8_;
	GVirDomainInfo* _tmp9_;
	BoxesLibvirtMachineMachineStat* _tmp10_;
	gint _tmp10__length1;
	BoxesLibvirtMachineMachineStat* _tmp11_;
	gint _tmp11__length1;
	BoxesLibvirtMachineMachineStat* _tmp12_;
	gint _tmp12__length1;
	BoxesLibvirtMachineMachineStat _tmp13_;
	BoxesLibvirtMachineMachineStat _tmp14_;
	GError* err;
	GError* _vala1_err;
	GError* _tmp15_;
	const gchar* _tmp16_;
	gdouble* _tmp17_;
	gdouble* _tmp18_;
	gdouble* _tmp19_;
	BoxesLibvirtMachineMachineStat* _tmp20_;
	gint _tmp20__length1;
	BoxesLibvirtMachineMachineStat* stat_collection;
	gint stat_collection_length1;
	gint _stat_collection_size_;
	gint stat_it;
	BoxesLibvirtMachineMachineStat _tmp21_;
	BoxesLibvirtMachineMachineStat _vala1_stat;
	gdouble* _tmp22_;
	gint _tmp22__length1;
	BoxesLibvirtMachineMachineStat _tmp23_;
	gdouble _tmp24_;
	gdouble* _tmp25_;
	gint _tmp25__length1;
	BoxesLibvirtMachineMachineStat _tmp26_;
	gdouble _tmp27_;
	BoxesLibvirtMachineMachineStat _tmp28_;
	gdouble _tmp29_;
	gdouble* _tmp30_;
	gint _tmp30__length1;
	BoxesLibvirtMachineMachineStat _tmp31_;
	gdouble _tmp32_;
	BoxesLibvirtMachineMachineStat _tmp33_;
	gdouble _tmp34_;
	GError * _inner_error_;
};

struct _Block35Data {
	int _ref_count_;
	BoxesLibvirtMachine* self;
	gboolean stats_updating;
};

struct _Block36Data {
	int _ref_count_;
	BoxesLibvirtMachine* self;
	GVirStream* stream;
	gpointer _async_data_;
};

struct _BoxesLibvirtMachineTakeScreenshotData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesLibvirtMachine* self;
	GdkPixbuf* result;
	Block36Data* _data36_;
	GVirDomainState state;
	GVirDomainInfo* _tmp0_;
	GVirDomain* _tmp1_;
	GVirDomainInfo* _tmp2_;
	GVirDomainInfo* _tmp3_;
	GVirDomainInfo* _tmp4_;
	GVirDomainState _tmp5_;
	GError* _error_;
	const gchar* _tmp6_;
	const gchar* _tmp7_;
	gboolean _tmp8_;
	gboolean _tmp9_;
	GVirDomainState _tmp10_;
	GVirDomainState _tmp11_;
	GVirDomainState _tmp12_;
	GVirConnection* _tmp13_;
	GVirStream* _tmp14_;
	GdkPixbufLoader* loader;
	GdkPixbufLoader* _tmp15_;
	GInputStream* input_stream;
	GVirStream* _tmp16_;
	GInputStream* _tmp17_;
	GInputStream* _tmp18_;
	guint8* buffer;
	guint8* _tmp19_;
	gint buffer_length1;
	gint _buffer_size_;
	gssize length;
	gboolean _tmp20_;
	gssize _tmp21_;
	gssize _tmp22_;
	GInputStream* _tmp23_;
	guint8* _tmp24_;
	gint _tmp24__length1;
	gssize _tmp25_;
	GdkPixbufLoader* _tmp26_;
	guint8* _tmp27_;
	gint _tmp27__length1;
	gssize _tmp28_;
	GdkPixbufLoader* _tmp29_;
	GdkPixbufLoader* _tmp30_;
	GdkPixbuf* _tmp31_;
	GdkPixbuf* _tmp32_;
	GError * _inner_error_;
};

struct _Block37Data {
	int _ref_count_;
	BoxesLibvirtMachine* self;
	GVirDomain* domain;
};

struct _BoxesLibvirtMachineSaveRealData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesLibvirtMachine* self;
	GVirDomain* _tmp0_;
	GError * _inner_error_;
};

struct _BoxesLibvirtMachineSuspendData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesLibvirtMachine* self;
	gboolean _tmp0_;
	gboolean _tmp1_;
	GVirDomain* _tmp2_;
	GError * _inner_error_;
};

struct _BoxesLibvirtMachineStartData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesLibvirtMachine* self;
	BoxesMachineConnectFlags flags;
	GCancellable* cancellable;
	BoxesMachineMachineState _tmp0_;
	BoxesMachineMachineState _tmp1_;
	BoxesMachineMachineState _tmp2_;
	BoxesMachineMachineState _tmp3_;
	GVirDomain* _tmp4_;
	GCancellable* _tmp5_;
	BoxesMachineMachineState _tmp6_;
	BoxesMachineMachineState _tmp7_;
	GVirDomain* _tmp8_;
	GCancellable* _tmp9_;
	gboolean _tmp10_;
	GVirDomain* _tmp11_;
	gboolean _tmp12_;
	BoxesMachineConnectFlags _tmp13_;
	gboolean restore;
	gboolean _tmp14_;
	const gchar* _tmp15_;
	const gchar* _tmp16_;
	const gchar* _tmp17_;
	gchar* _tmp18_;
	gchar* _tmp19_;
	const gchar* _tmp20_;
	const gchar* _tmp21_;
	const gchar* _tmp22_;
	gchar* _tmp23_;
	gchar* _tmp24_;
	GVirDomain* _tmp25_;
	BoxesMachineConnectFlags _tmp26_;
	GVirDomainStartFlags _tmp27_;
	GCancellable* _tmp28_;
	GError* _error_;
	const gchar* _tmp29_;
	const gchar* _tmp30_;
	GError* _vala1__error_;
	gboolean _tmp31_;
	GError* _tmp32_;
	const gchar* _tmp33_;
	GError* _tmp34_;
	GError* _tmp35_;
	const gchar* _tmp36_;
	GError* _tmp37_;
	GError * _inner_error_;
};

struct _Block38Data {
	int _ref_count_;
	BoxesLibvirtMachine* self;
	gulong state_id;
	GdNotification* notification;
};

typedef void (*BoxesNotificationOKFunc) (void* user_data);
typedef void (*BoxesNotificationCancelFunc) (void* user_data);
struct _Block39Data {
	int _ref_count_;
	BoxesLibvirtMachine* self;
	gpointer _async_data_;
};

struct _BoxesLibvirtMachineWaitForSaveData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesLibvirtMachine* self;
	Block39Data* _data39_;
	gboolean _tmp0_;
	gulong state_notify_id;
	gulong _tmp1_;
	gulong cancelled_id;
	GCancellable* _tmp2_;
	GCancellable* _tmp3_;
	gulong _tmp4_;
	const gchar* _tmp5_;
	const gchar* _tmp6_;
	gulong _tmp7_;
	GCancellable* _tmp8_;
	GCancellable* _tmp9_;
	gulong _tmp10_;
};


static gpointer boxes_libvirt_machine_parent_class = NULL;

GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_properties_page_get_type (void) G_GNUC_CONST;
GType property_creation_flag_get_type (void) G_GNUC_CONST;
GType boxes_property_get_type (void) G_GNUC_CONST;
GType boxes_iproperties_provider_get_type (void) G_GNUC_CONST;
GType boxes_machine_get_type (void) G_GNUC_CONST;
GType boxes_machine_connect_flags_get_type (void) G_GNUC_CONST;
GType boxes_libvirt_machine_get_type (void) G_GNUC_CONST;
GType boxes_libvirt_machine_properties_get_type (void) G_GNUC_CONST;
gpointer boxes_vm_creator_ref (gpointer instance);
void boxes_vm_creator_unref (gpointer instance);
GParamSpec* boxes_param_spec_vm_creator (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void boxes_value_set_vm_creator (GValue* value, gpointer v_object);
void boxes_value_take_vm_creator (GValue* value, gpointer v_object);
gpointer boxes_value_get_vm_creator (const GValue* value);
GType boxes_vm_creator_get_type (void) G_GNUC_CONST;
static GType boxes_libvirt_machine_machine_stat_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static BoxesLibvirtMachineMachineStat* boxes_libvirt_machine_machine_stat_dup (const BoxesLibvirtMachineMachineStat* self);
static void boxes_libvirt_machine_machine_stat_free (BoxesLibvirtMachineMachineStat* self);
static void boxes_libvirt_machine_machine_stat_copy (const BoxesLibvirtMachineMachineStat* self, BoxesLibvirtMachineMachineStat* dest);
static void boxes_libvirt_machine_machine_stat_destroy (BoxesLibvirtMachineMachineStat* self);
#define BOXES_LIBVIRT_MACHINE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachinePrivate))
enum  {
	BOXES_LIBVIRT_MACHINE_DUMMY_PROPERTY,
	BOXES_LIBVIRT_MACHINE_DOMAIN,
	BOXES_LIBVIRT_MACHINE_DOMAIN_CONFIG,
	BOXES_LIBVIRT_MACHINE_CONNECTION,
	BOXES_LIBVIRT_MACHINE_STORAGE_VOLUME,
	BOXES_LIBVIRT_MACHINE_VM_CREATOR,
	BOXES_LIBVIRT_MACHINE_IMPORTING,
	BOXES_LIBVIRT_MACHINE_SAVE_ON_QUIT,
	BOXES_LIBVIRT_MACHINE_CAN_SAVE,
	BOXES_LIBVIRT_MACHINE_SHOULD_AUTOSAVE
};
static void _vala_BoxesLibvirtMachineMachineStat_array_free (BoxesLibvirtMachineMachineStat* array, gint array_length);
#define BOXES_LIBVIRT_MACHINE_STATS_SIZE 20
static void boxes_libvirt_machine_real_disconnect_display (BoxesMachine* base);
void boxes_machine_disconnect_display (BoxesMachine* self);
static void boxes_libvirt_machine_real_connect_display_data_free (gpointer _data);
static void boxes_libvirt_machine_real_connect_display (BoxesMachine* base, BoxesMachineConnectFlags flags, GAsyncReadyCallback _callback_, gpointer _user_data_);
static gboolean boxes_libvirt_machine_real_connect_display_co (BoxesLibvirtMachineConnectDisplayData* _data_);
GCancellable* boxes_machine_get_connecting_cancellable (BoxesMachine* self);
static void boxes_libvirt_machine_wait_for_save (BoxesLibvirtMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_libvirt_machine_wait_for_save_finish (BoxesLibvirtMachine* self, GAsyncResult* _res_);
static void boxes_libvirt_machine_connect_display_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
void boxes_libvirt_machine_start (BoxesLibvirtMachine* self, BoxesMachineConnectFlags flags, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_libvirt_machine_start_finish (BoxesLibvirtMachine* self, GAsyncResult* _res_, GError** error);
gboolean boxes_libvirt_machine_update_display (BoxesLibvirtMachine* self, GError** error);
static gint ____lambda166_ (BoxesLibvirtMachine* self);
GVirDomain* boxes_libvirt_machine_get_domain (BoxesLibvirtMachine* self);
const gchar* boxes_collection_item_get_name (BoxesCollectionItem* self);
static gint _____lambda166__boxes_display_open_fd_func (gpointer self);
GType boxes_display_get_type (void) G_GNUC_CONST;
BoxesDisplay* boxes_machine_get_display (BoxesMachine* self);
void boxes_display_connect_it (BoxesDisplay* self, BoxesDisplayOpenFDFunc open_fd, void* open_fd_target, GError** error);
void boxes_machine_show_display (BoxesMachine* self);
void boxes_display_set_enable_audio (BoxesDisplay* self, gboolean enable);
void boxes_machine_set_status (BoxesMachine* self, const gchar* value);
void boxes_libvirt_machine_update_domain_config (BoxesLibvirtMachine* self);
void boxes_libvirt_machine_set_domain_config (BoxesLibvirtMachine* self, GVirConfigDomain* value);
GVirStorageVol* boxes_get_storage_volume (GVirConnection* connection, GVirDomain* domain);
GVirConnection* boxes_libvirt_machine_get_connection (BoxesLibvirtMachine* self);
void boxes_libvirt_machine_set_storage_volume (BoxesLibvirtMachine* self, GVirStorageVol* value);
static void boxes_libvirt_machine_reconnect_display (BoxesLibvirtMachine* self);
GType boxes_app_window_get_type (void) G_GNUC_CONST;
BoxesAppWindow* boxes_machine_get_window (BoxesMachine* self);
void boxes_machine_set_window (BoxesMachine* self, BoxesAppWindow* value);
void boxes_machine_connect_display (BoxesMachine* self, BoxesMachineConnectFlags flags, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_machine_connect_display_finish (BoxesMachine* self, GAsyncResult* _res_, GError** error);
BoxesLibvirtMachine* boxes_libvirt_machine_new (BoxesCollectionSource* source, GVirConnection* connection, GVirDomain* domain, GError** error);
BoxesLibvirtMachine* boxes_libvirt_machine_construct (GType object_type, BoxesCollectionSource* source, GVirConnection* connection, GVirDomain* domain, GError** error);
BoxesMachine* boxes_machine_construct (GType object_type, BoxesCollectionSource* source, const gchar* name);
void boxes_machine_create_display_config (BoxesMachine* self, const gchar* uuid);
void boxes_libvirt_machine_set_connection (BoxesLibvirtMachine* self, GVirConnection* value);
void boxes_libvirt_machine_set_domain (BoxesLibvirtMachine* self, GVirDomain* value);
BoxesLibvirtMachineProperties* boxes_libvirt_machine_properties_new (BoxesLibvirtMachine* machine);
BoxesLibvirtMachineProperties* boxes_libvirt_machine_properties_construct (GType object_type, BoxesLibvirtMachine* machine);
static void _vala_GVirDomainInfo_free (GVirDomainInfo* self);
GType boxes_machine_machine_state_get_type (void) G_GNUC_CONST;
void boxes_machine_set_state (BoxesMachine* self, BoxesMachineMachineState value);
static void boxes_libvirt_machine_set_stats_enable (BoxesLibvirtMachine* self, gboolean enable);
static void __lambda167_ (BoxesLibvirtMachine* self);
static void ___lambda167__gvir_domain_started (GVirDomain* _sender, gpointer self);
static void __lambda168_ (BoxesLibvirtMachine* self);
static void ___lambda168__gvir_domain_suspended (GVirDomain* _sender, gpointer self);
static void __lambda169_ (BoxesLibvirtMachine* self);
static void ___lambda169__gvir_domain_resumed (GVirDomain* _sender, gpointer self);
static void __lambda170_ (BoxesLibvirtMachine* self);
static void ___lambda170__gvir_domain_stopped (GVirDomain* _sender, gpointer self);
static void __lambda171_ (BoxesLibvirtMachine* self);
static void ___lambda171__gvir_domain_pmsuspended (GVirDomain* _sender, gpointer self);
static void __lambda172_ (BoxesLibvirtMachine* self);
BoxesMachineMachineState boxes_machine_get_state (BoxesMachine* self);
static void ___lambda172__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void _boxes_libvirt_machine_update_domain_config_gvir_domain_updated (GVirDomain* _sender, gpointer self);
void boxes_machine_load_screenshot (BoxesMachine* self);
void boxes_machine_set_screenshot_enable (BoxesMachine* self, gboolean enable);
static void boxes_libvirt_machine_update_cpu_stat (BoxesLibvirtMachine* self, GVirDomainInfo* info, BoxesLibvirtMachineMachineStat* stat);
static void boxes_libvirt_machine_update_mem_stat (BoxesLibvirtMachine* self, GVirDomainInfo* info, BoxesLibvirtMachineMachineStat* stat);
static void boxes_libvirt_machine_update_io_stat_data_free (gpointer _data);
static GVirDomainInfo* _vala_GVirDomainInfo_copy (GVirDomainInfo* self);
static void boxes_libvirt_machine_update_io_stat (BoxesLibvirtMachine* self, GVirDomainInfo* info, BoxesLibvirtMachineMachineStat* stat, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_libvirt_machine_update_io_stat_finish (BoxesLibvirtMachine* self, GAsyncResult* _res_);
static gboolean boxes_libvirt_machine_update_io_stat_co (BoxesLibvirtMachineUpdateIoStatData* _data_);
static Block31Data* block31_data_ref (Block31Data* _data31_);
static void block31_data_unref (void * _userdata_);
static Block32Data* block32_data_ref (Block32Data* _data32_);
static void block32_data_unref (void * _userdata_);
GVirDomainDisk* boxes_libvirt_machine_get_domain_disk (BoxesLibvirtMachine* self, GError** error);
static void ___lambda82_ (Block32Data* _data32_, GError** error);
static void _vala_GVirDomainDiskStats_free (GVirDomainDiskStats* self);
static void ____lambda82__boxes_run_in_thread_func (gpointer self, GError** error);
static void boxes_libvirt_machine_update_io_stat_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_libvirt_machine_update_net_stat_data_free (gpointer _data);
static void boxes_libvirt_machine_update_net_stat (BoxesLibvirtMachine* self, GVirDomainInfo* info, BoxesLibvirtMachineMachineStat* stat, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_libvirt_machine_update_net_stat_finish (BoxesLibvirtMachine* self, GAsyncResult* _res_);
static gboolean boxes_libvirt_machine_update_net_stat_co (BoxesLibvirtMachineUpdateNetStatData* _data_);
static Block33Data* block33_data_ref (Block33Data* _data33_);
static void block33_data_unref (void * _userdata_);
static Block34Data* block34_data_ref (Block34Data* _data34_);
static void block34_data_unref (void * _userdata_);
static GVirDomainInterface* boxes_libvirt_machine_get_domain_network_interface (BoxesLibvirtMachine* self, GError** error);
static void ___lambda83_ (Block34Data* _data34_, GError** error);
static void _vala_GVirDomainInterfaceStats_free (GVirDomainInterfaceStats* self);
static void ____lambda83__boxes_run_in_thread_func (gpointer self, GError** error);
static void boxes_libvirt_machine_update_net_stat_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_libvirt_machine_update_stats_data_free (gpointer _data);
static void boxes_libvirt_machine_update_stats (BoxesLibvirtMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_libvirt_machine_update_stats_finish (BoxesLibvirtMachine* self, GAsyncResult* _res_);
static gboolean boxes_libvirt_machine_update_stats_co (BoxesLibvirtMachineUpdateStatsData* _data_);
static void boxes_libvirt_machine_update_stats_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static BoxesLibvirtMachineMachineStat* _vala_array_dup1 (BoxesLibvirtMachineMachineStat* self, int length);
static void _vala_array_add4 (BoxesLibvirtMachineMachineStat** array, int* length, int* size, const BoxesLibvirtMachineMachineStat* value);
static void _vala_array_add5 (gdouble** array, int* length, int* size, gdouble value);
static void _vala_array_add6 (gdouble** array, int* length, int* size, gdouble value);
static void _vala_array_add7 (gdouble** array, int* length, int* size, gdouble value);
static Block35Data* block35_data_ref (Block35Data* _data35_);
static void block35_data_unref (void * _userdata_);
static gboolean ___lambda81_ (Block35Data* _data35_);
static void __lambda84_ (Block35Data* _data35_);
static void ___lambda84__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static gboolean ____lambda81__gsource_func (gpointer self);
static GList* boxes_libvirt_machine_real_get_properties (BoxesMachine* base, BoxesPropertiesPage page, PropertyCreationFlag* flags);
GList* boxes_iproperties_provider_get_properties (BoxesIPropertiesProvider* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
GList* boxes_display_get_properties (BoxesDisplay* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
static void _g_object_unref0_ (gpointer var);
static void _g_list_free__g_object_unref0_ (GList* self);
static BoxesDisplay* boxes_libvirt_machine_create_display (BoxesLibvirtMachine* self, GError** error);
void boxes_machine_set_display (BoxesMachine* self, BoxesDisplay* value);
GVirConfigDomain* boxes_libvirt_machine_get_domain_config (BoxesLibvirtMachine* self);
gchar* boxes_extract_xpath (const gchar* xmldoc, const gchar* xpath, gboolean required, GError** error);
BoxesSpiceDisplay* boxes_spice_display_new (BoxesMachine* machine, BoxesBoxConfig* config, const gchar* host, gint port, gint tls_port, const gchar* host_subject);
BoxesSpiceDisplay* boxes_spice_display_construct (GType object_type, BoxesMachine* machine, BoxesBoxConfig* config, const gchar* host, gint port, gint tls_port, const gchar* host_subject);
GType boxes_spice_display_get_type (void) G_GNUC_CONST;
BoxesVncDisplay* boxes_vnc_display_new (BoxesBoxConfig* config, const gchar* host, gint port);
BoxesVncDisplay* boxes_vnc_display_construct (GType object_type, BoxesBoxConfig* config, const gchar* host, gint port);
GType boxes_vnc_display_get_type (void) G_GNUC_CONST;
static void boxes_libvirt_machine_real_take_screenshot_data_free (gpointer _data);
static void boxes_libvirt_machine_real_take_screenshot (BoxesMachine* base, GAsyncReadyCallback _callback_, gpointer _user_data_);
static gboolean boxes_libvirt_machine_real_take_screenshot_co (BoxesLibvirtMachineTakeScreenshotData* _data_);
static Block36Data* block36_data_ref (Block36Data* _data36_);
static void block36_data_unref (void * _userdata_);
static void boxes_libvirt_machine_take_screenshot_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void __lambda173_ (Block36Data* _data36_, GError** error);
static void ___lambda173__boxes_run_in_thread_func (gpointer self, GError** error);
static void boxes_libvirt_machine_real_delete (BoxesMachine* base, gboolean by_user);
void boxes_machine_delete (BoxesMachine* self, gboolean by_user);
static Block37Data* block37_data_ref (Block37Data* _data37_);
static void block37_data_unref (void * _userdata_);
static void ___lambda85_ (Block37Data* _data37_, GError** error);
GVirStorageVol* boxes_libvirt_machine_get_storage_volume (BoxesLibvirtMachine* self);
static void ____lambda85__boxes_run_in_thread_func (gpointer self, GError** error);
static void boxes_libvirt_machine_real_save_real_data_free (gpointer _data);
static void boxes_libvirt_machine_real_save_real (BoxesMachine* base, GAsyncReadyCallback _callback_, gpointer _user_data_);
static gboolean boxes_libvirt_machine_real_save_real_co (BoxesLibvirtMachineSaveRealData* _data_);
static void boxes_libvirt_machine_save_real_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_libvirt_machine_suspend_data_free (gpointer _data);
void boxes_libvirt_machine_suspend (BoxesLibvirtMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_libvirt_machine_suspend_finish (BoxesLibvirtMachine* self, GAsyncResult* _res_, GError** error);
static gboolean boxes_libvirt_machine_suspend_co (BoxesLibvirtMachineSuspendData* _data_);
gboolean boxes_libvirt_machine_get_save_on_quit (BoxesLibvirtMachine* self);
void boxes_machine_save (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_machine_save_finish (BoxesMachine* self, GAsyncResult* _res_, GError** error);
static void boxes_libvirt_machine_suspend_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
void boxes_libvirt_machine_force_shutdown (BoxesLibvirtMachine* self);
void boxes_libvirt_machine_try_shutdown (BoxesLibvirtMachine* self);
static GVirDomainStartFlags boxes_libvirt_machine_connect_flags_to_gvir (BoxesLibvirtMachine* self, BoxesMachineConnectFlags flags);
static void boxes_libvirt_machine_start_data_free (gpointer _data);
static gboolean boxes_libvirt_machine_start_co (BoxesLibvirtMachineStartData* _data_);
static void boxes_libvirt_machine_start_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_libvirt_machine_real_restart (BoxesMachine* base);
static Block38Data* block38_data_ref (Block38Data* _data38_);
static void block38_data_unref (void * _userdata_);
static void ___lambda139_ (BoxesLibvirtMachine* self, GObject* obj, GAsyncResult* res);
void boxes_machine_restart (BoxesMachine* self);
static void ____lambda139__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void __lambda140_ (Block38Data* _data38_);
static void ___lambda141_ (BoxesLibvirtMachine* self, GObject* obj, GAsyncResult* res);
static void ____lambda141__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void ___lambda140__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static gboolean __lambda142_ (Block38Data* _data38_);
static void __lambda143_ (Block38Data* _data38_);
static void ___lambda143__boxes_notification_ok_func (gpointer self);
GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
BoxesNotificationbar* boxes_app_window_get_notificationbar (BoxesAppWindow* self);
GdNotification* boxes_notificationbar_display_for_action (BoxesNotificationbar* self, const gchar* message, const gchar* action_label, BoxesNotificationOKFunc action_func, void* action_func_target, GDestroyNotify action_func_target_destroy_notify, BoxesNotificationCancelFunc ignore_func, void* ignore_func_target, GDestroyNotify ignore_func_target_destroy_notify, gint timeout);
static gboolean ___lambda142__gsource_func (gpointer self);
static void boxes_libvirt_machine_wait_for_save_data_free (gpointer _data);
static gboolean boxes_libvirt_machine_wait_for_save_co (BoxesLibvirtMachineWaitForSaveData* _data_);
static Block39Data* block39_data_ref (Block39Data* _data39_);
static void block39_data_unref (void * _userdata_);
static void __lambda163_ (Block39Data* _data39_);
static void ___lambda163__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void __lambda164_ (Block39Data* _data39_);
static gboolean __lambda165_ (Block39Data* _data39_);
static gboolean ___lambda165__gsource_func (gpointer self);
static void ___lambda164__g_cancellable_cancelled (GCancellable* _sender, gpointer self);
BoxesVMCreator* boxes_libvirt_machine_get_vm_creator (BoxesLibvirtMachine* self);
void boxes_libvirt_machine_set_vm_creator (BoxesLibvirtMachine* self, BoxesVMCreator* value);
gboolean boxes_libvirt_machine_get_importing (BoxesLibvirtMachine* self);
void boxes_machine_set_can_delete (BoxesMachine* self, gboolean value);
gboolean boxes_vm_configurator_is_live_config (GVirConfigDomain* domain);
void boxes_machine_set_under_construction (BoxesMachine* self, gboolean value);
GType boxes_vm_importer_get_type (void) G_GNUC_CONST;
void boxes_libvirt_machine_set_save_on_quit (BoxesLibvirtMachine* self, gboolean value);
gboolean boxes_machine_get_should_autosave (BoxesMachine* self);
gboolean boxes_vm_creator_get_express_install (BoxesVMCreator* self);
static GObject * boxes_libvirt_machine_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static GVirDomainDiskStats* _vala_GVirDomainDiskStats_copy (GVirDomainDiskStats* self);
static GVirDomainInterfaceStats* _vala_GVirDomainInterfaceStats_copy (GVirDomainInterfaceStats* self);
static void boxes_libvirt_machine_finalize (GObject* obj);
gboolean boxes_machine_get_can_save (BoxesMachine* self);
static void _vala_boxes_libvirt_machine_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_boxes_libvirt_machine_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);


static void _vala_BoxesLibvirtMachineMachineStat_array_free (BoxesLibvirtMachineMachineStat* array, gint array_length) {
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (array != NULL) {
#line 979 "libvirt-machine.c"
		int i;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		for (i = 0; i < array_length; i = i + 1) {
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			boxes_libvirt_machine_machine_stat_destroy (&array[i]);
#line 985 "libvirt-machine.c"
		}
	}
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_free (array);
#line 990 "libvirt-machine.c"
}


static void boxes_libvirt_machine_real_disconnect_display (BoxesMachine* base) {
	BoxesLibvirtMachine * self;
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self = (BoxesLibvirtMachine*) base;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	((BoxesMachine*) self)->stay_on_display = FALSE;
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	BOXES_MACHINE_CLASS (boxes_libvirt_machine_parent_class)->disconnect_display (G_TYPE_CHECK_INSTANCE_CAST (self, BOXES_TYPE_MACHINE, BoxesMachine));
#line 1002 "libvirt-machine.c"
}


static void boxes_libvirt_machine_real_connect_display_data_free (gpointer _data) {
	BoxesLibvirtMachineConnectDisplayData* _data_;
	_data_ = _data;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_slice_free (BoxesLibvirtMachineConnectDisplayData, _data_);
#line 1013 "libvirt-machine.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return self ? g_object_ref (self) : NULL;
#line 1020 "libvirt-machine.c"
}


static void boxes_libvirt_machine_real_connect_display (BoxesMachine* base, BoxesMachineConnectFlags flags, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesLibvirtMachine * self;
	BoxesLibvirtMachineConnectDisplayData* _data_;
	BoxesLibvirtMachine* _tmp0_ = NULL;
	BoxesMachineConnectFlags _tmp1_ = 0;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self = (BoxesLibvirtMachine*) base;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_slice_new0 (BoxesLibvirtMachineConnectDisplayData);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_libvirt_machine_real_connect_display);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_libvirt_machine_real_connect_display_data_free);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->self = _tmp0_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = flags;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->flags = _tmp1_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_real_connect_display_co (_data_);
#line 1047 "libvirt-machine.c"
}


static void boxes_libvirt_machine_real_connect_display_finish (BoxesMachine* base, GAsyncResult* _res_, GError** error) {
	BoxesLibvirtMachineConnectDisplayData* _data_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return;
#line 1057 "libvirt-machine.c"
	}
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 1061 "libvirt-machine.c"
}


static void boxes_libvirt_machine_connect_display_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesLibvirtMachineConnectDisplayData* _data_;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = _user_data_;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_source_object_ = source_object;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_res_ = _res_;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_real_connect_display_co (_data_);
#line 1075 "libvirt-machine.c"
}


static gint ____lambda166_ (BoxesLibvirtMachine* self) {
	gint result = 0;
	GError * _inner_error_ = NULL;
	{
		gint _tmp0_ = 0;
		GVirDomain* _tmp1_ = NULL;
		gint _tmp2_ = 0;
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp1_ = self->priv->_domain;
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp2_ = gvir_domain_open_graphics_fd (_tmp1_, (guint) 0, (guint) 0, &_inner_error_);
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp0_ = _tmp2_;
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1094 "libvirt-machine.c"
			goto __catch16_g_error;
		}
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		result = _tmp0_;
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return result;
#line 1101 "libvirt-machine.c"
	}
	goto __finally16;
	__catch16_g_error:
	{
		GError* _error_ = NULL;
		const gchar* _tmp3_ = NULL;
		const gchar* _tmp4_ = NULL;
		GError* _tmp5_ = NULL;
		const gchar* _tmp6_ = NULL;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_error_ = _inner_error_;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_inner_error_ = NULL;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp3_ = boxes_collection_item_get_name ((BoxesCollectionItem*) self);
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp4_ = _tmp3_;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp5_ = _error_;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp6_ = _tmp5_->message;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_critical ("libvirt-machine.vala:71: Failed to open graphics for %s: %s", _tmp4_, _tmp6_);
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		result = -1;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_error_free0 (_error_);
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return result;
#line 1131 "libvirt-machine.c"
	}
	__finally16:
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_clear_error (&_inner_error_);
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return 0;
#line 1140 "libvirt-machine.c"
}


static gint _____lambda166__boxes_display_open_fd_func (gpointer self) {
	gint result;
	result = ____lambda166_ ((BoxesLibvirtMachine*) self);
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 1149 "libvirt-machine.c"
}


static gboolean boxes_libvirt_machine_real_connect_display_co (BoxesLibvirtMachineConnectDisplayData* _data_) {
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	switch (_data_->_state_) {
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case 0:
#line 1158 "libvirt-machine.c"
		goto _state_0;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case 1:
#line 1162 "libvirt-machine.c"
		goto _state_1;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case 2:
#line 1166 "libvirt-machine.c"
		goto _state_2;
		default:
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_assert_not_reached ();
#line 1171 "libvirt-machine.c"
	}
	_state_0:
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp0_ = NULL;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp0_ = boxes_machine_get_connecting_cancellable ((BoxesMachine*) _data_->self);
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp1_ = NULL;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp1_ = _data_->_tmp0_;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_cancellable_reset (_data_->_tmp1_);
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_state_ = 1;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_wait_for_save (_data_->self, boxes_libvirt_machine_connect_display_ready, _data_);
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return FALSE;
#line 1190 "libvirt-machine.c"
	_state_1:
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_wait_for_save_finish (_data_->self, _data_->_res_);
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp2_ = NULL;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp2_ = boxes_machine_get_connecting_cancellable ((BoxesMachine*) _data_->self);
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp3_ = NULL;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp3_ = _data_->_tmp2_;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp4_ = FALSE;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp4_ = g_cancellable_is_cancelled (_data_->_tmp3_);
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_data_->_tmp4_) {
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp5_ = NULL;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp5_ = boxes_machine_get_connecting_cancellable ((BoxesMachine*) _data_->self);
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp6_ = NULL;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp6_ = _data_->_tmp5_;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_cancellable_reset (_data_->_tmp6_);
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (_data_->_state_ == 0) {
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1222 "libvirt-machine.c"
		} else {
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1226 "libvirt-machine.c"
		}
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_object_unref (_data_->_async_result);
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 1232 "libvirt-machine.c"
	}
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp7_ = 0;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp7_ = _data_->flags;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp8_ = NULL;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp8_ = boxes_machine_get_connecting_cancellable ((BoxesMachine*) _data_->self);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp9_ = NULL;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp9_ = _data_->_tmp8_;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_state_ = 2;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_start (_data_->self, _data_->_tmp7_, _data_->_tmp9_, boxes_libvirt_machine_connect_display_ready, _data_);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return FALSE;
#line 1252 "libvirt-machine.c"
	_state_2:
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_start_finish (_data_->self, _data_->_res_, &_data_->_inner_error_);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_error_free (_data_->_inner_error_);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (_data_->_state_ == 0) {
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1266 "libvirt-machine.c"
		} else {
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1270 "libvirt-machine.c"
		}
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_object_unref (_data_->_async_result);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 1276 "libvirt-machine.c"
	}
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp10_ = NULL;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp10_ = boxes_machine_get_connecting_cancellable ((BoxesMachine*) _data_->self);
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp11_ = NULL;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp11_ = _data_->_tmp10_;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp12_ = FALSE;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp12_ = g_cancellable_is_cancelled (_data_->_tmp11_);
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_data_->_tmp12_) {
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp13_ = NULL;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp13_ = boxes_machine_get_connecting_cancellable ((BoxesMachine*) _data_->self);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp14_ = NULL;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp14_ = _data_->_tmp13_;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_cancellable_reset (_data_->_tmp14_);
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (_data_->_state_ == 0) {
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1306 "libvirt-machine.c"
		} else {
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1310 "libvirt-machine.c"
		}
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_object_unref (_data_->_async_result);
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 1316 "libvirt-machine.c"
	}
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp16_ = FALSE;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp16_ = boxes_libvirt_machine_update_display (_data_->self, &_data_->_inner_error_);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp15_ = _data_->_tmp16_;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_error_free (_data_->_inner_error_);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (_data_->_state_ == 0) {
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1334 "libvirt-machine.c"
		} else {
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1338 "libvirt-machine.c"
		}
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_object_unref (_data_->_async_result);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 1344 "libvirt-machine.c"
	}
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_data_->_tmp15_) {
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->open_fd_target = NULL;
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->open_fd_target_destroy_notify = NULL;
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->open_fd = NULL;
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->open_fd_target = NULL;
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->open_fd_target_destroy_notify = NULL;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp17_ = NULL;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp17_ = ((BoxesMachine*) _data_->self)->source;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp18_ = NULL;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp18_ = boxes_collection_source_get_uri (_data_->_tmp17_);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp19_ = NULL;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp19_ = _data_->_tmp18_;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp20_ = NULL;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp20_ = _data_->_tmp19_;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp21_ = FALSE;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp21_ = g_str_has_prefix (_data_->_tmp20_, "qemu+unix");
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp22_ = FALSE;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp22_ = _data_->_tmp21_;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_free0 (_data_->_tmp20_);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (_data_->_tmp22_) {
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			(_data_->open_fd_target_destroy_notify == NULL) ? NULL : (_data_->open_fd_target_destroy_notify (_data_->open_fd_target), NULL);
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->open_fd = NULL;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->open_fd_target = NULL;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->open_fd_target_destroy_notify = NULL;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->open_fd = _____lambda166__boxes_display_open_fd_func;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->open_fd_target = g_object_ref (_data_->self);
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->open_fd_target_destroy_notify = g_object_unref;
#line 1400 "libvirt-machine.c"
		}
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp23_ = NULL;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp23_ = boxes_machine_get_display ((BoxesMachine*) _data_->self);
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp24_ = NULL;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp24_ = _data_->_tmp23_;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp25_ = NULL;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp25__target = NULL;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp25_ = _data_->open_fd;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp25__target = _data_->open_fd_target;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_display_connect_it (_data_->_tmp24_, _data_->_tmp25_, _data_->_tmp25__target, &_data_->_inner_error_);
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_error_free (_data_->_inner_error_);
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			(_data_->open_fd_target_destroy_notify == NULL) ? NULL : (_data_->open_fd_target_destroy_notify (_data_->open_fd_target), NULL);
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->open_fd = NULL;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->open_fd_target = NULL;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->open_fd_target_destroy_notify = NULL;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			if (_data_->_state_ == 0) {
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1438 "libvirt-machine.c"
			} else {
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 1442 "libvirt-machine.c"
			}
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_object_unref (_data_->_async_result);
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			return FALSE;
#line 1448 "libvirt-machine.c"
		}
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		(_data_->open_fd_target_destroy_notify == NULL) ? NULL : (_data_->open_fd_target_destroy_notify (_data_->open_fd_target), NULL);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->open_fd = NULL;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->open_fd_target = NULL;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->open_fd_target_destroy_notify = NULL;
#line 1458 "libvirt-machine.c"
	} else {
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_machine_show_display ((BoxesMachine*) _data_->self);
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp26_ = NULL;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp26_ = boxes_machine_get_display ((BoxesMachine*) _data_->self);
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp27_ = NULL;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp27_ = _data_->_tmp26_;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_display_set_enable_audio (_data_->_tmp27_, TRUE);
#line 1472 "libvirt-machine.c"
	}
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp28_ = NULL;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp28_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _data_->self);
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp29_ = NULL;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp29_ = _data_->_tmp28_;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_machine_set_status ((BoxesMachine*) _data_->self, _data_->_tmp29_);
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_data_->_state_ == 0) {
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1488 "libvirt-machine.c"
	} else {
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1492 "libvirt-machine.c"
	}
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_object_unref (_data_->_async_result);
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return FALSE;
#line 1498 "libvirt-machine.c"
}


void boxes_libvirt_machine_update_domain_config (BoxesLibvirtMachine* self) {
	GError * _inner_error_ = NULL;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_if_fail (self != NULL);
#line 1506 "libvirt-machine.c"
	{
		GVirConfigDomain* _tmp0_ = NULL;
		GVirDomain* _tmp1_ = NULL;
		GVirConfigDomain* _tmp2_ = NULL;
		GVirConnection* _tmp3_ = NULL;
		GVirDomain* _tmp4_ = NULL;
		GVirStorageVol* _tmp5_ = NULL;
		GVirStorageVol* _tmp6_ = NULL;
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp1_ = self->priv->_domain;
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp2_ = gvir_domain_get_config (_tmp1_, (guint) GVIR_DOMAIN_XML_NONE, &_inner_error_);
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp0_ = _tmp2_;
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1523 "libvirt-machine.c"
			goto __catch17_g_error;
		}
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_set_domain_config (self, _tmp0_);
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp3_ = self->priv->_connection;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp4_ = self->priv->_domain;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp5_ = boxes_get_storage_volume (_tmp3_, _tmp4_);
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp6_ = _tmp5_;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_set_storage_volume (self, _tmp6_);
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_object_unref0 (_tmp6_);
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_object_unref0 (_tmp0_);
#line 1542 "libvirt-machine.c"
	}
	goto __finally17;
	__catch17_g_error:
	{
		GError* _error_ = NULL;
		GVirDomain* _tmp7_ = NULL;
		const gchar* _tmp8_ = NULL;
		GError* _tmp9_ = NULL;
		const gchar* _tmp10_ = NULL;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_error_ = _inner_error_;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_inner_error_ = NULL;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp7_ = self->priv->_domain;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp8_ = gvir_domain_get_name (_tmp7_);
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp9_ = _error_;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp10_ = _tmp9_->message;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_critical ("libvirt-machine.vala:121: Failed to fetch configuration for domain '%s" \
"': %s", _tmp8_, _tmp10_);
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_error_free0 (_error_);
#line 1568 "libvirt-machine.c"
	}
	__finally17:
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_clear_error (&_inner_error_);
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return;
#line 1579 "libvirt-machine.c"
	}
}


static void boxes_libvirt_machine_reconnect_display (BoxesLibvirtMachine* self) {
	BoxesDisplay* _tmp0_ = NULL;
	BoxesDisplay* _tmp1_ = NULL;
	BoxesAppWindow* current_window = NULL;
	BoxesAppWindow* _tmp2_ = NULL;
	BoxesAppWindow* _tmp3_ = NULL;
	BoxesAppWindow* _tmp4_ = NULL;
	BoxesAppWindow* _tmp5_ = NULL;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_if_fail (self != NULL);
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = boxes_machine_get_display ((BoxesMachine*) self);
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = _tmp0_;
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_tmp1_ == NULL) {
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return;
#line 1602 "libvirt-machine.c"
	}
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp2_ = boxes_machine_get_window ((BoxesMachine*) self);
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp3_ = _tmp2_;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp4_ = _g_object_ref0 (_tmp3_);
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	current_window = _tmp4_;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_machine_disconnect_display ((BoxesMachine*) self);
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp5_ = current_window;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_machine_set_window ((BoxesMachine*) self, _tmp5_);
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_machine_connect_display ((BoxesMachine*) self, BOXES_MACHINE_CONNECT_FLAGS_NONE, NULL, NULL);
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (current_window);
#line 1622 "libvirt-machine.c"
}


static void _vala_GVirDomainInfo_free (GVirDomainInfo* self) {
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_boxed_free (gvir_domain_info_get_type (), self);
#line 1629 "libvirt-machine.c"
}


static void __lambda167_ (BoxesLibvirtMachine* self) {
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_machine_set_state ((BoxesMachine*) self, BOXES_MACHINE_MACHINE_STATE_RUNNING);
#line 1636 "libvirt-machine.c"
}


static void ___lambda167__gvir_domain_started (GVirDomain* _sender, gpointer self) {
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	__lambda167_ ((BoxesLibvirtMachine*) self);
#line 1643 "libvirt-machine.c"
}


static void __lambda168_ (BoxesLibvirtMachine* self) {
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_machine_set_state ((BoxesMachine*) self, BOXES_MACHINE_MACHINE_STATE_PAUSED);
#line 1650 "libvirt-machine.c"
}


static void ___lambda168__gvir_domain_suspended (GVirDomain* _sender, gpointer self) {
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	__lambda168_ ((BoxesLibvirtMachine*) self);
#line 1657 "libvirt-machine.c"
}


static void __lambda169_ (BoxesLibvirtMachine* self) {
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_machine_set_state ((BoxesMachine*) self, BOXES_MACHINE_MACHINE_STATE_RUNNING);
#line 1664 "libvirt-machine.c"
}


static void ___lambda169__gvir_domain_resumed (GVirDomain* _sender, gpointer self) {
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	__lambda169_ ((BoxesLibvirtMachine*) self);
#line 1671 "libvirt-machine.c"
}


static void __lambda170_ (BoxesLibvirtMachine* self) {
	GVirDomain* _tmp0_ = NULL;
	GSignalInvocationHint* _tmp1_ = NULL;
	GQuark _tmp2_ = 0U;
	GQuark _tmp3_ = 0U;
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = self->priv->_domain;
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = g_signal_get_invocation_hint (_tmp0_);
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp2_ = (*_tmp1_).detail;
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp3_ = g_quark_from_string ("saved");
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_tmp2_ == _tmp3_) {
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_machine_set_state ((BoxesMachine*) self, BOXES_MACHINE_MACHINE_STATE_SAVED);
#line 1692 "libvirt-machine.c"
	} else {
		gboolean _tmp4_ = FALSE;
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp4_ = self->priv->force_stopped;
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (_tmp4_) {
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			self->priv->force_stopped = FALSE;
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			boxes_machine_set_state ((BoxesMachine*) self, BOXES_MACHINE_MACHINE_STATE_FORCE_STOPPED);
#line 1703 "libvirt-machine.c"
		} else {
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			boxes_machine_set_state ((BoxesMachine*) self, BOXES_MACHINE_MACHINE_STATE_STOPPED);
#line 1707 "libvirt-machine.c"
		}
	}
}


static void ___lambda170__gvir_domain_stopped (GVirDomain* _sender, gpointer self) {
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	__lambda170_ ((BoxesLibvirtMachine*) self);
#line 1716 "libvirt-machine.c"
}


static void __lambda171_ (BoxesLibvirtMachine* self) {
#line 195 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_machine_set_state ((BoxesMachine*) self, BOXES_MACHINE_MACHINE_STATE_SLEEPING);
#line 1723 "libvirt-machine.c"
}


static void ___lambda171__gvir_domain_pmsuspended (GVirDomain* _sender, gpointer self) {
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	__lambda171_ ((BoxesLibvirtMachine*) self);
#line 1730 "libvirt-machine.c"
}


static void __lambda172_ (BoxesLibvirtMachine* self) {
	BoxesMachineMachineState _tmp0_ = 0;
	BoxesMachineMachineState _tmp1_ = 0;
#line 198 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = boxes_machine_get_state ((BoxesMachine*) self);
#line 198 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = _tmp0_;
#line 198 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_tmp1_ == BOXES_MACHINE_MACHINE_STATE_RUNNING) {
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_reconnect_display (self);
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_set_stats_enable (self, TRUE);
#line 1747 "libvirt-machine.c"
	} else {
#line 202 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_set_stats_enable (self, FALSE);
#line 1751 "libvirt-machine.c"
	}
}


static void ___lambda172__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	__lambda172_ ((BoxesLibvirtMachine*) self);
#line 1759 "libvirt-machine.c"
}


static void _boxes_libvirt_machine_update_domain_config_gvir_domain_updated (GVirDomain* _sender, gpointer self) {
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_update_domain_config ((BoxesLibvirtMachine*) self);
#line 1766 "libvirt-machine.c"
}


BoxesLibvirtMachine* boxes_libvirt_machine_construct (GType object_type, BoxesCollectionSource* source, GVirConnection* connection, GVirDomain* domain, GError** error) {
	BoxesLibvirtMachine * self = NULL;
	GVirConfigDomain* config = NULL;
	GVirDomain* _tmp0_ = NULL;
	GVirConfigDomain* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	GVirConfigDomain* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	gchar* item_name = NULL;
	gchar* _tmp7_ = NULL;
	BoxesCollectionSource* _tmp8_ = NULL;
	const gchar* _tmp9_ = NULL;
	GVirDomain* _tmp10_ = NULL;
	const gchar* _tmp11_ = NULL;
	gchar* _tmp12_ = NULL;
	gchar* _tmp13_ = NULL;
	GVirDomain* _tmp14_ = NULL;
	const gchar* _tmp15_ = NULL;
	GVirConnection* _tmp16_ = NULL;
	GVirDomain* _tmp17_ = NULL;
	BoxesLibvirtMachineProperties* _tmp18_ = NULL;
	GVirDomain* _tmp29_ = NULL;
	GVirDomain* _tmp30_ = NULL;
	GVirDomain* _tmp31_ = NULL;
	GVirDomain* _tmp32_ = NULL;
	GVirDomain* _tmp33_ = NULL;
	GVirDomain* _tmp34_ = NULL;
	BoxesMachineMachineState _tmp35_ = 0;
	BoxesMachineMachineState _tmp36_ = 0;
	GError * _inner_error_ = NULL;
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_val_if_fail (source != NULL, NULL);
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_val_if_fail (connection != NULL, NULL);
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_val_if_fail (domain != NULL, NULL);
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = domain;
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = gvir_domain_get_config (_tmp0_, (guint) GVIR_DOMAIN_XML_INACTIVE, &_inner_error_);
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	config = _tmp1_;
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_propagate_error (error, _inner_error_);
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_object_unref0 (self);
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return NULL;
#line 1820 "libvirt-machine.c"
	}
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp3_ = config;
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp4_ = gvir_config_domain_get_title (_tmp3_);
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp2_ = _tmp4_;
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_tmp2_ == NULL) {
#line 1830 "libvirt-machine.c"
		GVirDomain* _tmp5_ = NULL;
		const gchar* _tmp6_ = NULL;
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp5_ = domain;
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp6_ = gvir_domain_get_name (_tmp5_);
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp2_ = _tmp6_;
#line 1839 "libvirt-machine.c"
	}
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp7_ = g_strdup (_tmp2_);
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	item_name = _tmp7_;
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp8_ = source;
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp9_ = item_name;
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self = (BoxesLibvirtMachine*) boxes_machine_construct (object_type, _tmp8_, _tmp9_);
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp10_ = domain;
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp11_ = gvir_domain_get_name (_tmp10_);
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp12_ = g_strconcat ("new libvirt machine: ", _tmp11_, NULL);
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp13_ = _tmp12_;
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_debug ("libvirt-machine.vala:143: %s", _tmp13_);
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (_tmp13_);
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp14_ = domain;
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp15_ = gvir_domain_get_uuid (_tmp14_);
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_machine_create_display_config ((BoxesMachine*) self, _tmp15_);
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp16_ = connection;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_set_connection (self, _tmp16_);
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp17_ = domain;
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_set_domain (self, _tmp17_);
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp18_ = boxes_libvirt_machine_properties_new (self);
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (self->properties);
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self->properties = _tmp18_;
#line 1883 "libvirt-machine.c"
	{
		GVirDomainInfo* _tmp19_ = NULL;
		GVirDomain* _tmp20_ = NULL;
		GVirDomainInfo* _tmp21_ = NULL;
		GVirDomainState s = 0;
		GVirDomainInfo* _tmp22_ = NULL;
		GVirDomainInfo* _tmp23_ = NULL;
		GVirDomainState _tmp24_ = 0;
		GVirDomainState _tmp25_ = 0;
		GVirDomainState _tmp26_ = 0;
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp20_ = domain;
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp21_ = gvir_domain_get_info (_tmp20_, &_inner_error_);
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp19_ = _tmp21_;
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1902 "libvirt-machine.c"
			goto __catch18_g_error;
		}
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp22_ = _tmp19_;
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp19_ = NULL;
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp23_ = _tmp22_;
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp24_ = _tmp23_->state;
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp25_ = _tmp24_;
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		__vala_GVirDomainInfo_free0 (_tmp23_);
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		s = _tmp25_;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp26_ = s;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		switch (_tmp26_) {
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			case GVIR_DOMAIN_STATE_RUNNING:
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			case GVIR_DOMAIN_STATE_BLOCKED:
#line 1927 "libvirt-machine.c"
			{
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				boxes_machine_set_state ((BoxesMachine*) self, BOXES_MACHINE_MACHINE_STATE_RUNNING);
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				boxes_libvirt_machine_set_stats_enable (self, TRUE);
#line 156 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				break;
#line 1935 "libvirt-machine.c"
			}
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			case GVIR_DOMAIN_STATE_PAUSED:
#line 1939 "libvirt-machine.c"
			{
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				boxes_machine_set_state ((BoxesMachine*) self, BOXES_MACHINE_MACHINE_STATE_PAUSED);
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				break;
#line 1945 "libvirt-machine.c"
			}
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			case GVIR_DOMAIN_STATE_SHUTDOWN:
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			case GVIR_DOMAIN_STATE_SHUTOFF:
#line 1951 "libvirt-machine.c"
			{
				GVirDomain* _tmp27_ = NULL;
				gboolean _tmp28_ = FALSE;
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_tmp27_ = domain;
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_tmp28_ = gvir_domain_get_saved (_tmp27_);
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				if (_tmp28_) {
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					boxes_machine_set_state ((BoxesMachine*) self, BOXES_MACHINE_MACHINE_STATE_SAVED);
#line 1963 "libvirt-machine.c"
				} else {
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					boxes_machine_set_state ((BoxesMachine*) self, BOXES_MACHINE_MACHINE_STATE_STOPPED);
#line 1967 "libvirt-machine.c"
				}
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				break;
#line 1971 "libvirt-machine.c"
			}
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			case GVIR_DOMAIN_STATE_CRASHED:
#line 1975 "libvirt-machine.c"
			{
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				boxes_machine_set_state ((BoxesMachine*) self, BOXES_MACHINE_MACHINE_STATE_STOPPED);
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				break;
#line 1981 "libvirt-machine.c"
			}
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			case GVIR_DOMAIN_STATE_PMSUSPENDED:
#line 1985 "libvirt-machine.c"
			{
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				boxes_machine_set_state ((BoxesMachine*) self, BOXES_MACHINE_MACHINE_STATE_SLEEPING);
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				break;
#line 1991 "libvirt-machine.c"
			}
			default:
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			case GVIR_DOMAIN_STATE_NONE:
#line 1996 "libvirt-machine.c"
			{
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				boxes_machine_set_state ((BoxesMachine*) self, BOXES_MACHINE_MACHINE_STATE_UNKNOWN);
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				break;
#line 2002 "libvirt-machine.c"
			}
		}
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		__vala_GVirDomainInfo_free0 (_tmp19_);
#line 2007 "libvirt-machine.c"
	}
	goto __finally18;
	__catch18_g_error:
	{
		GError* _error_ = NULL;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_error_ = _inner_error_;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_inner_error_ = NULL;
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_machine_set_state ((BoxesMachine*) self, BOXES_MACHINE_MACHINE_STATE_UNKNOWN);
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_error_free0 (_error_);
#line 2021 "libvirt-machine.c"
	}
	__finally18:
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_propagate_error (error, _inner_error_);
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_free0 (item_name);
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_object_unref0 (config);
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_object_unref0 (self);
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return NULL;
#line 2036 "libvirt-machine.c"
	}
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp29_ = domain;
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_signal_connect_object (_tmp29_, "started", (GCallback) ___lambda167__gvir_domain_started, self, 0);
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp30_ = domain;
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_signal_connect_object (_tmp30_, "suspended", (GCallback) ___lambda168__gvir_domain_suspended, self, 0);
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp31_ = domain;
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_signal_connect_object (_tmp31_, "resumed", (GCallback) ___lambda169__gvir_domain_resumed, self, 0);
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp32_ = domain;
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_signal_connect_object (_tmp32_, "stopped", (GCallback) ___lambda170__gvir_domain_stopped, self, 0);
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp33_ = domain;
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_signal_connect_object (_tmp33_, "pmsuspended", (GCallback) ___lambda171__gvir_domain_pmsuspended, self, 0);
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_signal_connect_object ((GObject*) self, "notify::state", (GCallback) ___lambda172__g_object_notify, self, 0);
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_update_domain_config (self);
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp34_ = domain;
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_signal_connect_object (_tmp34_, "updated", (GCallback) _boxes_libvirt_machine_update_domain_config_gvir_domain_updated, self, 0);
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp35_ = boxes_machine_get_state ((BoxesMachine*) self);
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp36_ = _tmp35_;
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_tmp36_ != BOXES_MACHINE_MACHINE_STATE_STOPPED) {
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_machine_load_screenshot ((BoxesMachine*) self);
#line 2074 "libvirt-machine.c"
	}
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_machine_set_screenshot_enable ((BoxesMachine*) self, TRUE);
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (item_name);
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (config);
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return self;
#line 2084 "libvirt-machine.c"
}


BoxesLibvirtMachine* boxes_libvirt_machine_new (BoxesCollectionSource* source, GVirConnection* connection, GVirDomain* domain, GError** error) {
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return boxes_libvirt_machine_construct (BOXES_TYPE_LIBVIRT_MACHINE, source, connection, domain, error);
#line 2091 "libvirt-machine.c"
}


static void boxes_libvirt_machine_update_cpu_stat (BoxesLibvirtMachine* self, GVirDomainInfo* info, BoxesLibvirtMachineMachineStat* stat) {
	BoxesLibvirtMachineMachineStat prev = {0};
	BoxesLibvirtMachineMachineStat* _tmp0_ = NULL;
	gint _tmp0__length1 = 0;
	BoxesLibvirtMachineMachineStat _tmp1_ = {0};
	BoxesLibvirtMachineMachineStat _tmp2_ = {0};
	gboolean _tmp3_ = FALSE;
	GVirDomainInfo* _tmp4_ = NULL;
	GVirDomainState _tmp5_ = 0;
	GVirDomainInfo* _tmp8_ = NULL;
	guint64 _tmp9_ = 0ULL;
	BoxesLibvirtMachineMachineStat _tmp10_ = {0};
	gdouble _tmp11_ = 0.0;
	GVirDomainInfo* _tmp12_ = NULL;
	guint64 _tmp13_ = 0ULL;
	gint64 dt = 0LL;
	BoxesLibvirtMachineMachineStat _tmp14_ = {0};
	gint64 _tmp15_ = 0LL;
	BoxesLibvirtMachineMachineStat _tmp16_ = {0};
	gint64 _tmp17_ = 0LL;
	gdouble percent = 0.0;
	BoxesLibvirtMachineMachineStat _tmp18_ = {0};
	gdouble _tmp19_ = 0.0;
	gint64 _tmp20_ = 0LL;
	gdouble _tmp21_ = 0.0;
	GVirDomainInfo* _tmp22_ = NULL;
	guint16 _tmp23_ = 0U;
	gdouble _tmp24_ = 0.0;
	gdouble _tmp25_ = 0.0;
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_if_fail (self != NULL);
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_if_fail (info != NULL);
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_if_fail (stat != NULL);
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = self->priv->stats;
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0__length1 = self->priv->stats_length1;
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = _tmp0_[BOXES_LIBVIRT_MACHINE_STATS_SIZE - 1];
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_machine_stat_copy (&_tmp1_, &_tmp2_);
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	prev = _tmp2_;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp4_ = info;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp5_ = _tmp4_->state;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_tmp5_ == GVIR_DOMAIN_STATE_CRASHED) {
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp3_ = TRUE;
#line 2148 "libvirt-machine.c"
	} else {
		GVirDomainInfo* _tmp6_ = NULL;
		GVirDomainState _tmp7_ = 0;
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp6_ = info;
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp7_ = _tmp6_->state;
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp3_ = _tmp7_ == GVIR_DOMAIN_STATE_SHUTOFF;
#line 2158 "libvirt-machine.c"
	}
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_tmp3_) {
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_machine_stat_destroy (&prev);
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return;
#line 2166 "libvirt-machine.c"
	}
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp8_ = info;
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp9_ = _tmp8_->cpuTime;
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp10_ = prev;
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp11_ = _tmp10_.cpu_time_abs;
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	(*stat).cpu_time = _tmp9_ - _tmp11_;
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp12_ = info;
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp13_ = _tmp12_->cpuTime;
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	(*stat).cpu_time_abs = (gdouble) _tmp13_;
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp14_ = *stat;
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp15_ = _tmp14_.timestamp;
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp16_ = prev;
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp17_ = _tmp16_.timestamp;
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	dt = (_tmp15_ - _tmp17_) * 10;
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp18_ = *stat;
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp19_ = _tmp18_.cpu_time;
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp20_ = dt;
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	percent = _tmp19_ / _tmp20_;
#line 225 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp21_ = percent;
#line 225 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp22_ = info;
#line 225 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp23_ = _tmp22_->nrVirtCpu;
#line 225 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	percent = _tmp21_ / _tmp23_;
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp24_ = percent;
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp25_ = CLAMP (_tmp24_, (gdouble) 0, (gdouble) 100);
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	(*stat).cpu_guest_percent = _tmp25_;
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_machine_stat_destroy (&prev);
#line 2218 "libvirt-machine.c"
}


static void boxes_libvirt_machine_update_mem_stat (BoxesLibvirtMachine* self, GVirDomainInfo* info, BoxesLibvirtMachineMachineStat* stat) {
	GVirDomainInfo* _tmp0_ = NULL;
	GVirDomainState _tmp1_ = 0;
	GVirDomainInfo* _tmp2_ = NULL;
	guint64 _tmp3_ = 0ULL;
	GVirDomainInfo* _tmp4_ = NULL;
	guint64 _tmp5_ = 0ULL;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_if_fail (self != NULL);
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_if_fail (info != NULL);
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_if_fail (stat != NULL);
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = info;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = _tmp0_->state;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_tmp1_ != GVIR_DOMAIN_STATE_RUNNING) {
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return;
#line 2243 "libvirt-machine.c"
	}
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp2_ = info;
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp3_ = _tmp2_->memory;
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp4_ = info;
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp5_ = _tmp4_->maxMem;
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	(*stat).memory_percent = (_tmp3_ * 100.0) / _tmp5_;
#line 2255 "libvirt-machine.c"
}


static void boxes_libvirt_machine_update_io_stat_data_free (gpointer _data) {
	BoxesLibvirtMachineUpdateIoStatData* _data_;
	_data_ = _data;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	__vala_GVirDomainInfo_free0 (_data_->info);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_slice_free (BoxesLibvirtMachineUpdateIoStatData, _data_);
#line 2268 "libvirt-machine.c"
}


static GVirDomainInfo* _vala_GVirDomainInfo_copy (GVirDomainInfo* self) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return g_boxed_copy (gvir_domain_info_get_type (), self);
#line 2275 "libvirt-machine.c"
}


static gpointer __vala_GVirDomainInfo_copy0 (gpointer self) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return self ? _vala_GVirDomainInfo_copy (self) : NULL;
#line 2282 "libvirt-machine.c"
}


static void boxes_libvirt_machine_update_io_stat (BoxesLibvirtMachine* self, GVirDomainInfo* info, BoxesLibvirtMachineMachineStat* stat, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesLibvirtMachineUpdateIoStatData* _data_;
	BoxesLibvirtMachine* _tmp0_ = NULL;
	GVirDomainInfo* _tmp1_ = NULL;
	GVirDomainInfo* _tmp2_ = NULL;
	BoxesLibvirtMachineMachineStat* _tmp3_ = NULL;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_slice_new0 (BoxesLibvirtMachineUpdateIoStatData);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_libvirt_machine_update_io_stat);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_libvirt_machine_update_io_stat_data_free);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->self = _tmp0_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = info;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp2_ = __vala_GVirDomainInfo_copy0 (_tmp1_);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	__vala_GVirDomainInfo_free0 (_data_->info);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->info = _tmp2_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp3_ = stat;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->stat = _tmp3_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_update_io_stat_co (_data_);
#line 2316 "libvirt-machine.c"
}


static void boxes_libvirt_machine_update_io_stat_finish (BoxesLibvirtMachine* self, GAsyncResult* _res_) {
	BoxesLibvirtMachineUpdateIoStatData* _data_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 2324 "libvirt-machine.c"
}


static Block31Data* block31_data_ref (Block31Data* _data31_) {
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_atomic_int_inc (&_data31_->_ref_count_);
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return _data31_;
#line 2333 "libvirt-machine.c"
}


static void block31_data_unref (void * _userdata_) {
	Block31Data* _data31_;
	_data31_ = (Block31Data*) _userdata_;
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (g_atomic_int_dec_and_test (&_data31_->_ref_count_)) {
#line 2342 "libvirt-machine.c"
		BoxesLibvirtMachine* self;
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		self = _data31_->self;
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_object_unref0 (self);
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_slice_free (Block31Data, _data31_);
#line 2350 "libvirt-machine.c"
	}
}


static Block32Data* block32_data_ref (Block32Data* _data32_) {
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_atomic_int_inc (&_data32_->_ref_count_);
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return _data32_;
#line 2360 "libvirt-machine.c"
}


static void block32_data_unref (void * _userdata_) {
	Block32Data* _data32_;
	_data32_ = (Block32Data*) _userdata_;
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (g_atomic_int_dec_and_test (&_data32_->_ref_count_)) {
#line 2369 "libvirt-machine.c"
		BoxesLibvirtMachine* self;
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		self = _data32_->_data31_->self;
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_object_unref0 (_data32_->disk);
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		block31_data_unref (_data32_->_data31_);
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data32_->_data31_ = NULL;
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_slice_free (Block32Data, _data32_);
#line 2381 "libvirt-machine.c"
	}
}


static void _vala_GVirDomainDiskStats_free (GVirDomainDiskStats* self) {
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_boxed_free (gvir_domain_disk_stats_get_type (), self);
#line 2389 "libvirt-machine.c"
}


static void ___lambda82_ (Block32Data* _data32_, GError** error) {
	Block31Data* _data31_;
	BoxesLibvirtMachine* self;
	GVirDomainDiskStats* _tmp0_ = NULL;
	GVirDomainDisk* _tmp1_ = NULL;
	GVirDomainDiskStats* _tmp2_ = NULL;
	GVirDomainDiskStats* _tmp3_ = NULL;
	GError * _inner_error_ = NULL;
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data31_ = _data32_->_data31_;
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self = _data31_->self;
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = _data32_->disk;
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp2_ = gvir_domain_disk_get_stats (_tmp1_, &_inner_error_);
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = _tmp2_;
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_propagate_error (error, _inner_error_);
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return;
#line 2417 "libvirt-machine.c"
	}
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp3_ = _tmp0_;
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = NULL;
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	__vala_GVirDomainDiskStats_free0 ((*_data31_->stat).disk);
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	(*_data31_->stat).disk = _tmp3_;
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	__vala_GVirDomainDiskStats_free0 (_tmp0_);
#line 2429 "libvirt-machine.c"
}


static void ____lambda82__boxes_run_in_thread_func (gpointer self, GError** error) {
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	___lambda82_ (self, error);
#line 2436 "libvirt-machine.c"
}


static void boxes_libvirt_machine_update_io_stat_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesLibvirtMachineUpdateIoStatData* _data_;
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = _user_data_;
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_source_object_ = source_object;
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_res_ = _res_;
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_update_io_stat_co (_data_);
#line 2450 "libvirt-machine.c"
}


static gboolean boxes_libvirt_machine_update_io_stat_co (BoxesLibvirtMachineUpdateIoStatData* _data_) {
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	switch (_data_->_state_) {
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case 0:
#line 2459 "libvirt-machine.c"
		goto _state_0;
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case 1:
#line 2463 "libvirt-machine.c"
		goto _state_1;
		default:
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_assert_not_reached ();
#line 2468 "libvirt-machine.c"
	}
	_state_0:
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_data31_ = g_slice_new0 (Block31Data);
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_data31_->_ref_count_ = 1;
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_data31_->self = g_object_ref (_data_->self);
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp0_ = NULL;
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp0_ = _data_->stat;
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_data31_->stat = _data_->_tmp0_;
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_data31_->_async_data_ = _data_;
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp1_ = NULL;
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp1_ = _data_->info;
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp2_ = 0;
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp2_ = _data_->_tmp1_->state;
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_data_->_tmp2_ != GVIR_DOMAIN_STATE_RUNNING) {
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		block31_data_unref (_data_->_data31_);
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_data31_ = NULL;
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (_data_->_state_ == 0) {
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2503 "libvirt-machine.c"
		} else {
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 2507 "libvirt-machine.c"
		}
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_object_unref (_data_->_async_result);
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 2513 "libvirt-machine.c"
	}
	{
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_data32_ = g_slice_new0 (Block32Data);
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_data32_->_ref_count_ = 1;
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_data32_->_data31_ = block31_data_ref (_data_->_data31_);
#line 241 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp3_ = NULL;
#line 241 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp3_ = boxes_libvirt_machine_get_domain_disk (_data_->self, &_data_->_inner_error_);
#line 241 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_data32_->disk = _data_->_tmp3_;
#line 241 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 241 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			block32_data_unref (_data_->_data32_);
#line 241 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_data32_ = NULL;
#line 2534 "libvirt-machine.c"
			goto __catch19_g_error;
		}
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp4_ = NULL;
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp4_ = _data_->_data32_->disk;
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (_data_->_tmp4_ == NULL) {
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			block32_data_unref (_data_->_data32_);
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_data32_ = NULL;
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			block31_data_unref (_data_->_data31_);
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_data31_ = NULL;
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			if (_data_->_state_ == 0) {
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2555 "libvirt-machine.c"
			} else {
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 2559 "libvirt-machine.c"
			}
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_object_unref (_data_->_async_result);
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			return FALSE;
#line 2565 "libvirt-machine.c"
		}
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_state_ = 1;
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_run_in_thread (____lambda82__boxes_run_in_thread_func, block32_data_ref (_data_->_data32_), block32_data_unref, boxes_libvirt_machine_update_io_stat_ready, _data_);
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 2573 "libvirt-machine.c"
		_state_1:
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_run_in_thread_finish (_data_->_res_, &_data_->_inner_error_);
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			block32_data_unref (_data_->_data32_);
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_data32_ = NULL;
#line 2583 "libvirt-machine.c"
			goto __catch19_g_error;
		}
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp5_ = NULL;
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp5__length1 = 0;
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp5_ = _data_->self->priv->stats;
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp5__length1 = _data_->self->priv->stats_length1;
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		memset (&_data_->_tmp6_, 0, sizeof (BoxesLibvirtMachineMachineStat));
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp6_ = _data_->_tmp5_[BOXES_LIBVIRT_MACHINE_STATS_SIZE - 1];
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		memset (&_data_->_tmp7_, 0, sizeof (BoxesLibvirtMachineMachineStat));
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_machine_stat_copy (&_data_->_tmp6_, &_data_->_tmp7_);
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->prev = _data_->_tmp7_;
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		memset (&_data_->_tmp8_, 0, sizeof (BoxesLibvirtMachineMachineStat));
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp8_ = _data_->prev;
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp9_ = NULL;
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp9_ = _data_->_tmp8_.disk;
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (_data_->_tmp9_ != NULL) {
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp10_ = NULL;
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp10_ = _data_->_data31_->stat;
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp11_ = NULL;
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp11_ = (*_data_->_tmp10_).disk;
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp12_ = 0LL;
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp12_ = _data_->_tmp11_->rd_bytes;
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			memset (&_data_->_tmp13_, 0, sizeof (BoxesLibvirtMachineMachineStat));
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp13_ = _data_->prev;
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp14_ = NULL;
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp14_ = _data_->_tmp13_.disk;
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp15_ = 0LL;
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp15_ = _data_->_tmp14_->rd_bytes;
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			(*_data_->_data31_->stat).disk_read = (gdouble) (_data_->_tmp12_ - _data_->_tmp15_);
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp16_ = NULL;
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp16_ = _data_->_data31_->stat;
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp17_ = NULL;
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp17_ = (*_data_->_tmp16_).disk;
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp18_ = 0LL;
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp18_ = _data_->_tmp17_->wr_bytes;
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			memset (&_data_->_tmp19_, 0, sizeof (BoxesLibvirtMachineMachineStat));
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp19_ = _data_->prev;
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp20_ = NULL;
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp20_ = _data_->_tmp19_.disk;
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp21_ = 0LL;
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp21_ = _data_->_tmp20_->wr_bytes;
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			(*_data_->_data31_->stat).disk_write = (gdouble) (_data_->_tmp18_ - _data_->_tmp21_);
#line 2666 "libvirt-machine.c"
		}
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_machine_stat_destroy (&_data_->prev);
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		block32_data_unref (_data_->_data32_);
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_data32_ = NULL;
#line 2674 "libvirt-machine.c"
	}
	goto __finally19;
	__catch19_g_error:
	{
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->err = _data_->_inner_error_;
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_inner_error_ = NULL;
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp22_ = NULL;
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp22_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _data_->self);
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp23_ = NULL;
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp23_ = _data_->_tmp22_;
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp24_ = NULL;
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp24_ = _data_->err;
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp25_ = NULL;
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp25_ = _data_->_tmp24_->message;
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_warning ("libvirt-machine.vala:254: Failed to fetch I/O statistics for %s: %s", _data_->_tmp23_, _data_->_tmp25_);
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_error_free0 (_data_->err);
#line 2703 "libvirt-machine.c"
	}
	__finally19:
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		block31_data_unref (_data_->_data31_);
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_data31_ = NULL;
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_clear_error (&_data_->_inner_error_);
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 2718 "libvirt-machine.c"
	}
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	block31_data_unref (_data_->_data31_);
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_data31_ = NULL;
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_data_->_state_ == 0) {
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2728 "libvirt-machine.c"
	} else {
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2732 "libvirt-machine.c"
	}
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_object_unref (_data_->_async_result);
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return FALSE;
#line 2738 "libvirt-machine.c"
}


static void boxes_libvirt_machine_update_net_stat_data_free (gpointer _data) {
	BoxesLibvirtMachineUpdateNetStatData* _data_;
	_data_ = _data;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	__vala_GVirDomainInfo_free0 (_data_->info);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_slice_free (BoxesLibvirtMachineUpdateNetStatData, _data_);
#line 2751 "libvirt-machine.c"
}


static void boxes_libvirt_machine_update_net_stat (BoxesLibvirtMachine* self, GVirDomainInfo* info, BoxesLibvirtMachineMachineStat* stat, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesLibvirtMachineUpdateNetStatData* _data_;
	BoxesLibvirtMachine* _tmp0_ = NULL;
	GVirDomainInfo* _tmp1_ = NULL;
	GVirDomainInfo* _tmp2_ = NULL;
	BoxesLibvirtMachineMachineStat* _tmp3_ = NULL;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_slice_new0 (BoxesLibvirtMachineUpdateNetStatData);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_libvirt_machine_update_net_stat);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_libvirt_machine_update_net_stat_data_free);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->self = _tmp0_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = info;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp2_ = __vala_GVirDomainInfo_copy0 (_tmp1_);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	__vala_GVirDomainInfo_free0 (_data_->info);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->info = _tmp2_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp3_ = stat;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->stat = _tmp3_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_update_net_stat_co (_data_);
#line 2785 "libvirt-machine.c"
}


static void boxes_libvirt_machine_update_net_stat_finish (BoxesLibvirtMachine* self, GAsyncResult* _res_) {
	BoxesLibvirtMachineUpdateNetStatData* _data_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 2793 "libvirt-machine.c"
}


static Block33Data* block33_data_ref (Block33Data* _data33_) {
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_atomic_int_inc (&_data33_->_ref_count_);
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return _data33_;
#line 2802 "libvirt-machine.c"
}


static void block33_data_unref (void * _userdata_) {
	Block33Data* _data33_;
	_data33_ = (Block33Data*) _userdata_;
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (g_atomic_int_dec_and_test (&_data33_->_ref_count_)) {
#line 2811 "libvirt-machine.c"
		BoxesLibvirtMachine* self;
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		self = _data33_->self;
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_object_unref0 (self);
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_slice_free (Block33Data, _data33_);
#line 2819 "libvirt-machine.c"
	}
}


static Block34Data* block34_data_ref (Block34Data* _data34_) {
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_atomic_int_inc (&_data34_->_ref_count_);
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return _data34_;
#line 2829 "libvirt-machine.c"
}


static void block34_data_unref (void * _userdata_) {
	Block34Data* _data34_;
	_data34_ = (Block34Data*) _userdata_;
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (g_atomic_int_dec_and_test (&_data34_->_ref_count_)) {
#line 2838 "libvirt-machine.c"
		BoxesLibvirtMachine* self;
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		self = _data34_->_data33_->self;
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_object_unref0 (_data34_->net);
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		block33_data_unref (_data34_->_data33_);
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data34_->_data33_ = NULL;
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_slice_free (Block34Data, _data34_);
#line 2850 "libvirt-machine.c"
	}
}


static void _vala_GVirDomainInterfaceStats_free (GVirDomainInterfaceStats* self) {
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_boxed_free (gvir_domain_interface_stats_get_type (), self);
#line 2858 "libvirt-machine.c"
}


static void ___lambda83_ (Block34Data* _data34_, GError** error) {
	Block33Data* _data33_;
	BoxesLibvirtMachine* self;
	GVirDomainInterfaceStats* _tmp0_ = NULL;
	GVirDomainInterface* _tmp1_ = NULL;
	GVirDomainInterfaceStats* _tmp2_ = NULL;
	GVirDomainInterfaceStats* _tmp3_ = NULL;
	GError * _inner_error_ = NULL;
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data33_ = _data34_->_data33_;
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self = _data33_->self;
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = _data34_->net;
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp2_ = gvir_domain_interface_get_stats (_tmp1_, &_inner_error_);
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = _tmp2_;
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_propagate_error (error, _inner_error_);
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return;
#line 2886 "libvirt-machine.c"
	}
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp3_ = _tmp0_;
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = NULL;
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	__vala_GVirDomainInterfaceStats_free0 ((*_data33_->stat).net);
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	(*_data33_->stat).net = _tmp3_;
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	__vala_GVirDomainInterfaceStats_free0 (_tmp0_);
#line 2898 "libvirt-machine.c"
}


static void ____lambda83__boxes_run_in_thread_func (gpointer self, GError** error) {
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	___lambda83_ (self, error);
#line 2905 "libvirt-machine.c"
}


static void boxes_libvirt_machine_update_net_stat_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesLibvirtMachineUpdateNetStatData* _data_;
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = _user_data_;
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_source_object_ = source_object;
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_res_ = _res_;
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_update_net_stat_co (_data_);
#line 2919 "libvirt-machine.c"
}


static gboolean boxes_libvirt_machine_update_net_stat_co (BoxesLibvirtMachineUpdateNetStatData* _data_) {
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	switch (_data_->_state_) {
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case 0:
#line 2928 "libvirt-machine.c"
		goto _state_0;
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case 1:
#line 2932 "libvirt-machine.c"
		goto _state_1;
		default:
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_assert_not_reached ();
#line 2937 "libvirt-machine.c"
	}
	_state_0:
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_data33_ = g_slice_new0 (Block33Data);
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_data33_->_ref_count_ = 1;
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_data33_->self = g_object_ref (_data_->self);
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp0_ = NULL;
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp0_ = _data_->stat;
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_data33_->stat = _data_->_tmp0_;
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_data33_->_async_data_ = _data_;
#line 259 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp1_ = NULL;
#line 259 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp1_ = _data_->info;
#line 259 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp2_ = 0;
#line 259 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp2_ = _data_->_tmp1_->state;
#line 259 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_data_->_tmp2_ != GVIR_DOMAIN_STATE_RUNNING) {
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		block33_data_unref (_data_->_data33_);
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_data33_ = NULL;
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (_data_->_state_ == 0) {
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2972 "libvirt-machine.c"
		} else {
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 2976 "libvirt-machine.c"
		}
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_object_unref (_data_->_async_result);
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 2982 "libvirt-machine.c"
	}
	{
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_data34_ = g_slice_new0 (Block34Data);
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_data34_->_ref_count_ = 1;
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_data34_->_data33_ = block33_data_ref (_data_->_data33_);
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp3_ = NULL;
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp3_ = boxes_libvirt_machine_get_domain_network_interface (_data_->self, &_data_->_inner_error_);
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_data34_->net = _data_->_tmp3_;
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			block34_data_unref (_data_->_data34_);
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_data34_ = NULL;
#line 3003 "libvirt-machine.c"
			goto __catch20_g_error;
		}
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp4_ = NULL;
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp4_ = _data_->_data34_->net;
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (_data_->_tmp4_ == NULL) {
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			block34_data_unref (_data_->_data34_);
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_data34_ = NULL;
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			block33_data_unref (_data_->_data33_);
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_data33_ = NULL;
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			if (_data_->_state_ == 0) {
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3024 "libvirt-machine.c"
			} else {
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 3028 "libvirt-machine.c"
			}
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_object_unref (_data_->_async_result);
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			return FALSE;
#line 3034 "libvirt-machine.c"
		}
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_state_ = 1;
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_run_in_thread (____lambda83__boxes_run_in_thread_func, block34_data_ref (_data_->_data34_), block34_data_unref, boxes_libvirt_machine_update_net_stat_ready, _data_);
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 3042 "libvirt-machine.c"
		_state_1:
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_run_in_thread_finish (_data_->_res_, &_data_->_inner_error_);
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			block34_data_unref (_data_->_data34_);
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_data34_ = NULL;
#line 3052 "libvirt-machine.c"
			goto __catch20_g_error;
		}
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp5_ = NULL;
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp5__length1 = 0;
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp5_ = _data_->self->priv->stats;
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp5__length1 = _data_->self->priv->stats_length1;
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		memset (&_data_->_tmp6_, 0, sizeof (BoxesLibvirtMachineMachineStat));
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp6_ = _data_->_tmp5_[BOXES_LIBVIRT_MACHINE_STATS_SIZE - 1];
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		memset (&_data_->_tmp7_, 0, sizeof (BoxesLibvirtMachineMachineStat));
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_machine_stat_copy (&_data_->_tmp6_, &_data_->_tmp7_);
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->prev = _data_->_tmp7_;
#line 271 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		memset (&_data_->_tmp8_, 0, sizeof (BoxesLibvirtMachineMachineStat));
#line 271 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp8_ = _data_->prev;
#line 271 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp9_ = NULL;
#line 271 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp9_ = _data_->_tmp8_.net;
#line 271 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (_data_->_tmp9_ != NULL) {
#line 272 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp10_ = NULL;
#line 272 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp10_ = _data_->_data33_->stat;
#line 272 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp11_ = NULL;
#line 272 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp11_ = (*_data_->_tmp10_).net;
#line 272 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp12_ = 0LL;
#line 272 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp12_ = _data_->_tmp11_->rx_bytes;
#line 272 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			memset (&_data_->_tmp13_, 0, sizeof (BoxesLibvirtMachineMachineStat));
#line 272 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp13_ = _data_->prev;
#line 272 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp14_ = NULL;
#line 272 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp14_ = _data_->_tmp13_.net;
#line 272 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp15_ = 0LL;
#line 272 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp15_ = _data_->_tmp14_->rx_bytes;
#line 272 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			(*_data_->_data33_->stat).net_read = (gdouble) (_data_->_tmp12_ - _data_->_tmp15_);
#line 273 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp16_ = NULL;
#line 273 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp16_ = _data_->_data33_->stat;
#line 273 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp17_ = NULL;
#line 273 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp17_ = (*_data_->_tmp16_).net;
#line 273 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp18_ = 0LL;
#line 273 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp18_ = _data_->_tmp17_->tx_bytes;
#line 273 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			memset (&_data_->_tmp19_, 0, sizeof (BoxesLibvirtMachineMachineStat));
#line 273 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp19_ = _data_->prev;
#line 273 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp20_ = NULL;
#line 273 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp20_ = _data_->_tmp19_.net;
#line 273 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp21_ = 0LL;
#line 273 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp21_ = _data_->_tmp20_->tx_bytes;
#line 273 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			(*_data_->_data33_->stat).net_write = (gdouble) (_data_->_tmp18_ - _data_->_tmp21_);
#line 3135 "libvirt-machine.c"
		}
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_machine_stat_destroy (&_data_->prev);
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		block34_data_unref (_data_->_data34_);
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_data34_ = NULL;
#line 3143 "libvirt-machine.c"
	}
	goto __finally20;
	__catch20_g_error:
	{
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->err = _data_->_inner_error_;
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_inner_error_ = NULL;
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp22_ = NULL;
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp22_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _data_->self);
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp23_ = NULL;
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp23_ = _data_->_tmp22_;
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp24_ = NULL;
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp24_ = _data_->err;
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp25_ = NULL;
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp25_ = _data_->_tmp24_->message;
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_warning ("libvirt-machine.vala:276: Failed to fetch network statistics for %s: %" \
"s", _data_->_tmp23_, _data_->_tmp25_);
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_error_free0 (_data_->err);
#line 3172 "libvirt-machine.c"
	}
	__finally20:
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		block33_data_unref (_data_->_data33_);
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_data33_ = NULL;
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_clear_error (&_data_->_inner_error_);
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 3187 "libvirt-machine.c"
	}
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	block33_data_unref (_data_->_data33_);
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_data33_ = NULL;
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_data_->_state_ == 0) {
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3197 "libvirt-machine.c"
	} else {
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3201 "libvirt-machine.c"
	}
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_object_unref (_data_->_async_result);
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return FALSE;
#line 3207 "libvirt-machine.c"
}


static void boxes_libvirt_machine_update_stats_data_free (gpointer _data) {
	BoxesLibvirtMachineUpdateStatsData* _data_;
	_data_ = _data;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_slice_free (BoxesLibvirtMachineUpdateStatsData, _data_);
#line 3218 "libvirt-machine.c"
}


static void boxes_libvirt_machine_update_stats (BoxesLibvirtMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesLibvirtMachineUpdateStatsData* _data_;
	BoxesLibvirtMachine* _tmp0_ = NULL;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_slice_new0 (BoxesLibvirtMachineUpdateStatsData);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_libvirt_machine_update_stats);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_libvirt_machine_update_stats_data_free);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->self = _tmp0_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_update_stats_co (_data_);
#line 3237 "libvirt-machine.c"
}


static void boxes_libvirt_machine_update_stats_finish (BoxesLibvirtMachine* self, GAsyncResult* _res_) {
	BoxesLibvirtMachineUpdateStatsData* _data_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 3245 "libvirt-machine.c"
}


static void boxes_libvirt_machine_update_stats_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesLibvirtMachineUpdateStatsData* _data_;
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = _user_data_;
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_source_object_ = source_object;
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_res_ = _res_;
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_update_stats_co (_data_);
#line 3259 "libvirt-machine.c"
}


static BoxesLibvirtMachineMachineStat* _vala_array_dup1 (BoxesLibvirtMachineMachineStat* self, int length) {
	BoxesLibvirtMachineMachineStat* result;
	int i;
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	result = g_new0 (BoxesLibvirtMachineMachineStat, length);
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	for (i = 0; i < length; i++) {
#line 3270 "libvirt-machine.c"
		BoxesLibvirtMachineMachineStat _tmp0_ = {0};
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_machine_stat_copy (&self[i], &_tmp0_);
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		result[i] = _tmp0_;
#line 3276 "libvirt-machine.c"
	}
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 3280 "libvirt-machine.c"
}


static void _vala_array_add4 (BoxesLibvirtMachineMachineStat** array, int* length, int* size, const BoxesLibvirtMachineMachineStat* value) {
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if ((*length) == (*size)) {
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		*array = g_renew (BoxesLibvirtMachineMachineStat, *array, *size);
#line 3291 "libvirt-machine.c"
	}
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	(*array)[(*length)++] = *value;
#line 3295 "libvirt-machine.c"
}


static void _vala_array_add5 (gdouble** array, int* length, int* size, gdouble value) {
#line 310 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if ((*length) == (*size)) {
#line 310 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 310 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		*array = g_renew (gdouble, *array, *size);
#line 3306 "libvirt-machine.c"
	}
#line 310 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	(*array)[(*length)++] = value;
#line 3310 "libvirt-machine.c"
}


static void _vala_array_add6 (gdouble** array, int* length, int* size, gdouble value) {
#line 311 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if ((*length) == (*size)) {
#line 311 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 311 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		*array = g_renew (gdouble, *array, *size);
#line 3321 "libvirt-machine.c"
	}
#line 311 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	(*array)[(*length)++] = value;
#line 3325 "libvirt-machine.c"
}


static void _vala_array_add7 (gdouble** array, int* length, int* size, gdouble value) {
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if ((*length) == (*size)) {
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		*array = g_renew (gdouble, *array, *size);
#line 3336 "libvirt-machine.c"
	}
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	(*array)[(*length)++] = value;
#line 3340 "libvirt-machine.c"
}


static gboolean boxes_libvirt_machine_update_stats_co (BoxesLibvirtMachineUpdateStatsData* _data_) {
#line 285 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	switch (_data_->_state_) {
#line 285 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case 0:
#line 3349 "libvirt-machine.c"
		goto _state_0;
#line 285 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case 1:
#line 3353 "libvirt-machine.c"
		goto _state_1;
#line 285 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case 2:
#line 3357 "libvirt-machine.c"
		goto _state_2;
#line 285 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case 3:
#line 3361 "libvirt-machine.c"
		goto _state_3;
		default:
#line 285 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_assert_not_reached ();
#line 3366 "libvirt-machine.c"
	}
	_state_0:
	{
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp0_ = 0LL;
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp0_ = g_get_monotonic_time ();
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->now = _data_->_tmp0_;
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp1_ = 0LL;
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp1_ = _data_->now;
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		memset (&_data_->_tmp2_, 0, sizeof (BoxesLibvirtMachineMachineStat));
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		memset (&_data_->_tmp2_, 0, sizeof (BoxesLibvirtMachineMachineStat));
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp2_.timestamp = _data_->_tmp1_;
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->stat = _data_->_tmp2_;
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp3_ = NULL;
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp3_ = _data_->self->priv->_domain;
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp4_ = NULL;
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp4_ = _data_->self->priv->stats_cancellable;
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_state_ = 1;
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		gvir_domain_get_info_async (_data_->_tmp3_, _data_->_tmp4_, boxes_libvirt_machine_update_stats_ready, _data_);
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 3402 "libvirt-machine.c"
		_state_1:
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp5_ = NULL;
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp5_ = gvir_domain_get_info_finish (_data_->_tmp3_, _data_->_res_, &_data_->_inner_error_);
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->info = _data_->_tmp5_;
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			boxes_libvirt_machine_machine_stat_destroy (&_data_->stat);
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			if (g_error_matches (_data_->_inner_error_, G_IO_ERROR, G_IO_ERROR_CANCELLED)) {
#line 3416 "libvirt-machine.c"
				goto __catch21_g_io_error_cancelled;
			}
			goto __catch21_g_error;
		}
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp6_ = NULL;
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp6_ = _data_->info;
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_update_cpu_stat (_data_->self, _data_->_tmp6_, &_data_->stat);
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp7_ = NULL;
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp7_ = _data_->info;
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_update_mem_stat (_data_->self, _data_->_tmp7_, &_data_->stat);
#line 293 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp8_ = NULL;
#line 293 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp8_ = _data_->info;
#line 293 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_state_ = 2;
#line 293 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_update_io_stat (_data_->self, _data_->_tmp8_, &_data_->stat, boxes_libvirt_machine_update_stats_ready, _data_);
#line 293 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 3443 "libvirt-machine.c"
		_state_2:
#line 293 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_update_io_stat_finish (_data_->self, _data_->_res_);
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp9_ = NULL;
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp9_ = _data_->info;
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_state_ = 3;
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_update_net_stat (_data_->self, _data_->_tmp9_, &_data_->stat, boxes_libvirt_machine_update_stats_ready, _data_);
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 3457 "libvirt-machine.c"
		_state_3:
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_update_net_stat_finish (_data_->self, _data_->_res_);
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp10_ = NULL;
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp10__length1 = 0;
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp10_ = _data_->self->priv->stats;
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp10__length1 = _data_->self->priv->stats_length1;
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp11_ = NULL;
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp11__length1 = 0;
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp11_ = ((_data_->_tmp10_ + 1) != NULL) ? _vala_array_dup1 (_data_->_tmp10_ + 1, BOXES_LIBVIRT_MACHINE_STATS_SIZE - 1) : ((gpointer) (_data_->_tmp10_ + 1));
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp11__length1 = BOXES_LIBVIRT_MACHINE_STATS_SIZE - 1;
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->self->priv->stats = (_vala_BoxesLibvirtMachineMachineStat_array_free (_data_->self->priv->stats, _data_->self->priv->stats_length1), NULL);
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->self->priv->stats = _data_->_tmp11_;
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->self->priv->stats_length1 = _data_->_tmp11__length1;
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->self->priv->_stats_size_ = _data_->self->priv->stats_length1;
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp12_ = NULL;
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp12__length1 = 0;
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp12_ = _data_->self->priv->stats;
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp12__length1 = _data_->self->priv->stats_length1;
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		memset (&_data_->_tmp13_, 0, sizeof (BoxesLibvirtMachineMachineStat));
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp13_ = _data_->stat;
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		memset (&_data_->_tmp14_, 0, sizeof (BoxesLibvirtMachineMachineStat));
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_machine_stat_copy (&_data_->_tmp13_, &_data_->_tmp14_);
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_vala_array_add4 (&_data_->self->priv->stats, &_data_->self->priv->stats_length1, &_data_->self->priv->_stats_size_, &_data_->_tmp14_);
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		__vala_GVirDomainInfo_free0 (_data_->info);
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_machine_stat_destroy (&_data_->stat);
#line 3507 "libvirt-machine.c"
	}
	goto __finally21;
	__catch21_g_io_error_cancelled:
	{
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->err = _data_->_inner_error_;
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_inner_error_ = NULL;
#line 300 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_error_free0 (_data_->err);
#line 300 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (_data_->_state_ == 0) {
#line 300 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3522 "libvirt-machine.c"
		} else {
#line 300 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 3526 "libvirt-machine.c"
		}
#line 300 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_object_unref (_data_->_async_result);
#line 300 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 3532 "libvirt-machine.c"
	}
	goto __finally21;
	__catch21_g_error:
	{
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_vala1_err = _data_->_inner_error_;
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_inner_error_ = NULL;
#line 302 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp15_ = NULL;
#line 302 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp15_ = _data_->_vala1_err;
#line 302 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp16_ = NULL;
#line 302 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp16_ = _data_->_tmp15_->message;
#line 302 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_warning ("libvirt-machine.vala:302: %s", _data_->_tmp16_);
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_error_free0 (_data_->_vala1_err);
#line 3553 "libvirt-machine.c"
	}
	__finally21:
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_clear_error (&_data_->_inner_error_);
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 3564 "libvirt-machine.c"
	}
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp17_ = NULL;
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp17_ = g_new0 (gdouble, 0);
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->self->cpu_stats = (g_free (_data_->self->cpu_stats), NULL);
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->self->cpu_stats = _data_->_tmp17_;
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->self->cpu_stats_length1 = 0;
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->self->_cpu_stats_size_ = _data_->self->cpu_stats_length1;
#line 306 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp18_ = NULL;
#line 306 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp18_ = g_new0 (gdouble, 0);
#line 306 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->self->io_stats = (g_free (_data_->self->io_stats), NULL);
#line 306 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->self->io_stats = _data_->_tmp18_;
#line 306 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->self->io_stats_length1 = 0;
#line 306 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->self->_io_stats_size_ = _data_->self->io_stats_length1;
#line 307 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp19_ = NULL;
#line 307 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp19_ = g_new0 (gdouble, 0);
#line 307 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->self->net_stats = (g_free (_data_->self->net_stats), NULL);
#line 307 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->self->net_stats = _data_->_tmp19_;
#line 307 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->self->net_stats_length1 = 0;
#line 307 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->self->_net_stats_size_ = _data_->self->net_stats_length1;
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp20_ = NULL;
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp20__length1 = 0;
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp20_ = _data_->self->priv->stats;
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp20__length1 = _data_->self->priv->stats_length1;
#line 3610 "libvirt-machine.c"
	{
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->stat_collection_length1 = 0;
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_stat_collection_size_ = 0;
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->stat_collection = _data_->_tmp20_;
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->stat_collection_length1 = _data_->_tmp20__length1;
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		for (_data_->stat_it = 0; _data_->stat_it < _data_->_tmp20__length1; _data_->stat_it = _data_->stat_it + 1) {
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			memset (&_data_->_tmp21_, 0, sizeof (BoxesLibvirtMachineMachineStat));
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			boxes_libvirt_machine_machine_stat_copy (&_data_->stat_collection[_data_->stat_it], &_data_->_tmp21_);
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_vala1_stat = _data_->_tmp21_;
#line 3628 "libvirt-machine.c"
			{
#line 310 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp22_ = NULL;
#line 310 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp22__length1 = 0;
#line 310 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp22_ = _data_->self->cpu_stats;
#line 310 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp22__length1 = _data_->self->cpu_stats_length1;
#line 310 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				memset (&_data_->_tmp23_, 0, sizeof (BoxesLibvirtMachineMachineStat));
#line 310 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp23_ = _data_->_vala1_stat;
#line 310 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp24_ = 0.0;
#line 310 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp24_ = _data_->_tmp23_.cpu_guest_percent;
#line 310 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_vala_array_add5 (&_data_->self->cpu_stats, &_data_->self->cpu_stats_length1, &_data_->self->_cpu_stats_size_, _data_->_tmp24_);
#line 311 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp25_ = NULL;
#line 311 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp25__length1 = 0;
#line 311 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp25_ = _data_->self->net_stats;
#line 311 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp25__length1 = _data_->self->net_stats_length1;
#line 311 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				memset (&_data_->_tmp26_, 0, sizeof (BoxesLibvirtMachineMachineStat));
#line 311 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp26_ = _data_->_vala1_stat;
#line 311 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp27_ = 0.0;
#line 311 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp27_ = _data_->_tmp26_.net_read;
#line 311 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				memset (&_data_->_tmp28_, 0, sizeof (BoxesLibvirtMachineMachineStat));
#line 311 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp28_ = _data_->_vala1_stat;
#line 311 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp29_ = 0.0;
#line 311 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp29_ = _data_->_tmp28_.net_write;
#line 311 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_vala_array_add6 (&_data_->self->net_stats, &_data_->self->net_stats_length1, &_data_->self->_net_stats_size_, _data_->_tmp27_ + _data_->_tmp29_);
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp30_ = NULL;
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp30__length1 = 0;
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp30_ = _data_->self->io_stats;
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp30__length1 = _data_->self->io_stats_length1;
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				memset (&_data_->_tmp31_, 0, sizeof (BoxesLibvirtMachineMachineStat));
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp31_ = _data_->_vala1_stat;
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp32_ = 0.0;
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp32_ = _data_->_tmp31_.disk_read;
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				memset (&_data_->_tmp33_, 0, sizeof (BoxesLibvirtMachineMachineStat));
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp33_ = _data_->_vala1_stat;
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp34_ = 0.0;
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp34_ = _data_->_tmp33_.disk_write;
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_vala_array_add7 (&_data_->self->io_stats, &_data_->self->io_stats_length1, &_data_->self->_io_stats_size_, _data_->_tmp32_ + _data_->_tmp34_);
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				boxes_libvirt_machine_machine_stat_destroy (&_data_->_vala1_stat);
#line 3702 "libvirt-machine.c"
			}
		}
	}
#line 315 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_signal_emit_by_name (_data_->self, "stats-updated");
#line 285 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_data_->_state_ == 0) {
#line 285 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3712 "libvirt-machine.c"
	} else {
#line 285 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3716 "libvirt-machine.c"
	}
#line 285 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_object_unref (_data_->_async_result);
#line 285 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return FALSE;
#line 3722 "libvirt-machine.c"
}


static Block35Data* block35_data_ref (Block35Data* _data35_) {
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_atomic_int_inc (&_data35_->_ref_count_);
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return _data35_;
#line 3731 "libvirt-machine.c"
}


static void block35_data_unref (void * _userdata_) {
	Block35Data* _data35_;
	_data35_ = (Block35Data*) _userdata_;
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (g_atomic_int_dec_and_test (&_data35_->_ref_count_)) {
#line 3740 "libvirt-machine.c"
		BoxesLibvirtMachine* self;
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		self = _data35_->self;
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_object_unref0 (self);
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_slice_free (Block35Data, _data35_);
#line 3748 "libvirt-machine.c"
	}
}


static void __lambda84_ (Block35Data* _data35_) {
	BoxesLibvirtMachine* self;
#line 334 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self = _data35_->self;
#line 334 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data35_->stats_updating = FALSE;
#line 3759 "libvirt-machine.c"
}


static void ___lambda84__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 334 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	__lambda84_ (self);
#line 334 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	block35_data_unref (self);
#line 3768 "libvirt-machine.c"
}


static gboolean ___lambda81_ (Block35Data* _data35_) {
	BoxesLibvirtMachine* self;
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
#line 326 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self = _data35_->self;
#line 327 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = _data35_->stats_updating;
#line 327 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_tmp0_) {
#line 3782 "libvirt-machine.c"
		const gchar* _tmp1_ = NULL;
		const gchar* _tmp2_ = NULL;
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp1_ = boxes_collection_item_get_name ((BoxesCollectionItem*) self);
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp2_ = _tmp1_;
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_warning ("libvirt-machine.vala:328: Fetching of stats for '%s' is taking too lon" \
"g. Probably a libvirt bug.", _tmp2_);
#line 330 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		result = TRUE;
#line 330 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return result;
#line 3795 "libvirt-machine.c"
	}
#line 333 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data35_->stats_updating = TRUE;
#line 334 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_update_stats (self, ___lambda84__gasync_ready_callback, block35_data_ref (_data35_));
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	result = TRUE;
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 3805 "libvirt-machine.c"
}


static gboolean ____lambda81__gsource_func (gpointer self) {
	gboolean result;
	result = ___lambda81_ (self);
#line 326 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 3814 "libvirt-machine.c"
}


static void boxes_libvirt_machine_set_stats_enable (BoxesLibvirtMachine* self, gboolean enable) {
	gboolean _tmp0_ = FALSE;
#line 318 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_if_fail (self != NULL);
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = enable;
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_tmp0_) {
#line 3826 "libvirt-machine.c"
		Block35Data* _data35_;
		const gchar* _tmp1_ = NULL;
		const gchar* _tmp2_ = NULL;
		gchar* _tmp3_ = NULL;
		gchar* _tmp4_ = NULL;
		guint _tmp5_ = 0U;
		GCancellable* _tmp6_ = NULL;
		guint _tmp7_ = 0U;
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data35_ = g_slice_new0 (Block35Data);
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data35_->_ref_count_ = 1;
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data35_->self = g_object_ref (self);
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp1_ = boxes_collection_item_get_name ((BoxesCollectionItem*) self);
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp2_ = _tmp1_;
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp3_ = g_strconcat ("enable statistics for ", _tmp2_, NULL);
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp4_ = _tmp3_;
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_debug ("libvirt-machine.vala:320: %s", _tmp4_);
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_free0 (_tmp4_);
#line 321 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp5_ = self->priv->stats_update_timeout;
#line 321 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (_tmp5_ != ((guint) 0)) {
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			block35_data_unref (_data35_);
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data35_ = NULL;
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			return;
#line 3863 "libvirt-machine.c"
		}
#line 324 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp6_ = self->priv->stats_cancellable;
#line 324 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_cancellable_reset (_tmp6_);
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data35_->stats_updating = FALSE;
#line 326 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp7_ = g_timeout_add_seconds_full (G_PRIORITY_DEFAULT, (guint) 1, ____lambda81__gsource_func, block35_data_ref (_data35_), block35_data_unref);
#line 326 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		self->priv->stats_update_timeout = _tmp7_;
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		block35_data_unref (_data35_);
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data35_ = NULL;
#line 3879 "libvirt-machine.c"
	} else {
		const gchar* _tmp8_ = NULL;
		const gchar* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
		gchar* _tmp11_ = NULL;
		guint _tmp12_ = 0U;
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp8_ = boxes_collection_item_get_name ((BoxesCollectionItem*) self);
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp9_ = _tmp8_;
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp10_ = g_strconcat ("disable statistics for ", _tmp9_, NULL);
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp11_ = _tmp10_;
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_debug ("libvirt-machine.vala:339: %s", _tmp11_);
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_free0 (_tmp11_);
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp12_ = self->priv->stats_update_timeout;
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (_tmp12_ != ((guint) 0)) {
#line 3902 "libvirt-machine.c"
			GCancellable* _tmp13_ = NULL;
			guint _tmp14_ = 0U;
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_tmp13_ = self->priv->stats_cancellable;
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_cancellable_cancel (_tmp13_);
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_tmp14_ = self->priv->stats_update_timeout;
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_source_remove (_tmp14_);
#line 3913 "libvirt-machine.c"
		}
#line 344 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		self->priv->stats_update_timeout = (guint) 0;
#line 3917 "libvirt-machine.c"
	}
}


static void _g_object_unref0_ (gpointer var) {
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 3925 "libvirt-machine.c"
}


static void _g_list_free__g_object_unref0_ (GList* self) {
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_list_foreach (self, (GFunc) _g_object_unref0_, NULL);
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_list_free (self);
#line 3934 "libvirt-machine.c"
}


static GList* boxes_libvirt_machine_real_get_properties (BoxesMachine* base, BoxesPropertiesPage page, PropertyCreationFlag* flags) {
	BoxesLibvirtMachine * self;
	GList* result = NULL;
	GList* list = NULL;
	BoxesLibvirtMachineProperties* _tmp0_ = NULL;
	BoxesPropertiesPage _tmp1_ = 0;
	GList* _tmp2_ = NULL;
	BoxesDisplay* _tmp3_ = NULL;
	BoxesDisplay* _tmp4_ = NULL;
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self = (BoxesLibvirtMachine*) base;
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = self->properties;
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = page;
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp2_ = boxes_iproperties_provider_get_properties ((BoxesIPropertiesProvider*) _tmp0_, _tmp1_, flags);
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	list = _tmp2_;
#line 351 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp3_ = boxes_machine_get_display ((BoxesMachine*) self);
#line 351 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp4_ = _tmp3_;
#line 351 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_tmp4_ != NULL) {
#line 3963 "libvirt-machine.c"
		BoxesDisplay* _tmp5_ = NULL;
		BoxesDisplay* _tmp6_ = NULL;
		BoxesPropertiesPage _tmp7_ = 0;
		GList* _tmp8_ = NULL;
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp5_ = boxes_machine_get_display ((BoxesMachine*) self);
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp6_ = _tmp5_;
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp7_ = page;
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp8_ = boxes_display_get_properties (_tmp6_, _tmp7_, flags);
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		list = g_list_concat (list, _tmp8_);
#line 3978 "libvirt-machine.c"
	}
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	result = list;
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 3984 "libvirt-machine.c"
}


gboolean boxes_libvirt_machine_update_display (BoxesLibvirtMachine* self, GError** error) {
	gboolean result = FALSE;
	gboolean created_display = FALSE;
	BoxesDisplay* _tmp0_ = NULL;
	BoxesDisplay* _tmp1_ = NULL;
	BoxesDisplay* _tmp2_ = NULL;
	BoxesDisplay* _tmp3_ = NULL;
	GError * _inner_error_ = NULL;
#line 358 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_update_domain_config (self);
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = boxes_machine_get_display ((BoxesMachine*) self);
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = _tmp0_;
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	created_display = _tmp1_ == NULL;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp2_ = boxes_machine_get_display ((BoxesMachine*) self);
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp3_ = _tmp2_;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_tmp3_ == NULL) {
#line 4012 "libvirt-machine.c"
		BoxesDisplay* _tmp4_ = NULL;
		BoxesDisplay* _tmp5_ = NULL;
#line 363 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp5_ = boxes_libvirt_machine_create_display (self, &_inner_error_);
#line 363 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp4_ = _tmp5_;
#line 363 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 363 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_propagate_error (error, _inner_error_);
#line 363 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			return FALSE;
#line 4025 "libvirt-machine.c"
		}
#line 363 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_machine_set_display ((BoxesMachine*) self, _tmp4_);
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_object_unref0 (_tmp4_);
#line 4031 "libvirt-machine.c"
	}
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	result = created_display;
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 4037 "libvirt-machine.c"
}


static const gchar* string_to_string (const gchar* self) {
	const gchar* result = NULL;
#line 1314 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1315 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
	result = self;
#line 1315 "/home/zeenix/jhbuild/share/vala-0.30/vapi/glib-2.0.vapi"
	return result;
#line 4049 "libvirt-machine.c"
}


static BoxesDisplay* boxes_libvirt_machine_create_display (BoxesLibvirtMachine* self, GError** error) {
	BoxesDisplay* result = NULL;
	gchar* type = NULL;
	gchar* port = NULL;
	gchar* socket = NULL;
	gchar* host = NULL;
	gchar* xmldoc = NULL;
	GVirConfigDomain* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	const gchar* _tmp7_ = NULL;
	const gchar* _tmp8_ = NULL;
	const gchar* _tmp9_ = NULL;
	gchar* _tmp10_ = NULL;
	gchar* _tmp11_ = NULL;
	gchar* _tmp12_ = NULL;
	gchar* _tmp13_ = NULL;
	gchar* _tmp14_ = NULL;
	gchar* _tmp15_ = NULL;
	const gchar* _tmp16_ = NULL;
	const gchar* _tmp17_ = NULL;
	const gchar* _tmp18_ = NULL;
	gchar* _tmp19_ = NULL;
	gchar* _tmp20_ = NULL;
	gchar* _tmp21_ = NULL;
	gchar* _tmp22_ = NULL;
	gchar* _tmp23_ = NULL;
	gchar* _tmp24_ = NULL;
	const gchar* _tmp25_ = NULL;
	const gchar* _tmp26_ = NULL;
	const gchar* _tmp27_ = NULL;
	gchar* _tmp28_ = NULL;
	gchar* _tmp29_ = NULL;
	gchar* _tmp30_ = NULL;
	gchar* _tmp31_ = NULL;
	gchar* _tmp32_ = NULL;
	gboolean _tmp33_ = FALSE;
	const gchar* _tmp34_ = NULL;
	const gchar* _tmp37_ = NULL;
	const gchar* _tmp38_ = NULL;
	GQuark _tmp40_ = 0U;
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	static GQuark _tmp39_label0 = 0;
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	static GQuark _tmp39_label1 = 0;
#line 4102 "libvirt-machine.c"
	GError * _inner_error_ = NULL;
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 370 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = self->priv->_domain_config;
#line 370 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = gvir_config_object_to_xml ((GVirConfigObject*) _tmp0_);
#line 370 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	xmldoc = _tmp1_;
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp3_ = xmldoc;
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp4_ = boxes_extract_xpath (_tmp3_, "string(/domain/devices/graphics/@type)", TRUE, &_inner_error_);
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp2_ = _tmp4_;
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (_inner_error_->domain == BOXES_ERROR) {
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_propagate_error (error, _inner_error_);
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (xmldoc);
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (host);
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (socket);
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (port);
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (type);
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			return NULL;
#line 4136 "libvirt-machine.c"
		} else {
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (xmldoc);
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (host);
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (socket);
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (port);
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (type);
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_clear_error (&_inner_error_);
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			return NULL;
#line 4154 "libvirt-machine.c"
		}
	}
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp5_ = _tmp2_;
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp2_ = NULL;
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (type);
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	type = _tmp5_;
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp7_ = xmldoc;
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp8_ = type;
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp9_ = string_to_string (_tmp8_);
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp10_ = g_strconcat ("string(/domain/devices/graphics[@type='", _tmp9_, "']/@port)", NULL);
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp11_ = _tmp10_;
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp12_ = boxes_extract_xpath (_tmp7_, _tmp11_, FALSE, &_inner_error_);
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp13_ = _tmp12_;
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (_tmp11_);
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp6_ = _tmp13_;
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (_inner_error_->domain == BOXES_ERROR) {
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_propagate_error (error, _inner_error_);
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (_tmp2_);
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (xmldoc);
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (host);
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (socket);
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (port);
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (type);
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			return NULL;
#line 4203 "libvirt-machine.c"
		} else {
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (_tmp2_);
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (xmldoc);
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (host);
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (socket);
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (port);
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (type);
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_clear_error (&_inner_error_);
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			return NULL;
#line 4223 "libvirt-machine.c"
		}
	}
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp14_ = _tmp6_;
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp6_ = NULL;
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (port);
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	port = _tmp14_;
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp16_ = xmldoc;
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp17_ = type;
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp18_ = string_to_string (_tmp17_);
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp19_ = g_strconcat ("string(/domain/devices/graphics[@type='", _tmp18_, "']/@socket)", NULL);
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp20_ = _tmp19_;
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp21_ = boxes_extract_xpath (_tmp16_, _tmp20_, FALSE, &_inner_error_);
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp22_ = _tmp21_;
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (_tmp20_);
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp15_ = _tmp22_;
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (_inner_error_->domain == BOXES_ERROR) {
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_propagate_error (error, _inner_error_);
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (_tmp6_);
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (_tmp2_);
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (xmldoc);
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (host);
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (socket);
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (port);
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (type);
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			return NULL;
#line 4274 "libvirt-machine.c"
		} else {
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (_tmp6_);
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (_tmp2_);
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (xmldoc);
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (host);
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (socket);
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (port);
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (type);
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_clear_error (&_inner_error_);
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			return NULL;
#line 4296 "libvirt-machine.c"
		}
	}
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp23_ = _tmp15_;
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp15_ = NULL;
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (socket);
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	socket = _tmp23_;
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp25_ = xmldoc;
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp26_ = type;
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp27_ = string_to_string (_tmp26_);
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp28_ = g_strconcat ("string(/domain/devices/graphics[@type='", _tmp27_, "']/@listen)", NULL);
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp29_ = _tmp28_;
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp30_ = boxes_extract_xpath (_tmp25_, _tmp29_, FALSE, &_inner_error_);
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp31_ = _tmp30_;
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (_tmp29_);
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp24_ = _tmp31_;
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (_inner_error_->domain == BOXES_ERROR) {
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_propagate_error (error, _inner_error_);
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (_tmp15_);
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (_tmp6_);
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (_tmp2_);
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (xmldoc);
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (host);
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (socket);
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (port);
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (type);
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			return NULL;
#line 4349 "libvirt-machine.c"
		} else {
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (_tmp15_);
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (_tmp6_);
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (_tmp2_);
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (xmldoc);
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (host);
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (socket);
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (port);
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (type);
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_clear_error (&_inner_error_);
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			return NULL;
#line 4373 "libvirt-machine.c"
		}
	}
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp32_ = _tmp24_;
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp24_ = NULL;
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (host);
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	host = _tmp32_;
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp34_ = host;
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_tmp34_ == NULL) {
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp33_ = TRUE;
#line 4390 "libvirt-machine.c"
	} else {
		const gchar* _tmp35_ = NULL;
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp35_ = host;
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp33_ = g_strcmp0 (_tmp35_, "") == 0;
#line 4397 "libvirt-machine.c"
	}
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_tmp33_) {
#line 4401 "libvirt-machine.c"
		gchar* _tmp36_ = NULL;
#line 377 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp36_ = g_strdup ("localhost");
#line 377 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_free0 (host);
#line 377 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		host = _tmp36_;
#line 4409 "libvirt-machine.c"
	}
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp37_ = type;
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp38_ = _tmp37_;
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp40_ = (NULL == _tmp38_) ? 0 : g_quark_from_string (_tmp38_);
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_tmp40_ == ((0 != _tmp39_label0) ? _tmp39_label0 : (_tmp39_label0 = g_quark_from_static_string ("spice")))) {
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		switch (0) {
#line 4421 "libvirt-machine.c"
			default:
			{
				BoxesBoxConfig* _tmp41_ = NULL;
				const gchar* _tmp42_ = NULL;
				const gchar* _tmp43_ = NULL;
				gint _tmp44_ = 0;
				BoxesSpiceDisplay* _tmp45_ = NULL;
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_tmp41_ = ((BoxesMachine*) self)->config;
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_tmp42_ = host;
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_tmp43_ = port;
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_tmp44_ = atoi (_tmp43_);
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_tmp45_ = boxes_spice_display_new ((BoxesMachine*) self, _tmp41_, _tmp42_, _tmp44_, 0, NULL);
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				result = (BoxesDisplay*) _tmp45_;
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_g_free0 (_tmp24_);
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_g_free0 (_tmp15_);
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_g_free0 (_tmp6_);
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_g_free0 (_tmp2_);
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_g_free0 (xmldoc);
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_g_free0 (host);
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_g_free0 (socket);
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_g_free0 (port);
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_g_free0 (type);
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				return result;
#line 4461 "libvirt-machine.c"
			}
		}
	} else if (_tmp40_ == ((0 != _tmp39_label1) ? _tmp39_label1 : (_tmp39_label1 = g_quark_from_static_string ("vnc")))) {
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		switch (0) {
#line 4467 "libvirt-machine.c"
			default:
			{
				BoxesBoxConfig* _tmp46_ = NULL;
				const gchar* _tmp47_ = NULL;
				const gchar* _tmp48_ = NULL;
				gint _tmp49_ = 0;
				BoxesVncDisplay* _tmp50_ = NULL;
#line 384 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_tmp46_ = ((BoxesMachine*) self)->config;
#line 384 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_tmp47_ = host;
#line 384 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_tmp48_ = port;
#line 384 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_tmp49_ = atoi (_tmp48_);
#line 384 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_tmp50_ = boxes_vnc_display_new (_tmp46_, _tmp47_, _tmp49_);
#line 384 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				result = (BoxesDisplay*) _tmp50_;
#line 384 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_g_free0 (_tmp24_);
#line 384 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_g_free0 (_tmp15_);
#line 384 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_g_free0 (_tmp6_);
#line 384 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_g_free0 (_tmp2_);
#line 384 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_g_free0 (xmldoc);
#line 384 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_g_free0 (host);
#line 384 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_g_free0 (socket);
#line 384 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_g_free0 (port);
#line 384 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_g_free0 (type);
#line 384 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				return result;
#line 4507 "libvirt-machine.c"
			}
		}
	} else {
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		switch (0) {
#line 4513 "libvirt-machine.c"
			default:
			{
				const gchar* _tmp51_ = NULL;
				gchar* _tmp52_ = NULL;
				gchar* _tmp53_ = NULL;
				GError* _tmp54_ = NULL;
				GError* _tmp55_ = NULL;
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_tmp51_ = type;
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_tmp52_ = g_strconcat ("unsupported display of type ", _tmp51_, NULL);
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_tmp53_ = _tmp52_;
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_tmp54_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_INVALID, _tmp53_);
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_tmp55_ = _tmp54_;
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_g_free0 (_tmp53_);
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_inner_error_ = _tmp55_;
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				if (_inner_error_->domain == BOXES_ERROR) {
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					g_propagate_error (error, _inner_error_);
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_g_free0 (_tmp24_);
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_g_free0 (_tmp15_);
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_g_free0 (_tmp6_);
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_g_free0 (_tmp2_);
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_g_free0 (xmldoc);
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_g_free0 (host);
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_g_free0 (socket);
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_g_free0 (port);
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_g_free0 (type);
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					return NULL;
#line 4559 "libvirt-machine.c"
				} else {
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_g_free0 (_tmp24_);
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_g_free0 (_tmp15_);
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_g_free0 (_tmp6_);
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_g_free0 (_tmp2_);
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_g_free0 (xmldoc);
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_g_free0 (host);
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_g_free0 (socket);
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_g_free0 (port);
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_g_free0 (type);
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					g_clear_error (&_inner_error_);
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					return NULL;
#line 4585 "libvirt-machine.c"
				}
			}
		}
	}
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (_tmp24_);
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (_tmp15_);
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (_tmp6_);
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (_tmp2_);
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (xmldoc);
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (host);
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (socket);
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (port);
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (type);
#line 4608 "libvirt-machine.c"
}


static void boxes_libvirt_machine_real_take_screenshot_data_free (gpointer _data) {
	BoxesLibvirtMachineTakeScreenshotData* _data_;
	_data_ = _data;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->result);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_slice_free (BoxesLibvirtMachineTakeScreenshotData, _data_);
#line 4621 "libvirt-machine.c"
}


static void boxes_libvirt_machine_real_take_screenshot (BoxesMachine* base, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesLibvirtMachine * self;
	BoxesLibvirtMachineTakeScreenshotData* _data_;
	BoxesLibvirtMachine* _tmp0_ = NULL;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self = (BoxesLibvirtMachine*) base;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_slice_new0 (BoxesLibvirtMachineTakeScreenshotData);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_libvirt_machine_real_take_screenshot);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_libvirt_machine_real_take_screenshot_data_free);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->self = _tmp0_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_real_take_screenshot_co (_data_);
#line 4643 "libvirt-machine.c"
}


static GdkPixbuf* boxes_libvirt_machine_real_take_screenshot_finish (BoxesMachine* base, GAsyncResult* _res_, GError** error) {
	GdkPixbuf* result;
	BoxesLibvirtMachineTakeScreenshotData* _data_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return NULL;
#line 4654 "libvirt-machine.c"
	}
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	result = _data_->result;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->result = NULL;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 4664 "libvirt-machine.c"
}


static Block36Data* block36_data_ref (Block36Data* _data36_) {
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_atomic_int_inc (&_data36_->_ref_count_);
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return _data36_;
#line 4673 "libvirt-machine.c"
}


static void block36_data_unref (void * _userdata_) {
	Block36Data* _data36_;
	_data36_ = (Block36Data*) _userdata_;
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (g_atomic_int_dec_and_test (&_data36_->_ref_count_)) {
#line 4682 "libvirt-machine.c"
		BoxesLibvirtMachine* self;
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		self = _data36_->self;
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_object_unref0 (_data36_->stream);
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_object_unref0 (self);
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_slice_free (Block36Data, _data36_);
#line 4692 "libvirt-machine.c"
	}
}


static void boxes_libvirt_machine_take_screenshot_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesLibvirtMachineTakeScreenshotData* _data_;
#line 394 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = _user_data_;
#line 394 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_source_object_ = source_object;
#line 394 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_res_ = _res_;
#line 394 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_real_take_screenshot_co (_data_);
#line 4707 "libvirt-machine.c"
}


static void __lambda173_ (Block36Data* _data36_, GError** error) {
	BoxesLibvirtMachine* self;
	GVirDomain* _tmp0_ = NULL;
	GVirStream* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	GError * _inner_error_ = NULL;
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self = _data36_->self;
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = self->priv->_domain;
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = _data36_->stream;
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp2_ = gvir_domain_screenshot (_tmp0_, _tmp1_, (guint) 0, (guint) 0, &_inner_error_);
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp3_ = _tmp2_;
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (_tmp3_);
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_propagate_error (error, _inner_error_);
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return;
#line 4736 "libvirt-machine.c"
	}
}


static void ___lambda173__boxes_run_in_thread_func (gpointer self, GError** error) {
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	__lambda173_ (self, error);
#line 4744 "libvirt-machine.c"
}


static gboolean boxes_libvirt_machine_real_take_screenshot_co (BoxesLibvirtMachineTakeScreenshotData* _data_) {
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	switch (_data_->_state_) {
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case 0:
#line 4753 "libvirt-machine.c"
		goto _state_0;
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case 1:
#line 4757 "libvirt-machine.c"
		goto _state_1;
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case 2:
#line 4761 "libvirt-machine.c"
		goto _state_2;
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case 3:
#line 4765 "libvirt-machine.c"
		goto _state_3;
		default:
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_assert_not_reached ();
#line 4770 "libvirt-machine.c"
	}
	_state_0:
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_data36_ = g_slice_new0 (Block36Data);
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_data36_->_ref_count_ = 1;
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_data36_->self = g_object_ref (_data_->self);
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_data36_->_async_data_ = _data_;
#line 392 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->state = GVIR_DOMAIN_STATE_NONE;
#line 4783 "libvirt-machine.c"
	{
#line 394 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp1_ = NULL;
#line 394 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp1_ = _data_->self->priv->_domain;
#line 394 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_state_ = 1;
#line 394 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		gvir_domain_get_info_async (_data_->_tmp1_, NULL, boxes_libvirt_machine_take_screenshot_ready, _data_);
#line 394 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 4795 "libvirt-machine.c"
		_state_1:
#line 394 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp2_ = NULL;
#line 394 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp2_ = gvir_domain_get_info_finish (_data_->_tmp1_, _data_->_res_, &_data_->_inner_error_);
#line 394 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp0_ = _data_->_tmp2_;
#line 394 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 4805 "libvirt-machine.c"
			goto __catch22_g_error;
		}
#line 394 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp3_ = NULL;
#line 394 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp3_ = _data_->_tmp0_;
#line 394 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp0_ = NULL;
#line 394 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp4_ = NULL;
#line 394 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp4_ = _data_->_tmp3_;
#line 394 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp5_ = 0;
#line 394 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp5_ = _data_->_tmp4_->state;
#line 394 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->state = _data_->_tmp5_;
#line 394 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		__vala_GVirDomainInfo_free0 (_data_->_tmp4_);
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		__vala_GVirDomainInfo_free0 (_data_->_tmp0_);
#line 4828 "libvirt-machine.c"
	}
	goto __finally22;
	__catch22_g_error:
	{
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_inner_error_ = NULL;
#line 396 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp6_ = NULL;
#line 396 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp6_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _data_->self);
#line 396 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp7_ = NULL;
#line 396 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp7_ = _data_->_tmp6_;
#line 396 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_warning ("libvirt-machine.vala:396: Failed to get information on '%s'", _data_->_tmp7_);
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_error_free0 (_data_->_error_);
#line 4849 "libvirt-machine.c"
	}
	__finally22:
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_error_free (_data_->_inner_error_);
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		block36_data_unref (_data_->_data36_);
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_data36_ = NULL;
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (_data_->_state_ == 0) {
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4866 "libvirt-machine.c"
		} else {
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 4870 "libvirt-machine.c"
		}
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_object_unref (_data_->_async_result);
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 4876 "libvirt-machine.c"
	}
#line 399 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp10_ = 0;
#line 399 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp10_ = _data_->state;
#line 399 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_data_->_tmp10_ != GVIR_DOMAIN_STATE_RUNNING) {
#line 399 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp11_ = 0;
#line 399 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp11_ = _data_->state;
#line 399 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp9_ = _data_->_tmp11_ != GVIR_DOMAIN_STATE_PAUSED;
#line 4890 "libvirt-machine.c"
	} else {
#line 399 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp9_ = FALSE;
#line 4894 "libvirt-machine.c"
	}
#line 399 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_data_->_tmp9_) {
#line 399 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp12_ = 0;
#line 399 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp12_ = _data_->state;
#line 399 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp8_ = _data_->_tmp12_ != GVIR_DOMAIN_STATE_PMSUSPENDED;
#line 4904 "libvirt-machine.c"
	} else {
#line 399 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp8_ = FALSE;
#line 4908 "libvirt-machine.c"
	}
#line 399 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_data_->_tmp8_) {
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->result = NULL;
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		block36_data_unref (_data_->_data36_);
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_data36_ = NULL;
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (_data_->_state_ == 0) {
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4922 "libvirt-machine.c"
		} else {
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 4926 "libvirt-machine.c"
		}
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_object_unref (_data_->_async_result);
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 4932 "libvirt-machine.c"
	}
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp13_ = NULL;
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp13_ = _data_->self->priv->_connection;
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp14_ = NULL;
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp14_ = gvir_connection_get_stream (_data_->_tmp13_, (guint) 0);
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_data36_->stream = _data_->_tmp14_;
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_state_ = 2;
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_run_in_thread (___lambda173__boxes_run_in_thread_func, block36_data_ref (_data_->_data36_), block36_data_unref, boxes_libvirt_machine_take_screenshot_ready, _data_);
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return FALSE;
#line 4950 "libvirt-machine.c"
	_state_2:
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_run_in_thread_finish (_data_->_res_, &_data_->_inner_error_);
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_error_free (_data_->_inner_error_);
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		block36_data_unref (_data_->_data36_);
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_data36_ = NULL;
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (_data_->_state_ == 0) {
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4968 "libvirt-machine.c"
		} else {
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 4972 "libvirt-machine.c"
		}
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_object_unref (_data_->_async_result);
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 4978 "libvirt-machine.c"
	}
#line 407 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp15_ = NULL;
#line 407 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp15_ = gdk_pixbuf_loader_new ();
#line 407 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->loader = _data_->_tmp15_;
#line 408 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp16_ = NULL;
#line 408 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp16_ = _data_->_data36_->stream;
#line 408 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp17_ = NULL;
#line 408 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp17_ = g_io_stream_get_input_stream ((GIOStream*) _data_->_tmp16_);
#line 408 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp18_ = NULL;
#line 408 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp18_ = _g_object_ref0 (_data_->_tmp17_);
#line 408 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->input_stream = _data_->_tmp18_;
#line 409 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp19_ = NULL;
#line 409 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp19_ = g_new0 (guint8, 65535);
#line 409 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->buffer_length1 = 0;
#line 409 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_buffer_size_ = 0;
#line 409 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->buffer = _data_->_tmp19_;
#line 409 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->buffer_length1 = 65535;
#line 409 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_buffer_size_ = _data_->buffer_length1;
#line 410 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->length = (gssize) 0;
#line 5016 "libvirt-machine.c"
	{
#line 411 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp20_ = TRUE;
#line 411 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		while (TRUE) {
#line 411 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			if (!_data_->_tmp20_) {
#line 414 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp21_ = 0L;
#line 414 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp21_ = _data_->length;
#line 414 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				if (!(_data_->_tmp21_ > ((gssize) 0))) {
#line 414 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					break;
#line 5032 "libvirt-machine.c"
				}
			}
#line 411 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp20_ = FALSE;
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp23_ = NULL;
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp23_ = _data_->input_stream;
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp24_ = NULL;
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp24__length1 = 0;
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp24_ = _data_->buffer;
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp24__length1 = _data_->buffer_length1;
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_state_ = 3;
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_input_stream_read_async (_data_->_tmp23_, _data_->_tmp24_, (gsize) _data_->_tmp24__length1, G_PRIORITY_DEFAULT, NULL, boxes_libvirt_machine_take_screenshot_ready, _data_);
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			return FALSE;
#line 5055 "libvirt-machine.c"
			_state_3:
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp25_ = 0L;
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp25_ = g_input_stream_read_finish (_data_->_tmp23_, _data_->_res_, &_data_->_inner_error_);
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp22_ = _data_->_tmp25_;
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				g_error_free (_data_->_inner_error_);
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->buffer = (g_free (_data_->buffer), NULL);
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_g_object_unref0 (_data_->input_stream);
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_g_object_unref0 (_data_->loader);
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				block36_data_unref (_data_->_data36_);
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_data36_ = NULL;
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				if (_data_->_state_ == 0) {
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 5083 "libvirt-machine.c"
				} else {
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					g_simple_async_result_complete (_data_->_async_result);
#line 5087 "libvirt-machine.c"
				}
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				g_object_unref (_data_->_async_result);
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				return FALSE;
#line 5093 "libvirt-machine.c"
			}
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->length = _data_->_tmp22_;
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp26_ = NULL;
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp26_ = _data_->loader;
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp27_ = NULL;
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp27__length1 = 0;
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp27_ = _data_->buffer;
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp27__length1 = _data_->buffer_length1;
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp28_ = 0L;
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp28_ = _data_->length;
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			gdk_pixbuf_loader_write (_data_->_tmp26_, _data_->_tmp27_ + 0, (gsize) (((gint) _data_->_tmp28_) - 0), &_data_->_inner_error_);
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				g_error_free (_data_->_inner_error_);
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->buffer = (g_free (_data_->buffer), NULL);
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_g_object_unref0 (_data_->input_stream);
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_g_object_unref0 (_data_->loader);
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				block36_data_unref (_data_->_data36_);
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_data36_ = NULL;
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				if (_data_->_state_ == 0) {
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 5135 "libvirt-machine.c"
				} else {
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					g_simple_async_result_complete (_data_->_async_result);
#line 5139 "libvirt-machine.c"
				}
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				g_object_unref (_data_->_async_result);
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				return FALSE;
#line 5145 "libvirt-machine.c"
			}
		}
	}
#line 415 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp29_ = NULL;
#line 415 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp29_ = _data_->loader;
#line 415 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	gdk_pixbuf_loader_close (_data_->_tmp29_, &_data_->_inner_error_);
#line 415 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 415 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 415 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_error_free (_data_->_inner_error_);
#line 415 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->buffer = (g_free (_data_->buffer), NULL);
#line 415 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_object_unref0 (_data_->input_stream);
#line 415 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_object_unref0 (_data_->loader);
#line 415 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		block36_data_unref (_data_->_data36_);
#line 415 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_data36_ = NULL;
#line 415 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (_data_->_state_ == 0) {
#line 415 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 5175 "libvirt-machine.c"
		} else {
#line 415 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 5179 "libvirt-machine.c"
		}
#line 415 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_object_unref (_data_->_async_result);
#line 415 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 5185 "libvirt-machine.c"
	}
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp30_ = NULL;
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp30_ = _data_->loader;
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp31_ = NULL;
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp31_ = gdk_pixbuf_loader_get_pixbuf (_data_->_tmp30_);
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp32_ = NULL;
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp32_ = _g_object_ref0 (_data_->_tmp31_);
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->result = _data_->_tmp32_;
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->buffer = (g_free (_data_->buffer), NULL);
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->input_stream);
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->loader);
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	block36_data_unref (_data_->_data36_);
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_data36_ = NULL;
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_data_->_state_ == 0) {
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 5215 "libvirt-machine.c"
	} else {
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 5219 "libvirt-machine.c"
	}
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_object_unref (_data_->_async_result);
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return FALSE;
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->buffer = (g_free (_data_->buffer), NULL);
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->input_stream);
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->loader);
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	block36_data_unref (_data_->_data36_);
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_data36_ = NULL;
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_data_->_state_ == 0) {
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 5239 "libvirt-machine.c"
	} else {
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 5243 "libvirt-machine.c"
	}
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_object_unref (_data_->_async_result);
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return FALSE;
#line 5249 "libvirt-machine.c"
}


static Block37Data* block37_data_ref (Block37Data* _data37_) {
#line 430 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_atomic_int_inc (&_data37_->_ref_count_);
#line 430 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return _data37_;
#line 5258 "libvirt-machine.c"
}


static void block37_data_unref (void * _userdata_) {
	Block37Data* _data37_;
	_data37_ = (Block37Data*) _userdata_;
#line 430 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (g_atomic_int_dec_and_test (&_data37_->_ref_count_)) {
#line 5267 "libvirt-machine.c"
		BoxesLibvirtMachine* self;
#line 430 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		self = _data37_->self;
#line 430 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_object_unref0 (_data37_->domain);
#line 430 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_object_unref0 (self);
#line 430 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_slice_free (Block37Data, _data37_);
#line 5277 "libvirt-machine.c"
	}
}


static void ___lambda85_ (Block37Data* _data37_, GError** error) {
	BoxesLibvirtMachine* self;
	GVirStorageVol* _tmp6_ = NULL;
	GError * _inner_error_ = NULL;
#line 435 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self = _data37_->self;
#line 5288 "libvirt-machine.c"
	{
		GVirDomain* _tmp0_ = NULL;
#line 438 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp0_ = _data37_->domain;
#line 438 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		gvir_domain_delete (_tmp0_, (guint) (GVIR_DOMAIN_DELETE_SAVED_STATE | GVIR_DOMAIN_DELETE_SNAPSHOTS_METADATA), &_inner_error_);
#line 438 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5297 "libvirt-machine.c"
			goto __catch23_g_error;
		}
	}
	goto __finally23;
	__catch23_g_error:
	{
		GError* err = NULL;
		GError* _tmp1_ = NULL;
		const gchar* _tmp2_ = NULL;
#line 436 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		err = _inner_error_;
#line 436 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_inner_error_ = NULL;
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp1_ = err;
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp2_ = _tmp1_->message;
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_warning ("libvirt-machine.vala:441: %s", _tmp2_);
#line 436 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_error_free0 (err);
#line 5319 "libvirt-machine.c"
	}
	__finally23:
#line 436 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 436 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_propagate_error (error, _inner_error_);
#line 436 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return;
#line 5328 "libvirt-machine.c"
	}
	{
		GVirDomain* _tmp3_ = NULL;
#line 446 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp3_ = _data37_->domain;
#line 446 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		gvir_domain_stop (_tmp3_, (guint) 0, &_inner_error_);
#line 446 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5338 "libvirt-machine.c"
			goto __catch24_g_error;
		}
	}
	goto __finally24;
	__catch24_g_error:
	{
		GError* err = NULL;
		GError* _tmp4_ = NULL;
		const gchar* _tmp5_ = NULL;
#line 444 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		err = _inner_error_;
#line 444 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_inner_error_ = NULL;
#line 448 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp4_ = err;
#line 448 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp5_ = _tmp4_->message;
#line 448 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_debug ("libvirt-machine.vala:448: %s", _tmp5_);
#line 444 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_error_free0 (err);
#line 5360 "libvirt-machine.c"
	}
	__finally24:
#line 444 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 444 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_propagate_error (error, _inner_error_);
#line 444 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return;
#line 5369 "libvirt-machine.c"
	}
#line 452 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp6_ = self->priv->_storage_volume;
#line 452 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_tmp6_ != NULL) {
#line 5375 "libvirt-machine.c"
		{
			GVirStorageVol* _tmp7_ = NULL;
#line 454 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_tmp7_ = self->priv->_storage_volume;
#line 454 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			gvir_storage_vol_delete (_tmp7_, (guint) 0, &_inner_error_);
#line 454 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5384 "libvirt-machine.c"
				goto __catch25_g_error;
			}
		}
		goto __finally25;
		__catch25_g_error:
		{
			GError* err = NULL;
			GError* _tmp8_ = NULL;
			const gchar* _tmp9_ = NULL;
#line 453 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			err = _inner_error_;
#line 453 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_inner_error_ = NULL;
#line 456 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_tmp8_ = err;
#line 456 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_tmp9_ = _tmp8_->message;
#line 456 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_warning ("libvirt-machine.vala:456: %s", _tmp9_);
#line 453 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_error_free0 (err);
#line 5406 "libvirt-machine.c"
		}
		__finally25:
#line 453 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 453 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_propagate_error (error, _inner_error_);
#line 453 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			return;
#line 5415 "libvirt-machine.c"
		}
	}
}


static void ____lambda85__boxes_run_in_thread_func (gpointer self, GError** error) {
#line 435 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	___lambda85_ (self, error);
#line 5424 "libvirt-machine.c"
}


static void boxes_libvirt_machine_real_delete (BoxesMachine* base, gboolean by_user) {
	BoxesLibvirtMachine * self;
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gboolean _tmp4_ = FALSE;
	guint _tmp5_ = 0U;
	gboolean _tmp7_ = FALSE;
#line 420 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self = (BoxesLibvirtMachine*) base;
#line 421 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = boxes_collection_item_get_name ((BoxesCollectionItem*) self);
#line 421 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = _tmp0_;
#line 421 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp2_ = g_strconcat ("delete libvirt machine: ", _tmp1_, NULL);
#line 421 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp3_ = _tmp2_;
#line 421 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_debug ("libvirt-machine.vala:421: %s", _tmp3_);
#line 421 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (_tmp3_);
#line 422 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp4_ = by_user;
#line 422 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	BOXES_MACHINE_CLASS (boxes_libvirt_machine_parent_class)->delete (G_TYPE_CHECK_INSTANCE_CAST (self, BOXES_TYPE_MACHINE, BoxesMachine), _tmp4_);
#line 424 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_set_stats_enable (self, FALSE);
#line 425 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp5_ = self->priv->shutdown_timeout;
#line 425 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_tmp5_ != ((guint) 0)) {
#line 5461 "libvirt-machine.c"
		guint _tmp6_ = 0U;
#line 426 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp6_ = self->priv->shutdown_timeout;
#line 426 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_source_remove (_tmp6_);
#line 427 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		self->priv->shutdown_timeout = (guint) 0;
#line 5469 "libvirt-machine.c"
	}
#line 430 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp7_ = by_user;
#line 430 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_tmp7_) {
#line 5475 "libvirt-machine.c"
		Block37Data* _data37_;
		GVirDomain* _tmp8_ = NULL;
		GVirDomain* _tmp9_ = NULL;
#line 430 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data37_ = g_slice_new0 (Block37Data);
#line 430 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data37_->_ref_count_ = 1;
#line 430 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data37_->self = g_object_ref (self);
#line 431 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp8_ = self->priv->_domain;
#line 431 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp9_ = _g_object_ref0 (_tmp8_);
#line 431 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data37_->domain = _tmp9_;
#line 435 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_run_in_thread (____lambda85__boxes_run_in_thread_func, block37_data_ref (_data37_), block37_data_unref, NULL, NULL);
#line 430 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		block37_data_unref (_data37_);
#line 430 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data37_ = NULL;
#line 5497 "libvirt-machine.c"
	}
}


static void boxes_libvirt_machine_real_save_real_data_free (gpointer _data) {
	BoxesLibvirtMachineSaveRealData* _data_;
	_data_ = _data;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_slice_free (BoxesLibvirtMachineSaveRealData, _data_);
#line 5509 "libvirt-machine.c"
}


static void boxes_libvirt_machine_real_save_real (BoxesMachine* base, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesLibvirtMachine * self;
	BoxesLibvirtMachineSaveRealData* _data_;
	BoxesLibvirtMachine* _tmp0_ = NULL;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self = (BoxesLibvirtMachine*) base;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_slice_new0 (BoxesLibvirtMachineSaveRealData);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_libvirt_machine_real_save_real);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_libvirt_machine_real_save_real_data_free);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->self = _tmp0_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_real_save_real_co (_data_);
#line 5531 "libvirt-machine.c"
}


static void boxes_libvirt_machine_real_save_real_finish (BoxesMachine* base, GAsyncResult* _res_, GError** error) {
	BoxesLibvirtMachineSaveRealData* _data_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return;
#line 5541 "libvirt-machine.c"
	}
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 5545 "libvirt-machine.c"
}


static void boxes_libvirt_machine_save_real_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesLibvirtMachineSaveRealData* _data_;
#line 464 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = _user_data_;
#line 464 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_source_object_ = source_object;
#line 464 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_res_ = _res_;
#line 464 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_real_save_real_co (_data_);
#line 5559 "libvirt-machine.c"
}


static gboolean boxes_libvirt_machine_real_save_real_co (BoxesLibvirtMachineSaveRealData* _data_) {
#line 462 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	switch (_data_->_state_) {
#line 462 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case 0:
#line 5568 "libvirt-machine.c"
		goto _state_0;
#line 462 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case 1:
#line 5572 "libvirt-machine.c"
		goto _state_1;
		default:
#line 462 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_assert_not_reached ();
#line 5577 "libvirt-machine.c"
	}
	_state_0:
#line 463 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->self->priv->saving = TRUE;
#line 464 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp0_ = NULL;
#line 464 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp0_ = _data_->self->priv->_domain;
#line 464 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_state_ = 1;
#line 464 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	gvir_domain_save_async (_data_->_tmp0_, (guint) 0, NULL, boxes_libvirt_machine_save_real_ready, _data_);
#line 464 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return FALSE;
#line 5592 "libvirt-machine.c"
	_state_1:
#line 464 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	gvir_domain_save_finish (_data_->_tmp0_, _data_->_res_, &_data_->_inner_error_);
#line 464 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 464 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 464 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_error_free (_data_->_inner_error_);
#line 464 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (_data_->_state_ == 0) {
#line 464 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 5606 "libvirt-machine.c"
		} else {
#line 464 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 5610 "libvirt-machine.c"
		}
#line 464 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_object_unref (_data_->_async_result);
#line 464 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 5616 "libvirt-machine.c"
	}
#line 465 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->self->priv->saving = FALSE;
#line 462 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_data_->_state_ == 0) {
#line 462 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 5624 "libvirt-machine.c"
	} else {
#line 462 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 5628 "libvirt-machine.c"
	}
#line 462 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_object_unref (_data_->_async_result);
#line 462 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return FALSE;
#line 5634 "libvirt-machine.c"
}


static void boxes_libvirt_machine_suspend_data_free (gpointer _data) {
	BoxesLibvirtMachineSuspendData* _data_;
	_data_ = _data;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_slice_free (BoxesLibvirtMachineSuspendData, _data_);
#line 5645 "libvirt-machine.c"
}


void boxes_libvirt_machine_suspend (BoxesLibvirtMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesLibvirtMachineSuspendData* _data_;
	BoxesLibvirtMachine* _tmp0_ = NULL;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_slice_new0 (BoxesLibvirtMachineSuspendData);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_libvirt_machine_suspend);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_libvirt_machine_suspend_data_free);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->self = _tmp0_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_suspend_co (_data_);
#line 5664 "libvirt-machine.c"
}


void boxes_libvirt_machine_suspend_finish (BoxesLibvirtMachine* self, GAsyncResult* _res_, GError** error) {
	BoxesLibvirtMachineSuspendData* _data_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return;
#line 5674 "libvirt-machine.c"
	}
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 5678 "libvirt-machine.c"
}


static void boxes_libvirt_machine_suspend_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesLibvirtMachineSuspendData* _data_;
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = _user_data_;
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_source_object_ = source_object;
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_res_ = _res_;
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_suspend_co (_data_);
#line 5692 "libvirt-machine.c"
}


static gboolean boxes_libvirt_machine_suspend_co (BoxesLibvirtMachineSuspendData* _data_) {
#line 468 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	switch (_data_->_state_) {
#line 468 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case 0:
#line 5701 "libvirt-machine.c"
		goto _state_0;
#line 468 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case 1:
#line 5705 "libvirt-machine.c"
		goto _state_1;
		default:
#line 468 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_assert_not_reached ();
#line 5710 "libvirt-machine.c"
	}
	_state_0:
#line 469 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp0_ = FALSE;
#line 469 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp0_ = boxes_libvirt_machine_get_save_on_quit (_data_->self);
#line 469 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp1_ = FALSE;
#line 469 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp1_ = _data_->_tmp0_;
#line 469 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_data_->_tmp1_) {
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_state_ = 1;
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_machine_save ((BoxesMachine*) _data_->self, boxes_libvirt_machine_suspend_ready, _data_);
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 5729 "libvirt-machine.c"
		_state_1:
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_machine_save_finish ((BoxesMachine*) _data_->self, _data_->_res_, &_data_->_inner_error_);
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_error_free (_data_->_inner_error_);
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			if (_data_->_state_ == 0) {
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 5743 "libvirt-machine.c"
			} else {
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 5747 "libvirt-machine.c"
			}
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_object_unref (_data_->_async_result);
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			return FALSE;
#line 5753 "libvirt-machine.c"
		}
	} else {
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp2_ = NULL;
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp2_ = _data_->self->priv->_domain;
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		gvir_domain_suspend (_data_->_tmp2_, &_data_->_inner_error_);
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_error_free (_data_->_inner_error_);
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			if (_data_->_state_ == 0) {
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 5772 "libvirt-machine.c"
			} else {
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 5776 "libvirt-machine.c"
			}
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_object_unref (_data_->_async_result);
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			return FALSE;
#line 5782 "libvirt-machine.c"
		}
	}
#line 468 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_data_->_state_ == 0) {
#line 468 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 5789 "libvirt-machine.c"
	} else {
#line 468 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 5793 "libvirt-machine.c"
	}
#line 468 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_object_unref (_data_->_async_result);
#line 468 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return FALSE;
#line 5799 "libvirt-machine.c"
}


void boxes_libvirt_machine_force_shutdown (BoxesLibvirtMachine* self) {
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	GError * _inner_error_ = NULL;
#line 475 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_if_fail (self != NULL);
#line 476 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = boxes_collection_item_get_name ((BoxesCollectionItem*) self);
#line 476 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = _tmp0_;
#line 476 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_debug ("libvirt-machine.vala:476: Force shutdown '%s'..", _tmp1_);
#line 5815 "libvirt-machine.c"
	{
		GVirDomain* _tmp2_ = NULL;
#line 478 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		self->priv->force_stopped = TRUE;
#line 479 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp2_ = self->priv->_domain;
#line 479 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		gvir_domain_stop (_tmp2_, (guint) 0, &_inner_error_);
#line 479 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5826 "libvirt-machine.c"
			goto __catch26_g_error;
		}
	}
	goto __finally26;
	__catch26_g_error:
	{
		GError* _error_ = NULL;
		GVirDomain* _tmp3_ = NULL;
		const gchar* _tmp4_ = NULL;
		GError* _tmp5_ = NULL;
		const gchar* _tmp6_ = NULL;
#line 477 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_error_ = _inner_error_;
#line 477 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_inner_error_ = NULL;
#line 481 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp3_ = self->priv->_domain;
#line 481 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp4_ = gvir_domain_get_name (_tmp3_);
#line 481 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp5_ = _error_;
#line 481 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp6_ = _tmp5_->message;
#line 481 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_warning ("libvirt-machine.vala:481: Failed to shutdown '%s': %s", _tmp4_, _tmp6_);
#line 477 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_error_free0 (_error_);
#line 5854 "libvirt-machine.c"
	}
	__finally26:
#line 477 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 477 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 477 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_clear_error (&_inner_error_);
#line 477 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return;
#line 5865 "libvirt-machine.c"
	}
}


void boxes_libvirt_machine_try_shutdown (BoxesLibvirtMachine* self) {
	GError * _inner_error_ = NULL;
#line 485 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_if_fail (self != NULL);
#line 5874 "libvirt-machine.c"
	{
		GVirDomain* _tmp0_ = NULL;
#line 487 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp0_ = self->priv->_domain;
#line 487 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		gvir_domain_shutdown (_tmp0_, (guint) 0, &_inner_error_);
#line 487 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5883 "libvirt-machine.c"
			goto __catch27_g_error;
		}
	}
	goto __finally27;
	__catch27_g_error:
	{
		GError* _error_ = NULL;
		GVirDomain* _tmp1_ = NULL;
		const gchar* _tmp2_ = NULL;
		GError* _tmp3_ = NULL;
		const gchar* _tmp4_ = NULL;
#line 486 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_error_ = _inner_error_;
#line 486 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_inner_error_ = NULL;
#line 489 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp1_ = self->priv->_domain;
#line 489 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp2_ = gvir_domain_get_name (_tmp1_);
#line 489 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp3_ = _error_;
#line 489 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp4_ = _tmp3_->message;
#line 489 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_warning ("libvirt-machine.vala:489: Failed to reboot '%s': %s", _tmp2_, _tmp4_);
#line 486 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_error_free0 (_error_);
#line 5911 "libvirt-machine.c"
	}
	__finally27:
#line 486 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 486 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 486 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_clear_error (&_inner_error_);
#line 486 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return;
#line 5922 "libvirt-machine.c"
	}
}


GVirDomainDisk* boxes_libvirt_machine_get_domain_disk (BoxesLibvirtMachine* self, GError** error) {
	GVirDomainDisk* result = NULL;
	GVirDomainDisk* disk = NULL;
	gpointer _tmp0_ = NULL;
	GVirDomainDisk* _tmp1_ = NULL;
	GVirConfigDomain* _tmp2_ = NULL;
	GList* _tmp3_ = NULL;
	GError * _inner_error_ = NULL;
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 494 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = NULL;
#line 494 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, gvir_domain_disk_get_type ()) ? ((GVirDomainDisk*) _tmp0_) : NULL);
#line 494 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	disk = _tmp1_;
#line 496 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp2_ = self->priv->_domain_config;
#line 496 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp3_ = gvir_config_domain_get_devices (_tmp2_);
#line 5947 "libvirt-machine.c"
	{
		GList* device_config_collection = NULL;
		GList* device_config_it = NULL;
#line 496 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		device_config_collection = _tmp3_;
#line 496 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		for (device_config_it = device_config_collection; device_config_it != NULL; device_config_it = device_config_it->next) {
#line 5955 "libvirt-machine.c"
			GVirConfigDomainDevice* _tmp4_ = NULL;
			GVirConfigDomainDevice* device_config = NULL;
#line 496 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_tmp4_ = _g_object_ref0 ((GVirConfigDomainDevice*) device_config_it->data);
#line 496 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			device_config = _tmp4_;
#line 5962 "libvirt-machine.c"
			{
				GVirConfigDomainDevice* _tmp5_ = NULL;
#line 497 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_tmp5_ = device_config;
#line 497 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, gvir_config_domain_disk_get_type ())) {
#line 5969 "libvirt-machine.c"
					GVirConfigDomainDisk* disk_config = NULL;
					GVirConfigDomainDevice* _tmp6_ = NULL;
					GVirConfigDomainDisk* _tmp7_ = NULL;
					GVirConfigDomainDiskGuestDeviceType disk_type = 0;
					GVirConfigDomainDisk* _tmp8_ = NULL;
					GVirConfigDomainDiskGuestDeviceType _tmp9_ = 0;
					const gchar* _tmp10_ = NULL;
					GVirStorageVol* _tmp11_ = NULL;
					gchar* storage_volume_path = NULL;
					gchar* _tmp14_ = NULL;
					gboolean _tmp15_ = FALSE;
					GVirConfigDomainDiskGuestDeviceType _tmp16_ = 0;
#line 498 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_tmp6_ = device_config;
#line 498 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_tmp7_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp6_, gvir_config_domain_disk_get_type ()) ? ((GVirConfigDomainDisk*) _tmp6_) : NULL);
#line 498 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					disk_config = _tmp7_;
#line 499 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_tmp8_ = disk_config;
#line 499 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_tmp9_ = gvir_config_domain_disk_get_guest_device_type (_tmp8_);
#line 499 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					disk_type = _tmp9_;
#line 500 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_tmp11_ = self->priv->_storage_volume;
#line 500 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					if (_tmp11_ != NULL) {
#line 5998 "libvirt-machine.c"
						GVirStorageVol* _tmp12_ = NULL;
						const gchar* _tmp13_ = NULL;
#line 500 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
						_tmp12_ = self->priv->_storage_volume;
#line 500 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
						_tmp13_ = gvir_storage_vol_get_path (_tmp12_, &_inner_error_);
#line 500 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
						_tmp10_ = _tmp13_;
#line 500 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
						if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 500 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
							g_propagate_error (error, _inner_error_);
#line 500 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
							_g_object_unref0 (disk_config);
#line 500 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
							_g_object_unref0 (device_config);
#line 500 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
							__g_list_free__g_object_unref0_0 (device_config_collection);
#line 500 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
							_g_object_unref0 (disk);
#line 500 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
							return NULL;
#line 6021 "libvirt-machine.c"
						}
					} else {
#line 500 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
						_tmp10_ = NULL;
#line 6026 "libvirt-machine.c"
					}
#line 500 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_tmp14_ = g_strdup (_tmp10_);
#line 500 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					storage_volume_path = _tmp14_;
#line 503 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_tmp16_ = disk_type;
#line 503 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					if (_tmp16_ == GVIR_CONFIG_DOMAIN_DISK_GUEST_DEVICE_DISK) {
#line 6036 "libvirt-machine.c"
						GVirConfigDomainDisk* _tmp17_ = NULL;
						const gchar* _tmp18_ = NULL;
						const gchar* _tmp19_ = NULL;
#line 504 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
						_tmp17_ = disk_config;
#line 504 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
						_tmp18_ = gvir_config_domain_disk_get_source (_tmp17_);
#line 504 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
						_tmp19_ = storage_volume_path;
#line 504 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
						_tmp15_ = g_strcmp0 (_tmp18_, _tmp19_) == 0;
#line 6048 "libvirt-machine.c"
					} else {
#line 503 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
						_tmp15_ = FALSE;
#line 6052 "libvirt-machine.c"
					}
#line 503 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					if (_tmp15_) {
#line 6056 "libvirt-machine.c"
						GVirDomain* _tmp20_ = NULL;
						GVirConfigDomainDevice* _tmp21_ = NULL;
						GObject* _tmp22_ = NULL;
						GObject* _tmp23_ = NULL;
						GVirDomainDisk* _tmp24_ = NULL;
#line 505 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
						_tmp20_ = self->priv->_domain;
#line 505 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
						_tmp21_ = device_config;
#line 505 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
						_tmp22_ = g_object_new (gvir_domain_disk_get_type (), "domain", _tmp20_, "config", _tmp21_, NULL);
#line 505 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
						_tmp23_ = G_IS_INITIALLY_UNOWNED (_tmp22_) ? g_object_ref_sink (_tmp22_) : _tmp22_;
#line 505 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
						_tmp24_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp23_, gvir_domain_disk_get_type ()) ? ((GVirDomainDisk*) _tmp23_) : NULL;
#line 505 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
						if (_tmp24_ == NULL) {
#line 505 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
							_g_object_unref0 (_tmp23_);
#line 6076 "libvirt-machine.c"
						}
#line 505 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
						_g_object_unref0 (disk);
#line 505 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
						disk = _tmp24_;
#line 509 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
						_g_free0 (storage_volume_path);
#line 509 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
						_g_object_unref0 (disk_config);
#line 509 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
						_g_object_unref0 (device_config);
#line 509 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
						break;
#line 6090 "libvirt-machine.c"
					}
#line 503 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_g_free0 (storage_volume_path);
#line 503 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_g_object_unref0 (disk_config);
#line 6096 "libvirt-machine.c"
				}
#line 497 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_g_object_unref0 (device_config);
#line 6100 "libvirt-machine.c"
			}
		}
#line 497 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		__g_list_free__g_object_unref0_0 (device_config_collection);
#line 6105 "libvirt-machine.c"
	}
#line 514 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	result = disk;
#line 514 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 6111 "libvirt-machine.c"
}


static GVirDomainInterface* boxes_libvirt_machine_get_domain_network_interface (BoxesLibvirtMachine* self, GError** error) {
	GVirDomainInterface* result = NULL;
	GVirDomainInterface* net = NULL;
	gpointer _tmp0_ = NULL;
	GVirDomainInterface* _tmp1_ = NULL;
	GVirConfigDomain* _tmp2_ = NULL;
	GList* _tmp3_ = NULL;
#line 517 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 518 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = NULL;
#line 518 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, gvir_domain_interface_get_type ()) ? ((GVirDomainInterface*) _tmp0_) : NULL);
#line 518 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	net = _tmp1_;
#line 521 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp2_ = self->priv->_domain_config;
#line 521 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp3_ = gvir_config_domain_get_devices (_tmp2_);
#line 6134 "libvirt-machine.c"
	{
		GList* device_config_collection = NULL;
		GList* device_config_it = NULL;
#line 521 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		device_config_collection = _tmp3_;
#line 521 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		for (device_config_it = device_config_collection; device_config_it != NULL; device_config_it = device_config_it->next) {
#line 6142 "libvirt-machine.c"
			GVirConfigDomainDevice* _tmp4_ = NULL;
			GVirConfigDomainDevice* device_config = NULL;
#line 521 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_tmp4_ = _g_object_ref0 ((GVirConfigDomainDevice*) device_config_it->data);
#line 521 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			device_config = _tmp4_;
#line 6149 "libvirt-machine.c"
			{
				GVirConfigDomainDevice* _tmp5_ = NULL;
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_tmp5_ = device_config;
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, gvir_config_domain_interface_get_type ())) {
#line 6156 "libvirt-machine.c"
					GVirDomain* _tmp6_ = NULL;
					GVirConfigDomainDevice* _tmp7_ = NULL;
					GObject* _tmp8_ = NULL;
					GObject* _tmp9_ = NULL;
					GVirDomainInterface* _tmp10_ = NULL;
#line 523 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_tmp6_ = self->priv->_domain;
#line 523 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_tmp7_ = device_config;
#line 523 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_tmp8_ = g_object_new (gvir_domain_interface_get_type (), "domain", _tmp6_, "config", _tmp7_, NULL);
#line 523 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_tmp9_ = G_IS_INITIALLY_UNOWNED (_tmp8_) ? g_object_ref_sink (_tmp8_) : _tmp8_;
#line 523 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_tmp10_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp9_, gvir_domain_interface_get_type ()) ? ((GVirDomainInterface*) _tmp9_) : NULL;
#line 523 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					if (_tmp10_ == NULL) {
#line 523 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
						_g_object_unref0 (_tmp9_);
#line 6176 "libvirt-machine.c"
					}
#line 523 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_g_object_unref0 (net);
#line 523 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					net = _tmp10_;
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_g_object_unref0 (device_config);
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					break;
#line 6186 "libvirt-machine.c"
				}
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_g_object_unref0 (device_config);
#line 6190 "libvirt-machine.c"
			}
		}
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		__g_list_free__g_object_unref0_0 (device_config_collection);
#line 6195 "libvirt-machine.c"
	}
#line 530 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	result = net;
#line 530 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 6201 "libvirt-machine.c"
}


static GVirDomainStartFlags boxes_libvirt_machine_connect_flags_to_gvir (BoxesLibvirtMachine* self, BoxesMachineConnectFlags flags) {
	GVirDomainStartFlags result = 0;
	GVirDomainStartFlags gvir_flags = 0;
	BoxesMachineConnectFlags _tmp0_ = 0;
#line 533 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 534 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	gvir_flags = 0;
#line 535 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = flags;
#line 535 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if ((_tmp0_ & BOXES_MACHINE_CONNECT_FLAGS_IGNORE_SAVED_STATE) == BOXES_MACHINE_CONNECT_FLAGS_IGNORE_SAVED_STATE) {
#line 6217 "libvirt-machine.c"
		GVirDomainStartFlags _tmp1_ = 0;
#line 536 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp1_ = gvir_flags;
#line 536 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		gvir_flags = _tmp1_ | GVIR_DOMAIN_START_FORCE_BOOT;
#line 6223 "libvirt-machine.c"
	}
#line 537 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	result = gvir_flags;
#line 537 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 6229 "libvirt-machine.c"
}


static void boxes_libvirt_machine_start_data_free (gpointer _data) {
	BoxesLibvirtMachineStartData* _data_;
	_data_ = _data;
#line 517 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->cancellable);
#line 517 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->self);
#line 517 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_slice_free (BoxesLibvirtMachineStartData, _data_);
#line 6242 "libvirt-machine.c"
}


void boxes_libvirt_machine_start (BoxesLibvirtMachine* self, BoxesMachineConnectFlags flags, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesLibvirtMachineStartData* _data_;
	BoxesLibvirtMachine* _tmp0_ = NULL;
	BoxesMachineConnectFlags _tmp1_ = 0;
	GCancellable* _tmp2_ = NULL;
	GCancellable* _tmp3_ = NULL;
#line 517 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_slice_new0 (BoxesLibvirtMachineStartData);
#line 517 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_libvirt_machine_start);
#line 517 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_libvirt_machine_start_data_free);
#line 517 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 517 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->self = _tmp0_;
#line 517 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = flags;
#line 517 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->flags = _tmp1_;
#line 517 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp2_ = cancellable;
#line 517 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 517 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->cancellable);
#line 517 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->cancellable = _tmp3_;
#line 517 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_start_co (_data_);
#line 6276 "libvirt-machine.c"
}


void boxes_libvirt_machine_start_finish (BoxesLibvirtMachine* self, GAsyncResult* _res_, GError** error) {
	BoxesLibvirtMachineStartData* _data_;
#line 517 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 517 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return;
#line 6286 "libvirt-machine.c"
	}
#line 517 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 6290 "libvirt-machine.c"
}


static void boxes_libvirt_machine_start_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesLibvirtMachineStartData* _data_;
#line 545 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = _user_data_;
#line 545 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_source_object_ = source_object;
#line 545 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_res_ = _res_;
#line 545 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_start_co (_data_);
#line 6304 "libvirt-machine.c"
}


static gboolean boxes_libvirt_machine_start_co (BoxesLibvirtMachineStartData* _data_) {
#line 540 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	switch (_data_->_state_) {
#line 540 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case 0:
#line 6313 "libvirt-machine.c"
		goto _state_0;
#line 540 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case 1:
#line 6317 "libvirt-machine.c"
		goto _state_1;
#line 540 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case 2:
#line 6321 "libvirt-machine.c"
		goto _state_2;
#line 540 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case 3:
#line 6325 "libvirt-machine.c"
		goto _state_3;
		default:
#line 540 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_assert_not_reached ();
#line 6330 "libvirt-machine.c"
	}
	_state_0:
#line 541 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp0_ = 0;
#line 541 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp0_ = boxes_machine_get_state ((BoxesMachine*) _data_->self);
#line 541 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp1_ = 0;
#line 541 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp1_ = _data_->_tmp0_;
#line 541 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_data_->_tmp1_ == BOXES_MACHINE_MACHINE_STATE_RUNNING) {
#line 542 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (_data_->_state_ == 0) {
#line 542 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 6347 "libvirt-machine.c"
		} else {
#line 542 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 6351 "libvirt-machine.c"
		}
#line 542 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_object_unref (_data_->_async_result);
#line 542 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 6357 "libvirt-machine.c"
	}
#line 544 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp2_ = 0;
#line 544 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp2_ = boxes_machine_get_state ((BoxesMachine*) _data_->self);
#line 544 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp3_ = 0;
#line 544 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp3_ = _data_->_tmp2_;
#line 544 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_data_->_tmp3_ == BOXES_MACHINE_MACHINE_STATE_PAUSED) {
#line 545 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp4_ = NULL;
#line 545 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp4_ = _data_->self->priv->_domain;
#line 545 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp5_ = NULL;
#line 545 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp5_ = _data_->cancellable;
#line 545 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_state_ = 1;
#line 545 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		gvir_domain_resume_async (_data_->_tmp4_, _data_->_tmp5_, boxes_libvirt_machine_start_ready, _data_);
#line 545 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 6383 "libvirt-machine.c"
		_state_1:
#line 545 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		gvir_domain_resume_finish (_data_->_tmp4_, _data_->_res_, &_data_->_inner_error_);
#line 545 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 545 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 545 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_error_free (_data_->_inner_error_);
#line 545 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			if (_data_->_state_ == 0) {
#line 545 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 6397 "libvirt-machine.c"
			} else {
#line 545 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 6401 "libvirt-machine.c"
			}
#line 545 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_object_unref (_data_->_async_result);
#line 545 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			return FALSE;
#line 6407 "libvirt-machine.c"
		}
	} else {
#line 546 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp6_ = 0;
#line 546 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp6_ = boxes_machine_get_state ((BoxesMachine*) _data_->self);
#line 546 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp7_ = 0;
#line 546 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp7_ = _data_->_tmp6_;
#line 546 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (_data_->_tmp7_ == BOXES_MACHINE_MACHINE_STATE_SLEEPING) {
#line 547 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp8_ = NULL;
#line 547 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp8_ = _data_->self->priv->_domain;
#line 547 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp9_ = NULL;
#line 547 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp9_ = _data_->cancellable;
#line 547 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_state_ = 2;
#line 547 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			gvir_domain_wakeup_async (_data_->_tmp8_, (guint) 0, _data_->_tmp9_, boxes_libvirt_machine_start_ready, _data_);
#line 547 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			return FALSE;
#line 6434 "libvirt-machine.c"
			_state_2:
#line 547 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			gvir_domain_wakeup_finish (_data_->_tmp8_, _data_->_res_, &_data_->_inner_error_);
#line 547 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 547 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 547 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				g_error_free (_data_->_inner_error_);
#line 547 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				if (_data_->_state_ == 0) {
#line 547 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 6448 "libvirt-machine.c"
				} else {
#line 547 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					g_simple_async_result_complete (_data_->_async_result);
#line 6452 "libvirt-machine.c"
				}
#line 547 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				g_object_unref (_data_->_async_result);
#line 547 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				return FALSE;
#line 6458 "libvirt-machine.c"
			}
		} else {
#line 549 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp11_ = NULL;
#line 549 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp11_ = _data_->self->priv->_domain;
#line 549 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp12_ = FALSE;
#line 549 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp12_ = gvir_domain_get_saved (_data_->_tmp11_);
#line 549 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			if (_data_->_tmp12_) {
#line 550 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp13_ = 0;
#line 550 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp13_ = _data_->flags;
#line 550 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp10_ = !((_data_->_tmp13_ & BOXES_MACHINE_CONNECT_FLAGS_IGNORE_SAVED_STATE) == BOXES_MACHINE_CONNECT_FLAGS_IGNORE_SAVED_STATE);
#line 6477 "libvirt-machine.c"
			} else {
#line 549 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp10_ = FALSE;
#line 6481 "libvirt-machine.c"
			}
#line 549 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->restore = _data_->_tmp10_;
#line 551 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp14_ = FALSE;
#line 551 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp14_ = _data_->restore;
#line 551 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			if (_data_->_tmp14_) {
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp15_ = NULL;
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp15_ = _ ("Restoring %s from disk");
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp16_ = NULL;
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp16_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _data_->self);
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp17_ = NULL;
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp17_ = _data_->_tmp16_;
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp18_ = NULL;
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp18_ = g_strdup_printf (_data_->_tmp15_, _data_->_tmp17_);
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp19_ = NULL;
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp19_ = _data_->_tmp18_;
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				boxes_machine_set_status ((BoxesMachine*) _data_->self, _data_->_tmp19_);
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_g_free0 (_data_->_tmp19_);
#line 6515 "libvirt-machine.c"
			} else {
#line 556 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp20_ = NULL;
#line 556 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp20_ = _ ("Starting %s");
#line 556 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp21_ = NULL;
#line 556 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp21_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _data_->self);
#line 556 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp22_ = NULL;
#line 556 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp22_ = _data_->_tmp21_;
#line 556 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp23_ = NULL;
#line 556 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp23_ = g_strdup_printf (_data_->_tmp20_, _data_->_tmp22_);
#line 556 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp24_ = NULL;
#line 556 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp24_ = _data_->_tmp23_;
#line 556 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				boxes_machine_set_status ((BoxesMachine*) _data_->self, _data_->_tmp24_);
#line 556 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_g_free0 (_data_->_tmp24_);
#line 6541 "libvirt-machine.c"
			}
			{
#line 558 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp25_ = NULL;
#line 558 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp25_ = _data_->self->priv->_domain;
#line 558 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp26_ = 0;
#line 558 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp26_ = _data_->flags;
#line 558 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp27_ = 0;
#line 558 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp27_ = boxes_libvirt_machine_connect_flags_to_gvir (_data_->self, _data_->_tmp26_);
#line 558 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp28_ = NULL;
#line 558 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp28_ = _data_->cancellable;
#line 558 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_state_ = 3;
#line 558 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				gvir_domain_start_async (_data_->_tmp25_, (guint) _data_->_tmp27_, _data_->_tmp28_, boxes_libvirt_machine_start_ready, _data_);
#line 558 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				return FALSE;
#line 6566 "libvirt-machine.c"
				_state_3:
#line 558 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				gvir_domain_start_finish (_data_->_tmp25_, _data_->_res_, &_data_->_inner_error_);
#line 558 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 558 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					if (g_error_matches (_data_->_inner_error_, G_IO_ERROR, G_IO_ERROR_CANCELLED)) {
#line 6574 "libvirt-machine.c"
						goto __catch28_g_io_error_cancelled;
					}
					goto __catch28_g_error;
				}
			}
			goto __finally28;
			__catch28_g_io_error_cancelled:
			{
#line 557 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_error_ = _data_->_inner_error_;
#line 557 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_inner_error_ = NULL;
#line 560 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp29_ = NULL;
#line 560 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp29_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _data_->self);
#line 560 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp30_ = NULL;
#line 560 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp30_ = _data_->_tmp29_;
#line 560 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				g_debug ("libvirt-machine.vala:560: starting of %s was cancelled", _data_->_tmp30_);
#line 557 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_g_error_free0 (_data_->_error_);
#line 6599 "libvirt-machine.c"
			}
			goto __finally28;
			__catch28_g_error:
			{
#line 557 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_vala1__error_ = _data_->_inner_error_;
#line 557 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_inner_error_ = NULL;
#line 562 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp31_ = FALSE;
#line 562 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp31_ = _data_->restore;
#line 562 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				if (_data_->_tmp31_) {
#line 563 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_data_->_tmp32_ = NULL;
#line 563 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_data_->_tmp32_ = _data_->_vala1__error_;
#line 563 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_data_->_tmp33_ = NULL;
#line 563 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_data_->_tmp33_ = _data_->_tmp32_->message;
#line 563 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_data_->_tmp34_ = NULL;
#line 563 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_data_->_tmp34_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_RESTORE_FAILED, _data_->_tmp33_);
#line 563 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_data_->_inner_error_ = _data_->_tmp34_;
#line 563 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_g_error_free0 (_data_->_vala1__error_);
#line 6630 "libvirt-machine.c"
					goto __finally28;
				} else {
#line 565 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_data_->_tmp35_ = NULL;
#line 565 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_data_->_tmp35_ = _data_->_vala1__error_;
#line 565 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_data_->_tmp36_ = NULL;
#line 565 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_data_->_tmp36_ = _data_->_tmp35_->message;
#line 565 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_data_->_tmp37_ = NULL;
#line 565 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_data_->_tmp37_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_START_FAILED, _data_->_tmp36_);
#line 565 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_data_->_inner_error_ = _data_->_tmp37_;
#line 565 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_g_error_free0 (_data_->_vala1__error_);
#line 6649 "libvirt-machine.c"
					goto __finally28;
				}
#line 557 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_g_error_free0 (_data_->_vala1__error_);
#line 6654 "libvirt-machine.c"
			}
			__finally28:
#line 557 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 557 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 557 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				g_error_free (_data_->_inner_error_);
#line 557 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				if (_data_->_state_ == 0) {
#line 557 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 6667 "libvirt-machine.c"
				} else {
#line 557 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					g_simple_async_result_complete (_data_->_async_result);
#line 6671 "libvirt-machine.c"
				}
#line 557 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				g_object_unref (_data_->_async_result);
#line 557 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				return FALSE;
#line 6677 "libvirt-machine.c"
			}
		}
	}
#line 540 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_data_->_state_ == 0) {
#line 540 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 6685 "libvirt-machine.c"
	} else {
#line 540 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 6689 "libvirt-machine.c"
	}
#line 540 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_object_unref (_data_->_async_result);
#line 540 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return FALSE;
#line 6695 "libvirt-machine.c"
}


static Block38Data* block38_data_ref (Block38Data* _data38_) {
#line 570 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_atomic_int_inc (&_data38_->_ref_count_);
#line 570 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return _data38_;
#line 6704 "libvirt-machine.c"
}


static void block38_data_unref (void * _userdata_) {
	Block38Data* _data38_;
	_data38_ = (Block38Data*) _userdata_;
#line 570 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (g_atomic_int_dec_and_test (&_data38_->_ref_count_)) {
#line 6713 "libvirt-machine.c"
		BoxesLibvirtMachine* self;
#line 570 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		self = _data38_->self;
#line 570 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_object_unref0 (_data38_->notification);
#line 570 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_object_unref0 (self);
#line 570 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_slice_free (Block38Data, _data38_);
#line 6723 "libvirt-machine.c"
	}
}


static void ___lambda139_ (BoxesLibvirtMachine* self, GObject* obj, GAsyncResult* res) {
	GError * _inner_error_ = NULL;
#line 573 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_if_fail (res != NULL);
#line 6732 "libvirt-machine.c"
	{
		GAsyncResult* _tmp0_ = NULL;
#line 575 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp0_ = res;
#line 575 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_start_finish (self, _tmp0_, &_inner_error_);
#line 575 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 6741 "libvirt-machine.c"
			goto __catch29_g_error;
		}
#line 576 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_machine_restart ((BoxesMachine*) self);
#line 6746 "libvirt-machine.c"
	}
	goto __finally29;
	__catch29_g_error:
	{
		GError* _error_ = NULL;
		GVirDomain* _tmp1_ = NULL;
		const gchar* _tmp2_ = NULL;
		GError* _tmp3_ = NULL;
		const gchar* _tmp4_ = NULL;
#line 574 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_error_ = _inner_error_;
#line 574 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_inner_error_ = NULL;
#line 578 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp1_ = self->priv->_domain;
#line 578 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp2_ = gvir_domain_get_name (_tmp1_);
#line 578 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp3_ = _error_;
#line 578 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp4_ = _tmp3_->message;
#line 578 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_warning ("libvirt-machine.vala:578: Failed to start '%s': %s", _tmp2_, _tmp4_);
#line 574 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_error_free0 (_error_);
#line 6772 "libvirt-machine.c"
	}
	__finally29:
#line 574 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 574 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 574 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_clear_error (&_inner_error_);
#line 574 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return;
#line 6783 "libvirt-machine.c"
	}
}


static void ____lambda139__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 573 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	___lambda139_ ((BoxesLibvirtMachine*) self, source_object, res);
#line 573 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_object_unref (self);
#line 6793 "libvirt-machine.c"
}


static void ___lambda141_ (BoxesLibvirtMachine* self, GObject* obj, GAsyncResult* res) {
	GError * _inner_error_ = NULL;
#line 594 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_if_fail (res != NULL);
#line 6801 "libvirt-machine.c"
	{
		GAsyncResult* _tmp0_ = NULL;
#line 596 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp0_ = res;
#line 596 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_start_finish (self, _tmp0_, &_inner_error_);
#line 596 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 6810 "libvirt-machine.c"
			goto __catch30_g_error;
		}
	}
	goto __finally30;
	__catch30_g_error:
	{
		GError* _error_ = NULL;
		GVirDomain* _tmp1_ = NULL;
		const gchar* _tmp2_ = NULL;
		GError* _tmp3_ = NULL;
		const gchar* _tmp4_ = NULL;
#line 595 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_error_ = _inner_error_;
#line 595 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_inner_error_ = NULL;
#line 598 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp1_ = self->priv->_domain;
#line 598 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp2_ = gvir_domain_get_name (_tmp1_);
#line 598 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp3_ = _error_;
#line 598 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp4_ = _tmp3_->message;
#line 598 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_warning ("libvirt-machine.vala:598: Failed to start '%s': %s", _tmp2_, _tmp4_);
#line 595 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_error_free0 (_error_);
#line 6838 "libvirt-machine.c"
	}
	__finally30:
#line 595 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 595 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 595 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_clear_error (&_inner_error_);
#line 595 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return;
#line 6849 "libvirt-machine.c"
	}
}


static void ____lambda141__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 594 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	___lambda141_ ((BoxesLibvirtMachine*) self, source_object, res);
#line 594 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_object_unref (self);
#line 6859 "libvirt-machine.c"
}


static void __lambda140_ (Block38Data* _data38_) {
	BoxesLibvirtMachine* self;
	gboolean _tmp0_ = FALSE;
	BoxesMachineMachineState _tmp1_ = 0;
	BoxesMachineMachineState _tmp2_ = 0;
#line 590 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self = _data38_->self;
#line 591 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = boxes_machine_get_state ((BoxesMachine*) self);
#line 591 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp2_ = _tmp1_;
#line 591 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_tmp2_ == BOXES_MACHINE_MACHINE_STATE_STOPPED) {
#line 591 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp0_ = TRUE;
#line 6878 "libvirt-machine.c"
	} else {
		BoxesMachineMachineState _tmp3_ = 0;
		BoxesMachineMachineState _tmp4_ = 0;
#line 592 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp3_ = boxes_machine_get_state ((BoxesMachine*) self);
#line 592 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp4_ = _tmp3_;
#line 592 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp0_ = _tmp4_ == BOXES_MACHINE_MACHINE_STATE_FORCE_STOPPED;
#line 6888 "libvirt-machine.c"
	}
#line 591 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_tmp0_) {
#line 6892 "libvirt-machine.c"
		const gchar* _tmp5_ = NULL;
		const gchar* _tmp6_ = NULL;
		gulong _tmp7_ = 0UL;
		guint _tmp8_ = 0U;
		GdNotification* _tmp10_ = NULL;
#line 593 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp5_ = boxes_collection_item_get_name ((BoxesCollectionItem*) self);
#line 593 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp6_ = _tmp5_;
#line 593 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_debug ("libvirt-machine.vala:593: '%s' stopped.", _tmp6_);
#line 594 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_start (self, BOXES_MACHINE_CONNECT_FLAGS_NONE, NULL, ____lambda141__gasync_ready_callback, g_object_ref (self));
#line 602 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp7_ = _data38_->state_id;
#line 602 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_signal_handler_disconnect ((GObject*) self, _tmp7_);
#line 603 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp8_ = self->priv->shutdown_timeout;
#line 603 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (_tmp8_ != ((guint) 0)) {
#line 6914 "libvirt-machine.c"
			guint _tmp9_ = 0U;
#line 604 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_tmp9_ = self->priv->shutdown_timeout;
#line 604 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_source_remove (_tmp9_);
#line 605 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			self->priv->shutdown_timeout = (guint) 0;
#line 6922 "libvirt-machine.c"
		}
#line 607 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp10_ = _data38_->notification;
#line 607 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (_tmp10_ != NULL) {
#line 6928 "libvirt-machine.c"
			GdNotification* _tmp11_ = NULL;
#line 608 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_tmp11_ = _data38_->notification;
#line 608 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			gd_notification_dismiss (_tmp11_);
#line 609 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_object_unref0 (_data38_->notification);
#line 609 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data38_->notification = NULL;
#line 6938 "libvirt-machine.c"
		}
	}
}


static void ___lambda140__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 590 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	__lambda140_ (self);
#line 6947 "libvirt-machine.c"
}


static void __lambda143_ (Block38Data* _data38_) {
	BoxesLibvirtMachine* self;
#line 616 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self = _data38_->self;
#line 617 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data38_->notification);
#line 617 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data38_->notification = NULL;
#line 618 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_force_shutdown (self);
#line 6961 "libvirt-machine.c"
}


static void ___lambda143__boxes_notification_ok_func (gpointer self) {
#line 616 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	__lambda143_ (self);
#line 6968 "libvirt-machine.c"
}


static gboolean __lambda142_ (Block38Data* _data38_) {
	BoxesLibvirtMachine* self;
	gboolean result = FALSE;
	BoxesNotificationOKFunc really_force_shutdown = NULL;
	void* really_force_shutdown_target = NULL;
	GDestroyNotify really_force_shutdown_target_destroy_notify = NULL;
	gchar* message = NULL;
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	BoxesAppWindow* _tmp4_ = NULL;
	BoxesAppWindow* _tmp5_ = NULL;
	BoxesNotificationbar* _tmp6_ = NULL;
	BoxesNotificationbar* _tmp7_ = NULL;
	const gchar* _tmp8_ = NULL;
	BoxesNotificationOKFunc _tmp9_ = NULL;
	void* _tmp9__target = NULL;
	GDestroyNotify _tmp9__target_destroy_notify = NULL;
	GdNotification* _tmp10_ = NULL;
#line 614 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self = _data38_->self;
#line 616 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	really_force_shutdown = ___lambda143__boxes_notification_ok_func;
#line 616 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	really_force_shutdown_target = block38_data_ref (_data38_);
#line 616 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	really_force_shutdown_target_destroy_notify = block38_data_unref;
#line 621 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = _ ("Restart of '%s' is taking too long. Force it to shutdown?");
#line 621 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = boxes_collection_item_get_name ((BoxesCollectionItem*) self);
#line 621 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp2_ = _tmp1_;
#line 621 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp3_ = g_strdup_printf (_tmp0_, _tmp2_);
#line 621 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	message = _tmp3_;
#line 622 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp4_ = boxes_machine_get_window ((BoxesMachine*) self);
#line 622 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp5_ = _tmp4_;
#line 622 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp6_ = boxes_app_window_get_notificationbar (_tmp5_);
#line 622 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp7_ = _tmp6_;
#line 622 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp8_ = _ ("_Shutdown");
#line 622 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp9_ = really_force_shutdown;
#line 622 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp9__target = really_force_shutdown_target;
#line 622 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp9__target_destroy_notify = really_force_shutdown_target_destroy_notify;
#line 622 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	really_force_shutdown_target_destroy_notify = NULL;
#line 622 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp10_ = boxes_notificationbar_display_for_action (_tmp7_, message, _tmp8_, _tmp9_, _tmp9__target, _tmp9__target_destroy_notify, NULL, NULL, NULL, -1);
#line 622 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data38_->notification);
#line 622 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data38_->notification = _tmp10_;
#line 627 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self->priv->shutdown_timeout = (guint) 0;
#line 629 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	result = FALSE;
#line 629 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (message);
#line 629 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	(really_force_shutdown_target_destroy_notify == NULL) ? NULL : (really_force_shutdown_target_destroy_notify (really_force_shutdown_target), NULL);
#line 629 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	really_force_shutdown = NULL;
#line 629 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	really_force_shutdown_target = NULL;
#line 629 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	really_force_shutdown_target_destroy_notify = NULL;
#line 629 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 7050 "libvirt-machine.c"
}


static gboolean ___lambda142__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda142_ (self);
#line 614 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 7059 "libvirt-machine.c"
}


static void boxes_libvirt_machine_real_restart (BoxesMachine* base) {
	BoxesLibvirtMachine * self;
	Block38Data* _data38_;
	BoxesMachineMachineState _tmp0_ = 0;
	BoxesMachineMachineState _tmp1_ = 0;
	const gchar* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	gulong _tmp6_ = 0UL;
	guint _tmp7_ = 0U;
#line 570 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self = (BoxesLibvirtMachine*) base;
#line 570 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data38_ = g_slice_new0 (Block38Data);
#line 570 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data38_->_ref_count_ = 1;
#line 570 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data38_->self = g_object_ref (self);
#line 571 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = boxes_machine_get_state ((BoxesMachine*) self);
#line 571 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = _tmp0_;
#line 571 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_tmp1_ == BOXES_MACHINE_MACHINE_STATE_SAVED) {
#line 7086 "libvirt-machine.c"
		const gchar* _tmp2_ = NULL;
		const gchar* _tmp3_ = NULL;
#line 572 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp2_ = boxes_collection_item_get_name ((BoxesCollectionItem*) self);
#line 572 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp3_ = _tmp2_;
#line 572 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_debug ("libvirt-machine.vala:572: '%s' is in saved state. Resuming it..", _tmp3_);
#line 573 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_start (self, BOXES_MACHINE_CONNECT_FLAGS_NONE, NULL, ____lambda139__gasync_ready_callback, g_object_ref (self));
#line 582 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		block38_data_unref (_data38_);
#line 582 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data38_ = NULL;
#line 582 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return;
#line 7103 "libvirt-machine.c"
	}
#line 585 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	((BoxesMachine*) self)->stay_on_display = TRUE;
#line 586 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data38_->state_id = (gulong) 0;
#line 587 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data38_->notification = NULL;
#line 588 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp4_ = boxes_collection_item_get_name ((BoxesCollectionItem*) self);
#line 588 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp5_ = _tmp4_;
#line 588 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_debug ("libvirt-machine.vala:588: Rebooting '%s'..", _tmp5_);
#line 590 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp6_ = g_signal_connect_data ((GObject*) self, "notify::state", (GCallback) ___lambda140__g_object_notify, block38_data_ref (_data38_), (GClosureNotify) block38_data_unref, 0);
#line 590 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data38_->state_id = _tmp6_;
#line 614 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp7_ = g_timeout_add_seconds_full (G_PRIORITY_DEFAULT, (guint) 5, ___lambda142__gsource_func, block38_data_ref (_data38_), block38_data_unref);
#line 614 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self->priv->shutdown_timeout = _tmp7_;
#line 632 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_try_shutdown (self);
#line 570 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	block38_data_unref (_data38_);
#line 570 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data38_ = NULL;
#line 7131 "libvirt-machine.c"
}


static void boxes_libvirt_machine_wait_for_save_data_free (gpointer _data) {
	BoxesLibvirtMachineWaitForSaveData* _data_;
	_data_ = _data;
#line 517 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->self);
#line 517 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_slice_free (BoxesLibvirtMachineWaitForSaveData, _data_);
#line 7142 "libvirt-machine.c"
}


static void boxes_libvirt_machine_wait_for_save (BoxesLibvirtMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesLibvirtMachineWaitForSaveData* _data_;
	BoxesLibvirtMachine* _tmp0_ = NULL;
#line 517 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_slice_new0 (BoxesLibvirtMachineWaitForSaveData);
#line 517 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_libvirt_machine_wait_for_save);
#line 517 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_libvirt_machine_wait_for_save_data_free);
#line 517 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 517 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->self = _tmp0_;
#line 517 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_wait_for_save_co (_data_);
#line 7161 "libvirt-machine.c"
}


static void boxes_libvirt_machine_wait_for_save_finish (BoxesLibvirtMachine* self, GAsyncResult* _res_) {
	BoxesLibvirtMachineWaitForSaveData* _data_;
#line 517 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 7169 "libvirt-machine.c"
}


static Block39Data* block39_data_ref (Block39Data* _data39_) {
#line 635 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_atomic_int_inc (&_data39_->_ref_count_);
#line 635 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return _data39_;
#line 7178 "libvirt-machine.c"
}


static void block39_data_unref (void * _userdata_) {
	Block39Data* _data39_;
	_data39_ = (Block39Data*) _userdata_;
#line 635 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (g_atomic_int_dec_and_test (&_data39_->_ref_count_)) {
#line 7187 "libvirt-machine.c"
		BoxesLibvirtMachine* self;
#line 635 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		self = _data39_->self;
#line 635 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_object_unref0 (self);
#line 635 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_slice_free (Block39Data, _data39_);
#line 7195 "libvirt-machine.c"
	}
}


static void __lambda163_ (Block39Data* _data39_) {
	BoxesLibvirtMachine* self;
	BoxesMachineMachineState _tmp0_ = 0;
	BoxesMachineMachineState _tmp1_ = 0;
#line 639 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self = _data39_->self;
#line 640 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = boxes_machine_get_state ((BoxesMachine*) self);
#line 640 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = _tmp0_;
#line 640 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_tmp1_ == BOXES_MACHINE_MACHINE_STATE_SAVED) {
#line 641 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_wait_for_save_co (_data39_->_async_data_);
#line 7214 "libvirt-machine.c"
	}
}


static void ___lambda163__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 639 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	__lambda163_ (self);
#line 7222 "libvirt-machine.c"
}


static gboolean __lambda165_ (Block39Data* _data39_) {
	BoxesLibvirtMachine* self;
	gboolean result = FALSE;
#line 644 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self = _data39_->self;
#line 648 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_wait_for_save_co (_data39_->_async_data_);
#line 650 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	result = FALSE;
#line 650 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 7237 "libvirt-machine.c"
}


static gboolean ___lambda165__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda165_ (self);
#line 644 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 7246 "libvirt-machine.c"
}


static void __lambda164_ (Block39Data* _data39_) {
	BoxesLibvirtMachine* self;
#line 643 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self = _data39_->self;
#line 644 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, ___lambda165__gsource_func, block39_data_ref (_data39_), block39_data_unref);
#line 7256 "libvirt-machine.c"
}


static void ___lambda164__g_cancellable_cancelled (GCancellable* _sender, gpointer self) {
#line 643 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	__lambda164_ (self);
#line 7263 "libvirt-machine.c"
}


static gboolean boxes_libvirt_machine_wait_for_save_co (BoxesLibvirtMachineWaitForSaveData* _data_) {
#line 635 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	switch (_data_->_state_) {
#line 635 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case 0:
#line 7272 "libvirt-machine.c"
		goto _state_0;
#line 635 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case 1:
#line 7276 "libvirt-machine.c"
		goto _state_1;
		default:
#line 635 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_assert_not_reached ();
#line 7281 "libvirt-machine.c"
	}
	_state_0:
#line 635 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_data39_ = g_slice_new0 (Block39Data);
#line 635 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_data39_->_ref_count_ = 1;
#line 635 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_data39_->self = g_object_ref (_data_->self);
#line 635 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_data39_->_async_data_ = _data_;
#line 636 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp0_ = FALSE;
#line 636 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp0_ = _data_->self->priv->saving;
#line 636 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (!_data_->_tmp0_) {
#line 637 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		block39_data_unref (_data_->_data39_);
#line 637 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_data39_ = NULL;
#line 637 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (_data_->_state_ == 0) {
#line 637 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 7306 "libvirt-machine.c"
		} else {
#line 637 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 7310 "libvirt-machine.c"
		}
#line 637 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_object_unref (_data_->_async_result);
#line 637 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 7316 "libvirt-machine.c"
	}
#line 639 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp1_ = 0UL;
#line 639 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp1_ = g_signal_connect_data ((GObject*) _data_->self, "notify::state", (GCallback) ___lambda163__g_object_notify, block39_data_ref (_data_->_data39_), (GClosureNotify) block39_data_unref, 0);
#line 639 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->state_notify_id = _data_->_tmp1_;
#line 643 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp2_ = NULL;
#line 643 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp2_ = boxes_machine_get_connecting_cancellable ((BoxesMachine*) _data_->self);
#line 643 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp3_ = NULL;
#line 643 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp3_ = _data_->_tmp2_;
#line 643 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp4_ = 0UL;
#line 643 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp4_ = g_signal_connect_data (_data_->_tmp3_, "cancelled", (GCallback) ___lambda164__g_cancellable_cancelled, block39_data_ref (_data_->_data39_), (GClosureNotify) block39_data_unref, 0);
#line 643 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->cancelled_id = _data_->_tmp4_;
#line 654 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp5_ = NULL;
#line 654 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp5_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _data_->self);
#line 654 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp6_ = NULL;
#line 654 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp6_ = _data_->_tmp5_;
#line 654 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_debug ("libvirt-machine.vala:654: %s is being saved, delaying starting until i" \
"t's saved", _data_->_tmp6_);
#line 655 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_state_ = 1;
#line 655 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return FALSE;
#line 7352 "libvirt-machine.c"
	_state_1:
	;
#line 657 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp7_ = 0UL;
#line 657 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp7_ = _data_->state_notify_id;
#line 657 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_signal_handler_disconnect ((GObject*) _data_->self, _data_->_tmp7_);
#line 658 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp8_ = NULL;
#line 658 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp8_ = boxes_machine_get_connecting_cancellable ((BoxesMachine*) _data_->self);
#line 658 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp9_ = NULL;
#line 658 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp9_ = _data_->_tmp8_;
#line 658 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp10_ = 0UL;
#line 658 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp10_ = _data_->cancelled_id;
#line 658 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_cancellable_disconnect (_data_->_tmp9_, _data_->_tmp10_);
#line 635 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	block39_data_unref (_data_->_data39_);
#line 635 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_data39_ = NULL;
#line 635 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_data_->_state_ == 0) {
#line 635 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 7383 "libvirt-machine.c"
	} else {
#line 635 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 7387 "libvirt-machine.c"
	}
#line 635 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_object_unref (_data_->_async_result);
#line 635 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return FALSE;
#line 7393 "libvirt-machine.c"
}


GVirDomain* boxes_libvirt_machine_get_domain (BoxesLibvirtMachine* self) {
	GVirDomain* result;
	GVirDomain* _tmp0_ = NULL;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = self->priv->_domain;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	result = _tmp0_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 7408 "libvirt-machine.c"
}


void boxes_libvirt_machine_set_domain (BoxesLibvirtMachine* self, GVirDomain* value) {
	GVirDomain* _tmp0_ = NULL;
	GVirDomain* _tmp1_ = NULL;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_if_fail (self != NULL);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = value;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (self->priv->_domain);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self->priv->_domain = _tmp1_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_object_notify ((GObject *) self, "domain");
#line 7427 "libvirt-machine.c"
}


GVirConfigDomain* boxes_libvirt_machine_get_domain_config (BoxesLibvirtMachine* self) {
	GVirConfigDomain* result;
	GVirConfigDomain* _tmp0_ = NULL;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = self->priv->_domain_config;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	result = _tmp0_;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 7442 "libvirt-machine.c"
}


void boxes_libvirt_machine_set_domain_config (BoxesLibvirtMachine* self, GVirConfigDomain* value) {
	GVirConfigDomain* _tmp0_ = NULL;
	GVirConfigDomain* _tmp1_ = NULL;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_if_fail (self != NULL);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = value;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (self->priv->_domain_config);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self->priv->_domain_config = _tmp1_;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_object_notify ((GObject *) self, "domain-config");
#line 7461 "libvirt-machine.c"
}


GVirConnection* boxes_libvirt_machine_get_connection (BoxesLibvirtMachine* self) {
	GVirConnection* result;
	GVirConnection* _tmp0_ = NULL;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = self->priv->_connection;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	result = _tmp0_;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 7476 "libvirt-machine.c"
}


void boxes_libvirt_machine_set_connection (BoxesLibvirtMachine* self, GVirConnection* value) {
	GVirConnection* _tmp0_ = NULL;
	GVirConnection* _tmp1_ = NULL;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_if_fail (self != NULL);
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = value;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (self->priv->_connection);
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self->priv->_connection = _tmp1_;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_object_notify ((GObject *) self, "connection");
#line 7495 "libvirt-machine.c"
}


GVirStorageVol* boxes_libvirt_machine_get_storage_volume (BoxesLibvirtMachine* self) {
	GVirStorageVol* result;
	GVirStorageVol* _tmp0_ = NULL;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = self->priv->_storage_volume;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	result = _tmp0_;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 7510 "libvirt-machine.c"
}


void boxes_libvirt_machine_set_storage_volume (BoxesLibvirtMachine* self, GVirStorageVol* value) {
	GVirStorageVol* _tmp0_ = NULL;
	GVirStorageVol* _tmp1_ = NULL;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_if_fail (self != NULL);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = value;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (self->priv->_storage_volume);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self->priv->_storage_volume = _tmp1_;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_object_notify ((GObject *) self, "storage-volume");
#line 7529 "libvirt-machine.c"
}


BoxesVMCreator* boxes_libvirt_machine_get_vm_creator (BoxesLibvirtMachine* self) {
	BoxesVMCreator* result;
	BoxesVMCreator* _tmp0_ = NULL;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = self->priv->_vm_creator;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	result = _tmp0_;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 7544 "libvirt-machine.c"
}


static gpointer _boxes_vm_creator_ref0 (gpointer self) {
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return self ? boxes_vm_creator_ref (self) : NULL;
#line 7551 "libvirt-machine.c"
}


void boxes_libvirt_machine_set_vm_creator (BoxesLibvirtMachine* self, BoxesVMCreator* value) {
	BoxesVMCreator* _tmp0_ = NULL;
	BoxesVMCreator* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_ = FALSE;
	gboolean _tmp4_ = FALSE;
	BoxesVMCreator* _tmp5_ = NULL;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_if_fail (self != NULL);
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = value;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = _boxes_vm_creator_ref0 (_tmp0_);
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_boxes_vm_creator_unref0 (self->priv->_vm_creator);
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self->priv->_vm_creator = _tmp1_;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp2_ = boxes_libvirt_machine_get_importing (self);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp3_ = _tmp2_;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_machine_set_can_delete ((BoxesMachine*) self, !_tmp3_);
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp5_ = value;
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_tmp5_ != NULL) {
#line 7582 "libvirt-machine.c"
		GVirConfigDomain* _tmp6_ = NULL;
		gboolean _tmp7_ = FALSE;
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp6_ = self->priv->_domain_config;
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp7_ = boxes_vm_configurator_is_live_config (_tmp6_);
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp4_ = !_tmp7_;
#line 7591 "libvirt-machine.c"
	} else {
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp4_ = FALSE;
#line 7595 "libvirt-machine.c"
	}
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_machine_set_under_construction ((BoxesMachine*) self, _tmp4_);
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_object_notify ((GObject *) self, "vm-creator");
#line 7601 "libvirt-machine.c"
}


gboolean boxes_libvirt_machine_get_importing (BoxesLibvirtMachine* self) {
	gboolean result;
	gboolean _tmp0_ = FALSE;
	BoxesVMCreator* _tmp1_ = NULL;
	BoxesVMCreator* _tmp2_ = NULL;
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = boxes_libvirt_machine_get_vm_creator (self);
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp2_ = _tmp1_;
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_tmp2_ != NULL) {
#line 7618 "libvirt-machine.c"
		BoxesVMCreator* _tmp3_ = NULL;
		BoxesVMCreator* _tmp4_ = NULL;
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp3_ = boxes_libvirt_machine_get_vm_creator (self);
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp4_ = _tmp3_;
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp0_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, BOXES_TYPE_VM_IMPORTER);
#line 7627 "libvirt-machine.c"
	} else {
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp0_ = FALSE;
#line 7631 "libvirt-machine.c"
	}
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	result = _tmp0_;
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 7637 "libvirt-machine.c"
}


gboolean boxes_libvirt_machine_get_save_on_quit (BoxesLibvirtMachine* self) {
	gboolean result;
	BoxesCollectionSource* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = ((BoxesMachine*) self)->source;
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = boxes_iconfig_get_boolean ((BoxesIConfig*) _tmp0_, "source", "save-on-quit", FALSE);
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	result = _tmp1_;
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 7655 "libvirt-machine.c"
}


void boxes_libvirt_machine_set_save_on_quit (BoxesLibvirtMachine* self, gboolean value) {
	BoxesCollectionSource* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_if_fail (self != NULL);
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = ((BoxesMachine*) self)->source;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = value;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_iconfig_set_boolean ((BoxesIConfig*) _tmp0_, "source", "save-on-quit", _tmp1_);
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_object_notify ((GObject *) self, "save-on-quit");
#line 7672 "libvirt-machine.c"
}


static gboolean boxes_libvirt_machine_real_get_can_save (BoxesMachine* base) {
	gboolean result;
	BoxesLibvirtMachine* self;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self = (BoxesLibvirtMachine*) base;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = self->priv->saving;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (!_tmp1_) {
#line 7687 "libvirt-machine.c"
		BoxesMachineMachineState _tmp2_ = 0;
		BoxesMachineMachineState _tmp3_ = 0;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp2_ = boxes_machine_get_state ((BoxesMachine*) self);
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp3_ = _tmp2_;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp0_ = _tmp3_ != BOXES_MACHINE_MACHINE_STATE_SAVED;
#line 7696 "libvirt-machine.c"
	} else {
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp0_ = FALSE;
#line 7700 "libvirt-machine.c"
	}
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	result = _tmp0_;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 7706 "libvirt-machine.c"
}


static gboolean boxes_libvirt_machine_real_get_should_autosave (BoxesMachine* base) {
	gboolean result;
	BoxesLibvirtMachine* self;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self = (BoxesLibvirtMachine*) base;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = BOXES_MACHINE_CLASS (boxes_libvirt_machine_parent_class)->get_should_autosave (G_TYPE_CHECK_INSTANCE_CAST (self, BOXES_TYPE_MACHINE, BoxesMachine));
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_tmp1_) {
#line 7721 "libvirt-machine.c"
		gboolean _tmp2_ = FALSE;
		BoxesVMCreator* _tmp3_ = NULL;
		BoxesVMCreator* _tmp4_ = NULL;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp3_ = boxes_libvirt_machine_get_vm_creator (self);
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp4_ = _tmp3_;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (_tmp4_ == NULL) {
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_tmp2_ = TRUE;
#line 7733 "libvirt-machine.c"
		} else {
			BoxesVMCreator* _tmp5_ = NULL;
			BoxesVMCreator* _tmp6_ = NULL;
			gboolean _tmp7_ = FALSE;
			gboolean _tmp8_ = FALSE;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_tmp5_ = boxes_libvirt_machine_get_vm_creator (self);
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_tmp6_ = _tmp5_;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_tmp7_ = boxes_vm_creator_get_express_install (_tmp6_);
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_tmp8_ = _tmp7_;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_tmp2_ = !_tmp8_;
#line 7749 "libvirt-machine.c"
		}
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp0_ = _tmp2_;
#line 7753 "libvirt-machine.c"
	} else {
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp0_ = FALSE;
#line 7757 "libvirt-machine.c"
	}
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	result = _tmp0_;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 7763 "libvirt-machine.c"
}


static GObject * boxes_libvirt_machine_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	BoxesLibvirtMachine * self;
	BoxesLibvirtMachineMachineStat* _tmp0_ = NULL;
	GCancellable* _tmp1_ = NULL;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	parent_class = G_OBJECT_CLASS (boxes_libvirt_machine_parent_class);
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachine);
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = g_new0 (BoxesLibvirtMachineMachineStat, BOXES_LIBVIRT_MACHINE_STATS_SIZE);
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self->priv->stats = (_vala_BoxesLibvirtMachineMachineStat_array_free (self->priv->stats, self->priv->stats_length1), NULL);
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self->priv->stats = _tmp0_;
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self->priv->stats_length1 = BOXES_LIBVIRT_MACHINE_STATS_SIZE;
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self->priv->_stats_size_ = self->priv->stats_length1;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = g_cancellable_new ();
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (self->priv->stats_cancellable);
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self->priv->stats_cancellable = _tmp1_;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return obj;
#line 7797 "libvirt-machine.c"
}


static GVirDomainDiskStats* _vala_GVirDomainDiskStats_copy (GVirDomainDiskStats* self) {
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return g_boxed_copy (gvir_domain_disk_stats_get_type (), self);
#line 7804 "libvirt-machine.c"
}


static gpointer __vala_GVirDomainDiskStats_copy0 (gpointer self) {
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return self ? _vala_GVirDomainDiskStats_copy (self) : NULL;
#line 7811 "libvirt-machine.c"
}


static GVirDomainInterfaceStats* _vala_GVirDomainInterfaceStats_copy (GVirDomainInterfaceStats* self) {
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return g_boxed_copy (gvir_domain_interface_stats_get_type (), self);
#line 7818 "libvirt-machine.c"
}


static gpointer __vala_GVirDomainInterfaceStats_copy0 (gpointer self) {
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return self ? _vala_GVirDomainInterfaceStats_copy (self) : NULL;
#line 7825 "libvirt-machine.c"
}


static void boxes_libvirt_machine_machine_stat_copy (const BoxesLibvirtMachineMachineStat* self, BoxesLibvirtMachineMachineStat* dest) {
	gint64 _tmp0_ = 0LL;
	gdouble _tmp1_ = 0.0;
	gdouble _tmp2_ = 0.0;
	gdouble _tmp3_ = 0.0;
	gdouble _tmp4_ = 0.0;
	GVirDomainDiskStats* _tmp5_ = NULL;
	GVirDomainDiskStats* _tmp6_ = NULL;
	gdouble _tmp7_ = 0.0;
	gdouble _tmp8_ = 0.0;
	GVirDomainInterfaceStats* _tmp9_ = NULL;
	GVirDomainInterfaceStats* _tmp10_ = NULL;
	gdouble _tmp11_ = 0.0;
	gdouble _tmp12_ = 0.0;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = (*self).timestamp;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	(*dest).timestamp = _tmp0_;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = (*self).cpu_time;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	(*dest).cpu_time = _tmp1_;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp2_ = (*self).cpu_time_abs;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	(*dest).cpu_time_abs = _tmp2_;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp3_ = (*self).cpu_guest_percent;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	(*dest).cpu_guest_percent = _tmp3_;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp4_ = (*self).memory_percent;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	(*dest).memory_percent = _tmp4_;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp5_ = (*self).disk;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp6_ = __vala_GVirDomainDiskStats_copy0 (_tmp5_);
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	__vala_GVirDomainDiskStats_free0 ((*dest).disk);
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	(*dest).disk = _tmp6_;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp7_ = (*self).disk_read;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	(*dest).disk_read = _tmp7_;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp8_ = (*self).disk_write;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	(*dest).disk_write = _tmp8_;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp9_ = (*self).net;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp10_ = __vala_GVirDomainInterfaceStats_copy0 (_tmp9_);
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	__vala_GVirDomainInterfaceStats_free0 ((*dest).net);
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	(*dest).net = _tmp10_;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp11_ = (*self).net_read;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	(*dest).net_read = _tmp11_;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp12_ = (*self).net_write;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	(*dest).net_write = _tmp12_;
#line 7895 "libvirt-machine.c"
}


static void boxes_libvirt_machine_machine_stat_destroy (BoxesLibvirtMachineMachineStat* self) {
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	__vala_GVirDomainDiskStats_free0 ((*self).disk);
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	__vala_GVirDomainInterfaceStats_free0 ((*self).net);
#line 7904 "libvirt-machine.c"
}


static BoxesLibvirtMachineMachineStat* boxes_libvirt_machine_machine_stat_dup (const BoxesLibvirtMachineMachineStat* self) {
	BoxesLibvirtMachineMachineStat* dup;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	dup = g_new0 (BoxesLibvirtMachineMachineStat, 1);
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_machine_stat_copy (self, dup);
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return dup;
#line 7916 "libvirt-machine.c"
}


static void boxes_libvirt_machine_machine_stat_free (BoxesLibvirtMachineMachineStat* self) {
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_machine_stat_destroy (self);
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_free (self);
#line 7925 "libvirt-machine.c"
}


static GType boxes_libvirt_machine_machine_stat_get_type (void) {
	static volatile gsize boxes_libvirt_machine_machine_stat_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_libvirt_machine_machine_stat_type_id__volatile)) {
		GType boxes_libvirt_machine_machine_stat_type_id;
		boxes_libvirt_machine_machine_stat_type_id = g_boxed_type_register_static ("BoxesLibvirtMachineMachineStat", (GBoxedCopyFunc) boxes_libvirt_machine_machine_stat_dup, (GBoxedFreeFunc) boxes_libvirt_machine_machine_stat_free);
		g_once_init_leave (&boxes_libvirt_machine_machine_stat_type_id__volatile, boxes_libvirt_machine_machine_stat_type_id);
	}
	return boxes_libvirt_machine_machine_stat_type_id__volatile;
}


static void boxes_libvirt_machine_class_init (BoxesLibvirtMachineClass * klass) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_parent_class = g_type_class_peek_parent (klass);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_type_class_add_private (klass, sizeof (BoxesLibvirtMachinePrivate));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	((BoxesMachineClass *) klass)->disconnect_display = boxes_libvirt_machine_real_disconnect_display;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	((BoxesMachineClass *) klass)->connect_display = boxes_libvirt_machine_real_connect_display;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	((BoxesMachineClass *) klass)->connect_display_finish = boxes_libvirt_machine_real_connect_display_finish;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	((BoxesMachineClass *) klass)->get_properties = boxes_libvirt_machine_real_get_properties;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	((BoxesMachineClass *) klass)->take_screenshot = boxes_libvirt_machine_real_take_screenshot;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	((BoxesMachineClass *) klass)->take_screenshot_finish = boxes_libvirt_machine_real_take_screenshot_finish;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	((BoxesMachineClass *) klass)->delete = boxes_libvirt_machine_real_delete;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	((BoxesMachineClass *) klass)->save_real = boxes_libvirt_machine_real_save_real;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	((BoxesMachineClass *) klass)->save_real_finish = boxes_libvirt_machine_real_save_real_finish;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	((BoxesMachineClass *) klass)->restart = boxes_libvirt_machine_real_restart;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	BOXES_MACHINE_CLASS (klass)->get_can_save = boxes_libvirt_machine_real_get_can_save;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	BOXES_MACHINE_CLASS (klass)->get_should_autosave = boxes_libvirt_machine_real_get_should_autosave;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_libvirt_machine_get_property;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_libvirt_machine_set_property;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	G_OBJECT_CLASS (klass)->constructor = boxes_libvirt_machine_constructor;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_libvirt_machine_finalize;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_LIBVIRT_MACHINE_DOMAIN, g_param_spec_object ("domain", "domain", "domain", gvir_domain_get_type (), G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_LIBVIRT_MACHINE_DOMAIN_CONFIG, g_param_spec_object ("domain-config", "domain-config", "domain-config", gvir_config_domain_get_type (), G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_LIBVIRT_MACHINE_CONNECTION, g_param_spec_object ("connection", "connection", "connection", gvir_connection_get_type (), G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_LIBVIRT_MACHINE_STORAGE_VOLUME, g_param_spec_object ("storage-volume", "storage-volume", "storage-volume", gvir_storage_vol_get_type (), G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_LIBVIRT_MACHINE_VM_CREATOR, boxes_param_spec_vm_creator ("vm-creator", "vm-creator", "vm-creator", BOXES_TYPE_VM_CREATOR, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_LIBVIRT_MACHINE_IMPORTING, g_param_spec_boolean ("importing", "importing", "importing", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_LIBVIRT_MACHINE_SAVE_ON_QUIT, g_param_spec_boolean ("save-on-quit", "save-on-quit", "save-on-quit", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_LIBVIRT_MACHINE_CAN_SAVE, g_param_spec_boolean ("can-save", "can-save", "can-save", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_LIBVIRT_MACHINE_SHOULD_AUTOSAVE, g_param_spec_boolean ("should-autosave", "should-autosave", "should-autosave", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_signal_new ("stats_updated", BOXES_TYPE_LIBVIRT_MACHINE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 7997 "libvirt-machine.c"
}


static void boxes_libvirt_machine_instance_init (BoxesLibvirtMachine * self) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self->priv = BOXES_LIBVIRT_MACHINE_GET_PRIVATE (self);
#line 8004 "libvirt-machine.c"
}


static void boxes_libvirt_machine_finalize (GObject* obj) {
	BoxesLibvirtMachine * self;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachine);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (self->priv->_domain);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (self->priv->_domain_config);
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (self->priv->_connection);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (self->priv->_storage_volume);
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_boxes_vm_creator_unref0 (self->priv->_vm_creator);
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (self->properties);
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (self->priv->stats_cancellable);
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self->priv->stats = (_vala_BoxesLibvirtMachineMachineStat_array_free (self->priv->stats, self->priv->stats_length1), NULL);
#line 282 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self->cpu_stats = (g_free (self->cpu_stats), NULL);
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self->io_stats = (g_free (self->io_stats), NULL);
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self->net_stats = (g_free (self->net_stats), NULL);
#line 517 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	G_OBJECT_CLASS (boxes_libvirt_machine_parent_class)->finalize (obj);
#line 8036 "libvirt-machine.c"
}


GType boxes_libvirt_machine_get_type (void) {
	static volatile gsize boxes_libvirt_machine_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_libvirt_machine_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesLibvirtMachineClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_libvirt_machine_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesLibvirtMachine), 0, (GInstanceInitFunc) boxes_libvirt_machine_instance_init, NULL };
		GType boxes_libvirt_machine_type_id;
		boxes_libvirt_machine_type_id = g_type_register_static (BOXES_TYPE_MACHINE, "BoxesLibvirtMachine", &g_define_type_info, 0);
		g_once_init_leave (&boxes_libvirt_machine_type_id__volatile, boxes_libvirt_machine_type_id);
	}
	return boxes_libvirt_machine_type_id__volatile;
}


static void _vala_boxes_libvirt_machine_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesLibvirtMachine * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachine);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	switch (property_id) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case BOXES_LIBVIRT_MACHINE_DOMAIN:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_value_set_object (value, boxes_libvirt_machine_get_domain (self));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		break;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case BOXES_LIBVIRT_MACHINE_DOMAIN_CONFIG:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_value_set_object (value, boxes_libvirt_machine_get_domain_config (self));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		break;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case BOXES_LIBVIRT_MACHINE_CONNECTION:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_value_set_object (value, boxes_libvirt_machine_get_connection (self));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		break;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case BOXES_LIBVIRT_MACHINE_STORAGE_VOLUME:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_value_set_object (value, boxes_libvirt_machine_get_storage_volume (self));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		break;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case BOXES_LIBVIRT_MACHINE_VM_CREATOR:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_value_set_vm_creator (value, boxes_libvirt_machine_get_vm_creator (self));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		break;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case BOXES_LIBVIRT_MACHINE_IMPORTING:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_value_set_boolean (value, boxes_libvirt_machine_get_importing (self));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		break;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case BOXES_LIBVIRT_MACHINE_SAVE_ON_QUIT:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_value_set_boolean (value, boxes_libvirt_machine_get_save_on_quit (self));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		break;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case BOXES_LIBVIRT_MACHINE_CAN_SAVE:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_value_set_boolean (value, boxes_machine_get_can_save ((BoxesMachine*) self));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		break;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case BOXES_LIBVIRT_MACHINE_SHOULD_AUTOSAVE:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_value_set_boolean (value, boxes_machine_get_should_autosave ((BoxesMachine*) self));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		break;
#line 8111 "libvirt-machine.c"
		default:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		break;
#line 8117 "libvirt-machine.c"
	}
}


static void _vala_boxes_libvirt_machine_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesLibvirtMachine * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachine);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	switch (property_id) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case BOXES_LIBVIRT_MACHINE_DOMAIN:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_set_domain (self, g_value_get_object (value));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		break;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case BOXES_LIBVIRT_MACHINE_DOMAIN_CONFIG:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_set_domain_config (self, g_value_get_object (value));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		break;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case BOXES_LIBVIRT_MACHINE_CONNECTION:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_set_connection (self, g_value_get_object (value));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		break;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case BOXES_LIBVIRT_MACHINE_STORAGE_VOLUME:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_set_storage_volume (self, g_value_get_object (value));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		break;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case BOXES_LIBVIRT_MACHINE_VM_CREATOR:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_set_vm_creator (self, boxes_value_get_vm_creator (value));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		break;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case BOXES_LIBVIRT_MACHINE_SAVE_ON_QUIT:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_set_save_on_quit (self, g_value_get_boolean (value));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		break;
#line 8163 "libvirt-machine.c"
		default:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		break;
#line 8169 "libvirt-machine.c"
	}
}



