/* libvirt-machine-properties.c generated by valac 0.29.2.1-265d, the Vala compiler
 * generated from libvirt-machine-properties.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <libvirt-gconfig/libvirt-gconfig.h>
#include <libvirt-gobject/libvirt-gobject.h>
#include <stdlib.h>
#include <string.h>
#include <libcommon.h>
#include <gio/gio.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <glib/gstdio.h>
#include <glib/gi18n-lib.h>
#include <config.h>
#include <gtk/gtk.h>
#include <pango/pango.h>
#include <osinfo/osinfo.h>
#include <libgd/gd.h>
#include <float.h>
#include <math.h>


#define BOXES_TYPE_IPROPERTIES_PROVIDER (boxes_iproperties_provider_get_type ())
#define BOXES_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProvider))
#define BOXES_IS_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER))
#define BOXES_IPROPERTIES_PROVIDER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProviderIface))

typedef struct _BoxesIPropertiesProvider BoxesIPropertiesProvider;
typedef struct _BoxesIPropertiesProviderIface BoxesIPropertiesProviderIface;

#define BOXES_TYPE_PROPERTIES_PAGE (boxes_properties_page_get_type ())

#define TYPE_PROPERTY_CREATION_FLAG (property_creation_flag_get_type ())

#define BOXES_TYPE_PROPERTY (boxes_property_get_type ())
#define BOXES_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTY, BoxesProperty))
#define BOXES_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTY, BoxesPropertyClass))
#define BOXES_IS_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTY))
#define BOXES_IS_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTY))
#define BOXES_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTY, BoxesPropertyClass))

typedef struct _BoxesProperty BoxesProperty;
typedef struct _BoxesPropertyClass BoxesPropertyClass;

#define BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES (boxes_libvirt_machine_properties_get_type ())
#define BOXES_LIBVIRT_MACHINE_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES, BoxesLibvirtMachineProperties))
#define BOXES_LIBVIRT_MACHINE_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES, BoxesLibvirtMachinePropertiesClass))
#define BOXES_IS_LIBVIRT_MACHINE_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES))
#define BOXES_IS_LIBVIRT_MACHINE_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES))
#define BOXES_LIBVIRT_MACHINE_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES, BoxesLibvirtMachinePropertiesClass))

typedef struct _BoxesLibvirtMachineProperties BoxesLibvirtMachineProperties;
typedef struct _BoxesLibvirtMachinePropertiesClass BoxesLibvirtMachinePropertiesClass;
typedef struct _BoxesLibvirtMachinePropertiesPrivate BoxesLibvirtMachinePropertiesPrivate;

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_MACHINE (boxes_machine_get_type ())
#define BOXES_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE, BoxesMachine))
#define BOXES_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE, BoxesMachineClass))
#define BOXES_IS_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE))
#define BOXES_IS_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE))
#define BOXES_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE, BoxesMachineClass))

typedef struct _BoxesMachine BoxesMachine;
typedef struct _BoxesMachineClass BoxesMachineClass;

#define BOXES_TYPE_LIBVIRT_MACHINE (boxes_libvirt_machine_get_type ())
#define BOXES_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachine))
#define BOXES_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))
#define BOXES_IS_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_IS_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_LIBVIRT_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))

typedef struct _BoxesLibvirtMachine BoxesLibvirtMachine;
typedef struct _BoxesLibvirtMachineClass BoxesLibvirtMachineClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_UI_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_UI, BoxesUIIface))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIIface BoxesUIIface;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())
typedef struct _BoxesCollectionItemPrivate BoxesCollectionItemPrivate;
typedef struct _BoxesMachinePrivate BoxesMachinePrivate;

#define BOXES_MACHINE_TYPE_CONNECT_FLAGS (boxes_machine_connect_flags_get_type ())
#define _g_free0(var) (var = (g_free (var), NULL))
#define __vala_GVirDomainInfo_free0(var) ((var == NULL) ? NULL : (var = (_vala_GVirDomainInfo_free (var), NULL)))
#define __vala_GVirNodeInfo_free0(var) ((var == NULL) ? NULL : (var = (_vala_GVirNodeInfo_free (var), NULL)))
#define _g_string_free0(var) ((var == NULL) ? NULL : (var = (g_string_free (var, TRUE), NULL)))

#define BOXES_TYPE_DISPLAY (boxes_display_get_type ())
#define BOXES_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY, BoxesDisplay))
#define BOXES_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY, BoxesDisplayClass))
#define BOXES_IS_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY))
#define BOXES_IS_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY))
#define BOXES_DISPLAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY, BoxesDisplayClass))

typedef struct _BoxesDisplay BoxesDisplay;
typedef struct _BoxesDisplayClass BoxesDisplayClass;
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))

#define BOXES_TYPE_EDITABLE_STRING_PROPERTY (boxes_editable_string_property_get_type ())
#define BOXES_EDITABLE_STRING_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_EDITABLE_STRING_PROPERTY, BoxesEditableStringProperty))
#define BOXES_EDITABLE_STRING_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_EDITABLE_STRING_PROPERTY, BoxesEditableStringPropertyClass))
#define BOXES_IS_EDITABLE_STRING_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_EDITABLE_STRING_PROPERTY))
#define BOXES_IS_EDITABLE_STRING_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_EDITABLE_STRING_PROPERTY))
#define BOXES_EDITABLE_STRING_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_EDITABLE_STRING_PROPERTY, BoxesEditableStringPropertyClass))

typedef struct _BoxesEditableStringProperty BoxesEditableStringProperty;
typedef struct _BoxesEditableStringPropertyClass BoxesEditableStringPropertyClass;
typedef struct _Block40Data Block40Data;

#define BOXES_TYPE_STRING_PROPERTY (boxes_string_property_get_type ())
#define BOXES_STRING_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_STRING_PROPERTY, BoxesStringProperty))
#define BOXES_STRING_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_STRING_PROPERTY, BoxesStringPropertyClass))
#define BOXES_IS_STRING_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_STRING_PROPERTY))
#define BOXES_IS_STRING_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_STRING_PROPERTY))
#define BOXES_STRING_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_STRING_PROPERTY, BoxesStringPropertyClass))

typedef struct _BoxesStringProperty BoxesStringProperty;
typedef struct _BoxesStringPropertyClass BoxesStringPropertyClass;
typedef struct _Block41Data Block41Data;
typedef struct _Block42Data Block42Data;

#define BOXES_TYPE_SNAPSHOTS_PROPERTY (boxes_snapshots_property_get_type ())
#define BOXES_SNAPSHOTS_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SNAPSHOTS_PROPERTY, BoxesSnapshotsProperty))
#define BOXES_SNAPSHOTS_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SNAPSHOTS_PROPERTY, BoxesSnapshotsPropertyClass))
#define BOXES_IS_SNAPSHOTS_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SNAPSHOTS_PROPERTY))
#define BOXES_IS_SNAPSHOTS_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SNAPSHOTS_PROPERTY))
#define BOXES_SNAPSHOTS_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SNAPSHOTS_PROPERTY, BoxesSnapshotsPropertyClass))

typedef struct _BoxesSnapshotsProperty BoxesSnapshotsProperty;
typedef struct _BoxesSnapshotsPropertyClass BoxesSnapshotsPropertyClass;

#define BOXES_TYPE_SIZE_PROPERTY (boxes_size_property_get_type ())
#define BOXES_SIZE_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SIZE_PROPERTY, BoxesSizeProperty))
#define BOXES_SIZE_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SIZE_PROPERTY, BoxesSizePropertyClass))
#define BOXES_IS_SIZE_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SIZE_PROPERTY))
#define BOXES_IS_SIZE_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SIZE_PROPERTY))
#define BOXES_SIZE_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SIZE_PROPERTY, BoxesSizePropertyClass))

typedef struct _BoxesSizeProperty BoxesSizeProperty;
typedef struct _BoxesSizePropertyClass BoxesSizePropertyClass;
typedef struct _Block43Data Block43Data;

#define BOXES_TYPE_VM_CREATOR (boxes_vm_creator_get_type ())
#define BOXES_VM_CREATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_VM_CREATOR, BoxesVMCreator))
#define BOXES_VM_CREATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_VM_CREATOR, BoxesVMCreatorClass))
#define BOXES_IS_VM_CREATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_VM_CREATOR))
#define BOXES_IS_VM_CREATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_VM_CREATOR))
#define BOXES_VM_CREATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_VM_CREATOR, BoxesVMCreatorClass))

typedef struct _BoxesVMCreator BoxesVMCreator;
typedef struct _BoxesVMCreatorClass BoxesVMCreatorClass;

#define BOXES_TYPE_INSTALLER_MEDIA (boxes_installer_media_get_type ())
#define BOXES_INSTALLER_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMedia))
#define BOXES_INSTALLER_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMediaClass))
#define BOXES_IS_INSTALLER_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_INSTALLER_MEDIA))
#define BOXES_IS_INSTALLER_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_INSTALLER_MEDIA))
#define BOXES_INSTALLER_MEDIA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMediaClass))

typedef struct _BoxesInstallerMedia BoxesInstallerMedia;
typedef struct _BoxesInstallerMediaClass BoxesInstallerMediaClass;
typedef struct _BoxesInstallerMediaPrivate BoxesInstallerMediaPrivate;

#define BOXES_TYPE_APP_WINDOW (boxes_app_window_get_type ())
#define BOXES_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindow))
#define BOXES_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))
#define BOXES_IS_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP_WINDOW))
#define BOXES_IS_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP_WINDOW))
#define BOXES_APP_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))

typedef struct _BoxesAppWindow BoxesAppWindow;
typedef struct _BoxesAppWindowClass BoxesAppWindowClass;
typedef struct _BoxesAppWindowPrivate BoxesAppWindowPrivate;

#define BOXES_TYPE_WIZARD_WINDOW (boxes_wizard_window_get_type ())
#define BOXES_WIZARD_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD_WINDOW, BoxesWizardWindow))
#define BOXES_WIZARD_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD_WINDOW, BoxesWizardWindowClass))
#define BOXES_IS_WIZARD_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD_WINDOW))
#define BOXES_IS_WIZARD_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD_WINDOW))
#define BOXES_WIZARD_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD_WINDOW, BoxesWizardWindowClass))

typedef struct _BoxesWizardWindow BoxesWizardWindow;
typedef struct _BoxesWizardWindowClass BoxesWizardWindowClass;

#define BOXES_TYPE_PROPERTIES_WINDOW (boxes_properties_window_get_type ())
#define BOXES_PROPERTIES_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES_WINDOW, BoxesPropertiesWindow))
#define BOXES_PROPERTIES_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES_WINDOW, BoxesPropertiesWindowClass))
#define BOXES_IS_PROPERTIES_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES_WINDOW))
#define BOXES_IS_PROPERTIES_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES_WINDOW))
#define BOXES_PROPERTIES_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES_WINDOW, BoxesPropertiesWindowClass))

typedef struct _BoxesPropertiesWindow BoxesPropertiesWindow;
typedef struct _BoxesPropertiesWindowClass BoxesPropertiesWindowClass;

#define BOXES_TYPE_SEARCHBAR (boxes_searchbar_get_type ())
#define BOXES_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbar))
#define BOXES_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))
#define BOXES_IS_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SEARCHBAR))
#define BOXES_IS_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SEARCHBAR))
#define BOXES_SEARCHBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))

typedef struct _BoxesSearchbar BoxesSearchbar;
typedef struct _BoxesSearchbarClass BoxesSearchbarClass;

#define BOXES_TYPE_TOPBAR (boxes_topbar_get_type ())
#define BOXES_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TOPBAR, BoxesTopbar))
#define BOXES_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TOPBAR, BoxesTopbarClass))
#define BOXES_IS_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TOPBAR))
#define BOXES_IS_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TOPBAR))
#define BOXES_TOPBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TOPBAR, BoxesTopbarClass))

typedef struct _BoxesTopbar BoxesTopbar;
typedef struct _BoxesTopbarClass BoxesTopbarClass;

#define BOXES_TYPE_SELECTIONBAR (boxes_selectionbar_get_type ())
#define BOXES_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbar))
#define BOXES_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))
#define BOXES_IS_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SELECTIONBAR))
#define BOXES_IS_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SELECTIONBAR))
#define BOXES_SELECTIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))

typedef struct _BoxesSelectionbar BoxesSelectionbar;
typedef struct _BoxesSelectionbarClass BoxesSelectionbarClass;

#define BOXES_TYPE_DISPLAY_PAGE (boxes_display_page_get_type ())
#define BOXES_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage))
#define BOXES_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))
#define BOXES_IS_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_IS_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_DISPLAY_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))

typedef struct _BoxesDisplayPage BoxesDisplayPage;
typedef struct _BoxesDisplayPageClass BoxesDisplayPageClass;

#define BOXES_TYPE_EMPTY_BOXES (boxes_empty_boxes_get_type ())
#define BOXES_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxes))
#define BOXES_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))
#define BOXES_IS_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_IS_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_EMPTY_BOXES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))

typedef struct _BoxesEmptyBoxes BoxesEmptyBoxes;
typedef struct _BoxesEmptyBoxesClass BoxesEmptyBoxesClass;

#define BOXES_TYPE_COLLECTION_VIEW (boxes_collection_view_get_type ())
#define BOXES_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionView))
#define BOXES_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))
#define BOXES_IS_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_IS_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_COLLECTION_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))

typedef struct _BoxesCollectionView BoxesCollectionView;
typedef struct _BoxesCollectionViewClass BoxesCollectionViewClass;
typedef struct _BoxesLibvirtMachinePropertiesMarkRecommendedResourcesData BoxesLibvirtMachinePropertiesMarkRecommendedResourcesData;

#define BOXES_TYPE_OS_DATABASE (boxes_os_database_get_type ())
#define BOXES_OS_DATABASE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_OS_DATABASE, BoxesOSDatabase))
#define BOXES_OS_DATABASE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_OS_DATABASE, BoxesOSDatabaseClass))
#define BOXES_IS_OS_DATABASE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_OS_DATABASE))
#define BOXES_IS_OS_DATABASE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_OS_DATABASE))
#define BOXES_OS_DATABASE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_OS_DATABASE, BoxesOSDatabaseClass))

typedef struct _BoxesOSDatabase BoxesOSDatabase;
typedef struct _BoxesOSDatabaseClass BoxesOSDatabaseClass;

#define BOXES_TYPE_MEDIA_MANAGER (boxes_media_manager_get_type ())
#define BOXES_MEDIA_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManager))
#define BOXES_MEDIA_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManagerClass))
#define BOXES_IS_MEDIA_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MEDIA_MANAGER))
#define BOXES_IS_MEDIA_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MEDIA_MANAGER))
#define BOXES_MEDIA_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManagerClass))

typedef struct _BoxesMediaManager BoxesMediaManager;
typedef struct _BoxesMediaManagerClass BoxesMediaManagerClass;
typedef struct _BoxesLibvirtMachinePropertiesGetOsForMachineData BoxesLibvirtMachinePropertiesGetOsForMachineData;

#define BOXES_TYPE_RESOURCE_GRAPH (boxes_resource_graph_get_type ())
#define BOXES_RESOURCE_GRAPH(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_RESOURCE_GRAPH, BoxesResourceGraph))
#define BOXES_RESOURCE_GRAPH_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_RESOURCE_GRAPH, BoxesResourceGraphClass))
#define BOXES_IS_RESOURCE_GRAPH(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_RESOURCE_GRAPH))
#define BOXES_IS_RESOURCE_GRAPH_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_RESOURCE_GRAPH))
#define BOXES_RESOURCE_GRAPH_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_RESOURCE_GRAPH, BoxesResourceGraphClass))

typedef struct _BoxesResourceGraph BoxesResourceGraph;
typedef struct _BoxesResourceGraphClass BoxesResourceGraphClass;
typedef struct _Block44Data Block44Data;
typedef struct _BoxesLibvirtMachinePrivate BoxesLibvirtMachinePrivate;
typedef struct _Block45Data Block45Data;
typedef struct _Block46Data Block46Data;
typedef struct _Block47Data Block47Data;
#define __vala_GVirStorageVolInfo_free0(var) ((var == NULL) ? NULL : (var = (_vala_GVirStorageVolInfo_free (var), NULL)))
#define __vala_GVirStoragePoolInfo_free0(var) ((var == NULL) ? NULL : (var = (_vala_GVirStoragePoolInfo_free (var), NULL)))
typedef struct _Block48Data Block48Data;
typedef struct _Block49Data Block49Data;
typedef struct _BoxesLibvirtMachinePropertiesFetchSnapshotsData BoxesLibvirtMachinePropertiesFetchSnapshotsData;
#define _g_date_time_unref0(var) ((var == NULL) ? NULL : (var = (g_date_time_unref (var), NULL)))
typedef struct _BoxesLibvirtMachinePropertiesCreateSnapshotData BoxesLibvirtMachinePropertiesCreateSnapshotData;

typedef enum  {
	BOXES_PROPERTIES_PAGE_GENERAL,
	BOXES_PROPERTIES_PAGE_SYSTEM,
	BOXES_PROPERTIES_PAGE_DEVICES,
	BOXES_PROPERTIES_PAGE_SNAPSHOTS,
	BOXES_PROPERTIES_PAGE_LAST
} BoxesPropertiesPage;

typedef enum  {
	PROPERTY_CREATION_FLAG_NONE = 1 << 0,
	PROPERTY_CREATION_FLAG_NO_USB = 1 << 1
} PropertyCreationFlag;

struct _BoxesIPropertiesProviderIface {
	GTypeInterface parent_iface;
	GList* (*get_properties) (BoxesIPropertiesProvider* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
};

struct _BoxesLibvirtMachineProperties {
	GObject parent_instance;
	BoxesLibvirtMachinePropertiesPrivate * priv;
};

struct _BoxesLibvirtMachinePropertiesClass {
	GObjectClass parent_class;
};

struct _BoxesLibvirtMachinePropertiesPrivate {
	BoxesLibvirtMachine* machine;
};

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUIIface {
	GTypeInterface parent_iface;
	BoxesUIState (*get_previous_ui_state) (BoxesUI* self);
	void (*set_previous_ui_state) (BoxesUI* self, BoxesUIState value);
	BoxesUIState (*get_ui_state) (BoxesUI* self);
	void (*set_ui_state) (BoxesUI* self, BoxesUIState value);
};

struct _BoxesCollectionItem {
	GObject parent_instance;
	BoxesCollectionItemPrivate * priv;
};

struct _BoxesCollectionItemClass {
	GObjectClass parent_class;
	gint (*compare) (BoxesCollectionItem* self, BoxesCollectionItem* other);
};

typedef enum  {
	BOXES_MACHINE_CONNECT_FLAGS_NONE = 0,
	BOXES_MACHINE_CONNECT_FLAGS_IGNORE_SAVED_STATE = 1 << 0
} BoxesMachineConnectFlags;

struct _BoxesMachine {
	BoxesCollectionItem parent_instance;
	BoxesMachinePrivate * priv;
	BoxesCollectionSource* source;
	BoxesBoxConfig* config;
	gboolean stay_on_display;
	gboolean suspend_at_exit;
};

struct _BoxesMachineClass {
	BoxesCollectionItemClass parent_class;
	void (*save_real) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*save_real_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*take_screenshot) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GdkPixbuf* (*take_screenshot_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	GList* (*get_properties) (BoxesMachine* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
	void (*connect_display) (BoxesMachine* self, BoxesMachineConnectFlags flags, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*connect_display_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*restart) (BoxesMachine* self);
	void (*disconnect_display) (BoxesMachine* self);
	void (*delete) (BoxesMachine* self, gboolean by_user);
	gboolean (*get_can_save) (BoxesMachine* self);
	gboolean (*get_should_autosave) (BoxesMachine* self);
};

struct _Block40Data {
	int _ref_count_;
	BoxesLibvirtMachineProperties* self;
	BoxesEditableStringProperty* name_property;
};

struct _Block41Data {
	int _ref_count_;
	BoxesLibvirtMachineProperties* self;
	BoxesProperty* property;
};

struct _Block42Data {
	int _ref_count_;
	BoxesLibvirtMachineProperties* self;
	BoxesProperty* property;
};

struct _Block43Data {
	int _ref_count_;
	BoxesLibvirtMachineProperties* self;
	GtkLabel* label;
	gboolean empty;
	GtkLabel* button_label;
	GVirConfigDomainDisk* disk_config;
};

struct _BoxesInstallerMedia {
	GObject parent_instance;
	BoxesInstallerMediaPrivate * priv;
	OsinfoOs* os;
	OsinfoResources* resources;
	OsinfoMedia* os_media;
	gchar* label;
	gchar* device_file;
	gchar* mount_point;
	gboolean from_image;
};

struct _BoxesInstallerMediaClass {
	GObjectClass parent_class;
	void (*set_direct_boot_params) (BoxesInstallerMedia* self, GVirConfigDomainOs* os);
	void (*prepare) (BoxesInstallerMedia* self, BoxesActivityProgress* progress, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	gboolean (*prepare_finish) (BoxesInstallerMedia* self, GAsyncResult* _res_);
	void (*prepare_for_installation) (BoxesInstallerMedia* self, const gchar* vm_name, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*prepare_for_installation_finish) (BoxesInstallerMedia* self, GAsyncResult* _res_);
	void (*prepare_to_continue_installation) (BoxesInstallerMedia* self, const gchar* vm_name);
	void (*clean_up) (BoxesInstallerMedia* self);
	void (*clean_up_preparation_cache) (BoxesInstallerMedia* self);
	void (*setup_domain_config) (BoxesInstallerMedia* self, GVirConfigDomain* domain);
	void (*setup_post_install_domain_config) (BoxesInstallerMedia* self, GVirConfigDomain* domain);
	void (*populate_setup_box) (BoxesInstallerMedia* self, GtkBox* setup_box);
	GList* (*get_vm_properties) (BoxesInstallerMedia* self);
	BoxesVMCreator* (*get_vm_creator) (BoxesInstallerMedia* self);
	OsinfoDeviceList* (*get_supported_devices) (BoxesInstallerMedia* self);
	guint64 (*get_installed_size) (BoxesInstallerMedia* self);
	gboolean (*get_need_user_input_for_vm_creation) (BoxesInstallerMedia* self);
	gboolean (*get_ready_to_create) (BoxesInstallerMedia* self);
	gboolean (*get_live) (BoxesInstallerMedia* self);
	gchar* (*get_architecture) (BoxesInstallerMedia* self);
};

struct _BoxesAppWindow {
	GtkApplicationWindow parent_instance;
	BoxesAppWindowPrivate * priv;
	BoxesWizardWindow* wizard_window;
	BoxesPropertiesWindow* props_window;
	BoxesSearchbar* searchbar;
	BoxesTopbar* topbar;
	BoxesSelectionbar* selectionbar;
	BoxesDisplayPage* display_page;
	BoxesEmptyBoxes* empty_boxes;
	GtkStack* below_bin;
	BoxesCollectionView* view;
	GSettings* settings;
};

struct _BoxesAppWindowClass {
	GtkApplicationWindowClass parent_class;
};

typedef void (*BoxesPropertiesWindowFileChosenFunc) (const gchar* path, void* user_data);
struct _BoxesLibvirtMachinePropertiesMarkRecommendedResourcesData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesLibvirtMachineProperties* self;
	BoxesSizeProperty* ram_property;
	BoxesSizeProperty* storage_property;
	gboolean _tmp0_;
	BoxesSizeProperty* _tmp1_;
	BoxesSizeProperty* _tmp2_;
	OsinfoOs* os;
	BoxesLibvirtMachine* _tmp3_;
	OsinfoOs* _tmp4_;
	OsinfoOs* _tmp5_;
	gchar* architecture;
	BoxesLibvirtMachine* _tmp6_;
	GVirConfigDomain* _tmp7_;
	GVirConfigDomain* _tmp8_;
	GVirConfigDomainOs* _tmp9_;
	GVirConfigDomainOs* _tmp10_;
	const gchar* _tmp11_;
	gchar* _tmp12_;
	gchar* _tmp13_;
	OsinfoResources* resources;
	OsinfoOs* _tmp14_;
	const gchar* _tmp15_;
	OsinfoResources* _tmp16_;
	OsinfoResources* _tmp17_;
	BoxesSizeProperty* _tmp18_;
	BoxesSizeProperty* _tmp19_;
	OsinfoResources* _tmp20_;
	gint64 _tmp21_;
	gint64 _tmp22_;
	BoxesSizeProperty* _tmp23_;
	BoxesSizeProperty* _tmp24_;
	OsinfoResources* _tmp25_;
	gint64 _tmp26_;
	gint64 _tmp27_;
};

typedef enum  {
	BOXES_OS_DATABASE_ERROR_NON_BOOTABLE,
	BOXES_OS_DATABASE_ERROR_DB_LOADING_FAILED,
	BOXES_OS_DATABASE_ERROR_UNKNOWN_OS_ID,
	BOXES_OS_DATABASE_ERROR_UNKNOWN_MEDIA_ID
} BoxesOSDatabaseError;
#define BOXES_OS_DATABASE_ERROR boxes_os_database_error_quark ()
struct _BoxesLibvirtMachinePropertiesGetOsForMachineData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesLibvirtMachineProperties* self;
	BoxesLibvirtMachine* machine;
	OsinfoOs* result;
	gchar* os_id;
	BoxesLibvirtMachine* _tmp0_;
	GVirConfigDomain* _tmp1_;
	GVirConfigDomain* _tmp2_;
	gchar* _tmp3_;
	const gchar* _tmp4_;
	BoxesOSDatabase* os_db;
	BoxesMediaManager* _tmp5_;
	BoxesMediaManager* _tmp6_;
	BoxesOSDatabase* _tmp7_;
	BoxesOSDatabase* _tmp8_;
	BoxesOSDatabase* _tmp9_;
	BoxesOSDatabase* _tmp10_;
	OsinfoOs* _tmp11_;
	BoxesOSDatabase* _tmp12_;
	const gchar* _tmp13_;
	OsinfoOs* _tmp14_;
	OsinfoOs* _tmp15_;
	GError* _error_;
	const gchar* _tmp16_;
	GError* _tmp17_;
	const gchar* _tmp18_;
	GError * _inner_error_;
};

struct _Block44Data {
	int _ref_count_;
	BoxesLibvirtMachineProperties* self;
	BoxesResourceGraph* cpu_graph;
	BoxesResourceGraph* io_graph;
	BoxesResourceGraph* net_graph;
	gulong stats_id;
	BoxesProperty* prop;
	gulong flushed_id;
};

struct _BoxesLibvirtMachine {
	BoxesMachine parent_instance;
	BoxesLibvirtMachinePrivate * priv;
	BoxesLibvirtMachineProperties* properties;
	gdouble* cpu_stats;
	gint cpu_stats_length1;
	gint _cpu_stats_size_;
	gdouble* io_stats;
	gint io_stats_length1;
	gint _io_stats_size_;
	gdouble* net_stats;
	gint net_stats_length1;
	gint _net_stats_size_;
};

struct _BoxesLibvirtMachineClass {
	BoxesMachineClass parent_class;
};

struct _Block45Data {
	int _ref_count_;
	BoxesLibvirtMachineProperties* self;
	GtkButton* restart_button;
	GtkButton* shutdown_button;
	gulong state_notify_id;
	BoxesProperty* prop;
	gulong flushed_id;
};

struct _Block46Data {
	int _ref_count_;
	BoxesLibvirtMachineProperties* self;
	BoxesSizeProperty* property;
};

struct _Block47Data {
	int _ref_count_;
	BoxesLibvirtMachineProperties* self;
	BoxesProperty* property;
	guint64 value;
};

struct _Block48Data {
	int _ref_count_;
	BoxesLibvirtMachineProperties* self;
	guint64 value;
};

struct _Block49Data {
	int _ref_count_;
	Block48Data * _data48_;
	guint64 size;
	GVirStoragePool* pool;
};

struct _BoxesLibvirtMachinePropertiesFetchSnapshotsData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesLibvirtMachineProperties* self;
	GCancellable* cancellable;
	BoxesLibvirtMachine* _tmp0_;
	GVirDomain* _tmp1_;
	GVirDomain* _tmp2_;
	GCancellable* _tmp3_;
	GError * _inner_error_;
};

struct _BoxesLibvirtMachinePropertiesCreateSnapshotData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesLibvirtMachineProperties* self;
	GVirDomainSnapshot* result;
	GVirConfigDomainSnapshot* config;
	GVirConfigDomainSnapshot* _tmp0_;
	GDateTime* now;
	GDateTime* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	GVirDomainSnapshot* _tmp6_;
	BoxesLibvirtMachine* _tmp7_;
	GVirDomain* _tmp8_;
	GVirDomain* _tmp9_;
	GVirDomainSnapshot* _tmp10_;
	GVirDomainSnapshot* _tmp11_;
	GError * _inner_error_;
};


static gpointer boxes_libvirt_machine_properties_parent_class = NULL;
static BoxesIPropertiesProviderIface* boxes_libvirt_machine_properties_boxes_iproperties_provider_parent_iface = NULL;

GType boxes_properties_page_get_type (void) G_GNUC_CONST;
GType property_creation_flag_get_type (void) G_GNUC_CONST;
GType boxes_property_get_type (void) G_GNUC_CONST;
GType boxes_iproperties_provider_get_type (void) G_GNUC_CONST;
GType boxes_libvirt_machine_properties_get_type (void) G_GNUC_CONST;
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_machine_get_type (void) G_GNUC_CONST;
GType boxes_libvirt_machine_get_type (void) G_GNUC_CONST;
#define BOXES_LIBVIRT_MACHINE_PROPERTIES_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES, BoxesLibvirtMachinePropertiesPrivate))
enum  {
	BOXES_LIBVIRT_MACHINE_PROPERTIES_DUMMY_PROPERTY
};
#define BOXES_LIBVIRT_MACHINE_PROPERTIES_MEGABYTES ((guint64) (1000 * 1000))
BoxesLibvirtMachineProperties* boxes_libvirt_machine_properties_new (BoxesLibvirtMachine* machine);
BoxesLibvirtMachineProperties* boxes_libvirt_machine_properties_construct (GType object_type, BoxesLibvirtMachine* machine);
static void __lambda11_ (BoxesLibvirtMachineProperties* self);
static gboolean boxes_libvirt_machine_properties_save_machine_name_change (BoxesLibvirtMachineProperties* self);
static void ___lambda11__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
GVirDomain* boxes_libvirt_machine_get_domain (BoxesLibvirtMachine* self);
const gchar* boxes_collection_item_get_name (BoxesCollectionItem* self);
static void boxes_libvirt_machine_properties_try_enable_usb_redir (BoxesLibvirtMachineProperties* self, GError** error);
void boxes_vm_configurator_remove_usb_controllers (GVirConfigDomain* domain, GError** error);
void boxes_vm_configurator_add_usb_support (GVirConfigDomain* domain);
static void boxes_libvirt_machine_properties_try_enable_smartcard (BoxesLibvirtMachineProperties* self, GError** error);
void boxes_vm_configurator_add_smartcard_support (GVirConfigDomain* domain);
static gchar* boxes_libvirt_machine_properties_collect_logs (BoxesLibvirtMachineProperties* self);
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_machine_connect_flags_get_type (void) G_GNUC_CONST;
GVirConnection* boxes_libvirt_machine_get_connection (BoxesLibvirtMachine* self);
static void _vala_GVirDomainInfo_free (GVirDomainInfo* self);
static void _vala_GVirNodeInfo_free (GVirNodeInfo* self);
const gchar* gvir_domain_state_to_string (GVirDomainState self);
GType boxes_display_get_type (void) G_GNUC_CONST;
BoxesDisplay* boxes_machine_get_display (BoxesMachine* self);
void boxes_display_collect_logs (BoxesDisplay* self, GString* builder);
static GList* boxes_libvirt_machine_properties_real_get_properties (BoxesIPropertiesProvider* base, BoxesPropertiesPage page, PropertyCreationFlag* flags);
gboolean boxes_machine_is_on (BoxesMachine* self);
gboolean boxes_libvirt_machine_update_display (BoxesLibvirtMachine* self, GError** error);
static void _g_object_unref0_ (gpointer var);
static void _g_list_free__g_object_unref0_ (GList* self);
GType boxes_editable_string_property_get_type (void) G_GNUC_CONST;
static Block40Data* block40_data_ref (Block40Data* _data40_);
static void block40_data_unref (void * _userdata_);
BoxesEditableStringProperty* boxes_iproperties_provider_add_editable_string_property (BoxesIPropertiesProvider* self, GList** list, const gchar* name, const gchar* value);
static void ___lambda134_ (BoxesLibvirtMachineProperties* self, BoxesEditableStringProperty* property, const gchar* name);
void boxes_collection_item_set_name (BoxesCollectionItem* self, const gchar* value);
static void ____lambda134__boxes_editable_string_property_changed (BoxesEditableStringProperty* _sender, const gchar* value, gpointer self);
static void ___lambda135_ (Block40Data* _data40_);
void boxes_editable_string_property_set_text (BoxesEditableStringProperty* self, const gchar* value);
static void ____lambda135__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
GType boxes_string_property_get_type (void) G_GNUC_CONST;
BoxesStringProperty* boxes_iproperties_provider_add_string_property (BoxesIPropertiesProvider* self, GList** list, const gchar* name, const gchar* value);
const gchar* boxes_display_get_protocol (BoxesDisplay* self);
gchar* boxes_display_get_uri (BoxesDisplay* self);
static void boxes_libvirt_machine_properties_add_resource_usage_graphs (BoxesLibvirtMachineProperties* self, GList** list);
static void boxes_libvirt_machine_properties_add_system_props_buttons (BoxesLibvirtMachineProperties* self, GList** list);
void boxes_libvirt_machine_properties_get_resources_properties (BoxesLibvirtMachineProperties* self, GList** list);
GVirConfigDomain* boxes_libvirt_machine_get_domain_config (BoxesLibvirtMachine* self);
static void boxes_libvirt_machine_properties_add_cdrom_property (BoxesLibvirtMachineProperties* self, GVirConfigDomainDisk* disk_config, GList** list);
static Block41Data* block41_data_ref (Block41Data* _data41_);
static void block41_data_unref (void * _userdata_);
BoxesProperty* boxes_iproperties_provider_add_property (BoxesIPropertiesProvider* self, GList** list, const gchar* name, GtkWidget* widget, GtkWidget* extra_widget);
static void ____lambda154_ (Block41Data* _data41_);
void boxes_libvirt_machine_update_domain_config (BoxesLibvirtMachine* self);
void boxes_property_set_reboot_required (BoxesProperty* self, gboolean value);
static void _____lambda154__gtk_button_clicked (GtkButton* _sender, gpointer self);
static Block42Data* block42_data_ref (Block42Data* _data42_);
static void block42_data_unref (void * _userdata_);
static void ____lambda155_ (Block42Data* _data42_);
static void _____lambda155__gtk_button_clicked (GtkButton* _sender, gpointer self);
gboolean boxes_vm_configurator_is_install_config (GVirConfigDomain* domain);
GType boxes_snapshots_property_get_type (void) G_GNUC_CONST;
static BoxesSnapshotsProperty* boxes_libvirt_machine_properties_add_snapshots_property (BoxesLibvirtMachineProperties* self, GList** list, BoxesLibvirtMachine* machine);
GType boxes_size_property_get_type (void) G_GNUC_CONST;
static BoxesSizeProperty* boxes_libvirt_machine_properties_add_ram_property (BoxesLibvirtMachineProperties* self, GList** list);
static BoxesSizeProperty* boxes_libvirt_machine_properties_add_storage_property (BoxesLibvirtMachineProperties* self, GList** list);
static void boxes_libvirt_machine_properties_mark_recommended_resources (BoxesLibvirtMachineProperties* self, BoxesSizeProperty* ram_property, BoxesSizeProperty* storage_property, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_libvirt_machine_properties_mark_recommended_resources_finish (BoxesLibvirtMachineProperties* self, GAsyncResult* _res_);
static Block43Data* block43_data_ref (Block43Data* _data43_);
static void block43_data_unref (void * _userdata_);
gpointer boxes_vm_creator_ref (gpointer instance);
void boxes_vm_creator_unref (gpointer instance);
GParamSpec* boxes_param_spec_vm_creator (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void boxes_value_set_vm_creator (GValue* value, gpointer v_object);
void boxes_value_take_vm_creator (GValue* value, gpointer v_object);
gpointer boxes_value_get_vm_creator (const GValue* value);
GType boxes_vm_creator_get_type (void) G_GNUC_CONST;
BoxesVMCreator* boxes_libvirt_machine_get_vm_creator (BoxesLibvirtMachine* self);
GType boxes_installer_media_get_type (void) G_GNUC_CONST;
BoxesInstallerMedia* boxes_vm_creator_get_install_media (BoxesVMCreator* self);
gboolean boxes_vm_creator_get_express_install (BoxesVMCreator* self);
static void __lambda152_ (Block43Data* _data43_);
GType boxes_app_window_get_type (void) G_GNUC_CONST;
BoxesAppWindow* boxes_machine_get_window (BoxesMachine* self);
GType boxes_wizard_window_get_type (void) G_GNUC_CONST;
GType boxes_properties_window_get_type (void) G_GNUC_CONST;
GType boxes_searchbar_get_type (void) G_GNUC_CONST;
GType boxes_topbar_get_type (void) G_GNUC_CONST;
GType boxes_selectionbar_get_type (void) G_GNUC_CONST;
GType boxes_display_page_get_type (void) G_GNUC_CONST;
GType boxes_empty_boxes_get_type (void) G_GNUC_CONST;
GType boxes_collection_view_get_type (void) G_GNUC_CONST;
void boxes_properties_window_show_file_chooser (BoxesPropertiesWindow* self, BoxesPropertiesWindowFileChosenFunc file_chosen_func, void* file_chosen_func_target, GDestroyNotify file_chosen_func_target_destroy_notify);
static void ___lambda153_ (Block43Data* _data43_, const gchar* path);
static void ____lambda153__boxes_properties_window_file_chosen_func (const gchar* path, gpointer self);
static void ___lambda152__gtk_button_clicked (GtkButton* _sender, gpointer self);
void boxes_property_set_description_alignment (BoxesProperty* self, GtkAlign value);
static void boxes_libvirt_machine_properties_update_ram_property (BoxesLibvirtMachineProperties* self, BoxesProperty* property);
static void boxes_libvirt_machine_properties_mark_recommended_resources_data_free (gpointer _data);
static gboolean boxes_libvirt_machine_properties_mark_recommended_resources_co (BoxesLibvirtMachinePropertiesMarkRecommendedResourcesData* _data_);
static void boxes_libvirt_machine_properties_get_os_for_machine (BoxesLibvirtMachineProperties* self, BoxesLibvirtMachine* machine, GAsyncReadyCallback _callback_, gpointer _user_data_);
static OsinfoOs* boxes_libvirt_machine_properties_get_os_for_machine_finish (BoxesLibvirtMachineProperties* self, GAsyncResult* _res_);
static void boxes_libvirt_machine_properties_mark_recommended_resources_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
OsinfoResources* boxes_os_database_get_recommended_resources_for_os (OsinfoOs* os, const gchar* architecture);
void boxes_size_property_set_recommended (BoxesSizeProperty* self, guint64 value);
static void boxes_libvirt_machine_properties_get_os_for_machine_data_free (gpointer _data);
static gboolean boxes_libvirt_machine_properties_get_os_for_machine_co (BoxesLibvirtMachinePropertiesGetOsForMachineData* _data_);
gchar* boxes_vm_configurator_get_os_id (GVirConfigDomain* domain);
GType boxes_os_database_get_type (void) G_GNUC_CONST;
GType boxes_media_manager_get_type (void) G_GNUC_CONST;
BoxesMediaManager* boxes_media_manager_get_instance (void);
BoxesOSDatabase* boxes_media_manager_get_os_db (BoxesMediaManager* self);
void boxes_os_database_get_os_by_id (BoxesOSDatabase* self, const gchar* id, GAsyncReadyCallback _callback_, gpointer _user_data_);
GQuark boxes_os_database_error_quark (void);
OsinfoOs* boxes_os_database_get_os_by_id_finish (BoxesOSDatabase* self, GAsyncResult* _res_, GError** error);
static void boxes_libvirt_machine_properties_get_os_for_machine_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
GType boxes_resource_graph_get_type (void) G_GNUC_CONST;
static Block44Data* block44_data_ref (Block44Data* _data44_);
static void block44_data_unref (void * _userdata_);
BoxesResourceGraph* boxes_resource_graph_new (gdouble ymax);
BoxesResourceGraph* boxes_resource_graph_construct (GType object_type, gdouble ymax);
void boxes_resource_graph_set_npoints (BoxesResourceGraph* self, gint value);
static void __lambda136_ (Block44Data* _data44_);
void boxes_resource_graph_set_points (BoxesResourceGraph* self, gdouble* value, int value_length1);
static void ___lambda136__boxes_libvirt_machine_stats_updated (BoxesLibvirtMachine* _sender, gpointer self);
static void __lambda137_ (Block44Data* _data44_);
static void ___lambda137__boxes_property_flushed (BoxesProperty* _sender, gpointer self);
static Block45Data* block45_data_ref (Block45Data* _data45_);
static void block45_data_unref (void * _userdata_);
static void __lambda138_ (BoxesLibvirtMachineProperties* self);
void boxes_machine_restart (BoxesMachine* self);
void boxes_properties_window_revert_state (BoxesPropertiesWindow* self);
static void ___lambda138__gtk_button_clicked (GtkButton* _sender, gpointer self);
gboolean boxes_machine_is_running (BoxesMachine* self);
static void __lambda144_ (BoxesLibvirtMachineProperties* self);
void boxes_libvirt_machine_force_shutdown (BoxesLibvirtMachine* self);
static void ___lambda144__gtk_button_clicked (GtkButton* _sender, gpointer self);
static void __lambda145_ (Block45Data* _data45_);
static void ___lambda145__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void __lambda146_ (BoxesLibvirtMachineProperties* self);
void boxes_properties_window_show_troubleshoot_log (BoxesPropertiesWindow* self, const gchar* log);
static void ___lambda146__gtk_button_clicked (GtkButton* _sender, gpointer self);
static void __lambda147_ (Block45Data* _data45_);
static void ___lambda147__boxes_property_flushed (BoxesProperty* _sender, gpointer self);
static Block46Data* block46_data_ref (Block46Data* _data46_);
static void block46_data_unref (void * _userdata_);
BoxesSizeProperty* boxes_iproperties_provider_add_size_property (BoxesIPropertiesProvider* self, GList** list, const gchar* name, guint64 size, guint64 min, guint64 max, guint64 allocation, guint64 step, GFormatSizeFlags format_flags);
GtkWidget* boxes_property_get_widget (BoxesProperty* self);
gboolean boxes_vm_configurator_is_live_config (GVirConfigDomain* domain);
BoxesUIState boxes_ui_get_ui_state (BoxesUI* self);
void boxes_property_set_sensitive (BoxesProperty* self, gboolean value);
static void boxes_libvirt_machine_properties_on_ram_changed (BoxesLibvirtMachineProperties* self, BoxesProperty* property, guint64 value);
static void _boxes_libvirt_machine_properties_on_ram_changed_boxes_size_property_changed (BoxesSizeProperty* _sender, guint64 value, gpointer self);
static void ___lambda149_ (Block46Data* _data46_);
static void ____lambda149__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static Block47Data* block47_data_ref (Block47Data* _data47_);
static void block47_data_unref (void * _userdata_);
static gboolean __lambda148_ (Block47Data* _data47_);
static gboolean ___lambda148__gsource_func (gpointer self);
void boxes_property_set_deferred_change (BoxesProperty* self, GSourceFunc value, gpointer value_target, GDestroyNotify value_target_destroy_notify);
gboolean boxes_libvirt_machine_get_importing (BoxesLibvirtMachine* self);
GVirStorageVol* boxes_libvirt_machine_get_storage_volume (BoxesLibvirtMachine* self);
GVirStoragePool* boxes_get_storage_pool (GVirConnection* connection);
static void _vala_GVirStorageVolInfo_free (GVirStorageVolInfo* self);
static guint64 boxes_libvirt_machine_properties_get_minimum_disk_size (BoxesLibvirtMachineProperties* self, GError** error);
static void _vala_GVirStoragePoolInfo_free (GVirStoragePoolInfo* self);
void boxes_property_set_defer_interval (BoxesProperty* self, guint value);
static void boxes_libvirt_machine_properties_on_storage_changed (BoxesLibvirtMachineProperties* self, BoxesProperty* property, guint64 value);
static void _boxes_libvirt_machine_properties_on_storage_changed_boxes_size_property_changed (BoxesSizeProperty* _sender, guint64 value, gpointer self);
static Block48Data* block48_data_ref (Block48Data* _data48_);
static void block48_data_unref (void * _userdata_);
static gboolean __lambda150_ (Block48Data* _data48_);
GVirDomainDisk* boxes_libvirt_machine_get_domain_disk (BoxesLibvirtMachine* self, GError** error);
static Block49Data* block49_data_ref (Block49Data* _data49_);
static void block49_data_unref (void * _userdata_);
static void _____lambda151_ (Block49Data* _data49_, GObject* obj, GAsyncResult* res);
static void ______lambda151__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void boxes_libvirt_machine_properties_resize_storage_volume (BoxesLibvirtMachineProperties* self, guint64 size, GError** error);
static gboolean ___lambda150__gsource_func (gpointer self);
OsinfoResources* boxes_os_database_get_minimum_resources_for_os (OsinfoOs* os, const gchar* architecture);
OsinfoResources* boxes_os_database_get_default_resources (void);
void boxes_libvirt_machine_set_storage_volume (BoxesLibvirtMachine* self, GVirStorageVol* value);
static void boxes_libvirt_machine_properties_fetch_snapshots_data_free (gpointer _data);
void boxes_libvirt_machine_properties_fetch_snapshots (BoxesLibvirtMachineProperties* self, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_libvirt_machine_properties_fetch_snapshots_finish (BoxesLibvirtMachineProperties* self, GAsyncResult* _res_, GError** error);
static gboolean boxes_libvirt_machine_properties_fetch_snapshots_co (BoxesLibvirtMachinePropertiesFetchSnapshotsData* _data_);
static void boxes_libvirt_machine_properties_fetch_snapshots_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
GList* boxes_libvirt_machine_properties_get_snapshots (BoxesLibvirtMachineProperties* self);
static void boxes_libvirt_machine_properties_create_snapshot_data_free (gpointer _data);
void boxes_libvirt_machine_properties_create_snapshot (BoxesLibvirtMachineProperties* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
GVirDomainSnapshot* boxes_libvirt_machine_properties_create_snapshot_finish (BoxesLibvirtMachineProperties* self, GAsyncResult* _res_, GError** error);
static gboolean boxes_libvirt_machine_properties_create_snapshot_co (BoxesLibvirtMachinePropertiesCreateSnapshotData* _data_);
static void boxes_libvirt_machine_properties_create_snapshot_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
BoxesSnapshotsProperty* boxes_snapshots_property_new (BoxesLibvirtMachine* machine);
BoxesSnapshotsProperty* boxes_snapshots_property_construct (GType object_type, BoxesLibvirtMachine* machine);
static void boxes_libvirt_machine_properties_finalize (GObject* obj);


static void __lambda11_ (BoxesLibvirtMachineProperties* self) {
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_properties_save_machine_name_change (self);
#line 892 "libvirt-machine-properties.c"
}


static void ___lambda11__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	__lambda11_ ((BoxesLibvirtMachineProperties*) self);
#line 899 "libvirt-machine-properties.c"
}


BoxesLibvirtMachineProperties* boxes_libvirt_machine_properties_construct (GType object_type, BoxesLibvirtMachine* machine) {
	BoxesLibvirtMachineProperties * self = NULL;
	BoxesLibvirtMachine* _tmp0_ = NULL;
	BoxesLibvirtMachine* _tmp1_ = NULL;
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_val_if_fail (machine != NULL, NULL);
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self = (BoxesLibvirtMachineProperties*) g_object_new (object_type, NULL);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = machine;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self->priv->machine = _tmp0_;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = machine;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_signal_connect_object ((GObject*) _tmp1_, "notify::name", (GCallback) ___lambda11__g_object_notify, self, 0);
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return self;
#line 921 "libvirt-machine-properties.c"
}


BoxesLibvirtMachineProperties* boxes_libvirt_machine_properties_new (BoxesLibvirtMachine* machine) {
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return boxes_libvirt_machine_properties_construct (BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES, machine);
#line 928 "libvirt-machine-properties.c"
}


static gboolean boxes_libvirt_machine_properties_save_machine_name_change (BoxesLibvirtMachineProperties* self) {
	gboolean result = FALSE;
	GError * _inner_error_ = NULL;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 937 "libvirt-machine-properties.c"
	{
		GVirConfigDomain* config = NULL;
		BoxesLibvirtMachine* _tmp0_ = NULL;
		GVirDomain* _tmp1_ = NULL;
		GVirDomain* _tmp2_ = NULL;
		GVirConfigDomain* _tmp3_ = NULL;
		GVirConfigDomain* _tmp4_ = NULL;
		BoxesLibvirtMachine* _tmp5_ = NULL;
		const gchar* _tmp6_ = NULL;
		const gchar* _tmp7_ = NULL;
		BoxesLibvirtMachine* _tmp8_ = NULL;
		GVirDomain* _tmp9_ = NULL;
		GVirDomain* _tmp10_ = NULL;
		GVirConfigDomain* _tmp11_ = NULL;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp0_ = self->priv->machine;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp1_ = boxes_libvirt_machine_get_domain (_tmp0_);
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp2_ = _tmp1_;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp3_ = gvir_domain_get_config (_tmp2_, (guint) GVIR_DOMAIN_XML_INACTIVE, &_inner_error_);
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		config = _tmp3_;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 964 "libvirt-machine-properties.c"
			goto __catch31_g_error;
		}
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp4_ = config;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp5_ = self->priv->machine;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp6_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp5_);
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp7_ = _tmp6_;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gvir_config_domain_set_title (_tmp4_, _tmp7_);
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp8_ = self->priv->machine;
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp9_ = boxes_libvirt_machine_get_domain (_tmp8_);
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp10_ = _tmp9_;
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp11_ = config;
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gvir_domain_set_config (_tmp10_, _tmp11_, &_inner_error_);
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (config);
#line 991 "libvirt-machine-properties.c"
			goto __catch31_g_error;
		}
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		result = TRUE;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (config);
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return result;
#line 1000 "libvirt-machine-properties.c"
	}
	goto __finally31;
	__catch31_g_error:
	{
		GError* _error_ = NULL;
		BoxesLibvirtMachine* _tmp12_ = NULL;
		GVirDomain* _tmp13_ = NULL;
		GVirDomain* _tmp14_ = NULL;
		const gchar* _tmp15_ = NULL;
		BoxesLibvirtMachine* _tmp16_ = NULL;
		const gchar* _tmp17_ = NULL;
		const gchar* _tmp18_ = NULL;
		GError* _tmp19_ = NULL;
		const gchar* _tmp20_ = NULL;
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_error_ = _inner_error_;
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_inner_error_ = NULL;
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp12_ = self->priv->machine;
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp13_ = boxes_libvirt_machine_get_domain (_tmp12_);
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp14_ = _tmp13_;
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp15_ = gvir_domain_get_name (_tmp14_);
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp16_ = self->priv->machine;
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp17_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp16_);
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp18_ = _tmp17_;
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp19_ = _error_;
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp20_ = _tmp19_->message;
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_warning ("libvirt-machine-properties.vala:28: Failed to save change of title of " \
"box from '%s' to '%s': %s", _tmp15_, _tmp18_, _tmp20_);
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		result = FALSE;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (_error_);
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return result;
#line 1045 "libvirt-machine-properties.c"
	}
	__finally31:
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_clear_error (&_inner_error_);
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return FALSE;
#line 1054 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_try_enable_usb_redir (BoxesLibvirtMachineProperties* self, GError** error) {
	GVirConfigDomain* config = NULL;
	BoxesLibvirtMachine* _tmp0_ = NULL;
	GVirDomain* _tmp1_ = NULL;
	GVirDomain* _tmp2_ = NULL;
	GVirConfigDomain* _tmp3_ = NULL;
	GVirConfigDomain* _tmp4_ = NULL;
	GVirConfigDomain* _tmp5_ = NULL;
	BoxesLibvirtMachine* _tmp6_ = NULL;
	GVirDomain* _tmp7_ = NULL;
	GVirDomain* _tmp8_ = NULL;
	GVirConfigDomain* _tmp9_ = NULL;
	GError * _inner_error_ = NULL;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (self != NULL);
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = self->priv->machine;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = boxes_libvirt_machine_get_domain (_tmp0_);
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = _tmp1_;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = gvir_domain_get_config (_tmp2_, (guint) GVIR_DOMAIN_XML_INACTIVE, &_inner_error_);
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	config = _tmp3_;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_propagate_error (error, _inner_error_);
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return;
#line 1089 "libvirt-machine-properties.c"
	}
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp4_ = config;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_vm_configurator_remove_usb_controllers (_tmp4_, &_inner_error_);
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_propagate_error (error, _inner_error_);
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (config);
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return;
#line 1103 "libvirt-machine-properties.c"
	}
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp5_ = config;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_vm_configurator_add_usb_support (_tmp5_);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp6_ = self->priv->machine;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp7_ = boxes_libvirt_machine_get_domain (_tmp6_);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp8_ = _tmp7_;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp9_ = config;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gvir_domain_set_config (_tmp8_, _tmp9_, &_inner_error_);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_propagate_error (error, _inner_error_);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (config);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return;
#line 1127 "libvirt-machine-properties.c"
	}
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (config);
#line 1131 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_try_enable_smartcard (BoxesLibvirtMachineProperties* self, GError** error) {
	GVirConfigDomain* config = NULL;
	BoxesLibvirtMachine* _tmp0_ = NULL;
	GVirDomain* _tmp1_ = NULL;
	GVirDomain* _tmp2_ = NULL;
	GVirConfigDomain* _tmp3_ = NULL;
	GVirConfigDomain* _tmp4_ = NULL;
	BoxesLibvirtMachine* _tmp5_ = NULL;
	GVirDomain* _tmp6_ = NULL;
	GVirDomain* _tmp7_ = NULL;
	GVirConfigDomain* _tmp8_ = NULL;
	GError * _inner_error_ = NULL;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (self != NULL);
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = self->priv->machine;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = boxes_libvirt_machine_get_domain (_tmp0_);
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = _tmp1_;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = gvir_domain_get_config (_tmp2_, (guint) GVIR_DOMAIN_XML_INACTIVE, &_inner_error_);
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	config = _tmp3_;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_propagate_error (error, _inner_error_);
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return;
#line 1165 "libvirt-machine-properties.c"
	}
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp4_ = config;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_vm_configurator_add_smartcard_support (_tmp4_);
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp5_ = self->priv->machine;
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp6_ = boxes_libvirt_machine_get_domain (_tmp5_);
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp7_ = _tmp6_;
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp8_ = config;
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gvir_domain_set_config (_tmp7_, _tmp8_, &_inner_error_);
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_propagate_error (error, _inner_error_);
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (config);
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return;
#line 1189 "libvirt-machine-properties.c"
	}
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (config);
#line 1193 "libvirt-machine-properties.c"
}


static void _vala_GVirDomainInfo_free (GVirDomainInfo* self) {
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_boxed_free (gvir_domain_info_get_type (), self);
#line 1200 "libvirt-machine-properties.c"
}


static void _vala_GVirNodeInfo_free (GVirNodeInfo* self) {
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_boxed_free (gvir_node_info_get_type (), self);
#line 1207 "libvirt-machine-properties.c"
}


static gchar* boxes_libvirt_machine_properties_collect_logs (BoxesLibvirtMachineProperties* self) {
	gchar* result = NULL;
	GString* builder = NULL;
	GString* _tmp0_ = NULL;
	GString* _tmp1_ = NULL;
	BoxesLibvirtMachine* _tmp2_ = NULL;
	BoxesCollectionSource* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	GString* _tmp7_ = NULL;
	BoxesLibvirtMachine* _tmp8_ = NULL;
	GVirDomain* _tmp9_ = NULL;
	GVirDomain* _tmp10_ = NULL;
	const gchar* _tmp11_ = NULL;
	GString* _tmp12_ = NULL;
	BoxesLibvirtMachine* _tmp13_ = NULL;
	GVirDomain* _tmp14_ = NULL;
	GVirDomain* _tmp15_ = NULL;
	const gchar* _tmp16_ = NULL;
	const gchar* _tmp17_ = NULL;
	BoxesLibvirtMachine* _tmp18_ = NULL;
	GVirDomain* _tmp19_ = NULL;
	GVirDomain* _tmp20_ = NULL;
	gboolean _tmp21_ = FALSE;
	GString* _tmp22_ = NULL;
	BoxesLibvirtMachine* _tmp49_ = NULL;
	BoxesDisplay* _tmp50_ = NULL;
	BoxesDisplay* _tmp51_ = NULL;
	GString* _tmp80_ = NULL;
	const gchar* _tmp81_ = NULL;
	gchar* _tmp82_ = NULL;
	GError * _inner_error_ = NULL;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = g_string_new ("");
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	builder = _tmp0_;
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = builder;
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = self->priv->machine;
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = ((BoxesMachine*) _tmp2_)->source;
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp4_ = boxes_collection_source_get_uri (_tmp3_);
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp5_ = _tmp4_;
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp6_ = _tmp5_;
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_string_append_printf (_tmp1_, "Broker URL: %s\n", _tmp6_);
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_free0 (_tmp6_);
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp7_ = builder;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp8_ = self->priv->machine;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp9_ = boxes_libvirt_machine_get_domain (_tmp8_);
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp10_ = _tmp9_;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp11_ = gvir_domain_get_name (_tmp10_);
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_string_append_printf (_tmp7_, "Domain: %s\n", _tmp11_);
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp12_ = builder;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp13_ = self->priv->machine;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp14_ = boxes_libvirt_machine_get_domain (_tmp13_);
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp15_ = _tmp14_;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp16_ = gvir_domain_get_uuid (_tmp15_);
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_string_append_printf (_tmp12_, "UUID: %s\n", _tmp16_);
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp18_ = self->priv->machine;
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp19_ = boxes_libvirt_machine_get_domain (_tmp18_);
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp20_ = _tmp19_;
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp21_ = gvir_domain_get_persistent (_tmp20_);
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp21_) {
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp17_ = "yes";
#line 1302 "libvirt-machine-properties.c"
	} else {
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp17_ = "no";
#line 1306 "libvirt-machine-properties.c"
	}
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp22_ = builder;
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_string_append_printf (_tmp22_, "Persistent: %s\n", _tmp17_);
#line 1312 "libvirt-machine-properties.c"
	{
		GVirDomainInfo* info = NULL;
		BoxesLibvirtMachine* _tmp23_ = NULL;
		GVirDomain* _tmp24_ = NULL;
		GVirDomain* _tmp25_ = NULL;
		GVirDomainInfo* _tmp26_ = NULL;
		GString* _tmp27_ = NULL;
		GVirDomainInfo* _tmp28_ = NULL;
		guint64 _tmp29_ = 0ULL;
		GString* _tmp30_ = NULL;
		GVirDomainInfo* _tmp31_ = NULL;
		guint64 _tmp32_ = 0ULL;
		GVirNodeInfo* _tmp33_ = NULL;
		BoxesLibvirtMachine* _tmp34_ = NULL;
		GVirConnection* _tmp35_ = NULL;
		GVirConnection* _tmp36_ = NULL;
		GVirNodeInfo* _tmp37_ = NULL;
		GString* _tmp38_ = NULL;
		GVirNodeInfo* _tmp39_ = NULL;
		GVirNodeInfo* _tmp40_ = NULL;
		gulong _tmp41_ = 0UL;
		GString* _tmp42_ = NULL;
		GVirDomainInfo* _tmp43_ = NULL;
		guint16 _tmp44_ = 0U;
		GString* _tmp45_ = NULL;
		GVirDomainInfo* _tmp46_ = NULL;
		GVirDomainState _tmp47_ = 0;
		GEnumValue* _tmp48_;
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp23_ = self->priv->machine;
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp24_ = boxes_libvirt_machine_get_domain (_tmp23_);
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp25_ = _tmp24_;
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp26_ = gvir_domain_get_info (_tmp25_, &_inner_error_);
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		info = _tmp26_;
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1353 "libvirt-machine-properties.c"
			goto __catch32_g_error;
		}
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp27_ = builder;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp28_ = info;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp29_ = _tmp28_->cpuTime;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_string_append_printf (_tmp27_, "Cpu time: %" G_GINT64_MODIFIER "d\n", _tmp29_);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp30_ = builder;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp31_ = info;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp32_ = _tmp31_->memory;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_string_append_printf (_tmp30_, "Memory: %" G_GINT64_MODIFIER "d KiB\n", _tmp32_);
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp34_ = self->priv->machine;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp35_ = boxes_libvirt_machine_get_connection (_tmp34_);
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp36_ = _tmp35_;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp37_ = gvir_connection_get_node_info (_tmp36_, &_inner_error_);
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp33_ = _tmp37_;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			__vala_GVirDomainInfo_free0 (info);
#line 1386 "libvirt-machine-properties.c"
			goto __catch32_g_error;
		}
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp38_ = builder;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp39_ = _tmp33_;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp33_ = NULL;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp40_ = _tmp39_;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp41_ = _tmp40_->memory;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_string_append_printf (_tmp38_, "Max memory: %" G_GINT64_MODIFIER "d KiB\n", _tmp41_);
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		__vala_GVirNodeInfo_free0 (_tmp40_);
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp42_ = builder;
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp43_ = info;
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp44_ = _tmp43_->nrVirtCpu;
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_string_append_printf (_tmp42_, "CPUs: %d\n", (gint) _tmp44_);
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp45_ = builder;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp46_ = info;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp47_ = _tmp46_->state;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp48_ = g_enum_get_value (g_type_class_ref (gvir_domain_state_get_type ()), _tmp47_);
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_string_append_printf (_tmp45_, "State: %s\n", (_tmp48_ != NULL) ? _tmp48_->value_name : NULL);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		__vala_GVirNodeInfo_free0 (_tmp33_);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		__vala_GVirDomainInfo_free0 (info);
#line 1425 "libvirt-machine-properties.c"
	}
	goto __finally32;
	__catch32_g_error:
	{
		GError* e = NULL;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		e = _inner_error_;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_inner_error_ = NULL;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (e);
#line 1437 "libvirt-machine-properties.c"
	}
	__finally32:
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_string_free0 (builder);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_clear_error (&_inner_error_);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return NULL;
#line 1450 "libvirt-machine-properties.c"
	}
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp49_ = self->priv->machine;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp50_ = boxes_machine_get_display ((BoxesMachine*) _tmp49_);
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp51_ = _tmp50_;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp51_ != NULL) {
#line 1460 "libvirt-machine-properties.c"
		BoxesLibvirtMachine* _tmp52_ = NULL;
		BoxesDisplay* _tmp53_ = NULL;
		BoxesDisplay* _tmp54_ = NULL;
		GString* _tmp55_ = NULL;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp52_ = self->priv->machine;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp53_ = boxes_machine_get_display ((BoxesMachine*) _tmp52_);
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp54_ = _tmp53_;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp55_ = builder;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_display_collect_logs (_tmp54_, _tmp55_);
#line 1475 "libvirt-machine-properties.c"
	}
	{
		GVirConfigDomain* conf = NULL;
		BoxesLibvirtMachine* _tmp56_ = NULL;
		GVirDomain* _tmp57_ = NULL;
		GVirDomain* _tmp58_ = NULL;
		GVirConfigDomain* _tmp59_ = NULL;
		GString* _tmp60_ = NULL;
		GString* _tmp61_ = NULL;
		GString* _tmp62_ = NULL;
		gchar* _tmp63_ = NULL;
		gchar* _tmp64_ = NULL;
		GString* _tmp65_ = NULL;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp56_ = self->priv->machine;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp57_ = boxes_libvirt_machine_get_domain (_tmp56_);
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp58_ = _tmp57_;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp59_ = gvir_domain_get_config (_tmp58_, (guint) GVIR_DOMAIN_XML_NONE, &_inner_error_);
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		conf = _tmp59_;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1501 "libvirt-machine-properties.c"
			goto __catch33_g_error;
		}
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp60_ = builder;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_string_append_printf (_tmp60_, "\nDomain config:\n");
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp61_ = builder;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_string_append_printf (_tmp61_, "------------------------------------------------------------\n");
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp62_ = builder;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp63_ = gvir_config_object_to_xml ((GVirConfigObject*) conf);
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp64_ = _tmp63_;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_string_append (_tmp62_, _tmp64_);
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (_tmp64_);
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp65_ = builder;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_string_append_printf (_tmp65_, "%s", "\n" "------------------------------------------------------------\n");
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (conf);
#line 1528 "libvirt-machine-properties.c"
	}
	goto __finally33;
	__catch33_g_error:
	{
		GError* _error_ = NULL;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_error_ = _inner_error_;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_inner_error_ = NULL;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (_error_);
#line 1540 "libvirt-machine-properties.c"
	}
	__finally33:
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_string_free0 (builder);
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_clear_error (&_inner_error_);
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return NULL;
#line 1553 "libvirt-machine-properties.c"
	}
	{
		gchar* logfile = NULL;
		const gchar* _tmp66_ = NULL;
		BoxesLibvirtMachine* _tmp67_ = NULL;
		GVirDomain* _tmp68_ = NULL;
		GVirDomain* _tmp69_ = NULL;
		const gchar* _tmp70_ = NULL;
		gchar* _tmp71_ = NULL;
		gchar* _tmp72_ = NULL;
		gchar* _tmp73_ = NULL;
		gchar* _tmp74_ = NULL;
		gchar* data = NULL;
		gchar* _tmp75_ = NULL;
		GString* _tmp76_ = NULL;
		GString* _tmp77_ = NULL;
		GString* _tmp78_ = NULL;
		GString* _tmp79_ = NULL;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp66_ = g_get_user_cache_dir ();
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp67_ = self->priv->machine;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp68_ = boxes_libvirt_machine_get_domain (_tmp67_);
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp69_ = _tmp68_;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp70_ = gvir_domain_get_name (_tmp69_);
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp71_ = g_strconcat (_tmp70_, ".log", NULL);
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp72_ = _tmp71_;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp73_ = g_build_filename (_tmp66_, "libvirt/qemu/log", _tmp72_, NULL);
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp74_ = _tmp73_;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (_tmp72_);
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		logfile = _tmp74_;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_file_get_contents (logfile, &_tmp75_, NULL, &_inner_error_);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (data);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		data = _tmp75_;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_free0 (data);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_free0 (logfile);
#line 1606 "libvirt-machine-properties.c"
			goto __catch34_g_error;
		}
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp76_ = builder;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_string_append_printf (_tmp76_, "\nQEMU log:\n");
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp77_ = builder;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_string_append_printf (_tmp77_, "------------------------------------------------------------\n");
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp78_ = builder;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_string_append (_tmp78_, data);
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp79_ = builder;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_string_append_printf (_tmp79_, "------------------------------------------------------------\n");
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (data);
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (logfile);
#line 1629 "libvirt-machine-properties.c"
	}
	goto __finally34;
	__catch34_g_error:
	{
		GError* e = NULL;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		e = _inner_error_;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_inner_error_ = NULL;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (e);
#line 1641 "libvirt-machine-properties.c"
	}
	__finally34:
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_string_free0 (builder);
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_clear_error (&_inner_error_);
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return NULL;
#line 1654 "libvirt-machine-properties.c"
	}
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp80_ = builder;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp81_ = _tmp80_->str;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp82_ = g_strdup (_tmp81_);
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	result = _tmp82_;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_string_free0 (builder);
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return result;
#line 1668 "libvirt-machine-properties.c"
}


static void _g_object_unref0_ (gpointer var) {
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 1675 "libvirt-machine-properties.c"
}


static void _g_list_free__g_object_unref0_ (GList* self) {
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_list_foreach (self, (GFunc) _g_object_unref0_, NULL);
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_list_free (self);
#line 1684 "libvirt-machine-properties.c"
}


static Block40Data* block40_data_ref (Block40Data* _data40_) {
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_atomic_int_inc (&_data40_->_ref_count_);
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return _data40_;
#line 1693 "libvirt-machine-properties.c"
}


static void block40_data_unref (void * _userdata_) {
	Block40Data* _data40_;
	_data40_ = (Block40Data*) _userdata_;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (g_atomic_int_dec_and_test (&_data40_->_ref_count_)) {
#line 1702 "libvirt-machine-properties.c"
		BoxesLibvirtMachineProperties* self;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		self = _data40_->self;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data40_->name_property);
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (self);
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_slice_free (Block40Data, _data40_);
#line 1712 "libvirt-machine-properties.c"
	}
}


static void ___lambda134_ (BoxesLibvirtMachineProperties* self, BoxesEditableStringProperty* property, const gchar* name) {
	BoxesLibvirtMachine* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (property != NULL);
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (name != NULL);
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = self->priv->machine;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = name;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_collection_item_set_name ((BoxesCollectionItem*) _tmp0_, _tmp1_);
#line 1730 "libvirt-machine-properties.c"
}


static void ____lambda134__boxes_editable_string_property_changed (BoxesEditableStringProperty* _sender, const gchar* value, gpointer self) {
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	___lambda134_ ((BoxesLibvirtMachineProperties*) self, _sender, value);
#line 1737 "libvirt-machine-properties.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return self ? g_object_ref (self) : NULL;
#line 1744 "libvirt-machine-properties.c"
}


static void ___lambda135_ (Block40Data* _data40_) {
	BoxesLibvirtMachineProperties* self;
	BoxesEditableStringProperty* _tmp0_ = NULL;
	BoxesLibvirtMachine* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self = _data40_->self;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = _data40_->name_property;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = self->priv->machine;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp1_);
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = _tmp2_;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_editable_string_property_set_text (_tmp0_, _tmp3_);
#line 1766 "libvirt-machine-properties.c"
}


static void ____lambda135__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	___lambda135_ (self);
#line 1773 "libvirt-machine-properties.c"
}


static Block41Data* block41_data_ref (Block41Data* _data41_) {
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_atomic_int_inc (&_data41_->_ref_count_);
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return _data41_;
#line 1782 "libvirt-machine-properties.c"
}


static void block41_data_unref (void * _userdata_) {
	Block41Data* _data41_;
	_data41_ = (Block41Data*) _userdata_;
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (g_atomic_int_dec_and_test (&_data41_->_ref_count_)) {
#line 1791 "libvirt-machine-properties.c"
		BoxesLibvirtMachineProperties* self;
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		self = _data41_->self;
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data41_->property);
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (self);
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_slice_free (Block41Data, _data41_);
#line 1801 "libvirt-machine-properties.c"
	}
}


static void ____lambda154_ (Block41Data* _data41_) {
	BoxesLibvirtMachineProperties* self;
	GError * _inner_error_ = NULL;
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self = _data41_->self;
#line 1811 "libvirt-machine-properties.c"
	{
		BoxesLibvirtMachine* _tmp0_ = NULL;
		BoxesProperty* _tmp1_ = NULL;
		BoxesProperty* _tmp2_ = NULL;
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_libvirt_machine_properties_try_enable_usb_redir (self, &_inner_error_);
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1820 "libvirt-machine-properties.c"
			goto __catch37_g_error;
		}
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp0_ = self->priv->machine;
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_libvirt_machine_update_domain_config (_tmp0_);
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp1_ = _data41_->property;
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_signal_emit_by_name (_tmp1_, "refresh-properties");
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp2_ = _data41_->property;
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_property_set_reboot_required (_tmp2_, TRUE);
#line 1835 "libvirt-machine-properties.c"
	}
	goto __finally37;
	__catch37_g_error:
	{
		GError* _error_ = NULL;
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_error_ = _inner_error_;
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_inner_error_ = NULL;
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_warning ("libvirt-machine-properties.vala:190: Failed to enable usb");
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (_error_);
#line 1849 "libvirt-machine-properties.c"
	}
	__finally37:
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_clear_error (&_inner_error_);
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return;
#line 1860 "libvirt-machine-properties.c"
	}
}


static void _____lambda154__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	____lambda154_ (self);
#line 1868 "libvirt-machine-properties.c"
}


static Block42Data* block42_data_ref (Block42Data* _data42_) {
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_atomic_int_inc (&_data42_->_ref_count_);
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return _data42_;
#line 1877 "libvirt-machine-properties.c"
}


static void block42_data_unref (void * _userdata_) {
	Block42Data* _data42_;
	_data42_ = (Block42Data*) _userdata_;
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (g_atomic_int_dec_and_test (&_data42_->_ref_count_)) {
#line 1886 "libvirt-machine-properties.c"
		BoxesLibvirtMachineProperties* self;
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		self = _data42_->self;
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data42_->property);
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (self);
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_slice_free (Block42Data, _data42_);
#line 1896 "libvirt-machine-properties.c"
	}
}


static void ____lambda155_ (Block42Data* _data42_) {
	BoxesLibvirtMachineProperties* self;
	GError * _inner_error_ = NULL;
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self = _data42_->self;
#line 1906 "libvirt-machine-properties.c"
	{
		BoxesLibvirtMachine* _tmp0_ = NULL;
		BoxesProperty* _tmp1_ = NULL;
		BoxesProperty* _tmp2_ = NULL;
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_libvirt_machine_properties_try_enable_smartcard (self, &_inner_error_);
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1915 "libvirt-machine-properties.c"
			goto __catch38_g_error;
		}
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp0_ = self->priv->machine;
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_libvirt_machine_update_domain_config (_tmp0_);
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp1_ = _data42_->property;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_signal_emit_by_name (_tmp1_, "refresh-properties");
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp2_ = _data42_->property;
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_property_set_reboot_required (_tmp2_, TRUE);
#line 1930 "libvirt-machine-properties.c"
	}
	goto __finally38;
	__catch38_g_error:
	{
		GError* _error_ = NULL;
#line 202 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_error_ = _inner_error_;
#line 202 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_inner_error_ = NULL;
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_warning ("libvirt-machine-properties.vala:208: Failed to enable smartcard");
#line 202 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (_error_);
#line 1944 "libvirt-machine-properties.c"
	}
	__finally38:
#line 202 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 202 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 202 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_clear_error (&_inner_error_);
#line 202 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return;
#line 1955 "libvirt-machine-properties.c"
	}
}


static void _____lambda155__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	____lambda155_ (self);
#line 1963 "libvirt-machine-properties.c"
}


static GList* boxes_libvirt_machine_properties_real_get_properties (BoxesIPropertiesProvider* base, BoxesPropertiesPage page, PropertyCreationFlag* flags) {
	BoxesLibvirtMachineProperties * self;
	GList* result = NULL;
	GList* list = NULL;
	gboolean _tmp0_ = FALSE;
	BoxesLibvirtMachine* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	BoxesPropertiesPage _tmp9_ = 0;
	GError * _inner_error_ = NULL;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self = (BoxesLibvirtMachineProperties*) base;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	list = NULL;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = self->priv->machine;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = boxes_machine_is_on ((BoxesMachine*) _tmp1_);
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp2_) {
#line 1986 "libvirt-machine-properties.c"
		BoxesLibvirtMachine* _tmp3_ = NULL;
		BoxesDisplay* _tmp4_ = NULL;
		BoxesDisplay* _tmp5_ = NULL;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp3_ = self->priv->machine;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp4_ = boxes_machine_get_display ((BoxesMachine*) _tmp3_);
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp5_ = _tmp4_;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp0_ = _tmp5_ == NULL;
#line 1998 "libvirt-machine-properties.c"
	} else {
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp0_ = FALSE;
#line 2002 "libvirt-machine-properties.c"
	}
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp0_) {
#line 2006 "libvirt-machine-properties.c"
		{
			BoxesLibvirtMachine* _tmp6_ = NULL;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp6_ = self->priv->machine;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			boxes_libvirt_machine_update_display (_tmp6_, &_inner_error_);
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2015 "libvirt-machine-properties.c"
				goto __catch35_g_error;
			}
		}
		goto __finally35;
		__catch35_g_error:
		{
			GError* e = NULL;
			GError* _tmp7_ = NULL;
			const gchar* _tmp8_ = NULL;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			e = _inner_error_;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_inner_error_ = NULL;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp7_ = e;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp8_ = _tmp7_->message;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_warning ("libvirt-machine-properties.vala:113: %s", _tmp8_);
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_error_free0 (e);
#line 2037 "libvirt-machine-properties.c"
		}
		__finally35:
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			__g_list_free__g_object_unref0_0 (list);
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_clear_error (&_inner_error_);
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			return NULL;
#line 2050 "libvirt-machine-properties.c"
		}
	}
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp9_ = page;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	switch (_tmp9_) {
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		case BOXES_PROPERTIES_PAGE_GENERAL:
#line 2059 "libvirt-machine-properties.c"
		{
			Block40Data* _data40_;
			BoxesEditableStringProperty* property = NULL;
			const gchar* _tmp10_ = NULL;
			BoxesLibvirtMachine* _tmp11_ = NULL;
			const gchar* _tmp12_ = NULL;
			const gchar* _tmp13_ = NULL;
			BoxesEditableStringProperty* _tmp14_ = NULL;
			BoxesEditableStringProperty* _tmp15_ = NULL;
			BoxesEditableStringProperty* _tmp16_ = NULL;
			BoxesEditableStringProperty* _tmp17_ = NULL;
			BoxesLibvirtMachine* _tmp18_ = NULL;
			const gchar* _tmp19_ = NULL;
			BoxesLibvirtMachine* _tmp20_ = NULL;
			BoxesCollectionSource* _tmp21_ = NULL;
			gchar* _tmp22_ = NULL;
			gchar* _tmp23_ = NULL;
			gchar* _tmp24_ = NULL;
			BoxesStringProperty* _tmp25_ = NULL;
			BoxesStringProperty* _tmp26_ = NULL;
			BoxesLibvirtMachine* _tmp27_ = NULL;
			BoxesDisplay* _tmp28_ = NULL;
			BoxesDisplay* _tmp29_ = NULL;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data40_ = g_slice_new0 (Block40Data);
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data40_->_ref_count_ = 1;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data40_->self = g_object_ref (self);
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp10_ = _ ("Name");
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp11_ = self->priv->machine;
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp12_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp11_);
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp13_ = _tmp12_;
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp14_ = boxes_iproperties_provider_add_editable_string_property ((BoxesIPropertiesProvider*) self, &list, _tmp10_, _tmp13_);
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			property = _tmp14_;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp15_ = property;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_signal_connect_object (_tmp15_, "changed", (GCallback) ____lambda134__boxes_editable_string_property_changed, self, 0);
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp16_ = property;
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp17_ = _g_object_ref0 (_tmp16_);
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data40_->name_property = _tmp17_;
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp18_ = self->priv->machine;
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_signal_connect_data ((GObject*) _tmp18_, "notify::name", (GCallback) ____lambda135__g_object_notify, block40_data_ref (_data40_), (GClosureNotify) block40_data_unref, 0);
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp19_ = _ ("Broker");
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp20_ = self->priv->machine;
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp21_ = ((BoxesMachine*) _tmp20_)->source;
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp22_ = boxes_collection_source_get_name (_tmp21_);
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp23_ = _tmp22_;
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp24_ = _tmp23_;
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp25_ = boxes_iproperties_provider_add_string_property ((BoxesIPropertiesProvider*) self, &list, _tmp19_, _tmp24_);
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp26_ = _tmp25_;
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (_tmp26_);
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_free0 (_tmp24_);
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp27_ = self->priv->machine;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp28_ = boxes_machine_get_display ((BoxesMachine*) _tmp27_);
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp29_ = _tmp28_;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			if (_tmp29_ != NULL) {
#line 2143 "libvirt-machine-properties.c"
				const gchar* _tmp30_ = NULL;
				BoxesLibvirtMachine* _tmp31_ = NULL;
				BoxesDisplay* _tmp32_ = NULL;
				BoxesDisplay* _tmp33_ = NULL;
				const gchar* _tmp34_ = NULL;
				const gchar* _tmp35_ = NULL;
				BoxesStringProperty* _tmp36_ = NULL;
				BoxesStringProperty* _tmp37_ = NULL;
				const gchar* _tmp38_ = NULL;
				BoxesLibvirtMachine* _tmp39_ = NULL;
				BoxesDisplay* _tmp40_ = NULL;
				BoxesDisplay* _tmp41_ = NULL;
				gchar* _tmp42_ = NULL;
				gchar* _tmp43_ = NULL;
				gchar* _tmp44_ = NULL;
				BoxesStringProperty* _tmp45_ = NULL;
				BoxesStringProperty* _tmp46_ = NULL;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp30_ = _ ("Protocol");
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp31_ = self->priv->machine;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp32_ = boxes_machine_get_display ((BoxesMachine*) _tmp31_);
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp33_ = _tmp32_;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp34_ = boxes_display_get_protocol (_tmp33_);
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp35_ = _tmp34_;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp36_ = boxes_iproperties_provider_add_string_property ((BoxesIPropertiesProvider*) self, &list, _tmp30_, _tmp35_);
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp37_ = _tmp36_;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_g_object_unref0 (_tmp37_);
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp38_ = _ ("URI");
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp39_ = self->priv->machine;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp40_ = boxes_machine_get_display ((BoxesMachine*) _tmp39_);
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp41_ = _tmp40_;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp42_ = boxes_display_get_uri (_tmp41_);
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp43_ = _tmp42_;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp44_ = _tmp43_;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp45_ = boxes_iproperties_provider_add_string_property ((BoxesIPropertiesProvider*) self, &list, _tmp38_, _tmp44_);
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp46_ = _tmp45_;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_g_object_unref0 (_tmp46_);
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_g_free0 (_tmp44_);
#line 2201 "libvirt-machine-properties.c"
			}
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (property);
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			block40_data_unref (_data40_);
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data40_ = NULL;
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			break;
#line 2211 "libvirt-machine-properties.c"
		}
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		case BOXES_PROPERTIES_PAGE_SYSTEM:
#line 2215 "libvirt-machine-properties.c"
		{
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			boxes_libvirt_machine_properties_add_resource_usage_graphs (self, &list);
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			boxes_libvirt_machine_properties_add_system_props_buttons (self, &list);
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			boxes_libvirt_machine_properties_get_resources_properties (self, &list);
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			break;
#line 2225 "libvirt-machine-properties.c"
		}
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		case BOXES_PROPERTIES_PAGE_DEVICES:
#line 2229 "libvirt-machine-properties.c"
		{
			BoxesLibvirtMachine* _tmp47_ = NULL;
			GVirConfigDomain* _tmp48_ = NULL;
			GVirConfigDomain* _tmp49_ = NULL;
			GList* _tmp50_ = NULL;
			gboolean has_usb_redir = FALSE;
			gboolean has_smartcard = FALSE;
			gboolean _tmp74_ = FALSE;
			gboolean _tmp76_ = FALSE;
			gboolean _tmp77_ = FALSE;
			gboolean _tmp85_ = FALSE;
			gboolean _tmp86_ = FALSE;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp47_ = self->priv->machine;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp48_ = boxes_libvirt_machine_get_domain_config (_tmp47_);
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp49_ = _tmp48_;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp50_ = gvir_config_domain_get_devices (_tmp49_);
#line 2250 "libvirt-machine-properties.c"
			{
				GList* device_config_collection = NULL;
				GList* device_config_it = NULL;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				device_config_collection = _tmp50_;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				for (device_config_it = device_config_collection; device_config_it != NULL; device_config_it = device_config_it->next) {
#line 2258 "libvirt-machine-properties.c"
					GVirConfigDomainDevice* _tmp51_ = NULL;
					GVirConfigDomainDevice* device_config = NULL;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
					_tmp51_ = _g_object_ref0 ((GVirConfigDomainDevice*) device_config_it->data);
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
					device_config = _tmp51_;
#line 2265 "libvirt-machine-properties.c"
					{
						GVirConfigDomainDevice* _tmp52_ = NULL;
						GVirConfigDomainDisk* disk_config = NULL;
						GVirConfigDomainDevice* _tmp53_ = NULL;
						GVirConfigDomainDisk* _tmp54_ = NULL;
						GVirConfigDomainDiskGuestDeviceType disk_type = 0;
						GVirConfigDomainDisk* _tmp55_ = NULL;
						GVirConfigDomainDiskGuestDeviceType _tmp56_ = 0;
						GVirConfigDomainDiskGuestDeviceType _tmp57_ = 0;
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
						_tmp52_ = device_config;
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
						if (!G_TYPE_CHECK_INSTANCE_TYPE (_tmp52_, gvir_config_domain_disk_get_type ())) {
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
							_g_object_unref0 (device_config);
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
							continue;
#line 2283 "libvirt-machine-properties.c"
						}
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
						_tmp53_ = device_config;
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
						_tmp54_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp53_, gvir_config_domain_disk_get_type ()) ? ((GVirConfigDomainDisk*) _tmp53_) : NULL);
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
						disk_config = _tmp54_;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
						_tmp55_ = disk_config;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
						_tmp56_ = gvir_config_domain_disk_get_guest_device_type (_tmp55_);
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
						disk_type = _tmp56_;
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
						_tmp57_ = disk_type;
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
						if (_tmp57_ == GVIR_CONFIG_DOMAIN_DISK_GUEST_DEVICE_CDROM) {
#line 2301 "libvirt-machine-properties.c"
							GVirConfigDomainDisk* _tmp58_ = NULL;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
							_tmp58_ = disk_config;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
							boxes_libvirt_machine_properties_add_cdrom_property (self, _tmp58_, &list);
#line 2307 "libvirt-machine-properties.c"
						}
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
						_g_object_unref0 (disk_config);
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
						_g_object_unref0 (device_config);
#line 2313 "libvirt-machine-properties.c"
					}
				}
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				__g_list_free__g_object_unref0_0 (device_config_collection);
#line 2318 "libvirt-machine-properties.c"
			}
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			has_usb_redir = FALSE;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			has_smartcard = FALSE;
#line 2324 "libvirt-machine-properties.c"
			{
				GVirConfigDomain* inactive_config = NULL;
				BoxesLibvirtMachine* _tmp59_ = NULL;
				GVirDomain* _tmp60_ = NULL;
				GVirDomain* _tmp61_ = NULL;
				GVirConfigDomain* _tmp62_ = NULL;
				GVirConfigDomain* _tmp63_ = NULL;
				GList* _tmp64_ = NULL;
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp59_ = self->priv->machine;
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp60_ = boxes_libvirt_machine_get_domain (_tmp59_);
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp61_ = _tmp60_;
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp62_ = gvir_domain_get_config (_tmp61_, (guint) GVIR_DOMAIN_XML_INACTIVE, &_inner_error_);
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				inactive_config = _tmp62_;
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2345 "libvirt-machine-properties.c"
					goto __catch36_g_error;
				}
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp63_ = inactive_config;
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp64_ = gvir_config_domain_get_devices (_tmp63_);
#line 2352 "libvirt-machine-properties.c"
				{
					GList* device_collection = NULL;
					GList* device_it = NULL;
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
					device_collection = _tmp64_;
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
					for (device_it = device_collection; device_it != NULL; device_it = device_it->next) {
#line 2360 "libvirt-machine-properties.c"
						GVirConfigDomainDevice* _tmp65_ = NULL;
						GVirConfigDomainDevice* device = NULL;
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
						_tmp65_ = _g_object_ref0 ((GVirConfigDomainDevice*) device_it->data);
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
						device = _tmp65_;
#line 2367 "libvirt-machine-properties.c"
						{
							GVirConfigDomainDevice* _tmp66_ = NULL;
							GVirConfigDomainDevice* _tmp67_ = NULL;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
							_tmp66_ = device;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
							if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp66_, gvir_config_domain_redirdev_get_type ())) {
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
								has_usb_redir = TRUE;
#line 2377 "libvirt-machine-properties.c"
							}
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
							_tmp67_ = device;
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
							if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp67_, gvir_config_domain_smartcard_get_type ())) {
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
								has_smartcard = TRUE;
#line 2385 "libvirt-machine-properties.c"
							}
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
							_g_object_unref0 (device);
#line 2389 "libvirt-machine-properties.c"
						}
					}
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
					__g_list_free__g_object_unref0_0 (device_collection);
#line 2394 "libvirt-machine-properties.c"
				}
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_g_object_unref0 (inactive_config);
#line 2398 "libvirt-machine-properties.c"
			}
			goto __finally36;
			__catch36_g_error:
			{
				GError* _error_ = NULL;
				BoxesLibvirtMachine* _tmp68_ = NULL;
				GVirDomain* _tmp69_ = NULL;
				GVirDomain* _tmp70_ = NULL;
				const gchar* _tmp71_ = NULL;
				GError* _tmp72_ = NULL;
				const gchar* _tmp73_ = NULL;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_error_ = _inner_error_;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_inner_error_ = NULL;
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp68_ = self->priv->machine;
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp69_ = boxes_libvirt_machine_get_domain (_tmp68_);
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp70_ = _tmp69_;
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp71_ = gvir_domain_get_name (_tmp70_);
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp72_ = _error_;
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp73_ = _tmp72_->message;
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				g_warning ("libvirt-machine-properties.vala:169: Failed to fetch configuration for" \
" domain '%s': %s", _tmp71_, _tmp73_);
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_g_error_free0 (_error_);
#line 2430 "libvirt-machine-properties.c"
			}
			__finally36:
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				__g_list_free__g_object_unref0_0 (list);
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				g_clear_error (&_inner_error_);
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				return NULL;
#line 2443 "libvirt-machine-properties.c"
			}
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp74_ = has_usb_redir;
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			if (!_tmp74_) {
#line 2449 "libvirt-machine-properties.c"
				PropertyCreationFlag _tmp75_ = 0;
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp75_ = *flags;
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				*flags = _tmp75_ | PROPERTY_CREATION_FLAG_NO_USB;
#line 2455 "libvirt-machine-properties.c"
			}
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp77_ = has_usb_redir;
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			if (!_tmp77_) {
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp76_ = HAVE_USBREDIR;
#line 2463 "libvirt-machine-properties.c"
			} else {
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp76_ = FALSE;
#line 2467 "libvirt-machine-properties.c"
			}
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			if (_tmp76_) {
#line 2471 "libvirt-machine-properties.c"
				Block41Data* _data41_;
				GtkButton* button = NULL;
				const gchar* _tmp78_ = NULL;
				GtkButton* _tmp79_ = NULL;
				GtkButton* _tmp80_ = NULL;
				const gchar* _tmp81_ = NULL;
				GtkButton* _tmp82_ = NULL;
				BoxesProperty* _tmp83_ = NULL;
				GtkButton* _tmp84_ = NULL;
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_data41_ = g_slice_new0 (Block41Data);
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_data41_->_ref_count_ = 1;
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_data41_->self = g_object_ref (self);
#line 180 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp78_ = _ ("Add support to guest");
#line 180 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp79_ = (GtkButton*) gtk_button_new_with_label (_tmp78_);
#line 180 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				g_object_ref_sink (_tmp79_);
#line 180 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				button = _tmp79_;
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp80_ = button;
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				gtk_widget_set_halign ((GtkWidget*) _tmp80_, GTK_ALIGN_START);
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp81_ = _ ("USB device support");
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp82_ = button;
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp83_ = boxes_iproperties_provider_add_property ((BoxesIPropertiesProvider*) self, &list, _tmp81_, (GtkWidget*) _tmp82_, NULL);
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_data41_->property = _tmp83_;
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp84_ = button;
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				g_signal_connect_data (_tmp84_, "clicked", (GCallback) _____lambda154__gtk_button_clicked, block41_data_ref (_data41_), (GClosureNotify) block41_data_unref, 0);
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_g_object_unref0 (button);
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				block41_data_unref (_data41_);
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_data41_ = NULL;
#line 2517 "libvirt-machine-properties.c"
			}
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp86_ = has_smartcard;
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			if (!_tmp86_) {
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp85_ = HAVE_SMARTCARD;
#line 2525 "libvirt-machine-properties.c"
			} else {
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp85_ = FALSE;
#line 2529 "libvirt-machine-properties.c"
			}
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			if (_tmp85_) {
#line 2533 "libvirt-machine-properties.c"
				Block42Data* _data42_;
				GtkButton* button = NULL;
				const gchar* _tmp87_ = NULL;
				GtkButton* _tmp88_ = NULL;
				GtkButton* _tmp89_ = NULL;
				const gchar* _tmp90_ = NULL;
				GtkButton* _tmp91_ = NULL;
				BoxesProperty* _tmp92_ = NULL;
				GtkButton* _tmp93_ = NULL;
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_data42_ = g_slice_new0 (Block42Data);
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_data42_->_ref_count_ = 1;
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_data42_->self = g_object_ref (self);
#line 198 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp87_ = _ ("Add support to guest");
#line 198 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp88_ = (GtkButton*) gtk_button_new_with_label (_tmp87_);
#line 198 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				g_object_ref_sink (_tmp88_);
#line 198 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				button = _tmp88_;
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp89_ = button;
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				gtk_widget_set_halign ((GtkWidget*) _tmp89_, GTK_ALIGN_START);
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp90_ = _ ("Smartcard support");
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp91_ = button;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp92_ = boxes_iproperties_provider_add_property ((BoxesIPropertiesProvider*) self, &list, _tmp90_, (GtkWidget*) _tmp91_, NULL);
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_data42_->property = _tmp92_;
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp93_ = button;
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				g_signal_connect_data (_tmp93_, "clicked", (GCallback) _____lambda155__gtk_button_clicked, block42_data_ref (_data42_), (GClosureNotify) block42_data_unref, 0);
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_g_object_unref0 (button);
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				block42_data_unref (_data42_);
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_data42_ = NULL;
#line 2579 "libvirt-machine-properties.c"
			}
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			break;
#line 2583 "libvirt-machine-properties.c"
		}
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		case BOXES_PROPERTIES_PAGE_SNAPSHOTS:
#line 2587 "libvirt-machine-properties.c"
		{
			{
				GVirConfigDomain* config = NULL;
				BoxesLibvirtMachine* _tmp94_ = NULL;
				GVirDomain* _tmp95_ = NULL;
				GVirDomain* _tmp96_ = NULL;
				GVirConfigDomain* _tmp97_ = NULL;
				gboolean _tmp98_ = FALSE;
				GVirConfigDomain* _tmp99_ = NULL;
				GVirConfigDomainCpu* _tmp100_ = NULL;
				GVirConfigDomainCpu* _tmp101_ = NULL;
				GVirConfigDomainCpuMode _tmp102_ = 0;
				gboolean _tmp103_ = FALSE;
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp94_ = self->priv->machine;
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp95_ = boxes_libvirt_machine_get_domain (_tmp94_);
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp96_ = _tmp95_;
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp97_ = gvir_domain_get_config (_tmp96_, (guint) 0, &_inner_error_);
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				config = _tmp97_;
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2613 "libvirt-machine-properties.c"
					goto __catch39_g_error;
				}
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp99_ = config;
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp100_ = gvir_config_domain_get_cpu (_tmp99_);
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp101_ = _tmp100_;
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp102_ = gvir_config_domain_cpu_get_mode (_tmp101_);
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp103_ = _tmp102_ != GVIR_CONFIG_DOMAIN_CPU_MODE_HOST_PASSTHROUGH;
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_g_object_unref0 (_tmp101_);
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				if (_tmp103_) {
#line 2630 "libvirt-machine-properties.c"
					GVirConfigDomain* _tmp104_ = NULL;
					gboolean _tmp105_ = FALSE;
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
					_tmp104_ = config;
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
					_tmp105_ = boxes_vm_configurator_is_install_config (_tmp104_);
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
					_tmp98_ = !_tmp105_;
#line 2639 "libvirt-machine-properties.c"
				} else {
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
					_tmp98_ = FALSE;
#line 2643 "libvirt-machine-properties.c"
				}
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				if (_tmp98_) {
#line 2647 "libvirt-machine-properties.c"
					BoxesLibvirtMachine* _tmp106_ = NULL;
					BoxesSnapshotsProperty* _tmp107_ = NULL;
					BoxesSnapshotsProperty* _tmp108_ = NULL;
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
					_tmp106_ = self->priv->machine;
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
					_tmp107_ = boxes_libvirt_machine_properties_add_snapshots_property (self, &list, _tmp106_);
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
					_tmp108_ = _tmp107_;
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
					_g_object_unref0 (_tmp108_);
#line 2659 "libvirt-machine-properties.c"
				}
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_g_object_unref0 (config);
#line 2663 "libvirt-machine-properties.c"
			}
			goto __finally39;
			__catch39_g_error:
			{
				GError* e = NULL;
				GError* _tmp109_ = NULL;
				const gchar* _tmp110_ = NULL;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				e = _inner_error_;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_inner_error_ = NULL;
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp109_ = e;
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp110_ = _tmp109_->message;
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				g_warning ("libvirt-machine-properties.vala:223: %s", _tmp110_);
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_g_error_free0 (e);
#line 2683 "libvirt-machine-properties.c"
			}
			__finally39:
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				__g_list_free__g_object_unref0_0 (list);
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				g_clear_error (&_inner_error_);
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				return NULL;
#line 2696 "libvirt-machine-properties.c"
			}
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			break;
#line 2700 "libvirt-machine-properties.c"
		}
		default:
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		break;
#line 2705 "libvirt-machine-properties.c"
	}
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	result = list;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return result;
#line 2711 "libvirt-machine-properties.c"
}


void boxes_libvirt_machine_properties_get_resources_properties (BoxesLibvirtMachineProperties* self, GList** list) {
	BoxesSizeProperty* ram_property = NULL;
	BoxesSizeProperty* _tmp0_ = NULL;
	BoxesSizeProperty* storage_property = NULL;
	BoxesSizeProperty* _tmp1_ = NULL;
#line 232 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (self != NULL);
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = boxes_libvirt_machine_properties_add_ram_property (self, list);
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	ram_property = _tmp0_;
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = boxes_libvirt_machine_properties_add_storage_property (self, list);
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	storage_property = _tmp1_;
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_properties_mark_recommended_resources (self, ram_property, storage_property, NULL, NULL);
#line 232 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (storage_property);
#line 232 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (ram_property);
#line 2736 "libvirt-machine-properties.c"
}


static Block43Data* block43_data_ref (Block43Data* _data43_) {
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_atomic_int_inc (&_data43_->_ref_count_);
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return _data43_;
#line 2745 "libvirt-machine-properties.c"
}


static void block43_data_unref (void * _userdata_) {
	Block43Data* _data43_;
	_data43_ = (Block43Data*) _userdata_;
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (g_atomic_int_dec_and_test (&_data43_->_ref_count_)) {
#line 2754 "libvirt-machine-properties.c"
		BoxesLibvirtMachineProperties* self;
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		self = _data43_->self;
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data43_->button_label);
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data43_->label);
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data43_->disk_config);
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (self);
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_slice_free (Block43Data, _data43_);
#line 2768 "libvirt-machine-properties.c"
	}
}


static void ___lambda153_ (Block43Data* _data43_, const gchar* path) {
	BoxesLibvirtMachineProperties* self;
	GVirConfigDomainDisk* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	GError * _inner_error_ = NULL;
#line 282 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self = _data43_->self;
#line 282 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (path != NULL);
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = _data43_->disk_config;
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = path;
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gvir_config_domain_disk_set_source (_tmp0_, _tmp1_);
#line 2788 "libvirt-machine-properties.c"
	{
		BoxesLibvirtMachine* _tmp2_ = NULL;
		GVirDomain* _tmp3_ = NULL;
		GVirDomain* _tmp4_ = NULL;
		GVirConfigDomainDisk* _tmp5_ = NULL;
		GtkLabel* _tmp6_ = NULL;
		const gchar* _tmp7_ = NULL;
		GtkLabel* _tmp8_ = NULL;
		const gchar* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
		gchar* _tmp11_ = NULL;
#line 285 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp2_ = self->priv->machine;
#line 285 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp3_ = boxes_libvirt_machine_get_domain (_tmp2_);
#line 285 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp4_ = _tmp3_;
#line 285 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp5_ = _data43_->disk_config;
#line 285 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gvir_domain_update_device (_tmp4_, (GVirConfigDomainDevice*) _tmp5_, (guint) GVIR_DOMAIN_UPDATE_DEVICE_CURRENT, &_inner_error_);
#line 285 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2812 "libvirt-machine-properties.c"
			goto __catch40_g_error;
		}
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp6_ = _data43_->button_label;
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp7_ = _ ("Remove");
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gtk_label_set_text (_tmp6_, _tmp7_);
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp8_ = _data43_->label;
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp9_ = path;
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp10_ = boxes_get_utf8_basename (_tmp9_);
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp11_ = _tmp10_;
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gtk_label_set_text (_tmp8_, _tmp11_);
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (_tmp11_);
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data43_->empty = FALSE;
#line 2835 "libvirt-machine-properties.c"
	}
	goto __finally40;
	__catch40_g_error:
	{
		GError* e = NULL;
		gchar* path_basename = NULL;
		const gchar* _tmp12_ = NULL;
		gchar* _tmp13_ = NULL;
		gchar* msg = NULL;
		const gchar* _tmp14_ = NULL;
		gchar* _tmp15_ = NULL;
		BoxesLibvirtMachine* _tmp16_ = NULL;
		const gchar* _tmp17_ = NULL;
		const gchar* _tmp18_ = NULL;
		BoxesLibvirtMachine* _tmp19_ = NULL;
		const gchar* _tmp20_ = NULL;
		const gchar* _tmp21_ = NULL;
		gchar* _tmp22_ = NULL;
		gchar* _tmp23_ = NULL;
		const gchar* _tmp24_ = NULL;
		BoxesLibvirtMachine* _tmp25_ = NULL;
		const gchar* _tmp26_ = NULL;
		const gchar* _tmp27_ = NULL;
		GError* _tmp28_ = NULL;
		const gchar* _tmp29_ = NULL;
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		e = _inner_error_;
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_inner_error_ = NULL;
#line 290 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp12_ = path;
#line 290 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp13_ = boxes_get_utf8_basename (_tmp12_);
#line 290 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		path_basename = _tmp13_;
#line 293 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp14_ = _ ("Insertion of '%s' as a CD/DVD into '%s' failed");
#line 293 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp15_ = g_strdup (_tmp14_);
#line 293 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		msg = _tmp15_;
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp16_ = self->priv->machine;
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp17_ = msg;
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp18_ = path_basename;
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp19_ = self->priv->machine;
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp20_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp19_);
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp21_ = _tmp20_;
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp22_ = g_strdup_printf (_tmp17_, _tmp18_, _tmp21_);
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp23_ = _tmp22_;
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_signal_emit_by_name ((BoxesMachine*) _tmp16_, "got-error", _tmp23_);
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (_tmp23_);
#line 295 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp24_ = path_basename;
#line 295 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp25_ = self->priv->machine;
#line 295 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp26_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp25_);
#line 295 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp27_ = _tmp26_;
#line 295 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp28_ = e;
#line 295 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp29_ = _tmp28_->message;
#line 295 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_debug ("libvirt-machine-properties.vala:295: Error inserting '%s' as CD into '" \
"%s': %s", _tmp24_, _tmp27_, _tmp29_);
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (msg);
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (path_basename);
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (e);
#line 2917 "libvirt-machine-properties.c"
	}
	__finally40:
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_clear_error (&_inner_error_);
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return;
#line 2928 "libvirt-machine-properties.c"
	}
}


static void ____lambda153__boxes_properties_window_file_chosen_func (const gchar* path, gpointer self) {
#line 282 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	___lambda153_ (self, path);
#line 2936 "libvirt-machine-properties.c"
}


static void __lambda152_ (Block43Data* _data43_) {
	BoxesLibvirtMachineProperties* self;
	gboolean _tmp0_ = FALSE;
	GError * _inner_error_ = NULL;
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self = _data43_->self;
#line 281 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = _data43_->empty;
#line 281 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp0_) {
#line 2950 "libvirt-machine-properties.c"
		BoxesLibvirtMachine* _tmp1_ = NULL;
		BoxesAppWindow* _tmp2_ = NULL;
		BoxesAppWindow* _tmp3_ = NULL;
		BoxesPropertiesWindow* _tmp4_ = NULL;
#line 282 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp1_ = self->priv->machine;
#line 282 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp2_ = boxes_machine_get_window ((BoxesMachine*) _tmp1_);
#line 282 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp3_ = _tmp2_;
#line 282 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp4_ = _tmp3_->props_window;
#line 282 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_properties_window_show_file_chooser (_tmp4_, ____lambda153__boxes_properties_window_file_chosen_func, block43_data_ref (_data43_), block43_data_unref);
#line 2965 "libvirt-machine-properties.c"
	} else {
		GVirConfigDomainDisk* _tmp5_ = NULL;
#line 299 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp5_ = _data43_->disk_config;
#line 299 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gvir_config_domain_disk_set_source (_tmp5_, "");
#line 2972 "libvirt-machine-properties.c"
		{
			BoxesLibvirtMachine* _tmp6_ = NULL;
			GVirDomain* _tmp7_ = NULL;
			GVirDomain* _tmp8_ = NULL;
			GVirConfigDomainDisk* _tmp9_ = NULL;
			GtkLabel* _tmp10_ = NULL;
			const gchar* _tmp11_ = NULL;
			GtkLabel* _tmp12_ = NULL;
			const gchar* _tmp13_ = NULL;
			gchar* _tmp14_ = NULL;
			gchar* _tmp15_ = NULL;
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp6_ = self->priv->machine;
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp7_ = boxes_libvirt_machine_get_domain (_tmp6_);
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp8_ = _tmp7_;
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp9_ = _data43_->disk_config;
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			gvir_domain_update_device (_tmp8_, (GVirConfigDomainDevice*) _tmp9_, (guint) GVIR_DOMAIN_UPDATE_DEVICE_CURRENT, &_inner_error_);
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2996 "libvirt-machine-properties.c"
				goto __catch41_g_error;
			}
#line 302 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data43_->empty = TRUE;
#line 303 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp10_ = _data43_->button_label;
#line 303 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp11_ = _ ("Select");
#line 303 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			gtk_label_set_text (_tmp10_, _tmp11_);
#line 304 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp12_ = _data43_->label;
#line 304 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp13_ = _ ("empty");
#line 304 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp14_ = g_markup_printf_escaped ("<i>%s</i>", _tmp13_);
#line 304 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp15_ = _tmp14_;
#line 304 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			gtk_label_set_markup (_tmp12_, _tmp15_);
#line 304 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_free0 (_tmp15_);
#line 3019 "libvirt-machine-properties.c"
		}
		goto __finally41;
		__catch41_g_error:
		{
			GError* e = NULL;
			BoxesLibvirtMachine* _tmp16_ = NULL;
			const gchar* _tmp17_ = NULL;
			BoxesLibvirtMachine* _tmp18_ = NULL;
			const gchar* _tmp19_ = NULL;
			const gchar* _tmp20_ = NULL;
			gchar* _tmp21_ = NULL;
			gchar* _tmp22_ = NULL;
			BoxesLibvirtMachine* _tmp23_ = NULL;
			const gchar* _tmp24_ = NULL;
			const gchar* _tmp25_ = NULL;
			GError* _tmp26_ = NULL;
			const gchar* _tmp27_ = NULL;
#line 300 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			e = _inner_error_;
#line 300 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_inner_error_ = NULL;
#line 307 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp16_ = self->priv->machine;
#line 307 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp17_ = _ ("Removal of CD/DVD from '%s' failed");
#line 307 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp18_ = self->priv->machine;
#line 307 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp19_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp18_);
#line 307 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp20_ = _tmp19_;
#line 307 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp21_ = g_strdup_printf (_tmp17_, _tmp20_);
#line 307 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp22_ = _tmp21_;
#line 307 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_signal_emit_by_name ((BoxesMachine*) _tmp16_, "got-error", _tmp22_);
#line 307 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_free0 (_tmp22_);
#line 308 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp23_ = self->priv->machine;
#line 308 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp24_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp23_);
#line 308 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp25_ = _tmp24_;
#line 308 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp26_ = e;
#line 308 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp27_ = _tmp26_->message;
#line 308 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_debug ("libvirt-machine-properties.vala:308: Error ejecting CD from '%s': %s", _tmp25_, _tmp27_);
#line 300 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_error_free0 (e);
#line 3073 "libvirt-machine-properties.c"
		}
		__finally41:
#line 300 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 300 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 300 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_clear_error (&_inner_error_);
#line 300 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			return;
#line 3084 "libvirt-machine-properties.c"
		}
	}
}


static void ___lambda152__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	__lambda152_ (self);
#line 3093 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_add_cdrom_property (BoxesLibvirtMachineProperties* self, GVirConfigDomainDisk* disk_config, GList** list) {
	Block43Data* _data43_;
	GVirConfigDomainDisk* _tmp0_ = NULL;
	GVirConfigDomainDisk* _tmp1_ = NULL;
	GtkGrid* grid = NULL;
	GtkGrid* _tmp2_ = NULL;
	GtkGrid* _tmp3_ = NULL;
	GtkGrid* _tmp4_ = NULL;
	GtkLabel* _tmp5_ = NULL;
	GtkLabel* _tmp6_ = NULL;
	GtkGrid* _tmp7_ = NULL;
	GtkLabel* _tmp8_ = NULL;
	gchar* source = NULL;
	GVirConfigDomainDisk* _tmp9_ = NULL;
	const gchar* _tmp10_ = NULL;
	gchar* _tmp11_ = NULL;
	gboolean _tmp12_ = FALSE;
	const gchar* _tmp13_ = NULL;
	gboolean _tmp15_ = FALSE;
	BoxesLibvirtMachine* _tmp24_ = NULL;
	BoxesVMCreator* _tmp25_ = NULL;
	BoxesVMCreator* _tmp26_ = NULL;
	GtkLabel* _tmp50_ = NULL;
	GtkButton* button = NULL;
	GtkButton* _tmp51_ = NULL;
	GtkButton* _tmp52_ = NULL;
	GtkLabel* _tmp53_ = NULL;
	GtkGrid* _tmp54_ = NULL;
	GtkButton* _tmp55_ = NULL;
	gboolean _tmp56_ = FALSE;
	GtkButton* _tmp61_ = NULL;
	BoxesProperty* property = NULL;
	const gchar* _tmp62_ = NULL;
	GtkGrid* _tmp63_ = NULL;
	BoxesProperty* _tmp64_ = NULL;
	BoxesProperty* _tmp65_ = NULL;
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (self != NULL);
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (disk_config != NULL);
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data43_ = g_slice_new0 (Block43Data);
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data43_->_ref_count_ = 1;
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data43_->self = g_object_ref (self);
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = disk_config;
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data43_->disk_config);
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data43_->disk_config = _tmp1_;
#line 239 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = (GtkGrid*) gtk_grid_new ();
#line 239 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_ref_sink (_tmp2_);
#line 239 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	grid = _tmp2_;
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = grid;
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_orientable_set_orientation ((GtkOrientable*) _tmp3_, GTK_ORIENTATION_HORIZONTAL);
#line 241 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp4_ = grid;
#line 241 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_grid_set_column_spacing (_tmp4_, (guint) 12);
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp5_ = (GtkLabel*) gtk_label_new ("");
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_ref_sink (_tmp5_);
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data43_->label = _tmp5_;
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp6_ = _data43_->label;
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_label_set_ellipsize (_tmp6_, PANGO_ELLIPSIZE_END);
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp7_ = grid;
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp8_ = _data43_->label;
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_container_add ((GtkContainer*) _tmp7_, (GtkWidget*) _tmp8_);
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp9_ = _data43_->disk_config;
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp10_ = gvir_config_domain_disk_get_source (_tmp9_);
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp11_ = g_strdup (_tmp10_);
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	source = _tmp11_;
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp13_ = source;
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp13_ == NULL) {
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp12_ = TRUE;
#line 3195 "libvirt-machine-properties.c"
	} else {
		const gchar* _tmp14_ = NULL;
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp14_ = source;
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp12_ = g_strcmp0 (_tmp14_, "") == 0;
#line 3202 "libvirt-machine-properties.c"
	}
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data43_->empty = _tmp12_;
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp15_ = _data43_->empty;
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp15_) {
#line 3210 "libvirt-machine-properties.c"
		GtkLabel* _tmp16_ = NULL;
		const gchar* _tmp17_ = NULL;
		gchar* _tmp18_ = NULL;
		gchar* _tmp19_ = NULL;
#line 252 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp16_ = _data43_->label;
#line 252 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp17_ = _ ("empty");
#line 252 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp18_ = g_markup_printf_escaped ("<i>%s</i>", _tmp17_);
#line 252 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp19_ = _tmp18_;
#line 252 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gtk_label_set_markup (_tmp16_, _tmp19_);
#line 252 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (_tmp19_);
#line 3227 "libvirt-machine-properties.c"
	} else {
		GtkLabel* _tmp20_ = NULL;
		const gchar* _tmp21_ = NULL;
		gchar* _tmp22_ = NULL;
		gchar* _tmp23_ = NULL;
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp20_ = _data43_->label;
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp21_ = source;
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp22_ = boxes_get_utf8_basename (_tmp21_);
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp23_ = _tmp22_;
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gtk_label_set_text (_tmp20_, _tmp23_);
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (_tmp23_);
#line 3245 "libvirt-machine-properties.c"
	}
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp24_ = self->priv->machine;
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp25_ = boxes_libvirt_machine_get_vm_creator (_tmp24_);
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp26_ = _tmp25_;
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp26_ != NULL) {
#line 3255 "libvirt-machine-properties.c"
		BoxesInstallerMedia* media = NULL;
		BoxesLibvirtMachine* _tmp27_ = NULL;
		BoxesVMCreator* _tmp28_ = NULL;
		BoxesVMCreator* _tmp29_ = NULL;
		BoxesInstallerMedia* _tmp30_ = NULL;
		BoxesInstallerMedia* _tmp31_ = NULL;
		BoxesInstallerMedia* _tmp32_ = NULL;
		gboolean _tmp33_ = FALSE;
		BoxesLibvirtMachine* _tmp34_ = NULL;
		BoxesVMCreator* _tmp35_ = NULL;
		BoxesVMCreator* _tmp36_ = NULL;
		gboolean _tmp37_ = FALSE;
		gboolean _tmp38_ = FALSE;
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp27_ = self->priv->machine;
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp28_ = boxes_libvirt_machine_get_vm_creator (_tmp27_);
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp29_ = _tmp28_;
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp30_ = boxes_vm_creator_get_install_media (_tmp29_);
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp31_ = _tmp30_;
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp32_ = _g_object_ref0 (_tmp31_);
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		media = _tmp32_;
#line 259 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp34_ = self->priv->machine;
#line 259 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp35_ = boxes_libvirt_machine_get_vm_creator (_tmp34_);
#line 259 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp36_ = _tmp35_;
#line 259 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp37_ = boxes_vm_creator_get_express_install (_tmp36_);
#line 259 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp38_ = _tmp37_;
#line 259 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_tmp38_) {
#line 259 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp33_ = TRUE;
#line 3297 "libvirt-machine-properties.c"
		} else {
			gboolean _tmp39_ = FALSE;
			BoxesInstallerMedia* _tmp40_ = NULL;
			OsinfoMedia* _tmp41_ = NULL;
#line 259 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp40_ = media;
#line 259 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp41_ = _tmp40_->os_media;
#line 259 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			if (_tmp41_ != NULL) {
#line 3308 "libvirt-machine-properties.c"
				BoxesInstallerMedia* _tmp42_ = NULL;
				OsinfoMedia* _tmp43_ = NULL;
				gboolean _tmp44_ = FALSE;
				gboolean _tmp45_ = FALSE;
#line 259 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp42_ = media;
#line 259 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp43_ = _tmp42_->os_media;
#line 259 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				g_object_get (_tmp43_, "live", &_tmp44_, NULL);
#line 259 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp45_ = _tmp44_;
#line 259 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp39_ = _tmp45_;
#line 3323 "libvirt-machine-properties.c"
			} else {
#line 259 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp39_ = FALSE;
#line 3327 "libvirt-machine-properties.c"
			}
#line 259 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp33_ = _tmp39_;
#line 3331 "libvirt-machine-properties.c"
		}
#line 259 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_tmp33_) {
#line 3335 "libvirt-machine-properties.c"
			const gchar* _tmp46_ = NULL;
			GtkGrid* _tmp47_ = NULL;
			BoxesProperty* _tmp48_ = NULL;
			BoxesProperty* _tmp49_ = NULL;
#line 261 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp46_ = _ ("CD/DVD");
#line 261 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp47_ = grid;
#line 261 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp48_ = boxes_iproperties_provider_add_property ((BoxesIPropertiesProvider*) self, list, _tmp46_, (GtkWidget*) _tmp47_, NULL);
#line 261 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp49_ = _tmp48_;
#line 261 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (_tmp49_);
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (media);
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_free0 (source);
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (grid);
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			block43_data_unref (_data43_);
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data43_ = NULL;
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			return;
#line 3362 "libvirt-machine-properties.c"
		}
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (media);
#line 3366 "libvirt-machine-properties.c"
	}
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp50_ = (GtkLabel*) gtk_label_new ("");
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_ref_sink (_tmp50_);
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data43_->button_label = _tmp50_;
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp51_ = (GtkButton*) gtk_button_new ();
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_ref_sink (_tmp51_);
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	button = _tmp51_;
#line 269 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp52_ = button;
#line 269 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp53_ = _data43_->button_label;
#line 269 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_container_add ((GtkContainer*) _tmp52_, (GtkWidget*) _tmp53_);
#line 271 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp54_ = grid;
#line 271 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp55_ = button;
#line 271 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_container_add ((GtkContainer*) _tmp54_, (GtkWidget*) _tmp55_);
#line 273 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp56_ = _data43_->empty;
#line 273 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp56_) {
#line 3396 "libvirt-machine-properties.c"
		GtkLabel* _tmp57_ = NULL;
		const gchar* _tmp58_ = NULL;
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp57_ = _data43_->button_label;
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp58_ = _ ("Select");
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gtk_label_set_text (_tmp57_, _tmp58_);
#line 3405 "libvirt-machine-properties.c"
	} else {
		GtkLabel* _tmp59_ = NULL;
		const gchar* _tmp60_ = NULL;
#line 278 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp59_ = _data43_->button_label;
#line 278 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp60_ = _ ("Remove");
#line 278 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gtk_label_set_text (_tmp59_, _tmp60_);
#line 3415 "libvirt-machine-properties.c"
	}
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp61_ = button;
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_signal_connect_data (_tmp61_, "clicked", (GCallback) ___lambda152__gtk_button_clicked, block43_data_ref (_data43_), (GClosureNotify) block43_data_unref, 0);
#line 313 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp62_ = _ ("CD/DVD");
#line 313 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp63_ = grid;
#line 313 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp64_ = boxes_iproperties_provider_add_property ((BoxesIPropertiesProvider*) self, list, _tmp62_, (GtkWidget*) _tmp63_, NULL);
#line 313 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	property = _tmp64_;
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp65_ = property;
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_property_set_description_alignment (_tmp65_, GTK_ALIGN_START);
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (property);
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (button);
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_free0 (source);
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (grid);
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	block43_data_unref (_data43_);
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data43_ = NULL;
#line 3445 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_update_ram_property (BoxesLibvirtMachineProperties* self, BoxesProperty* property) {
	GError * _inner_error_ = NULL;
#line 317 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (self != NULL);
#line 317 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (property != NULL);
#line 3455 "libvirt-machine-properties.c"
	{
		GVirConfigDomain* config = NULL;
		BoxesLibvirtMachine* _tmp0_ = NULL;
		GVirDomain* _tmp1_ = NULL;
		GVirDomain* _tmp2_ = NULL;
		GVirConfigDomain* _tmp3_ = NULL;
		guint64 actual = 0ULL;
		BoxesLibvirtMachine* _tmp4_ = NULL;
		GVirConfigDomain* _tmp5_ = NULL;
		GVirConfigDomain* _tmp6_ = NULL;
		guint64 _tmp7_ = 0ULL;
		guint64 _tmp8_ = 0ULL;
		guint64 pending = 0ULL;
		guint64 _tmp9_ = 0ULL;
		guint64 _tmp10_ = 0ULL;
		guint64 _tmp11_ = 0ULL;
		guint64 _tmp12_ = 0ULL;
		BoxesProperty* _tmp13_ = NULL;
		guint64 _tmp14_ = 0ULL;
		guint64 _tmp15_ = 0ULL;
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp0_ = self->priv->machine;
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp1_ = boxes_libvirt_machine_get_domain (_tmp0_);
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp2_ = _tmp1_;
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp3_ = gvir_domain_get_config (_tmp2_, (guint) GVIR_DOMAIN_XML_INACTIVE, &_inner_error_);
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		config = _tmp3_;
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3488 "libvirt-machine-properties.c"
			goto __catch42_g_error;
		}
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp4_ = self->priv->machine;
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp5_ = boxes_libvirt_machine_get_domain_config (_tmp4_);
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp6_ = _tmp5_;
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp7_ = gvir_config_domain_get_memory (_tmp6_);
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp8_ = _tmp7_;
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		actual = _tmp8_ / 1024;
#line 323 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp9_ = gvir_config_domain_get_memory (config);
#line 323 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp10_ = _tmp9_;
#line 323 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		pending = _tmp10_ / 1024;
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp11_ = actual;
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp12_ = pending;
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_debug ("libvirt-machine-properties.vala:325: RAM actual: %llu, pending: %llu", _tmp11_, _tmp12_);
#line 327 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp13_ = property;
#line 327 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp14_ = actual;
#line 327 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp15_ = pending;
#line 327 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_property_set_reboot_required (_tmp13_, (_tmp14_ - _tmp15_) > ((guint64) 1));
#line 318 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (config);
#line 3525 "libvirt-machine-properties.c"
	}
	goto __finally42;
	__catch42_g_error:
	{
		GError* e = NULL;
#line 318 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		e = _inner_error_;
#line 318 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_inner_error_ = NULL;
#line 318 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (e);
#line 3537 "libvirt-machine-properties.c"
	}
	__finally42:
#line 318 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 318 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 318 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_clear_error (&_inner_error_);
#line 318 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return;
#line 3548 "libvirt-machine-properties.c"
	}
}


static void boxes_libvirt_machine_properties_mark_recommended_resources_data_free (gpointer _data) {
	BoxesLibvirtMachinePropertiesMarkRecommendedResourcesData* _data_;
	_data_ = _data;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->ram_property);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->storage_property);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_slice_free (BoxesLibvirtMachinePropertiesMarkRecommendedResourcesData, _data_);
#line 3564 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_mark_recommended_resources (BoxesLibvirtMachineProperties* self, BoxesSizeProperty* ram_property, BoxesSizeProperty* storage_property, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesLibvirtMachinePropertiesMarkRecommendedResourcesData* _data_;
	BoxesLibvirtMachineProperties* _tmp0_ = NULL;
	BoxesSizeProperty* _tmp1_ = NULL;
	BoxesSizeProperty* _tmp2_ = NULL;
	BoxesSizeProperty* _tmp3_ = NULL;
	BoxesSizeProperty* _tmp4_ = NULL;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_ = g_slice_new0 (BoxesLibvirtMachinePropertiesMarkRecommendedResourcesData);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_libvirt_machine_properties_mark_recommended_resources);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_libvirt_machine_properties_mark_recommended_resources_data_free);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->self = _tmp0_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = ram_property;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->ram_property);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->ram_property = _tmp2_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = storage_property;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp4_ = _g_object_ref0 (_tmp3_);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->storage_property);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->storage_property = _tmp4_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_properties_mark_recommended_resources_co (_data_);
#line 3603 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_mark_recommended_resources_finish (BoxesLibvirtMachineProperties* self, GAsyncResult* _res_) {
	BoxesLibvirtMachinePropertiesMarkRecommendedResourcesData* _data_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 3611 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_mark_recommended_resources_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesLibvirtMachinePropertiesMarkRecommendedResourcesData* _data_;
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_ = _user_data_;
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_source_object_ = source_object;
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_res_ = _res_;
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_properties_mark_recommended_resources_co (_data_);
#line 3625 "libvirt-machine-properties.c"
}


static gboolean boxes_libvirt_machine_properties_mark_recommended_resources_co (BoxesLibvirtMachinePropertiesMarkRecommendedResourcesData* _data_) {
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	switch (_data_->_state_) {
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		case 0:
#line 3634 "libvirt-machine-properties.c"
		goto _state_0;
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		case 1:
#line 3638 "libvirt-machine-properties.c"
		goto _state_1;
		default:
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_assert_not_reached ();
#line 3643 "libvirt-machine-properties.c"
	}
	_state_0:
#line 333 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp1_ = NULL;
#line 333 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp1_ = _data_->ram_property;
#line 333 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_data_->_tmp1_ == NULL) {
#line 333 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp2_ = NULL;
#line 333 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp2_ = _data_->storage_property;
#line 333 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp0_ = _data_->_tmp2_ == NULL;
#line 3658 "libvirt-machine-properties.c"
	} else {
#line 333 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp0_ = FALSE;
#line 3662 "libvirt-machine-properties.c"
	}
#line 333 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_data_->_tmp0_) {
#line 334 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_data_->_state_ == 0) {
#line 334 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3670 "libvirt-machine-properties.c"
		} else {
#line 334 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 3674 "libvirt-machine-properties.c"
		}
#line 334 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_object_unref (_data_->_async_result);
#line 334 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return FALSE;
#line 3680 "libvirt-machine-properties.c"
	}
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp3_ = NULL;
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp3_ = _data_->self->priv->machine;
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_state_ = 1;
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_properties_get_os_for_machine (_data_->self, _data_->_tmp3_, boxes_libvirt_machine_properties_mark_recommended_resources_ready, _data_);
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return FALSE;
#line 3692 "libvirt-machine-properties.c"
	_state_1:
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp4_ = NULL;
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp4_ = boxes_libvirt_machine_properties_get_os_for_machine_finish (_data_->self, _data_->_res_);
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->os = _data_->_tmp4_;
#line 337 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp5_ = NULL;
#line 337 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp5_ = _data_->os;
#line 337 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_data_->_tmp5_ == NULL) {
#line 338 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data_->os);
#line 338 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_data_->_state_ == 0) {
#line 338 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3712 "libvirt-machine-properties.c"
		} else {
#line 338 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 3716 "libvirt-machine-properties.c"
		}
#line 338 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_object_unref (_data_->_async_result);
#line 338 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return FALSE;
#line 3722 "libvirt-machine-properties.c"
	}
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp6_ = NULL;
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp6_ = _data_->self->priv->machine;
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp7_ = NULL;
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp7_ = boxes_libvirt_machine_get_domain_config (_data_->_tmp6_);
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp8_ = NULL;
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp8_ = _data_->_tmp7_;
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp9_ = NULL;
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp9_ = gvir_config_domain_get_os (_data_->_tmp8_);
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp10_ = NULL;
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp10_ = _data_->_tmp9_;
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp11_ = NULL;
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp11_ = gvir_config_domain_os_get_arch (_data_->_tmp10_);
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp12_ = NULL;
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp12_ = g_strdup (_data_->_tmp11_);
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp13_ = NULL;
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp13_ = _data_->_tmp12_;
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->_tmp10_);
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->architecture = _data_->_tmp13_;
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp14_ = NULL;
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp14_ = _data_->os;
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp15_ = NULL;
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp15_ = _data_->architecture;
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp16_ = NULL;
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp16_ = boxes_os_database_get_recommended_resources_for_os (_data_->_tmp14_, _data_->_tmp15_);
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->resources = _data_->_tmp16_;
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp17_ = NULL;
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp17_ = _data_->resources;
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_data_->_tmp17_ != NULL) {
#line 343 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp18_ = NULL;
#line 343 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp18_ = _data_->ram_property;
#line 343 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_data_->_tmp18_ != NULL) {
#line 344 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp19_ = NULL;
#line 344 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp19_ = _data_->ram_property;
#line 344 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp20_ = NULL;
#line 344 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp20_ = _data_->resources;
#line 344 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp21_ = 0LL;
#line 344 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp21_ = osinfo_resources_get_ram (_data_->_tmp20_);
#line 344 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp22_ = 0LL;
#line 344 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp22_ = _data_->_tmp21_;
#line 344 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			boxes_size_property_set_recommended (_data_->_tmp19_, (guint64) _data_->_tmp22_);
#line 3804 "libvirt-machine-properties.c"
		}
#line 345 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp23_ = NULL;
#line 345 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp23_ = _data_->storage_property;
#line 345 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_data_->_tmp23_ != NULL) {
#line 346 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp24_ = NULL;
#line 346 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp24_ = _data_->storage_property;
#line 346 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp25_ = NULL;
#line 346 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp25_ = _data_->resources;
#line 346 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp26_ = 0LL;
#line 346 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp26_ = osinfo_resources_get_storage (_data_->_tmp25_);
#line 346 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp27_ = 0LL;
#line 346 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp27_ = _data_->_tmp26_;
#line 346 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			boxes_size_property_set_recommended (_data_->_tmp24_, (guint64) _data_->_tmp27_);
#line 3830 "libvirt-machine-properties.c"
		}
	}
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->resources);
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_free0 (_data_->architecture);
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->os);
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_data_->_state_ == 0) {
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3843 "libvirt-machine-properties.c"
	} else {
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3847 "libvirt-machine-properties.c"
	}
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_unref (_data_->_async_result);
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return FALSE;
#line 3853 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_get_os_for_machine_data_free (gpointer _data) {
	BoxesLibvirtMachinePropertiesGetOsForMachineData* _data_;
	_data_ = _data;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->machine);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->result);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_slice_free (BoxesLibvirtMachinePropertiesGetOsForMachineData, _data_);
#line 3868 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_get_os_for_machine (BoxesLibvirtMachineProperties* self, BoxesLibvirtMachine* machine, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesLibvirtMachinePropertiesGetOsForMachineData* _data_;
	BoxesLibvirtMachineProperties* _tmp0_ = NULL;
	BoxesLibvirtMachine* _tmp1_ = NULL;
	BoxesLibvirtMachine* _tmp2_ = NULL;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_ = g_slice_new0 (BoxesLibvirtMachinePropertiesGetOsForMachineData);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_libvirt_machine_properties_get_os_for_machine);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_libvirt_machine_properties_get_os_for_machine_data_free);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->self = _tmp0_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = machine;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->machine);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->machine = _tmp2_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_properties_get_os_for_machine_co (_data_);
#line 3897 "libvirt-machine-properties.c"
}


static OsinfoOs* boxes_libvirt_machine_properties_get_os_for_machine_finish (BoxesLibvirtMachineProperties* self, GAsyncResult* _res_) {
	OsinfoOs* result;
	BoxesLibvirtMachinePropertiesGetOsForMachineData* _data_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	result = _data_->result;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->result = NULL;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return result;
#line 3912 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_get_os_for_machine_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesLibvirtMachinePropertiesGetOsForMachineData* _data_;
#line 357 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_ = _user_data_;
#line 357 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_source_object_ = source_object;
#line 357 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_res_ = _res_;
#line 357 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_properties_get_os_for_machine_co (_data_);
#line 3926 "libvirt-machine-properties.c"
}


static gboolean boxes_libvirt_machine_properties_get_os_for_machine_co (BoxesLibvirtMachinePropertiesGetOsForMachineData* _data_) {
#line 350 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	switch (_data_->_state_) {
#line 350 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		case 0:
#line 3935 "libvirt-machine-properties.c"
		goto _state_0;
#line 350 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		case 1:
#line 3939 "libvirt-machine-properties.c"
		goto _state_1;
		default:
#line 350 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_assert_not_reached ();
#line 3944 "libvirt-machine-properties.c"
	}
	_state_0:
#line 351 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp0_ = NULL;
#line 351 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp0_ = _data_->machine;
#line 351 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp1_ = NULL;
#line 351 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp1_ = boxes_libvirt_machine_get_domain_config (_data_->_tmp0_);
#line 351 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp2_ = NULL;
#line 351 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp2_ = _data_->_tmp1_;
#line 351 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp3_ = NULL;
#line 351 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp3_ = boxes_vm_configurator_get_os_id (_data_->_tmp2_);
#line 351 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->os_id = _data_->_tmp3_;
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp4_ = NULL;
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp4_ = _data_->os_id;
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_data_->_tmp4_ == NULL) {
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->result = NULL;
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (_data_->os_id);
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_data_->_state_ == 0) {
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3979 "libvirt-machine-properties.c"
		} else {
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 3983 "libvirt-machine-properties.c"
		}
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_object_unref (_data_->_async_result);
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return FALSE;
#line 3989 "libvirt-machine-properties.c"
	}
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp5_ = NULL;
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp5_ = boxes_media_manager_get_instance ();
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp6_ = NULL;
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp6_ = _data_->_tmp5_;
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp7_ = NULL;
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp7_ = boxes_media_manager_get_os_db (_data_->_tmp6_);
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp8_ = NULL;
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp8_ = _data_->_tmp7_;
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp9_ = NULL;
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp9_ = _g_object_ref0 (_data_->_tmp8_);
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp10_ = NULL;
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp10_ = _data_->_tmp9_;
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->_tmp6_);
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->os_db = _data_->_tmp10_;
#line 4019 "libvirt-machine-properties.c"
	{
#line 357 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp12_ = NULL;
#line 357 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp12_ = _data_->os_db;
#line 357 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp13_ = NULL;
#line 357 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp13_ = _data_->os_id;
#line 357 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_state_ = 1;
#line 357 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_os_database_get_os_by_id (_data_->_tmp12_, _data_->_tmp13_, boxes_libvirt_machine_properties_get_os_for_machine_ready, _data_);
#line 357 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return FALSE;
#line 4035 "libvirt-machine-properties.c"
		_state_1:
#line 357 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp14_ = NULL;
#line 357 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp14_ = boxes_os_database_get_os_by_id_finish (_data_->_tmp12_, _data_->_res_, &_data_->_inner_error_);
#line 357 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp11_ = _data_->_tmp14_;
#line 357 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 357 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			if (_data_->_inner_error_->domain == BOXES_OS_DATABASE_ERROR) {
#line 4047 "libvirt-machine-properties.c"
				goto __catch43_boxes_os_database_error;
			}
#line 357 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (_data_->os_db);
#line 357 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_free0 (_data_->os_id);
#line 357 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 357 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_clear_error (&_data_->_inner_error_);
#line 357 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			return FALSE;
#line 4060 "libvirt-machine-properties.c"
		}
#line 357 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp15_ = NULL;
#line 357 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp15_ = _data_->_tmp11_;
#line 357 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp11_ = NULL;
#line 357 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->result = _data_->_tmp15_;
#line 357 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data_->_tmp11_);
#line 357 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data_->os_db);
#line 357 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (_data_->os_id);
#line 357 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_data_->_state_ == 0) {
#line 357 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4080 "libvirt-machine-properties.c"
		} else {
#line 357 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 4084 "libvirt-machine-properties.c"
		}
#line 357 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_object_unref (_data_->_async_result);
#line 357 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return FALSE;
#line 4090 "libvirt-machine-properties.c"
	}
	goto __finally43;
	__catch43_boxes_os_database_error:
	{
#line 356 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 356 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_inner_error_ = NULL;
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp16_ = NULL;
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp16_ = _data_->os_id;
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp17_ = NULL;
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp17_ = _data_->_error_;
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp18_ = NULL;
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp18_ = _data_->_tmp17_->message;
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_warning ("libvirt-machine-properties.vala:359: Failed to find OS with ID '%s': %" \
"s", _data_->_tmp16_, _data_->_tmp18_);
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->result = NULL;
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (_data_->_error_);
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data_->os_db);
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (_data_->os_id);
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_data_->_state_ == 0) {
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4125 "libvirt-machine-properties.c"
		} else {
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 4129 "libvirt-machine-properties.c"
		}
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_object_unref (_data_->_async_result);
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return FALSE;
#line 4135 "libvirt-machine-properties.c"
	}
	__finally43:
#line 356 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->os_db);
#line 356 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_free0 (_data_->os_id);
#line 356 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 356 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_clear_error (&_data_->_inner_error_);
#line 356 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return FALSE;
#line 350 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->os_db);
#line 350 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_free0 (_data_->os_id);
#line 350 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_data_->_state_ == 0) {
#line 350 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4156 "libvirt-machine-properties.c"
	} else {
#line 350 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 4160 "libvirt-machine-properties.c"
	}
#line 350 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_unref (_data_->_async_result);
#line 350 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return FALSE;
#line 4166 "libvirt-machine-properties.c"
}


static Block44Data* block44_data_ref (Block44Data* _data44_) {
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_atomic_int_inc (&_data44_->_ref_count_);
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return _data44_;
#line 4175 "libvirt-machine-properties.c"
}


static void block44_data_unref (void * _userdata_) {
	Block44Data* _data44_;
	_data44_ = (Block44Data*) _userdata_;
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (g_atomic_int_dec_and_test (&_data44_->_ref_count_)) {
#line 4184 "libvirt-machine-properties.c"
		BoxesLibvirtMachineProperties* self;
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		self = _data44_->self;
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data44_->prop);
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data44_->net_graph);
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data44_->io_graph);
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data44_->cpu_graph);
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (self);
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_slice_free (Block44Data, _data44_);
#line 4200 "libvirt-machine-properties.c"
	}
}


static void __lambda136_ (Block44Data* _data44_) {
	BoxesLibvirtMachineProperties* self;
	BoxesLibvirtMachine* _tmp0_ = NULL;
	gdouble* _tmp1_ = NULL;
	gint _tmp1__length1 = 0;
	BoxesLibvirtMachine* _tmp2_ = NULL;
	gdouble* _tmp3_ = NULL;
	gint _tmp3__length1 = 0;
	BoxesLibvirtMachine* _tmp4_ = NULL;
	gdouble* _tmp5_ = NULL;
	gint _tmp5__length1 = 0;
#line 392 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self = _data44_->self;
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = self->priv->machine;
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = _tmp0_->cpu_stats;
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1__length1 = _tmp0_->cpu_stats_length1;
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_resource_graph_set_points (_data44_->cpu_graph, _tmp1_, _tmp1__length1);
#line 394 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = self->priv->machine;
#line 394 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = _tmp2_->io_stats;
#line 394 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3__length1 = _tmp2_->io_stats_length1;
#line 394 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_resource_graph_set_points (_data44_->io_graph, _tmp3_, _tmp3__length1);
#line 395 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp4_ = self->priv->machine;
#line 395 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp5_ = _tmp4_->net_stats;
#line 395 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp5__length1 = _tmp4_->net_stats_length1;
#line 395 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_resource_graph_set_points (_data44_->net_graph, _tmp5_, _tmp5__length1);
#line 4242 "libvirt-machine-properties.c"
}


static void ___lambda136__boxes_libvirt_machine_stats_updated (BoxesLibvirtMachine* _sender, gpointer self) {
#line 392 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	__lambda136_ (self);
#line 4249 "libvirt-machine-properties.c"
}


static void __lambda137_ (Block44Data* _data44_) {
	BoxesLibvirtMachineProperties* self;
	BoxesLibvirtMachine* _tmp0_ = NULL;
	gulong _tmp1_ = 0UL;
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self = _data44_->self;
#line 401 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = self->priv->machine;
#line 401 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_signal_handler_disconnect ((GObject*) _tmp0_, _data44_->stats_id);
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = _data44_->flushed_id;
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_signal_handler_disconnect ((GObject*) _data44_->prop, _tmp1_);
#line 4267 "libvirt-machine-properties.c"
}


static void ___lambda137__boxes_property_flushed (BoxesProperty* _sender, gpointer self) {
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	__lambda137_ (self);
#line 4274 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_add_resource_usage_graphs (BoxesLibvirtMachineProperties* self, GList** list) {
	Block44Data* _data44_;
	GtkGrid* grid = NULL;
	GtkGrid* _tmp0_ = NULL;
	BoxesResourceGraph* _tmp1_ = NULL;
	GtkLabel* label = NULL;
	const gchar* _tmp2_ = NULL;
	GtkLabel* _tmp3_ = NULL;
	GtkLabel* _tmp4_ = NULL;
	BoxesResourceGraph* _tmp5_ = NULL;
	const gchar* _tmp6_ = NULL;
	GtkLabel* _tmp7_ = NULL;
	GtkLabel* _tmp8_ = NULL;
	BoxesResourceGraph* _tmp9_ = NULL;
	const gchar* _tmp10_ = NULL;
	GtkLabel* _tmp11_ = NULL;
	GtkLabel* _tmp12_ = NULL;
	BoxesLibvirtMachine* _tmp13_ = NULL;
	gulong _tmp14_ = 0UL;
	BoxesProperty* _tmp15_ = NULL;
	gulong _tmp16_ = 0UL;
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (self != NULL);
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data44_ = g_slice_new0 (Block44Data);
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data44_->_ref_count_ = 1;
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data44_->self = g_object_ref (self);
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = (GtkGrid*) gtk_grid_new ();
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_ref_sink (_tmp0_);
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	grid = _tmp0_;
#line 366 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_widget_set_margin_top ((GtkWidget*) grid, 20);
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_widget_set_margin_bottom ((GtkWidget*) grid, 20);
#line 368 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_grid_set_row_spacing (grid, 5);
#line 369 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_grid_set_column_spacing (grid, 10);
#line 370 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_grid_set_column_homogeneous (grid, TRUE);
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_widget_set_vexpand ((GtkWidget*) grid, FALSE);
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = boxes_resource_graph_new ((gdouble) 100);
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_ref_sink (_tmp1_);
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data44_->cpu_graph = _tmp1_;
#line 375 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_resource_graph_set_npoints (_data44_->cpu_graph, 20);
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_grid_attach (grid, (GtkWidget*) _data44_->cpu_graph, 0, 0, 1, 1);
#line 377 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = _ ("CPU");
#line 377 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = (GtkLabel*) gtk_label_new (_tmp2_);
#line 377 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_ref_sink (_tmp3_);
#line 377 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	label = _tmp3_;
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp4_ = label;
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_grid_attach (grid, (GtkWidget*) _tmp4_, 0, 1, 1, 1);
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp5_ = boxes_resource_graph_new ((gdouble) 104857600);
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_ref_sink (_tmp5_);
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data44_->io_graph = _tmp5_;
#line 382 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_grid_attach (grid, (GtkWidget*) _data44_->io_graph, 1, 0, 1, 1);
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp6_ = _ ("I/O");
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp7_ = (GtkLabel*) gtk_label_new (_tmp6_);
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_ref_sink (_tmp7_);
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (label);
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	label = _tmp7_;
#line 384 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp8_ = label;
#line 384 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_grid_attach (grid, (GtkWidget*) _tmp8_, 1, 1, 1, 1);
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp9_ = boxes_resource_graph_new ((gdouble) 1048576);
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_ref_sink (_tmp9_);
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data44_->net_graph = _tmp9_;
#line 388 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_grid_attach (grid, (GtkWidget*) _data44_->net_graph, 2, 0, 1, 1);
#line 389 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp10_ = _ ("Network");
#line 389 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp11_ = (GtkLabel*) gtk_label_new (_tmp10_);
#line 389 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_ref_sink (_tmp11_);
#line 389 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (label);
#line 389 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	label = _tmp11_;
#line 390 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp12_ = label;
#line 390 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_grid_attach (grid, (GtkWidget*) _tmp12_, 2, 1, 1, 1);
#line 392 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp13_ = self->priv->machine;
#line 392 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp14_ = g_signal_connect_data (_tmp13_, "stats-updated", (GCallback) ___lambda136__boxes_libvirt_machine_stats_updated, block44_data_ref (_data44_), (GClosureNotify) block44_data_unref, 0);
#line 392 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data44_->stats_id = _tmp14_;
#line 398 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp15_ = boxes_iproperties_provider_add_property ((BoxesIPropertiesProvider*) self, list, NULL, (GtkWidget*) grid, NULL);
#line 398 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data44_->prop = _tmp15_;
#line 399 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data44_->flushed_id = (gulong) 0;
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp16_ = g_signal_connect_data (_data44_->prop, "flushed", (GCallback) ___lambda137__boxes_property_flushed, block44_data_ref (_data44_), (GClosureNotify) block44_data_unref, 0);
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data44_->flushed_id = _tmp16_;
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (label);
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (grid);
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	block44_data_unref (_data44_);
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data44_ = NULL;
#line 4415 "libvirt-machine-properties.c"
}


static Block45Data* block45_data_ref (Block45Data* _data45_) {
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_atomic_int_inc (&_data45_->_ref_count_);
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return _data45_;
#line 4424 "libvirt-machine-properties.c"
}


static void block45_data_unref (void * _userdata_) {
	Block45Data* _data45_;
	_data45_ = (Block45Data*) _userdata_;
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (g_atomic_int_dec_and_test (&_data45_->_ref_count_)) {
#line 4433 "libvirt-machine-properties.c"
		BoxesLibvirtMachineProperties* self;
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		self = _data45_->self;
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data45_->prop);
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data45_->shutdown_button);
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data45_->restart_button);
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (self);
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_slice_free (Block45Data, _data45_);
#line 4447 "libvirt-machine-properties.c"
	}
}


static void __lambda138_ (BoxesLibvirtMachineProperties* self) {
	BoxesLibvirtMachine* _tmp0_ = NULL;
	BoxesLibvirtMachine* _tmp1_ = NULL;
	BoxesAppWindow* _tmp2_ = NULL;
	BoxesAppWindow* _tmp3_ = NULL;
	BoxesPropertiesWindow* _tmp4_ = NULL;
#line 420 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = self->priv->machine;
#line 420 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_machine_restart ((BoxesMachine*) _tmp0_);
#line 421 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = self->priv->machine;
#line 421 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = boxes_machine_get_window ((BoxesMachine*) _tmp1_);
#line 421 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = _tmp2_;
#line 421 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp4_ = _tmp3_->props_window;
#line 421 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_properties_window_revert_state (_tmp4_);
#line 4472 "libvirt-machine-properties.c"
}


static void ___lambda138__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 419 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	__lambda138_ ((BoxesLibvirtMachineProperties*) self);
#line 4479 "libvirt-machine-properties.c"
}


static void __lambda144_ (BoxesLibvirtMachineProperties* self) {
	BoxesLibvirtMachine* _tmp0_ = NULL;
	BoxesLibvirtMachine* _tmp1_ = NULL;
	BoxesAppWindow* _tmp2_ = NULL;
	BoxesAppWindow* _tmp3_ = NULL;
	BoxesPropertiesWindow* _tmp4_ = NULL;
#line 429 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = self->priv->machine;
#line 429 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_force_shutdown (_tmp0_);
#line 430 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = self->priv->machine;
#line 430 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = boxes_machine_get_window ((BoxesMachine*) _tmp1_);
#line 430 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = _tmp2_;
#line 430 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp4_ = _tmp3_->props_window;
#line 430 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_properties_window_revert_state (_tmp4_);
#line 4503 "libvirt-machine-properties.c"
}


static void ___lambda144__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 428 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	__lambda144_ ((BoxesLibvirtMachineProperties*) self);
#line 4510 "libvirt-machine-properties.c"
}


static void __lambda145_ (Block45Data* _data45_) {
	BoxesLibvirtMachineProperties* self;
	BoxesLibvirtMachine* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	BoxesLibvirtMachine* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
#line 435 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self = _data45_->self;
#line 436 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = self->priv->machine;
#line 436 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = boxes_machine_is_running ((BoxesMachine*) _tmp0_);
#line 436 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _data45_->restart_button, _tmp1_);
#line 437 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = self->priv->machine;
#line 437 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = boxes_machine_is_running ((BoxesMachine*) _tmp2_);
#line 437 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _data45_->shutdown_button, _tmp3_);
#line 4534 "libvirt-machine-properties.c"
}


static void ___lambda145__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 435 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	__lambda145_ (self);
#line 4541 "libvirt-machine-properties.c"
}


static void __lambda146_ (BoxesLibvirtMachineProperties* self) {
	gchar* log = NULL;
	gchar* _tmp0_ = NULL;
	BoxesLibvirtMachine* _tmp1_ = NULL;
	BoxesAppWindow* _tmp2_ = NULL;
	BoxesAppWindow* _tmp3_ = NULL;
	BoxesPropertiesWindow* _tmp4_ = NULL;
#line 444 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = boxes_libvirt_machine_properties_collect_logs (self);
#line 444 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	log = _tmp0_;
#line 445 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = self->priv->machine;
#line 445 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = boxes_machine_get_window ((BoxesMachine*) _tmp1_);
#line 445 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = _tmp2_;
#line 445 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp4_ = _tmp3_->props_window;
#line 445 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_properties_window_show_troubleshoot_log (_tmp4_, log);
#line 443 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_free0 (log);
#line 4568 "libvirt-machine-properties.c"
}


static void ___lambda146__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 443 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	__lambda146_ ((BoxesLibvirtMachineProperties*) self);
#line 4575 "libvirt-machine-properties.c"
}


static void __lambda147_ (Block45Data* _data45_) {
	BoxesLibvirtMachineProperties* self;
	BoxesLibvirtMachine* _tmp0_ = NULL;
	gulong _tmp1_ = 0UL;
#line 450 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self = _data45_->self;
#line 451 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = self->priv->machine;
#line 451 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_signal_handler_disconnect ((GObject*) _tmp0_, _data45_->state_notify_id);
#line 452 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = _data45_->flushed_id;
#line 452 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_signal_handler_disconnect ((GObject*) _data45_->prop, _tmp1_);
#line 4593 "libvirt-machine-properties.c"
}


static void ___lambda147__boxes_property_flushed (BoxesProperty* _sender, gpointer self) {
#line 450 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	__lambda147_ (self);
#line 4600 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_add_system_props_buttons (BoxesLibvirtMachineProperties* self, GList** list) {
	Block45Data* _data45_;
	GtkGrid* grid = NULL;
	GtkGrid* _tmp0_ = NULL;
	GtkGrid* inner_grid = NULL;
	GtkGrid* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	GtkButton* _tmp3_ = NULL;
	BoxesLibvirtMachine* _tmp4_ = NULL;
	gboolean _tmp5_ = FALSE;
	const gchar* _tmp6_ = NULL;
	GtkButton* _tmp7_ = NULL;
	GtkStyleContext* _tmp8_ = NULL;
	BoxesLibvirtMachine* _tmp9_ = NULL;
	gboolean _tmp10_ = FALSE;
	BoxesLibvirtMachine* _tmp11_ = NULL;
	gulong _tmp12_ = 0UL;
	GtkButton* log_button = NULL;
	const gchar* _tmp13_ = NULL;
	GtkButton* _tmp14_ = NULL;
	BoxesProperty* _tmp15_ = NULL;
	gulong _tmp16_ = 0UL;
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (self != NULL);
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data45_ = g_slice_new0 (Block45Data);
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data45_->_ref_count_ = 1;
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data45_->self = g_object_ref (self);
#line 407 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = (GtkGrid*) gtk_grid_new ();
#line 407 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_ref_sink (_tmp0_);
#line 407 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	grid = _tmp0_;
#line 408 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_widget_set_margin_bottom ((GtkWidget*) grid, 20);
#line 409 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_grid_set_column_spacing (grid, 5);
#line 410 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_widget_set_hexpand ((GtkWidget*) grid, TRUE);
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = (GtkGrid*) gtk_grid_new ();
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_ref_sink (_tmp1_);
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	inner_grid = _tmp1_;
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_grid_set_column_spacing (inner_grid, 5);
#line 414 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_widget_set_halign ((GtkWidget*) inner_grid, GTK_ALIGN_START);
#line 415 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_widget_set_hexpand ((GtkWidget*) inner_grid, TRUE);
#line 416 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_grid_attach (grid, (GtkWidget*) inner_grid, 0, 0, 1, 1);
#line 418 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = _ ("Restart");
#line 418 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = (GtkButton*) gtk_button_new_with_label (_tmp2_);
#line 418 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_ref_sink (_tmp3_);
#line 418 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data45_->restart_button = _tmp3_;
#line 419 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_signal_connect_object (_data45_->restart_button, "clicked", (GCallback) ___lambda138__gtk_button_clicked, self, 0);
#line 423 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp4_ = self->priv->machine;
#line 423 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp5_ = boxes_machine_is_running ((BoxesMachine*) _tmp4_);
#line 423 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _data45_->restart_button, _tmp5_);
#line 424 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_grid_attach (inner_grid, (GtkWidget*) _data45_->restart_button, 1, 0, 1, 1);
#line 426 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp6_ = _ ("Force Shutdown");
#line 426 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp7_ = (GtkButton*) gtk_button_new_with_label (_tmp6_);
#line 426 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_ref_sink (_tmp7_);
#line 426 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data45_->shutdown_button = _tmp7_;
#line 427 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp8_ = gtk_widget_get_style_context ((GtkWidget*) _data45_->shutdown_button);
#line 427 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_style_context_add_class (_tmp8_, GTK_STYLE_CLASS_DESTRUCTIVE_ACTION);
#line 428 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_signal_connect_object (_data45_->shutdown_button, "clicked", (GCallback) ___lambda144__gtk_button_clicked, self, 0);
#line 432 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp9_ = self->priv->machine;
#line 432 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp10_ = boxes_machine_is_running ((BoxesMachine*) _tmp9_);
#line 432 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _data45_->shutdown_button, _tmp10_);
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_grid_attach (inner_grid, (GtkWidget*) _data45_->shutdown_button, 2, 0, 1, 1);
#line 435 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp11_ = self->priv->machine;
#line 435 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp12_ = g_signal_connect_data ((GObject*) _tmp11_, "notify::state", (GCallback) ___lambda145__g_object_notify, block45_data_ref (_data45_), (GClosureNotify) block45_data_unref, 0);
#line 435 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data45_->state_notify_id = _tmp12_;
#line 440 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp13_ = _ ("Troubleshooting Log");
#line 440 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp14_ = (GtkButton*) gtk_button_new_with_label (_tmp13_);
#line 440 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_ref_sink (_tmp14_);
#line 440 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	log_button = _tmp14_;
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_widget_set_halign ((GtkWidget*) log_button, GTK_ALIGN_END);
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_grid_attach (grid, (GtkWidget*) log_button, 1, 0, 1, 1);
#line 443 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_signal_connect_object (log_button, "clicked", (GCallback) ___lambda146__gtk_button_clicked, self, 0);
#line 448 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp15_ = boxes_iproperties_provider_add_property ((BoxesIPropertiesProvider*) self, list, NULL, (GtkWidget*) grid, NULL);
#line 448 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data45_->prop = _tmp15_;
#line 449 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data45_->flushed_id = (gulong) 0;
#line 450 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp16_ = g_signal_connect_data (_data45_->prop, "flushed", (GCallback) ___lambda147__boxes_property_flushed, block45_data_ref (_data45_), (GClosureNotify) block45_data_unref, 0);
#line 450 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data45_->flushed_id = _tmp16_;
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (log_button);
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (inner_grid);
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (grid);
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	block45_data_unref (_data45_);
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data45_ = NULL;
#line 4740 "libvirt-machine-properties.c"
}


static Block46Data* block46_data_ref (Block46Data* _data46_) {
#line 457 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_atomic_int_inc (&_data46_->_ref_count_);
#line 457 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return _data46_;
#line 4749 "libvirt-machine-properties.c"
}


static void block46_data_unref (void * _userdata_) {
	Block46Data* _data46_;
	_data46_ = (Block46Data*) _userdata_;
#line 457 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (g_atomic_int_dec_and_test (&_data46_->_ref_count_)) {
#line 4758 "libvirt-machine-properties.c"
		BoxesLibvirtMachineProperties* self;
#line 457 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		self = _data46_->self;
#line 457 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data46_->property);
#line 457 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (self);
#line 457 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_slice_free (Block46Data, _data46_);
#line 4768 "libvirt-machine-properties.c"
	}
}


static void _boxes_libvirt_machine_properties_on_ram_changed_boxes_size_property_changed (BoxesSizeProperty* _sender, guint64 value, gpointer self) {
#line 475 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_properties_on_ram_changed ((BoxesLibvirtMachineProperties*) self, _sender, value);
#line 4776 "libvirt-machine-properties.c"
}


static void ___lambda149_ (Block46Data* _data46_) {
	BoxesLibvirtMachineProperties* self;
	BoxesLibvirtMachine* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
#line 477 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self = _data46_->self;
#line 478 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = self->priv->machine;
#line 478 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = boxes_machine_is_on ((BoxesMachine*) _tmp0_);
#line 478 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (!_tmp1_) {
#line 4792 "libvirt-machine-properties.c"
		BoxesSizeProperty* _tmp2_ = NULL;
#line 479 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp2_ = _data46_->property;
#line 479 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_property_set_reboot_required ((BoxesProperty*) _tmp2_, FALSE);
#line 4798 "libvirt-machine-properties.c"
	}
}


static void ____lambda149__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 477 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	___lambda149_ (self);
#line 4806 "libvirt-machine-properties.c"
}


static BoxesSizeProperty* boxes_libvirt_machine_properties_add_ram_property (BoxesLibvirtMachineProperties* self, GList** list) {
	BoxesSizeProperty* result = NULL;
	GError * _inner_error_ = NULL;
#line 456 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 4815 "libvirt-machine-properties.c"
	{
		Block46Data* _data46_;
		GVirNodeInfo* _tmp0_ = NULL;
		BoxesLibvirtMachine* _tmp1_ = NULL;
		GVirConnection* _tmp2_ = NULL;
		GVirConnection* _tmp3_ = NULL;
		GVirNodeInfo* _tmp4_ = NULL;
		gulong max_ram = 0UL;
		GVirNodeInfo* _tmp5_ = NULL;
		GVirNodeInfo* _tmp6_ = NULL;
		gulong _tmp7_ = 0UL;
		gulong _tmp8_ = 0UL;
		const gchar* _tmp9_ = NULL;
		BoxesLibvirtMachine* _tmp10_ = NULL;
		GVirConfigDomain* _tmp11_ = NULL;
		GVirConfigDomain* _tmp12_ = NULL;
		guint64 _tmp13_ = 0ULL;
		guint64 _tmp14_ = 0ULL;
		gulong _tmp15_ = 0UL;
		BoxesSizeProperty* _tmp16_ = NULL;
		BoxesSizeProperty* _tmp17_ = NULL;
		BoxesSizeProperty* _tmp18_ = NULL;
		GtkWidget* _tmp19_ = NULL;
		GtkWidget* _tmp20_ = NULL;
		gboolean _tmp21_ = FALSE;
		gboolean _tmp22_ = FALSE;
		BoxesLibvirtMachine* _tmp23_ = NULL;
		GVirConfigDomain* _tmp24_ = NULL;
		GVirConfigDomain* _tmp25_ = NULL;
		gboolean _tmp26_ = FALSE;
		BoxesLibvirtMachine* _tmp38_ = NULL;
		BoxesSizeProperty* _tmp39_ = NULL;
		BoxesSizeProperty* _tmp40_ = NULL;
		BoxesSizeProperty* _tmp41_ = NULL;
#line 457 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data46_ = g_slice_new0 (Block46Data);
#line 457 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data46_->_ref_count_ = 1;
#line 457 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data46_->self = g_object_ref (self);
#line 458 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp1_ = self->priv->machine;
#line 458 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp2_ = boxes_libvirt_machine_get_connection (_tmp1_);
#line 458 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp3_ = _tmp2_;
#line 458 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp4_ = gvir_connection_get_node_info (_tmp3_, &_inner_error_);
#line 458 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp0_ = _tmp4_;
#line 458 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 458 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			block46_data_unref (_data46_);
#line 458 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data46_ = NULL;
#line 4872 "libvirt-machine-properties.c"
			goto __catch44_g_error;
		}
#line 458 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp5_ = _tmp0_;
#line 458 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp0_ = NULL;
#line 458 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp6_ = _tmp5_;
#line 458 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp7_ = _tmp6_->memory;
#line 458 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp8_ = _tmp7_;
#line 458 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		__vala_GVirNodeInfo_free0 (_tmp6_);
#line 458 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		max_ram = _tmp8_;
#line 460 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp9_ = _ ("Memory");
#line 460 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp10_ = self->priv->machine;
#line 460 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp11_ = boxes_libvirt_machine_get_domain_config (_tmp10_);
#line 460 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp12_ = _tmp11_;
#line 460 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp13_ = gvir_config_domain_get_memory (_tmp12_);
#line 460 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp14_ = _tmp13_;
#line 460 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp15_ = max_ram;
#line 460 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp16_ = boxes_iproperties_provider_add_size_property ((BoxesIPropertiesProvider*) self, list, _tmp9_, _tmp14_ * OSINFO_KIBIBYTES, (guint64) (64 * OSINFO_MEBIBYTES), (guint64) (_tmp15_ * OSINFO_KIBIBYTES), (guint64) 0, (guint64) (64 * OSINFO_MEBIBYTES), G_FORMAT_SIZE_IEC_UNITS);
#line 460 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data46_->property = _tmp16_;
#line 468 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp17_ = _data46_->property;
#line 468 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_property_set_description_alignment ((BoxesProperty*) _tmp17_, GTK_ALIGN_START);
#line 469 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp18_ = _data46_->property;
#line 469 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp19_ = boxes_property_get_widget ((BoxesProperty*) _tmp18_);
#line 469 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp20_ = _tmp19_;
#line 469 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gtk_widget_set_margin_top (_tmp20_, 5);
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp23_ = self->priv->machine;
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp24_ = boxes_libvirt_machine_get_domain_config (_tmp23_);
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp25_ = _tmp24_;
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp26_ = boxes_vm_configurator_is_install_config (_tmp25_);
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_tmp26_) {
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp22_ = TRUE;
#line 4931 "libvirt-machine-properties.c"
		} else {
			BoxesLibvirtMachine* _tmp27_ = NULL;
			GVirConfigDomain* _tmp28_ = NULL;
			GVirConfigDomain* _tmp29_ = NULL;
			gboolean _tmp30_ = FALSE;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp27_ = self->priv->machine;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp28_ = boxes_libvirt_machine_get_domain_config (_tmp27_);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp29_ = _tmp28_;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp30_ = boxes_vm_configurator_is_live_config (_tmp29_);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp22_ = _tmp30_;
#line 4947 "libvirt-machine-properties.c"
		}
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_tmp22_) {
#line 4951 "libvirt-machine-properties.c"
			BoxesLibvirtMachine* _tmp31_ = NULL;
			BoxesAppWindow* _tmp32_ = NULL;
			BoxesAppWindow* _tmp33_ = NULL;
			BoxesUIState _tmp34_ = 0;
			BoxesUIState _tmp35_ = 0;
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp31_ = self->priv->machine;
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp32_ = boxes_machine_get_window ((BoxesMachine*) _tmp31_);
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp33_ = _tmp32_;
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp34_ = boxes_ui_get_ui_state ((BoxesUI*) _tmp33_);
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp35_ = _tmp34_;
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp21_ = _tmp35_ != BOXES_UI_STATE_WIZARD;
#line 4969 "libvirt-machine-properties.c"
		} else {
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp21_ = FALSE;
#line 4973 "libvirt-machine-properties.c"
		}
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_tmp21_) {
#line 4977 "libvirt-machine-properties.c"
			BoxesSizeProperty* _tmp36_ = NULL;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp36_ = _data46_->property;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			boxes_property_set_sensitive ((BoxesProperty*) _tmp36_, FALSE);
#line 4983 "libvirt-machine-properties.c"
		} else {
			BoxesSizeProperty* _tmp37_ = NULL;
#line 475 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp37_ = _data46_->property;
#line 475 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_signal_connect_object (_tmp37_, "changed", (GCallback) _boxes_libvirt_machine_properties_on_ram_changed_boxes_size_property_changed, self, 0);
#line 4990 "libvirt-machine-properties.c"
		}
#line 477 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp38_ = self->priv->machine;
#line 477 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_signal_connect_data ((GObject*) _tmp38_, "notify::state", (GCallback) ____lambda149__g_object_notify, block46_data_ref (_data46_), (GClosureNotify) block46_data_unref, 0);
#line 482 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp39_ = _data46_->property;
#line 482 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_libvirt_machine_properties_update_ram_property (self, (BoxesProperty*) _tmp39_);
#line 484 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp40_ = _data46_->property;
#line 484 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp41_ = _g_object_ref0 (_tmp40_);
#line 484 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		result = _tmp41_;
#line 484 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		__vala_GVirNodeInfo_free0 (_tmp0_);
#line 484 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		block46_data_unref (_data46_);
#line 484 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data46_ = NULL;
#line 484 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return result;
#line 5014 "libvirt-machine-properties.c"
	}
	goto __finally44;
	__catch44_g_error:
	{
		GError* _error_ = NULL;
#line 457 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_error_ = _inner_error_;
#line 457 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_inner_error_ = NULL;
#line 486 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		result = NULL;
#line 486 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (_error_);
#line 486 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return result;
#line 5030 "libvirt-machine-properties.c"
	}
	__finally44:
#line 457 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 457 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_clear_error (&_inner_error_);
#line 457 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return NULL;
#line 5039 "libvirt-machine-properties.c"
}


static Block47Data* block47_data_ref (Block47Data* _data47_) {
#line 490 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_atomic_int_inc (&_data47_->_ref_count_);
#line 490 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return _data47_;
#line 5048 "libvirt-machine-properties.c"
}


static void block47_data_unref (void * _userdata_) {
	Block47Data* _data47_;
	_data47_ = (Block47Data*) _userdata_;
#line 490 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (g_atomic_int_dec_and_test (&_data47_->_ref_count_)) {
#line 5057 "libvirt-machine-properties.c"
		BoxesLibvirtMachineProperties* self;
#line 490 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		self = _data47_->self;
#line 490 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data47_->property);
#line 490 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (self);
#line 490 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_slice_free (Block47Data, _data47_);
#line 5067 "libvirt-machine-properties.c"
	}
}


static gboolean __lambda148_ (Block47Data* _data47_) {
	BoxesLibvirtMachineProperties* self;
	gboolean result = FALSE;
	guint64 ram = 0ULL;
	guint64 _tmp0_ = 0ULL;
	BoxesProperty* _tmp24_ = NULL;
	GError * _inner_error_ = NULL;
#line 492 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self = _data47_->self;
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = _data47_->value;
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	ram = ((_tmp0_ + OSINFO_KIBIBYTES) - 1) / OSINFO_KIBIBYTES;
#line 5085 "libvirt-machine-properties.c"
	{
		GVirConfigDomain* config = NULL;
		BoxesLibvirtMachine* _tmp1_ = NULL;
		GVirDomain* _tmp2_ = NULL;
		GVirDomain* _tmp3_ = NULL;
		GVirConfigDomain* _tmp4_ = NULL;
		GVirConfigDomain* _tmp5_ = NULL;
		guint64 _tmp6_ = 0ULL;
		GVirConfigDomain* _tmp7_ = NULL;
		GObjectClass* _tmp8_ = NULL;
		GParamSpec* _tmp9_ = NULL;
		BoxesLibvirtMachine* _tmp12_ = NULL;
		GVirDomain* _tmp13_ = NULL;
		GVirDomain* _tmp14_ = NULL;
		GVirConfigDomain* _tmp15_ = NULL;
		guint64 _tmp16_ = 0ULL;
#line 495 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp1_ = self->priv->machine;
#line 495 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp2_ = boxes_libvirt_machine_get_domain (_tmp1_);
#line 495 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp3_ = _tmp2_;
#line 495 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp4_ = gvir_domain_get_config (_tmp3_, (guint) GVIR_DOMAIN_XML_INACTIVE, &_inner_error_);
#line 495 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		config = _tmp4_;
#line 495 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5114 "libvirt-machine-properties.c"
			goto __catch45_g_error;
		}
#line 496 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp5_ = config;
#line 496 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp6_ = ram;
#line 496 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gvir_config_domain_set_memory (_tmp5_, _tmp6_);
#line 497 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp7_ = config;
#line 497 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp8_ = G_OBJECT_GET_CLASS ((GObject*) _tmp7_);
#line 497 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp9_ = g_object_class_find_property (_tmp8_, "current-memory");
#line 497 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_tmp9_ != NULL) {
#line 5131 "libvirt-machine-properties.c"
			GVirConfigDomain* _tmp10_ = NULL;
			guint64 _tmp11_ = 0ULL;
#line 498 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp10_ = config;
#line 498 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp11_ = ram;
#line 498 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_object_set ((GObject*) _tmp10_, "current-memory", _tmp11_, NULL);
#line 5140 "libvirt-machine-properties.c"
		}
#line 499 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp12_ = self->priv->machine;
#line 499 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp13_ = boxes_libvirt_machine_get_domain (_tmp12_);
#line 499 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp14_ = _tmp13_;
#line 499 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp15_ = config;
#line 499 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gvir_domain_set_config (_tmp14_, _tmp15_, &_inner_error_);
#line 499 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 499 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (config);
#line 5156 "libvirt-machine-properties.c"
			goto __catch45_g_error;
		}
#line 500 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp16_ = ram;
#line 500 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_debug ("libvirt-machine-properties.vala:500: RAM changed to %llu KiB", _tmp16_);
#line 494 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (config);
#line 5165 "libvirt-machine-properties.c"
	}
	goto __finally45;
	__catch45_g_error:
	{
		GError* _error_ = NULL;
		BoxesLibvirtMachine* _tmp17_ = NULL;
		GVirDomain* _tmp18_ = NULL;
		GVirDomain* _tmp19_ = NULL;
		const gchar* _tmp20_ = NULL;
		guint64 _tmp21_ = 0ULL;
		GError* _tmp22_ = NULL;
		const gchar* _tmp23_ = NULL;
#line 494 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_error_ = _inner_error_;
#line 494 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_inner_error_ = NULL;
#line 502 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp17_ = self->priv->machine;
#line 502 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp18_ = boxes_libvirt_machine_get_domain (_tmp17_);
#line 502 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp19_ = _tmp18_;
#line 502 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp20_ = gvir_domain_get_name (_tmp19_);
#line 502 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp21_ = ram;
#line 502 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp22_ = _error_;
#line 502 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp23_ = _tmp22_->message;
#line 502 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_warning ("libvirt-machine-properties.vala:502: Failed to change RAM of box '%s' " \
"to %llu KiB: %s", _tmp20_, _tmp21_, _tmp23_);
#line 494 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (_error_);
#line 5200 "libvirt-machine-properties.c"
	}
	__finally45:
#line 494 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 494 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 494 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_clear_error (&_inner_error_);
#line 494 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return FALSE;
#line 5211 "libvirt-machine-properties.c"
	}
#line 508 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp24_ = _data47_->property;
#line 508 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_properties_update_ram_property (self, _tmp24_);
#line 510 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	result = FALSE;
#line 510 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return result;
#line 5221 "libvirt-machine-properties.c"
}


static gboolean ___lambda148__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda148_ (self);
#line 492 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return result;
#line 5230 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_on_ram_changed (BoxesLibvirtMachineProperties* self, BoxesProperty* property, guint64 value) {
	Block47Data* _data47_;
	BoxesProperty* _tmp0_ = NULL;
	BoxesProperty* _tmp1_ = NULL;
	guint64 _tmp2_ = 0ULL;
	BoxesProperty* _tmp3_ = NULL;
#line 490 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (self != NULL);
#line 490 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (property != NULL);
#line 490 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data47_ = g_slice_new0 (Block47Data);
#line 490 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data47_->_ref_count_ = 1;
#line 490 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data47_->self = g_object_ref (self);
#line 490 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = property;
#line 490 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 490 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data47_->property);
#line 490 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data47_->property = _tmp1_;
#line 490 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = value;
#line 490 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data47_->value = _tmp2_;
#line 492 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = _data47_->property;
#line 492 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_property_set_deferred_change (_tmp3_, ___lambda148__gsource_func, block47_data_ref (_data47_), block47_data_unref);
#line 490 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	block47_data_unref (_data47_);
#line 490 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data47_ = NULL;
#line 5270 "libvirt-machine-properties.c"
}


static void _vala_GVirStorageVolInfo_free (GVirStorageVolInfo* self) {
#line 521 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_boxed_free (gvir_storage_vol_info_get_type (), self);
#line 5277 "libvirt-machine-properties.c"
}


static void _vala_GVirStoragePoolInfo_free (GVirStoragePoolInfo* self) {
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_boxed_free (gvir_storage_pool_info_get_type (), self);
#line 5284 "libvirt-machine-properties.c"
}


static void _boxes_libvirt_machine_properties_on_storage_changed_boxes_size_property_changed (BoxesSizeProperty* _sender, guint64 value, gpointer self) {
#line 570 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_properties_on_storage_changed ((BoxesLibvirtMachineProperties*) self, _sender, value);
#line 5291 "libvirt-machine-properties.c"
}


static BoxesSizeProperty* boxes_libvirt_machine_properties_add_storage_property (BoxesLibvirtMachineProperties* self, GList** list) {
	BoxesSizeProperty* result = NULL;
	gboolean _tmp0_ = FALSE;
	BoxesLibvirtMachine* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_ = FALSE;
	GError * _inner_error_ = NULL;
#line 514 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = self->priv->machine;
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = boxes_libvirt_machine_get_importing (_tmp1_);
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = _tmp2_;
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp3_) {
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp0_ = TRUE;
#line 5314 "libvirt-machine-properties.c"
	} else {
		BoxesLibvirtMachine* _tmp4_ = NULL;
		GVirStorageVol* _tmp5_ = NULL;
		GVirStorageVol* _tmp6_ = NULL;
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp4_ = self->priv->machine;
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp5_ = boxes_libvirt_machine_get_storage_volume (_tmp4_);
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp6_ = _tmp5_;
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp0_ = _tmp6_ == NULL;
#line 5327 "libvirt-machine-properties.c"
	}
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp0_) {
#line 516 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		result = NULL;
#line 516 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return result;
#line 5335 "libvirt-machine-properties.c"
	}
	{
		GVirStorageVolInfo* volume_info = NULL;
		BoxesLibvirtMachine* _tmp7_ = NULL;
		GVirStorageVol* _tmp8_ = NULL;
		GVirStorageVol* _tmp9_ = NULL;
		GVirStorageVolInfo* _tmp10_ = NULL;
		GVirStoragePool* pool = NULL;
		BoxesLibvirtMachine* _tmp11_ = NULL;
		GVirConnection* _tmp12_ = NULL;
		GVirConnection* _tmp13_ = NULL;
		GVirStoragePool* _tmp14_ = NULL;
		GVirStoragePoolInfo* pool_info = NULL;
		GVirStoragePool* _tmp15_ = NULL;
		GVirStoragePoolInfo* _tmp16_ = NULL;
		guint64 min_storage = 0ULL;
		guint64 _tmp17_ = 0ULL;
		guint64 max_storage = 0ULL;
		GVirStorageVolInfo* _tmp18_ = NULL;
		guint64 _tmp19_ = 0ULL;
		GVirStoragePoolInfo* _tmp20_ = NULL;
		guint64 _tmp21_ = 0ULL;
		guint64 _tmp22_ = 0ULL;
		guint64 _tmp23_ = 0ULL;
		BoxesSizeProperty* property = NULL;
		const gchar* _tmp60_ = NULL;
		GVirStorageVolInfo* _tmp61_ = NULL;
		guint64 _tmp62_ = 0ULL;
		guint64 _tmp63_ = 0ULL;
		guint64 _tmp64_ = 0ULL;
		GVirStorageVolInfo* _tmp65_ = NULL;
		guint64 _tmp66_ = 0ULL;
		BoxesSizeProperty* _tmp67_ = NULL;
		BoxesSizeProperty* _tmp68_ = NULL;
		BoxesSizeProperty* _tmp69_ = NULL;
		gboolean _tmp70_ = FALSE;
		gboolean _tmp71_ = FALSE;
		BoxesLibvirtMachine* _tmp72_ = NULL;
		GVirConfigDomain* _tmp73_ = NULL;
		GVirConfigDomain* _tmp74_ = NULL;
		gboolean _tmp75_ = FALSE;
#line 519 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp7_ = self->priv->machine;
#line 519 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp8_ = boxes_libvirt_machine_get_storage_volume (_tmp7_);
#line 519 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp9_ = _tmp8_;
#line 519 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp10_ = gvir_storage_vol_get_info (_tmp9_, &_inner_error_);
#line 519 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		volume_info = _tmp10_;
#line 519 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5389 "libvirt-machine-properties.c"
			goto __catch46_g_error;
		}
#line 520 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp11_ = self->priv->machine;
#line 520 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp12_ = boxes_libvirt_machine_get_connection (_tmp11_);
#line 520 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp13_ = _tmp12_;
#line 520 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp14_ = boxes_get_storage_pool (_tmp13_);
#line 520 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		pool = _tmp14_;
#line 521 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp15_ = pool;
#line 521 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp16_ = gvir_storage_pool_get_info (_tmp15_, &_inner_error_);
#line 521 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		pool_info = _tmp16_;
#line 521 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 521 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (pool);
#line 521 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			__vala_GVirStorageVolInfo_free0 (volume_info);
#line 5414 "libvirt-machine-properties.c"
			goto __catch46_g_error;
		}
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp17_ = boxes_libvirt_machine_properties_get_minimum_disk_size (self, &_inner_error_);
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		min_storage = _tmp17_;
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			__vala_GVirStoragePoolInfo_free0 (pool_info);
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (pool);
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			__vala_GVirStorageVolInfo_free0 (volume_info);
#line 5429 "libvirt-machine-properties.c"
			goto __catch46_g_error;
		}
#line 523 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp18_ = volume_info;
#line 523 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp19_ = _tmp18_->allocation;
#line 523 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp20_ = pool_info;
#line 523 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp21_ = _tmp20_->available;
#line 523 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		max_storage = _tmp19_ + _tmp21_;
#line 525 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp22_ = min_storage;
#line 525 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp23_ = max_storage;
#line 525 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_tmp22_ >= _tmp23_) {
#line 5448 "libvirt-machine-properties.c"
			GtkLabel* label = NULL;
			GtkLabel* _tmp24_ = NULL;
			gchar* capacity = NULL;
			GVirStorageVolInfo* _tmp25_ = NULL;
			guint64 _tmp26_ = 0ULL;
			gchar* _tmp27_ = NULL;
			gchar* allocation = NULL;
			GVirStorageVolInfo* _tmp28_ = NULL;
			guint64 _tmp29_ = 0ULL;
			gchar* _tmp30_ = NULL;
			gchar* markup = NULL;
			const gchar* _tmp31_ = NULL;
			const gchar* _tmp32_ = NULL;
			const gchar* _tmp33_ = NULL;
			gchar* _tmp34_ = NULL;
			GtkLabel* _tmp35_ = NULL;
			const gchar* _tmp36_ = NULL;
			GtkLabel* _tmp37_ = NULL;
			GtkLabel* _tmp38_ = NULL;
			BoxesProperty* _tmp39_ = NULL;
			BoxesProperty* _tmp40_ = NULL;
			GtkInfoBar* infobar = NULL;
			GtkInfoBar* _tmp41_ = NULL;
			GtkInfoBar* _tmp42_ = NULL;
			GtkContainer* content = NULL;
			GtkInfoBar* _tmp43_ = NULL;
			GtkContainer* _tmp44_ = NULL;
			GtkContainer* _tmp45_ = NULL;
			GtkImage* image = NULL;
			GtkImage* _tmp46_ = NULL;
			GtkImage* _tmp47_ = NULL;
			GtkImage* _tmp48_ = NULL;
			GtkContainer* _tmp49_ = NULL;
			GtkImage* _tmp50_ = NULL;
			gchar* msg = NULL;
			const gchar* _tmp51_ = NULL;
			gchar* _tmp52_ = NULL;
			const gchar* _tmp53_ = NULL;
			GtkLabel* _tmp54_ = NULL;
			GtkContainer* _tmp55_ = NULL;
			GtkLabel* _tmp56_ = NULL;
			GtkInfoBar* _tmp57_ = NULL;
			BoxesProperty* _tmp58_ = NULL;
			BoxesProperty* _tmp59_ = NULL;
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp24_ = (GtkLabel*) gtk_label_new ("");
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_object_ref_sink (_tmp24_);
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			label = _tmp24_;
#line 527 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp25_ = volume_info;
#line 527 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp26_ = _tmp25_->capacity;
#line 527 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp27_ = g_format_size_full (_tmp26_, G_FORMAT_SIZE_DEFAULT);
#line 527 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			capacity = _tmp27_;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp28_ = volume_info;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp29_ = _tmp28_->allocation;
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp30_ = g_format_size_full (_tmp29_, G_FORMAT_SIZE_DEFAULT);
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			allocation = _tmp30_;
#line 529 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp31_ = _ ("<span color=\"grey\">Maximum Disk Size</span>\t\t %s <span color=\"gre" \
"y\">(%s used)</span>");
#line 529 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp32_ = capacity;
#line 529 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp33_ = allocation;
#line 529 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp34_ = g_strdup_printf (_tmp31_, _tmp32_, _tmp33_);
#line 529 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			markup = _tmp34_;
#line 530 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp35_ = label;
#line 530 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp36_ = markup;
#line 530 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			gtk_label_set_markup (_tmp35_, _tmp36_);
#line 531 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp37_ = label;
#line 531 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			gtk_widget_set_halign ((GtkWidget*) _tmp37_, GTK_ALIGN_START);
#line 533 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp38_ = label;
#line 533 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp39_ = boxes_iproperties_provider_add_property ((BoxesIPropertiesProvider*) self, list, NULL, (GtkWidget*) _tmp38_, NULL);
#line 533 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp40_ = _tmp39_;
#line 533 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (_tmp40_);
#line 535 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp41_ = (GtkInfoBar*) gtk_info_bar_new ();
#line 535 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_object_ref_sink (_tmp41_);
#line 535 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			infobar = _tmp41_;
#line 536 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp42_ = infobar;
#line 536 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			gtk_info_bar_set_message_type (_tmp42_, GTK_MESSAGE_WARNING);
#line 538 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp43_ = infobar;
#line 538 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp44_ = gtk_info_bar_get_content_area (_tmp43_);
#line 538 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp45_ = _g_object_ref0 (_tmp44_);
#line 538 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			content = _tmp45_;
#line 540 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp46_ = (GtkImage*) gtk_image_new ();
#line 540 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_object_ref_sink (_tmp46_);
#line 540 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			image = _tmp46_;
#line 541 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp47_ = image;
#line 541 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_object_set (_tmp47_, "icon-name", "dialog-warning", NULL);
#line 542 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp48_ = image;
#line 542 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_object_set (_tmp48_, "icon-size", 3, NULL);
#line 543 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp49_ = content;
#line 543 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp50_ = image;
#line 543 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			gtk_container_add (_tmp49_, (GtkWidget*) _tmp50_);
#line 545 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp51_ = _ ("There is not enough space on your machine to increase the maximum disk" \
" size.");
#line 545 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp52_ = g_strdup (_tmp51_);
#line 545 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			msg = _tmp52_;
#line 546 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp53_ = msg;
#line 546 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp54_ = (GtkLabel*) gtk_label_new (_tmp53_);
#line 546 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_object_ref_sink (_tmp54_);
#line 546 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (label);
#line 546 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			label = _tmp54_;
#line 547 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp55_ = content;
#line 547 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp56_ = label;
#line 547 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			gtk_container_add (_tmp55_, (GtkWidget*) _tmp56_);
#line 549 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp57_ = infobar;
#line 549 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp58_ = boxes_iproperties_provider_add_property ((BoxesIPropertiesProvider*) self, list, NULL, (GtkWidget*) _tmp57_, NULL);
#line 549 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp59_ = _tmp58_;
#line 549 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (_tmp59_);
#line 550 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			result = NULL;
#line 550 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_free0 (msg);
#line 550 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (image);
#line 550 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (content);
#line 550 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (infobar);
#line 550 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_free0 (markup);
#line 550 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_free0 (allocation);
#line 550 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_free0 (capacity);
#line 550 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (label);
#line 550 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			__vala_GVirStoragePoolInfo_free0 (pool_info);
#line 550 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (pool);
#line 550 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			__vala_GVirStorageVolInfo_free0 (volume_info);
#line 550 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			return result;
#line 5637 "libvirt-machine-properties.c"
		}
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp60_ = _ ("Maximum Disk Size");
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp61_ = volume_info;
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp62_ = _tmp61_->capacity;
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp63_ = min_storage;
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp64_ = max_storage;
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp65_ = volume_info;
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp66_ = _tmp65_->allocation;
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp67_ = boxes_iproperties_provider_add_size_property ((BoxesIPropertiesProvider*) self, list, _tmp60_, _tmp62_, _tmp63_, _tmp64_, _tmp66_, 256 * BOXES_LIBVIRT_MACHINE_PROPERTIES_MEGABYTES, G_FORMAT_SIZE_DEFAULT);
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		property = _tmp67_;
#line 560 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp68_ = property;
#line 560 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_property_set_description_alignment ((BoxesProperty*) _tmp68_, GTK_ALIGN_START);
#line 564 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp69_ = property;
#line 564 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_property_set_defer_interval ((BoxesProperty*) _tmp69_, (guint) 0);
#line 565 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp72_ = self->priv->machine;
#line 565 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp73_ = boxes_libvirt_machine_get_domain_config (_tmp72_);
#line 565 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp74_ = _tmp73_;
#line 565 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp75_ = boxes_vm_configurator_is_install_config (_tmp74_);
#line 565 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_tmp75_) {
#line 565 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp71_ = TRUE;
#line 5677 "libvirt-machine-properties.c"
		} else {
			BoxesLibvirtMachine* _tmp76_ = NULL;
			GVirConfigDomain* _tmp77_ = NULL;
			GVirConfigDomain* _tmp78_ = NULL;
			gboolean _tmp79_ = FALSE;
#line 566 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp76_ = self->priv->machine;
#line 566 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp77_ = boxes_libvirt_machine_get_domain_config (_tmp76_);
#line 566 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp78_ = _tmp77_;
#line 566 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp79_ = boxes_vm_configurator_is_live_config (_tmp78_);
#line 566 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp71_ = _tmp79_;
#line 5693 "libvirt-machine-properties.c"
		}
#line 565 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_tmp71_) {
#line 5697 "libvirt-machine-properties.c"
			BoxesLibvirtMachine* _tmp80_ = NULL;
			BoxesAppWindow* _tmp81_ = NULL;
			BoxesAppWindow* _tmp82_ = NULL;
			BoxesUIState _tmp83_ = 0;
			BoxesUIState _tmp84_ = 0;
#line 567 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp80_ = self->priv->machine;
#line 567 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp81_ = boxes_machine_get_window ((BoxesMachine*) _tmp80_);
#line 567 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp82_ = _tmp81_;
#line 567 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp83_ = boxes_ui_get_ui_state ((BoxesUI*) _tmp82_);
#line 567 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp84_ = _tmp83_;
#line 567 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp70_ = _tmp84_ != BOXES_UI_STATE_WIZARD;
#line 5715 "libvirt-machine-properties.c"
		} else {
#line 565 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp70_ = FALSE;
#line 5719 "libvirt-machine-properties.c"
		}
#line 565 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_tmp70_) {
#line 5723 "libvirt-machine-properties.c"
			BoxesSizeProperty* _tmp85_ = NULL;
#line 568 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp85_ = property;
#line 568 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			boxes_property_set_sensitive ((BoxesProperty*) _tmp85_, FALSE);
#line 5729 "libvirt-machine-properties.c"
		} else {
			BoxesSizeProperty* _tmp86_ = NULL;
#line 570 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp86_ = property;
#line 570 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_signal_connect_object (_tmp86_, "changed", (GCallback) _boxes_libvirt_machine_properties_on_storage_changed_boxes_size_property_changed, self, 0);
#line 5736 "libvirt-machine-properties.c"
		}
#line 572 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		result = property;
#line 572 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		__vala_GVirStoragePoolInfo_free0 (pool_info);
#line 572 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (pool);
#line 572 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		__vala_GVirStorageVolInfo_free0 (volume_info);
#line 572 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return result;
#line 5748 "libvirt-machine-properties.c"
	}
	goto __finally46;
	__catch46_g_error:
	{
		GError* _error_ = NULL;
		BoxesLibvirtMachine* _tmp87_ = NULL;
		GVirStorageVol* _tmp88_ = NULL;
		GVirStorageVol* _tmp89_ = NULL;
		const gchar* _tmp90_ = NULL;
		GError* _tmp91_ = NULL;
		const gchar* _tmp92_ = NULL;
#line 518 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_error_ = _inner_error_;
#line 518 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_inner_error_ = NULL;
#line 574 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp87_ = self->priv->machine;
#line 574 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp88_ = boxes_libvirt_machine_get_storage_volume (_tmp87_);
#line 574 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp89_ = _tmp88_;
#line 574 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp90_ = gvir_storage_vol_get_name (_tmp89_);
#line 574 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp91_ = _error_;
#line 574 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp92_ = _tmp91_->message;
#line 574 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_warning ("libvirt-machine-properties.vala:574: Failed to get information on volu" \
"me '%s' or it's parent pool: %s", _tmp90_, _tmp92_);
#line 577 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		result = NULL;
#line 577 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (_error_);
#line 577 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return result;
#line 5784 "libvirt-machine-properties.c"
	}
	__finally46:
#line 518 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 518 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_clear_error (&_inner_error_);
#line 518 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return NULL;
#line 5793 "libvirt-machine-properties.c"
}


static Block48Data* block48_data_ref (Block48Data* _data48_) {
#line 581 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_atomic_int_inc (&_data48_->_ref_count_);
#line 581 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return _data48_;
#line 5802 "libvirt-machine-properties.c"
}


static void block48_data_unref (void * _userdata_) {
	Block48Data* _data48_;
	_data48_ = (Block48Data*) _userdata_;
#line 581 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (g_atomic_int_dec_and_test (&_data48_->_ref_count_)) {
#line 5811 "libvirt-machine-properties.c"
		BoxesLibvirtMachineProperties* self;
#line 581 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		self = _data48_->self;
#line 581 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (self);
#line 581 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_slice_free (Block48Data, _data48_);
#line 5819 "libvirt-machine-properties.c"
	}
}


static Block49Data* block49_data_ref (Block49Data* _data49_) {
#line 590 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_atomic_int_inc (&_data49_->_ref_count_);
#line 590 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return _data49_;
#line 5829 "libvirt-machine-properties.c"
}


static void block49_data_unref (void * _userdata_) {
	Block49Data* _data49_;
	_data49_ = (Block49Data*) _userdata_;
#line 590 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (g_atomic_int_dec_and_test (&_data49_->_ref_count_)) {
#line 5838 "libvirt-machine-properties.c"
		BoxesLibvirtMachineProperties* self;
#line 590 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		self = _data49_->_data48_->self;
#line 590 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data49_->pool);
#line 590 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		block48_data_unref (_data49_->_data48_);
#line 590 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data49_->_data48_ = NULL;
#line 590 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_slice_free (Block49Data, _data49_);
#line 5850 "libvirt-machine-properties.c"
	}
}


static void _____lambda151_ (Block49Data* _data49_, GObject* obj, GAsyncResult* res) {
	Block48Data* _data48_;
	BoxesLibvirtMachineProperties* self;
	GError * _inner_error_ = NULL;
#line 595 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data48_ = _data49_->_data48_;
#line 595 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self = _data48_->self;
#line 595 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (res != NULL);
#line 5865 "libvirt-machine-properties.c"
	{
		GVirStoragePool* _tmp0_ = NULL;
		GAsyncResult* _tmp1_ = NULL;
		BoxesLibvirtMachine* _tmp2_ = NULL;
		guint64 _tmp3_ = 0ULL;
#line 597 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp0_ = _data49_->pool;
#line 597 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp1_ = res;
#line 597 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gvir_storage_pool_refresh_finish (_tmp0_, _tmp1_, &_inner_error_);
#line 597 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5879 "libvirt-machine-properties.c"
			goto __catch48_g_error;
		}
#line 598 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp2_ = self->priv->machine;
#line 598 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_libvirt_machine_update_domain_config (_tmp2_);
#line 599 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp3_ = _data49_->size;
#line 599 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_debug ("libvirt-machine-properties.vala:599: Storage changed to %llu KiB", _tmp3_);
#line 5890 "libvirt-machine-properties.c"
	}
	goto __finally48;
	__catch48_g_error:
	{
		GError* _error_ = NULL;
		BoxesLibvirtMachine* _tmp4_ = NULL;
		GVirStorageVol* _tmp5_ = NULL;
		GVirStorageVol* _tmp6_ = NULL;
		const gchar* _tmp7_ = NULL;
		guint64 _tmp8_ = 0ULL;
		GError* _tmp9_ = NULL;
		const gchar* _tmp10_ = NULL;
#line 596 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_error_ = _inner_error_;
#line 596 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_inner_error_ = NULL;
#line 601 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp4_ = self->priv->machine;
#line 601 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp5_ = boxes_libvirt_machine_get_storage_volume (_tmp4_);
#line 601 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp6_ = _tmp5_;
#line 601 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp7_ = gvir_storage_vol_get_name (_tmp6_);
#line 601 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp8_ = _data49_->size;
#line 601 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp9_ = _error_;
#line 601 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp10_ = _tmp9_->message;
#line 601 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_warning ("libvirt-machine-properties.vala:601: Failed to change storage capacity" \
" of volume '%s' to %llu KiB: %s", _tmp7_, _tmp8_, _tmp10_);
#line 596 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (_error_);
#line 5925 "libvirt-machine-properties.c"
	}
	__finally48:
#line 596 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 596 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 596 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_clear_error (&_inner_error_);
#line 596 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return;
#line 5936 "libvirt-machine-properties.c"
	}
}


static void ______lambda151__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 595 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_____lambda151_ (self, source_object, res);
#line 595 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	block49_data_unref (self);
#line 5946 "libvirt-machine-properties.c"
}


static gboolean __lambda150_ (Block48Data* _data48_) {
	BoxesLibvirtMachineProperties* self;
	gboolean result = FALSE;
	BoxesLibvirtMachine* _tmp0_ = NULL;
	GVirStorageVol* _tmp1_ = NULL;
	GVirStorageVol* _tmp2_ = NULL;
	GError * _inner_error_ = NULL;
#line 583 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self = _data48_->self;
#line 584 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = self->priv->machine;
#line 584 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = boxes_libvirt_machine_get_storage_volume (_tmp0_);
#line 584 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = _tmp1_;
#line 584 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp2_ == NULL) {
#line 585 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		result = FALSE;
#line 585 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return result;
#line 5971 "libvirt-machine-properties.c"
	}
	{
		BoxesLibvirtMachine* _tmp3_ = NULL;
		gboolean _tmp4_ = FALSE;
#line 588 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp3_ = self->priv->machine;
#line 588 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp4_ = boxes_machine_is_running ((BoxesMachine*) _tmp3_);
#line 588 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_tmp4_) {
#line 5982 "libvirt-machine-properties.c"
			GVirDomainDisk* disk = NULL;
			BoxesLibvirtMachine* _tmp5_ = NULL;
			GVirDomainDisk* _tmp6_ = NULL;
			GVirDomainDisk* _tmp7_ = NULL;
#line 589 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp5_ = self->priv->machine;
#line 589 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp6_ = boxes_libvirt_machine_get_domain_disk (_tmp5_, &_inner_error_);
#line 589 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			disk = _tmp6_;
#line 589 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5995 "libvirt-machine-properties.c"
				goto __catch47_g_error;
			}
#line 590 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp7_ = disk;
#line 590 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			if (_tmp7_ != NULL) {
#line 6002 "libvirt-machine-properties.c"
				Block49Data* _data49_;
				guint64 _tmp8_ = 0ULL;
				GVirDomainDisk* _tmp9_ = NULL;
				guint64 _tmp10_ = 0ULL;
				BoxesLibvirtMachine* _tmp11_ = NULL;
				GVirConnection* _tmp12_ = NULL;
				GVirConnection* _tmp13_ = NULL;
				GVirStoragePool* _tmp14_ = NULL;
				GVirStoragePool* _tmp15_ = NULL;
#line 590 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_data49_ = g_slice_new0 (Block49Data);
#line 590 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_data49_->_ref_count_ = 1;
#line 590 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_data49_->_data48_ = block48_data_ref (_data48_);
#line 591 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp8_ = _data48_->value;
#line 591 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_data49_->size = ((_tmp8_ + OSINFO_KIBIBYTES) - 1) / OSINFO_KIBIBYTES;
#line 592 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp9_ = disk;
#line 592 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp10_ = _data49_->size;
#line 592 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				gvir_domain_disk_resize (_tmp9_, _tmp10_, (guint) 0, &_inner_error_);
#line 592 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 592 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
					block49_data_unref (_data49_);
#line 592 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
					_data49_ = NULL;
#line 592 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
					_g_object_unref0 (disk);
#line 6036 "libvirt-machine-properties.c"
					goto __catch47_g_error;
				}
#line 594 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp11_ = self->priv->machine;
#line 594 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp12_ = boxes_libvirt_machine_get_connection (_tmp11_);
#line 594 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp13_ = _tmp12_;
#line 594 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp14_ = boxes_get_storage_pool (_tmp13_);
#line 594 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_data49_->pool = _tmp14_;
#line 595 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp15_ = _data49_->pool;
#line 595 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				gvir_storage_pool_refresh_async (_tmp15_, NULL, ______lambda151__gasync_ready_callback, block49_data_ref (_data49_));
#line 590 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				block49_data_unref (_data49_);
#line 590 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_data49_ = NULL;
#line 6057 "libvirt-machine-properties.c"
			}
#line 588 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (disk);
#line 6061 "libvirt-machine-properties.c"
		} else {
			guint64 _tmp16_ = 0ULL;
			guint64 _tmp17_ = 0ULL;
#line 609 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp16_ = _data48_->value;
#line 609 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			boxes_libvirt_machine_properties_resize_storage_volume (self, _tmp16_, &_inner_error_);
#line 609 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 6071 "libvirt-machine-properties.c"
				goto __catch47_g_error;
			}
#line 610 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp17_ = _data48_->value;
#line 610 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_debug ("libvirt-machine-properties.vala:610: Storage changed to %llu", _tmp17_);
#line 6078 "libvirt-machine-properties.c"
		}
	}
	goto __finally47;
	__catch47_g_error:
	{
		GError* _error_ = NULL;
		BoxesLibvirtMachine* _tmp18_ = NULL;
		GVirStorageVol* _tmp19_ = NULL;
		GVirStorageVol* _tmp20_ = NULL;
		const gchar* _tmp21_ = NULL;
		guint64 _tmp22_ = 0ULL;
		GError* _tmp23_ = NULL;
		const gchar* _tmp24_ = NULL;
#line 587 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_error_ = _inner_error_;
#line 587 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_inner_error_ = NULL;
#line 613 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp18_ = self->priv->machine;
#line 613 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp19_ = boxes_libvirt_machine_get_storage_volume (_tmp18_);
#line 613 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp20_ = _tmp19_;
#line 613 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp21_ = gvir_storage_vol_get_name (_tmp20_);
#line 613 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp22_ = _data48_->value;
#line 613 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp23_ = _error_;
#line 613 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp24_ = _tmp23_->message;
#line 613 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_warning ("libvirt-machine-properties.vala:613: Failed to change storage capacity" \
" of volume '%s' to %llu: %s", _tmp21_, _tmp22_, _tmp24_);
#line 587 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (_error_);
#line 6114 "libvirt-machine-properties.c"
	}
	__finally47:
#line 587 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 587 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 587 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_clear_error (&_inner_error_);
#line 587 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return FALSE;
#line 6125 "libvirt-machine-properties.c"
	}
#line 619 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	result = FALSE;
#line 619 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return result;
#line 6131 "libvirt-machine-properties.c"
}


static gboolean ___lambda150__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda150_ (self);
#line 583 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return result;
#line 6140 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_on_storage_changed (BoxesLibvirtMachineProperties* self, BoxesProperty* property, guint64 value) {
	Block48Data* _data48_;
	guint64 _tmp0_ = 0ULL;
	BoxesProperty* _tmp1_ = NULL;
#line 581 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (self != NULL);
#line 581 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (property != NULL);
#line 581 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data48_ = g_slice_new0 (Block48Data);
#line 581 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data48_->_ref_count_ = 1;
#line 581 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data48_->self = g_object_ref (self);
#line 581 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = value;
#line 581 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data48_->value = _tmp0_;
#line 583 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = property;
#line 583 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_property_set_deferred_change (_tmp1_, ___lambda150__gsource_func, block48_data_ref (_data48_), block48_data_unref);
#line 581 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	block48_data_unref (_data48_);
#line 581 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data48_ = NULL;
#line 6170 "libvirt-machine-properties.c"
}


static guint64 boxes_libvirt_machine_properties_get_minimum_disk_size (BoxesLibvirtMachineProperties* self, GError** error) {
	guint64 result = 0ULL;
	GVirStorageVolInfo* volume_info = NULL;
	BoxesLibvirtMachine* _tmp0_ = NULL;
	GVirStorageVol* _tmp1_ = NULL;
	GVirStorageVol* _tmp2_ = NULL;
	GVirStorageVolInfo* _tmp3_ = NULL;
	BoxesLibvirtMachine* _tmp4_ = NULL;
	BoxesVMCreator* _tmp5_ = NULL;
	BoxesVMCreator* _tmp6_ = NULL;
	OsinfoResources* minimum_resources = NULL;
	BoxesLibvirtMachine* _tmp9_ = NULL;
	BoxesVMCreator* _tmp10_ = NULL;
	BoxesVMCreator* _tmp11_ = NULL;
	BoxesInstallerMedia* _tmp12_ = NULL;
	BoxesInstallerMedia* _tmp13_ = NULL;
	OsinfoOs* _tmp14_ = NULL;
	gboolean _tmp33_ = FALSE;
	OsinfoResources* _tmp34_ = NULL;
	GError * _inner_error_ = NULL;
#line 623 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_val_if_fail (self != NULL, 0ULL);
#line 624 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = self->priv->machine;
#line 624 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = boxes_libvirt_machine_get_storage_volume (_tmp0_);
#line 624 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = _tmp1_;
#line 624 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = gvir_storage_vol_get_info (_tmp2_, &_inner_error_);
#line 624 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	volume_info = _tmp3_;
#line 624 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 624 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_propagate_error (error, _inner_error_);
#line 624 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return 0ULL;
#line 6212 "libvirt-machine-properties.c"
	}
#line 625 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp4_ = self->priv->machine;
#line 625 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp5_ = boxes_libvirt_machine_get_vm_creator (_tmp4_);
#line 625 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp6_ = _tmp5_;
#line 625 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp6_ == NULL) {
#line 6222 "libvirt-machine-properties.c"
		GVirStorageVolInfo* _tmp7_ = NULL;
		guint64 _tmp8_ = 0ULL;
#line 628 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp7_ = volume_info;
#line 628 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp8_ = _tmp7_->capacity;
#line 628 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		result = _tmp8_;
#line 628 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		__vala_GVirStorageVolInfo_free0 (volume_info);
#line 628 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return result;
#line 6235 "libvirt-machine-properties.c"
	}
#line 631 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	minimum_resources = NULL;
#line 633 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp9_ = self->priv->machine;
#line 633 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp10_ = boxes_libvirt_machine_get_vm_creator (_tmp9_);
#line 633 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp11_ = _tmp10_;
#line 633 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp12_ = boxes_vm_creator_get_install_media (_tmp11_);
#line 633 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp13_ = _tmp12_;
#line 633 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp14_ = _tmp13_->os;
#line 633 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp14_ != NULL) {
#line 6253 "libvirt-machine-properties.c"
		OsinfoOs* os = NULL;
		BoxesLibvirtMachine* _tmp15_ = NULL;
		BoxesVMCreator* _tmp16_ = NULL;
		BoxesVMCreator* _tmp17_ = NULL;
		BoxesInstallerMedia* _tmp18_ = NULL;
		BoxesInstallerMedia* _tmp19_ = NULL;
		OsinfoOs* _tmp20_ = NULL;
		OsinfoOs* _tmp21_ = NULL;
		gchar* architecture = NULL;
		BoxesLibvirtMachine* _tmp22_ = NULL;
		GVirConfigDomain* _tmp23_ = NULL;
		GVirConfigDomain* _tmp24_ = NULL;
		GVirConfigDomainOs* _tmp25_ = NULL;
		GVirConfigDomainOs* _tmp26_ = NULL;
		const gchar* _tmp27_ = NULL;
		gchar* _tmp28_ = NULL;
		gchar* _tmp29_ = NULL;
		OsinfoOs* _tmp30_ = NULL;
		const gchar* _tmp31_ = NULL;
		OsinfoResources* _tmp32_ = NULL;
#line 634 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp15_ = self->priv->machine;
#line 634 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp16_ = boxes_libvirt_machine_get_vm_creator (_tmp15_);
#line 634 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp17_ = _tmp16_;
#line 634 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp18_ = boxes_vm_creator_get_install_media (_tmp17_);
#line 634 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp19_ = _tmp18_;
#line 634 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp20_ = _tmp19_->os;
#line 634 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp21_ = _g_object_ref0 (_tmp20_);
#line 634 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		os = _tmp21_;
#line 635 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp22_ = self->priv->machine;
#line 635 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp23_ = boxes_libvirt_machine_get_domain_config (_tmp22_);
#line 635 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp24_ = _tmp23_;
#line 635 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp25_ = gvir_config_domain_get_os (_tmp24_);
#line 635 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp26_ = _tmp25_;
#line 635 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp27_ = gvir_config_domain_os_get_arch (_tmp26_);
#line 635 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp28_ = g_strdup (_tmp27_);
#line 635 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp29_ = _tmp28_;
#line 635 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_tmp26_);
#line 635 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		architecture = _tmp29_;
#line 636 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp30_ = os;
#line 636 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp31_ = architecture;
#line 636 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp32_ = boxes_os_database_get_minimum_resources_for_os (_tmp30_, _tmp31_);
#line 636 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (minimum_resources);
#line 636 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		minimum_resources = _tmp32_;
#line 633 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (architecture);
#line 633 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (os);
#line 6324 "libvirt-machine-properties.c"
	}
#line 639 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp34_ = minimum_resources;
#line 639 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp34_ != NULL) {
#line 6330 "libvirt-machine-properties.c"
		OsinfoResources* _tmp35_ = NULL;
		gint64 _tmp36_ = 0LL;
		gint64 _tmp37_ = 0LL;
#line 639 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp35_ = minimum_resources;
#line 639 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp36_ = osinfo_resources_get_storage (_tmp35_);
#line 639 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp37_ = _tmp36_;
#line 639 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp33_ = _tmp37_ != ((gint64) -1);
#line 6342 "libvirt-machine-properties.c"
	} else {
#line 639 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp33_ = FALSE;
#line 6346 "libvirt-machine-properties.c"
	}
#line 639 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp33_) {
#line 6350 "libvirt-machine-properties.c"
		OsinfoResources* _tmp38_ = NULL;
		gint64 _tmp39_ = 0LL;
		gint64 _tmp40_ = 0LL;
#line 640 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp38_ = minimum_resources;
#line 640 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp39_ = osinfo_resources_get_storage (_tmp38_);
#line 640 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp40_ = _tmp39_;
#line 640 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		result = (guint64) _tmp40_;
#line 640 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (minimum_resources);
#line 640 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		__vala_GVirStorageVolInfo_free0 (volume_info);
#line 640 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return result;
#line 6368 "libvirt-machine-properties.c"
	} else {
		OsinfoResources* default_resources = NULL;
		OsinfoResources* _tmp41_ = NULL;
		GVirStorageVolInfo* _tmp42_ = NULL;
		guint64 _tmp43_ = 0ULL;
		OsinfoResources* _tmp44_ = NULL;
		gint64 _tmp45_ = 0LL;
		gint64 _tmp46_ = 0LL;
		guint64 _tmp47_ = 0ULL;
#line 642 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp41_ = boxes_os_database_get_default_resources ();
#line 642 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		default_resources = _tmp41_;
#line 643 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp42_ = volume_info;
#line 643 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp43_ = _tmp42_->capacity;
#line 643 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp44_ = default_resources;
#line 643 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp45_ = osinfo_resources_get_storage (_tmp44_);
#line 643 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp46_ = _tmp45_;
#line 643 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp47_ = MIN (_tmp43_, (guint64) _tmp46_);
#line 643 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		result = _tmp47_;
#line 643 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (default_resources);
#line 643 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (minimum_resources);
#line 643 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		__vala_GVirStorageVolInfo_free0 (volume_info);
#line 643 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return result;
#line 6404 "libvirt-machine-properties.c"
	}
#line 623 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (minimum_resources);
#line 623 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	__vala_GVirStorageVolInfo_free0 (volume_info);
#line 6410 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_resize_storage_volume (BoxesLibvirtMachineProperties* self, guint64 size, GError** error) {
	GVirStorageVolInfo* volume_info = NULL;
	BoxesLibvirtMachine* _tmp0_ = NULL;
	GVirStorageVol* _tmp1_ = NULL;
	GVirStorageVol* _tmp2_ = NULL;
	GVirStorageVolInfo* _tmp3_ = NULL;
	gboolean _tmp4_ = FALSE;
	BoxesLibvirtMachine* _tmp5_ = NULL;
	BoxesVMCreator* _tmp6_ = NULL;
	BoxesVMCreator* _tmp7_ = NULL;
	GError * _inner_error_ = NULL;
#line 647 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (self != NULL);
#line 648 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = self->priv->machine;
#line 648 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = boxes_libvirt_machine_get_storage_volume (_tmp0_);
#line 648 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = _tmp1_;
#line 648 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = gvir_storage_vol_get_info (_tmp2_, &_inner_error_);
#line 648 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	volume_info = _tmp3_;
#line 648 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 648 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_propagate_error (error, _inner_error_);
#line 648 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return;
#line 6443 "libvirt-machine-properties.c"
	}
#line 649 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp5_ = self->priv->machine;
#line 649 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp6_ = boxes_libvirt_machine_get_vm_creator (_tmp5_);
#line 649 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp7_ = _tmp6_;
#line 649 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp7_ != NULL) {
#line 6453 "libvirt-machine-properties.c"
		guint64 _tmp8_ = 0ULL;
		GVirStorageVolInfo* _tmp9_ = NULL;
		guint64 _tmp10_ = 0ULL;
#line 649 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp8_ = size;
#line 649 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp9_ = volume_info;
#line 649 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp10_ = _tmp9_->capacity;
#line 649 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp4_ = _tmp8_ < _tmp10_;
#line 6465 "libvirt-machine-properties.c"
	} else {
#line 649 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp4_ = FALSE;
#line 6469 "libvirt-machine-properties.c"
	}
#line 649 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp4_) {
#line 6473 "libvirt-machine-properties.c"
		GVirConfigStorageVol* config = NULL;
		BoxesLibvirtMachine* _tmp11_ = NULL;
		GVirStorageVol* _tmp12_ = NULL;
		GVirStorageVol* _tmp13_ = NULL;
		GVirConfigStorageVol* _tmp14_ = NULL;
		GVirConfigStorageVol* _tmp15_ = NULL;
		guint64 _tmp16_ = 0ULL;
		BoxesLibvirtMachine* _tmp17_ = NULL;
		GVirStorageVol* _tmp18_ = NULL;
		GVirStorageVol* _tmp19_ = NULL;
		GVirStoragePool* pool = NULL;
		BoxesLibvirtMachine* _tmp20_ = NULL;
		GVirConnection* _tmp21_ = NULL;
		GVirConnection* _tmp22_ = NULL;
		GVirStoragePool* _tmp23_ = NULL;
		GVirStorageVol* _tmp24_ = NULL;
		GVirStoragePool* _tmp25_ = NULL;
		GVirConfigStorageVol* _tmp26_ = NULL;
		GVirStorageVol* _tmp27_ = NULL;
		BoxesLibvirtMachine* _tmp28_ = NULL;
#line 651 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp11_ = self->priv->machine;
#line 651 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp12_ = boxes_libvirt_machine_get_storage_volume (_tmp11_);
#line 651 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp13_ = _tmp12_;
#line 651 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp14_ = gvir_storage_vol_get_config (_tmp13_, (guint) GVIR_DOMAIN_XML_NONE, &_inner_error_);
#line 651 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		config = _tmp14_;
#line 651 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 651 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_propagate_error (error, _inner_error_);
#line 651 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			__vala_GVirStorageVolInfo_free0 (volume_info);
#line 651 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			return;
#line 6512 "libvirt-machine-properties.c"
		}
#line 652 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp15_ = config;
#line 652 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp16_ = size;
#line 652 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gvir_config_storage_vol_set_capacity (_tmp15_, _tmp16_);
#line 653 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp17_ = self->priv->machine;
#line 653 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp18_ = boxes_libvirt_machine_get_storage_volume (_tmp17_);
#line 653 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp19_ = _tmp18_;
#line 653 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gvir_storage_vol_delete (_tmp19_, (guint) 0, &_inner_error_);
#line 653 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 653 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_propagate_error (error, _inner_error_);
#line 653 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (config);
#line 653 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			__vala_GVirStorageVolInfo_free0 (volume_info);
#line 653 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			return;
#line 6538 "libvirt-machine-properties.c"
		}
#line 655 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp20_ = self->priv->machine;
#line 655 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp21_ = boxes_libvirt_machine_get_connection (_tmp20_);
#line 655 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp22_ = _tmp21_;
#line 655 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp23_ = boxes_get_storage_pool (_tmp22_);
#line 655 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		pool = _tmp23_;
#line 656 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp25_ = pool;
#line 656 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp26_ = config;
#line 656 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp27_ = gvir_storage_pool_create_volume (_tmp25_, _tmp26_, &_inner_error_);
#line 656 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp24_ = _tmp27_;
#line 656 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 656 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_propagate_error (error, _inner_error_);
#line 656 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (pool);
#line 656 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (config);
#line 656 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			__vala_GVirStorageVolInfo_free0 (volume_info);
#line 656 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			return;
#line 6570 "libvirt-machine-properties.c"
		}
#line 656 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp28_ = self->priv->machine;
#line 656 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_libvirt_machine_set_storage_volume (_tmp28_, _tmp24_);
#line 649 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_tmp24_);
#line 649 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (pool);
#line 649 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (config);
#line 6582 "libvirt-machine-properties.c"
	} else {
		BoxesLibvirtMachine* _tmp29_ = NULL;
		GVirStorageVol* _tmp30_ = NULL;
		GVirStorageVol* _tmp31_ = NULL;
		guint64 _tmp32_ = 0ULL;
#line 658 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp29_ = self->priv->machine;
#line 658 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp30_ = boxes_libvirt_machine_get_storage_volume (_tmp29_);
#line 658 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp31_ = _tmp30_;
#line 658 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp32_ = size;
#line 658 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gvir_storage_vol_resize (_tmp31_, _tmp32_, GVIR_STORAGE_VOL_RESIZE_NONE, &_inner_error_);
#line 658 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 658 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_propagate_error (error, _inner_error_);
#line 658 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			__vala_GVirStorageVolInfo_free0 (volume_info);
#line 658 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			return;
#line 6606 "libvirt-machine-properties.c"
		}
	}
#line 647 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	__vala_GVirStorageVolInfo_free0 (volume_info);
#line 6611 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_fetch_snapshots_data_free (gpointer _data) {
	BoxesLibvirtMachinePropertiesFetchSnapshotsData* _data_;
	_data_ = _data;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->cancellable);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_slice_free (BoxesLibvirtMachinePropertiesFetchSnapshotsData, _data_);
#line 6624 "libvirt-machine-properties.c"
}


void boxes_libvirt_machine_properties_fetch_snapshots (BoxesLibvirtMachineProperties* self, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesLibvirtMachinePropertiesFetchSnapshotsData* _data_;
	BoxesLibvirtMachineProperties* _tmp0_ = NULL;
	GCancellable* _tmp1_ = NULL;
	GCancellable* _tmp2_ = NULL;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_ = g_slice_new0 (BoxesLibvirtMachinePropertiesFetchSnapshotsData);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_libvirt_machine_properties_fetch_snapshots);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_libvirt_machine_properties_fetch_snapshots_data_free);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->self = _tmp0_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = cancellable;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->cancellable);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->cancellable = _tmp2_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_properties_fetch_snapshots_co (_data_);
#line 6653 "libvirt-machine-properties.c"
}


void boxes_libvirt_machine_properties_fetch_snapshots_finish (BoxesLibvirtMachineProperties* self, GAsyncResult* _res_, GError** error) {
	BoxesLibvirtMachinePropertiesFetchSnapshotsData* _data_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return;
#line 6663 "libvirt-machine-properties.c"
	}
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 6667 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_fetch_snapshots_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesLibvirtMachinePropertiesFetchSnapshotsData* _data_;
#line 663 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_ = _user_data_;
#line 663 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_source_object_ = source_object;
#line 663 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_res_ = _res_;
#line 663 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_properties_fetch_snapshots_co (_data_);
#line 6681 "libvirt-machine-properties.c"
}


static gboolean boxes_libvirt_machine_properties_fetch_snapshots_co (BoxesLibvirtMachinePropertiesFetchSnapshotsData* _data_) {
#line 662 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	switch (_data_->_state_) {
#line 662 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		case 0:
#line 6690 "libvirt-machine-properties.c"
		goto _state_0;
#line 662 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		case 1:
#line 6694 "libvirt-machine-properties.c"
		goto _state_1;
		default:
#line 662 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_assert_not_reached ();
#line 6699 "libvirt-machine-properties.c"
	}
	_state_0:
#line 663 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp0_ = NULL;
#line 663 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp0_ = _data_->self->priv->machine;
#line 663 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp1_ = NULL;
#line 663 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp1_ = boxes_libvirt_machine_get_domain (_data_->_tmp0_);
#line 663 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp2_ = NULL;
#line 663 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp2_ = _data_->_tmp1_;
#line 663 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp3_ = NULL;
#line 663 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp3_ = _data_->cancellable;
#line 663 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_state_ = 1;
#line 663 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gvir_domain_fetch_snapshots_async (_data_->_tmp2_, (guint) GVIR_DOMAIN_SNAPSHOT_LIST_ALL, _data_->_tmp3_, boxes_libvirt_machine_properties_fetch_snapshots_ready, _data_);
#line 663 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return FALSE;
#line 6724 "libvirt-machine-properties.c"
	_state_1:
#line 663 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gvir_domain_fetch_snapshots_finish (_data_->_tmp2_, _data_->_res_, &_data_->_inner_error_);
#line 663 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 663 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 663 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_error_free (_data_->_inner_error_);
#line 663 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_data_->_state_ == 0) {
#line 663 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 6738 "libvirt-machine-properties.c"
		} else {
#line 663 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 6742 "libvirt-machine-properties.c"
		}
#line 663 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_object_unref (_data_->_async_result);
#line 663 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return FALSE;
#line 6748 "libvirt-machine-properties.c"
	}
#line 662 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_data_->_state_ == 0) {
#line 662 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 6754 "libvirt-machine-properties.c"
	} else {
#line 662 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 6758 "libvirt-machine-properties.c"
	}
#line 662 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_unref (_data_->_async_result);
#line 662 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return FALSE;
#line 6764 "libvirt-machine-properties.c"
}


GList* boxes_libvirt_machine_properties_get_snapshots (BoxesLibvirtMachineProperties* self) {
	GList* result = NULL;
	BoxesLibvirtMachine* _tmp0_ = NULL;
	GVirDomain* _tmp1_ = NULL;
	GVirDomain* _tmp2_ = NULL;
	GList* _tmp3_ = NULL;
#line 666 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 667 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = self->priv->machine;
#line 667 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = boxes_libvirt_machine_get_domain (_tmp0_);
#line 667 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = _tmp1_;
#line 667 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = gvir_domain_get_snapshots (_tmp2_);
#line 667 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	result = _tmp3_;
#line 667 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return result;
#line 6788 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_create_snapshot_data_free (gpointer _data) {
	BoxesLibvirtMachinePropertiesCreateSnapshotData* _data_;
	_data_ = _data;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->result);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_slice_free (BoxesLibvirtMachinePropertiesCreateSnapshotData, _data_);
#line 6801 "libvirt-machine-properties.c"
}


void boxes_libvirt_machine_properties_create_snapshot (BoxesLibvirtMachineProperties* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesLibvirtMachinePropertiesCreateSnapshotData* _data_;
	BoxesLibvirtMachineProperties* _tmp0_ = NULL;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_ = g_slice_new0 (BoxesLibvirtMachinePropertiesCreateSnapshotData);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_libvirt_machine_properties_create_snapshot);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_libvirt_machine_properties_create_snapshot_data_free);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->self = _tmp0_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_properties_create_snapshot_co (_data_);
#line 6820 "libvirt-machine-properties.c"
}


GVirDomainSnapshot* boxes_libvirt_machine_properties_create_snapshot_finish (BoxesLibvirtMachineProperties* self, GAsyncResult* _res_, GError** error) {
	GVirDomainSnapshot* result;
	BoxesLibvirtMachinePropertiesCreateSnapshotData* _data_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return NULL;
#line 6831 "libvirt-machine-properties.c"
	}
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	result = _data_->result;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->result = NULL;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return result;
#line 6841 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_create_snapshot_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesLibvirtMachinePropertiesCreateSnapshotData* _data_;
#line 676 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_ = _user_data_;
#line 676 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_source_object_ = source_object;
#line 676 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_res_ = _res_;
#line 676 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_properties_create_snapshot_co (_data_);
#line 6855 "libvirt-machine-properties.c"
}


static gboolean boxes_libvirt_machine_properties_create_snapshot_co (BoxesLibvirtMachinePropertiesCreateSnapshotData* _data_) {
#line 670 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	switch (_data_->_state_) {
#line 670 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		case 0:
#line 6864 "libvirt-machine-properties.c"
		goto _state_0;
#line 670 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		case 1:
#line 6868 "libvirt-machine-properties.c"
		goto _state_1;
		default:
#line 670 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_assert_not_reached ();
#line 6873 "libvirt-machine-properties.c"
	}
	_state_0:
#line 671 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp0_ = NULL;
#line 671 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp0_ = gvir_config_domain_snapshot_new ();
#line 671 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->config = _data_->_tmp0_;
#line 672 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp1_ = NULL;
#line 672 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp1_ = g_date_time_new_now_local ();
#line 672 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->now = _data_->_tmp1_;
#line 673 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp2_ = NULL;
#line 673 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp2_ = g_date_time_format (_data_->now, "%F-%H-%M-%S");
#line 673 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp3_ = NULL;
#line 673 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp3_ = _data_->_tmp2_;
#line 673 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gvir_config_domain_snapshot_set_name (_data_->config, _data_->_tmp3_);
#line 673 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_free0 (_data_->_tmp3_);
#line 674 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp4_ = NULL;
#line 674 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp4_ = g_date_time_format (_data_->now, "%x, %X");
#line 674 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp5_ = NULL;
#line 674 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp5_ = _data_->_tmp4_;
#line 674 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gvir_config_domain_snapshot_set_description (_data_->config, _data_->_tmp5_);
#line 674 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_free0 (_data_->_tmp5_);
#line 676 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp7_ = NULL;
#line 676 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp7_ = _data_->self->priv->machine;
#line 676 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp8_ = NULL;
#line 676 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp8_ = boxes_libvirt_machine_get_domain (_data_->_tmp7_);
#line 676 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp9_ = NULL;
#line 676 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp9_ = _data_->_tmp8_;
#line 676 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_state_ = 1;
#line 676 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gvir_domain_create_snapshot_async (_data_->_tmp9_, _data_->config, (guint) 0, NULL, boxes_libvirt_machine_properties_create_snapshot_ready, _data_);
#line 676 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return FALSE;
#line 6930 "libvirt-machine-properties.c"
	_state_1:
#line 676 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp10_ = NULL;
#line 676 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp10_ = gvir_domain_create_snapshot_finish (_data_->_tmp9_, _data_->_res_, &_data_->_inner_error_);
#line 676 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp6_ = _data_->_tmp10_;
#line 676 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 676 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 676 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_error_free (_data_->_inner_error_);
#line 676 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_date_time_unref0 (_data_->now);
#line 676 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data_->config);
#line 676 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_data_->_state_ == 0) {
#line 676 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 6952 "libvirt-machine-properties.c"
		} else {
#line 676 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 6956 "libvirt-machine-properties.c"
		}
#line 676 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_object_unref (_data_->_async_result);
#line 676 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return FALSE;
#line 6962 "libvirt-machine-properties.c"
	}
#line 676 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp11_ = NULL;
#line 676 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp11_ = _data_->_tmp6_;
#line 676 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp6_ = NULL;
#line 676 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->result = _data_->_tmp11_;
#line 676 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->_tmp6_);
#line 676 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_date_time_unref0 (_data_->now);
#line 676 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->config);
#line 676 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_data_->_state_ == 0) {
#line 676 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 6982 "libvirt-machine-properties.c"
	} else {
#line 676 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 6986 "libvirt-machine-properties.c"
	}
#line 676 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_unref (_data_->_async_result);
#line 676 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return FALSE;
#line 670 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->_tmp6_);
#line 670 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_date_time_unref0 (_data_->now);
#line 670 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->config);
#line 670 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_data_->_state_ == 0) {
#line 670 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 7002 "libvirt-machine-properties.c"
	} else {
#line 670 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 7006 "libvirt-machine-properties.c"
	}
#line 670 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_unref (_data_->_async_result);
#line 670 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return FALSE;
#line 7012 "libvirt-machine-properties.c"
}


static BoxesSnapshotsProperty* boxes_libvirt_machine_properties_add_snapshots_property (BoxesLibvirtMachineProperties* self, GList** list, BoxesLibvirtMachine* machine) {
	BoxesSnapshotsProperty* result = NULL;
	BoxesSnapshotsProperty* property = NULL;
	BoxesLibvirtMachine* _tmp0_ = NULL;
	BoxesSnapshotsProperty* _tmp1_ = NULL;
	BoxesProperty* _tmp2_ = NULL;
#line 679 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 679 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_val_if_fail (machine != NULL, NULL);
#line 681 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = machine;
#line 681 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = boxes_snapshots_property_new (_tmp0_);
#line 681 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	property = _tmp1_;
#line 682 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = _g_object_ref0 ((BoxesProperty*) property);
#line 682 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	*list = g_list_append (*list, _tmp2_);
#line 684 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	result = property;
#line 684 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return result;
#line 7040 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_class_init (BoxesLibvirtMachinePropertiesClass * klass) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_properties_parent_class = g_type_class_peek_parent (klass);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_type_class_add_private (klass, sizeof (BoxesLibvirtMachinePropertiesPrivate));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_libvirt_machine_properties_finalize;
#line 7051 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_boxes_iproperties_provider_interface_init (BoxesIPropertiesProviderIface * iface) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_properties_boxes_iproperties_provider_parent_iface = g_type_interface_peek_parent (iface);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	iface->get_properties = (GList* (*)(BoxesIPropertiesProvider*, BoxesPropertiesPage, PropertyCreationFlag*)) boxes_libvirt_machine_properties_real_get_properties;
#line 7060 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_instance_init (BoxesLibvirtMachineProperties * self) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self->priv = BOXES_LIBVIRT_MACHINE_PROPERTIES_GET_PRIVATE (self);
#line 7067 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_finalize (GObject* obj) {
	BoxesLibvirtMachineProperties * self;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES, BoxesLibvirtMachineProperties);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	G_OBJECT_CLASS (boxes_libvirt_machine_properties_parent_class)->finalize (obj);
#line 7077 "libvirt-machine-properties.c"
}


GType boxes_libvirt_machine_properties_get_type (void) {
	static volatile gsize boxes_libvirt_machine_properties_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_libvirt_machine_properties_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesLibvirtMachinePropertiesClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_libvirt_machine_properties_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesLibvirtMachineProperties), 0, (GInstanceInitFunc) boxes_libvirt_machine_properties_instance_init, NULL };
		static const GInterfaceInfo boxes_iproperties_provider_info = { (GInterfaceInitFunc) boxes_libvirt_machine_properties_boxes_iproperties_provider_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType boxes_libvirt_machine_properties_type_id;
		boxes_libvirt_machine_properties_type_id = g_type_register_static (G_TYPE_OBJECT, "BoxesLibvirtMachineProperties", &g_define_type_info, 0);
		g_type_add_interface_static (boxes_libvirt_machine_properties_type_id, BOXES_TYPE_IPROPERTIES_PROVIDER, &boxes_iproperties_provider_info);
		g_once_init_leave (&boxes_libvirt_machine_properties_type_id__volatile, boxes_libvirt_machine_properties_type_id);
	}
	return boxes_libvirt_machine_properties_type_id__volatile;
}



